{"cells": [{"cell_type": "markdown", "metadata": {"tags": ["module-puregp", "module-seis"]}, "source": ["# Plotting Earthquake Focus\n", "[<!-- module-puregp badge --><span class=\"module module-puregp\">Pure Geophysics</span>](module-puregp) [<!-- module-seis badge --><span class=\"module module-seis\">Seismology</span>](module-seis) \n", "```{index} Plotting Earthquake Focus\n", "```"]}, {"cell_type": "code", "execution_count": 1, "metadata": {}, "outputs": [{"data": {"text/html": ["        <script type=\"text/javascript\">\n", "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n", "        if (window.MathJax && window.MathJax.Hub && window.MathJax.Hub.Config) {window.MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n", "        if (typeof require !== 'undefined') {\n", "        require.undef(\"plotly\");\n", "        requirejs.config({\n", "            paths: {\n", "                'plotly': ['https://cdn.plot.ly/plotly-2.14.0.min']\n", "            }\n", "        });\n", "        require(['plotly'], function(Plotly) {\n", "            window._Plotly = Plotly;\n", "        });\n", "        }\n", "        </script>\n", "        "]}, "metadata": {}, "output_type": "display_data"}], "source": ["import plotly.graph_objs as go\n", "from plotly.offline import plot, iplot, init_notebook_mode\n", "import plotly.express as px\n", "\n", "init_notebook_mode (connected = True)\n", "import numpy as np\n", "import pandas as pd"]}, {"cell_type": "markdown", "metadata": {}, "source": ["## 1. Import Earthquake data\n", "Create a dataset which contains longitude, latitude, depth, and magnitude of each event. The study area of this practice is New Zealand."]}, {"cell_type": "code", "execution_count": 2, "metadata": {}, "outputs": [{"data": {"text/html": ["<div>\n", "<style scoped>\n", "    .dataframe tbody tr th:only-of-type {\n", "        vertical-align: middle;\n", "    }\n", "\n", "    .dataframe tbody tr th {\n", "        vertical-align: top;\n", "    }\n", "\n", "    .dataframe thead th {\n", "        text-align: right;\n", "    }\n", "</style>\n", "<table border=\"1\" class=\"dataframe\">\n", "  <thead>\n", "    <tr style=\"text-align: right;\">\n", "      <th></th>\n", "      <th>Longitude</th>\n", "      <th>Latitude</th>\n", "      <th>Depth(km)</th>\n", "      <th>Unnamed: 3</th>\n", "      <th>Unnamed: 4</th>\n", "      <th>Unnamed: 5</th>\n", "      <th>Unnamed: 6</th>\n", "      <th>Unnamed: 7</th>\n", "      <th>Unnamed: 8</th>\n", "      <th>Unnamed: 9</th>\n", "      <th>Unnamed: 10</th>\n", "      <th>Unnamed: 11</th>\n", "      <th>Unnamed: 12</th>\n", "      <th>Unnamed: 13</th>\n", "      <th>Mag</th>\n", "      <th>Unnamed: 15</th>\n", "      <th>Unnamed: 16</th>\n", "      <th>Unnamed: 17</th>\n", "      <th>Lat</th>\n", "    </tr>\n", "  </thead>\n", "  <tbody>\n", "    <tr>\n", "      <th>0</th>\n", "      <td>182.31</td>\n", "      <td>-30.00</td>\n", "      <td>-44</td>\n", "      <td>6.98</td>\n", "      <td>-0.13</td>\n", "      <td>-6.84</td>\n", "      <td>1.35</td>\n", "      <td>2.57</td>\n", "      <td>-4.01</td>\n", "      <td>23</td>\n", "      <td>X</td>\n", "      <td>Y</td>\n", "      <td>090384A</td>\n", "      <td>7.500000e+23</td>\n", "      <td>5.2</td>\n", "      <td>NaN</td>\n", "      <td>-177.69</td>\n", "      <td>44</td>\n", "      <td>-30</td>\n", "    </tr>\n", "    <tr>\n", "      <th>1</th>\n", "      <td>183.30</td>\n", "      <td>-30.00</td>\n", "      <td>-14</td>\n", "      <td>1.27</td>\n", "      <td>-0.05</td>\n", "      <td>-1.22</td>\n", "      <td>0.33</td>\n", "      <td>1.28</td>\n", "      <td>-0.38</td>\n", "      <td>25</td>\n", "      <td>X</td>\n", "      <td>Y</td>\n", "      <td>200810050912A</td>\n", "      <td>1.800000e+25</td>\n", "      <td>6.1</td>\n", "      <td>NaN</td>\n", "      <td>-176.70</td>\n", "      <td>14</td>\n", "      <td>-30</td>\n", "    </tr>\n", "    <tr>\n", "      <th>2</th>\n", "      <td>183.19</td>\n", "      <td>-30.01</td>\n", "      <td>-22</td>\n", "      <td>1.05</td>\n", "      <td>0.09</td>\n", "      <td>-1.13</td>\n", "      <td>-0.21</td>\n", "      <td>0.01</td>\n", "      <td>-0.54</td>\n", "      <td>24</td>\n", "      <td>X</td>\n", "      <td>Y</td>\n", "      <td>052081B</td>\n", "      <td>1.100000e+24</td>\n", "      <td>5.3</td>\n", "      <td>NaN</td>\n", "      <td>-176.81</td>\n", "      <td>22</td>\n", "      <td>-30</td>\n", "    </tr>\n", "    <tr>\n", "      <th>3</th>\n", "      <td>182.84</td>\n", "      <td>-30.01</td>\n", "      <td>-17</td>\n", "      <td>0.95</td>\n", "      <td>-0.13</td>\n", "      <td>-0.82</td>\n", "      <td>-0.06</td>\n", "      <td>1.22</td>\n", "      <td>-0.35</td>\n", "      <td>24</td>\n", "      <td>X</td>\n", "      <td>Y</td>\n", "      <td>051304F</td>\n", "      <td>1.600000e+24</td>\n", "      <td>5.4</td>\n", "      <td>NaN</td>\n", "      <td>-177.16</td>\n", "      <td>17</td>\n", "      <td>-30</td>\n", "    </tr>\n", "    <tr>\n", "      <th>4</th>\n", "      <td>183.57</td>\n", "      <td>-30.01</td>\n", "      <td>-35</td>\n", "      <td>1.92</td>\n", "      <td>-0.16</td>\n", "      <td>-1.76</td>\n", "      <td>-0.32</td>\n", "      <td>-0.12</td>\n", "      <td>0.19</td>\n", "      <td>24</td>\n", "      <td>X</td>\n", "      <td>Y</td>\n", "      <td>200603311543A</td>\n", "      <td>2.000000e+24</td>\n", "      <td>5.5</td>\n", "      <td>NaN</td>\n", "      <td>-176.43</td>\n", "      <td>35</td>\n", "      <td>-30</td>\n", "    </tr>\n", "  </tbody>\n", "</table>\n", "</div>"], "text/plain": ["   Longitude  Latitude  Depth(km)  Unnamed: 3  Unnamed: 4  Unnamed: 5  \\\n", "0     182.31    -30.00        -44        6.98       -0.13       -6.84   \n", "1     183.30    -30.00        -14        1.27       -0.05       -1.22   \n", "2     183.19    -30.01        -22        1.05        0.09       -1.13   \n", "3     182.84    -30.01        -17        0.95       -0.13       -0.82   \n", "4     183.57    -30.01        -35        1.92       -0.16       -1.76   \n", "\n", "   Unnamed: 6  Unnamed: 7  Unnamed: 8  Unnamed: 9 Unnamed: 10 Unnamed: 11  \\\n", "0        1.35        2.57       -4.01          23           X           Y   \n", "1        0.33        1.28       -0.38          25           X           Y   \n", "2       -0.21        0.01       -0.54          24           X           Y   \n", "3       -0.06        1.22       -0.35          24           X           Y   \n", "4       -0.32       -0.12        0.19          24           X           Y   \n", "\n", "     Unnamed: 12   Unnamed: 13  Mag  Unnamed: 15  Unnamed: 16  Unnamed: 17  \\\n", "0        090384A  7.500000e+23  5.2          NaN      -177.69           44   \n", "1  200810050912A  1.800000e+25  6.1          NaN      -176.70           14   \n", "2        052081B  1.100000e+24  5.3          NaN      -176.81           22   \n", "3        051304F  1.600000e+24  5.4          NaN      -177.16           17   \n", "4  200603311543A  2.000000e+24  5.5          NaN      -176.43           35   \n", "\n", "   Lat  \n", "0  -30  \n", "1  -30  \n", "2  -30  \n", "3  -30  \n", "4  -30  "]}, "execution_count": 2, "metadata": {}, "output_type": "execute_result"}], "source": ["df = pd.read_excel('data/meca_all.xlsx')\n", "df.head()"]}, {"cell_type": "markdown", "metadata": {}, "source": ["## 2. Create a 3D plot of focus \n", "Hover to see the details of each event. Zoom in and rotate the diagram to suit yourself."]}, {"cell_type": "code", "execution_count": 3, "metadata": {}, "outputs": [{"data": {"application/vnd.plotly.v1+json": {"config": {"linkText": "Export to plot.ly", "plotlyServerURL": "https://plot.ly", "showLink": false}, "data": [{"marker": {"cmax": 8, "cmin": 4.5, "color": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5, 4.8, 5.4, 5.3, 5.4, 6.8, 5.3, 5.7, 5.3, 5.1, 5.4, 6, 5.3, 5.6, 4.9, 5, 5, 6.4, 5.1, 5.4, 5.4, 5.8, 5.4, 5.5, 5.3, 5.2, 5.2, 5.4, 5.6, 5.2, 5, 6, 6.1, 5, 5.6, 5.9, 5, 5.1, 5.2, 5.1, 5, 5.5, 5.2, 4.8, 6.3, 5, 4.9, 6.3, 6.6, 5.2, 5.4, 5.3, 5.1, 5.1, 5.3, 5.4, 5.5, 4.9, 5.6, 4.9, 5.3, 4.9, 5.1, 5.6, 5.3, 5.3, 5.7, 5.4, 5.2, 4.9, 5.2, 5.4, 5, 5.2, 5.3, 5, 5.1, 5.5, 5.3, 5.7, 5.8, 5.7, 5.1, 5.1, 5.2, 5, 5.2, 5.3, 5.1, 5.1, 7.5, 5.8, 5.2, 6.6, 5, 5, 5.1, 5.3, 5.4, 5.2, 5.5, 5.3, 6.2, 5.3, 6.4, 5.1, 5.1, 5.2, 5.5, 5.8, 5.7, 5.6, 5.2, 5.1, 5.4, 5.6, 6.5, 5.4, 5.7, 5.8, 5.3, 4.9, 5.3, 5.4, 5.3, 5.3, 5.3, 5.1, 5.9, 5.1, 5.5, 5.6, 5.2, 5.1, 5, 5, 5.8, 5.2, 5.2, 5.1, 5.3, 5.3, 5, 5, 5, 5.5, 5.6, 5, 5.1, 6.9, 5, 5.8, 4.9, 5.5, 6.5, 5.2, 5, 4.9, 5.1, 5.9, 6.5, 4.9, 5.1, 5.2, 5.1, 5.1, 5.8, 4.9, 6.4, 5.4, 4.9, 5, 5.2, 4.9, 4.9, 5.2, 5.4, 5, 5, 7, 6.4, 5.4, 5.6, 5, 5, 5.1, 5.1, 5, 5.1, 5, 5.2, 5.1, 5, 5.4, 5.4, 7.1, 5.1, 5.3, 5, 5.1, 5.4, 5.2, 5.5, 6.2, 5.3, 5.9, 5.4, 4.9, 5.1, 6.1, 5.3, 5.2, 5.6, 5.1, 5.4, 5.5, 5.3, 5.3, 4.8, 5.1, 5, 5.7, 5.7, 5.3, 6.3, 5.6, 5.1, 5.2, 5.3, 6.1, 5.4, 5.1, 4.9, 5.4, 5.2, 5.8, 5.1, 5.5, 5.5, 5.9, 6.1, 5.9, 6.3, 5.1, 5, 5.6, 5.4, 5.2, 5.5, 5.4, 5.2, 5.1, 5.2, 5.3, 5, 5, 5, 5.2, 5.7, 5.4, 5.4, 5, 5.4, 5.6, 5.2, 5.1, 5.4, 5.1, 4.9, 5.2, 5.7, 5.2, 5.6, 5.3, 5.5, 4.8, 5.2, 5.2, 5, 5.5, 5.3, 5.6, 5.8, 5.7, 5.1, 5.4, 5.4, 5, 5.6, 5.1, 5.6, 5.4, 5.8, 5.7, 5.4, 5.4, 5.2, 5, 5.8, 5.7, 6.1, 5.2, 6.1, 5, 5.8, 5, 5.5, 4.9, 5.1, 5.3, 5.2, 5.4, 6, 5.6, 5.2, 5.2, 5.6, 5.7, 5.1, 5.5, 5.1, 5.8, 5, 5.2, 5.8, 5.1, 5.2, 5.3, 5.5, 5.2, 5.2, 5.3, 4.9, 5.1, 5.1, 5.4, 6.4, 5.2, 6.7, 5.4, 5.4, 5.2, 5, 5.8, 4.8, 5.4, 5.2, 5.4, 5.1, 5.9, 5.3, 5.2, 5.1, 5, 5.3, 6.1, 6.5, 5.2, 5.3, 5, 5.5, 5.3, 5, 6, 5.7, 5.5, 5.3, 6.2, 5.3, 5.2, 5.1, 5.9, 5.2, 4.9, 5.3, 5, 5, 5.2, 5.2, 5.4, 5.1, 5.6, 4.9, 5.1, 4.9, 5.4, 6, 5.5, 4.9, 5.7, 5.1, 5.5, 5.4, 5.9, 5.5, 5.7, 5.2, 5, 5.3, 5.3, 5.1, 6.4, 5.5, 5.5, 5, 5.2, 5.2, 5.6, 5.2, 5.1, 5.9, 5, 4.9, 5.5, 5.4, 5.7, 5.6, 5.4, 4.9, 5.1, 5.1, 5.7, 5.3, 5.4, 5.5, 5.1, 5.3, 5.3, 5.3, 5.1, 5, 5.4, 5, 5.8, 5.6, 5.4, 5, 5.2, 5.6, 5.2, 5, 5.2, 5.6, 5.4, 5.5, 5, 5, 5.2, 5.5, 5.1, 5.9, 5.4, 5.2, 4.9, 5.4, 5.3, 5.6, 5, 5.3, 5.7, 5.1, 5.3, 5.4, 5.9, 5.6, 5.3, 4.9, 5.4, 5.4, 5.1, 5.3, 5.4, 5.2, 5.9, 5.2, 5.3, 5.1, 5.3, 5.1, 5.6, 5.1, 5.1, 5.3, 5.2, 5.1, 7.4, 5.2, 5.8, 5, 5.9, 6, 5.9, 5.5, 5.9, 4.9, 5.4, 5.5, 4.8, 4.7, 4.8, 5, 5.3, 5.5, 5.2, 5.4, 5.5, 5.3, 5, 4.9, 5.5, 5.1, 5, 6.2, 5, 5, 5.1, 5.9, 5.1, 5.1, 5.5, 5.3, 5.4, 5.5, 6, 5.5, 5.4, 5.9, 5.2, 5, 4.9, 5.4, 5, 5.1, 5.1, 5.2, 4.9, 5.1, 5.1, 5.2, 4.9, 6, 5.6, 5.4, 5.1, 4.9, 5.3, 6, 5.3, 5.1, 5.1, 5.9, 5.6, 5, 5, 5.3, 5.5, 5.4, 5.6, 5.4, 5, 4.8, 5.2, 4.9, 5.3, 5.7, 5.5, 5.5, 5.8, 5.1, 5, 5, 5.4, 5.4, 5.5, 5.3, 5, 5.2, 5.6, 6.1, 5, 5.1, 5.6, 5.7, 6.6, 5.7, 5.2, 5.1, 5.3, 5.5, 5.3, 5.1, 6.5, 5.2, 5.3, 4.9, 5.6, 5.1, 5, 4.9, 5.1, 5, 5, 6.1, 5.3, 5.6, 5.9, 5.2, 5.6, 5.4, 5.3, 5.4, 5.2, 5, 5.2, 5.2, 6.8, 5.6, 5.3, 6.1, 5.3, 5.5, 5.6, 5.9, 5.2, 5.4, 5.4, 5.4, 5.2, 5.7, 5.1, 5.4, 5.6, 5.1, 5, 5.2, 5.5, 5.1, 5.6, 5.2, 5.3, 5.7, 4.9, 5.3, 6.5, 5.4, 5.8, 5.3, 5, 5.1, 5.1, 5.9, 5.1, 5.3, 5.8, 6.1, 5.8, 5.6, 4.9, 5.2, 5.3, 5.1, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 5.2, 5.4, 5.6, 5.4, 5.1, 5.8, 5.4, 5.3, 5.3, 5.4, 5, 5.7, 5.2, 5, 5.2, 5, 5.2, 5.2, 5.2, 5.2, 5.2, 5.4, 5.4, 5.3, 5.6, 6.3, 5.3, 5.4, 5.1, 5.9, 5.1, 5.4, 5.4, 5.4, 5.6, 5.6, 5.7, 5.7, 5.8, 5.3, 5.4, 5.3, 5.1, 5, 6.1, 5.4, 5.4, 5.8, 5.1, 5.4, 5.7, 5.1, 6.8, 5.2, 5.3, 5, 7.1, 5.6, 5.4, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 4.9, 5.2, 5.5, 5.4, 5, 5.3, 5.3, 5.7, 5.3, 5.5, 5.4, 5.4, 5.7, 5.3, 5.2, 6.7, 5, 5.1, 5.8, 5.4, 6, 5.2, 6.3, 5.8, 5.1, 5, 5.2, 5, 5.1, 7.1, 5.8, 5, 5.9, 5, 4.9, 5, 5.1, 4.9, 6, 5.6, 5.3, 5.2, 5, 5.1, 5.9, 5.2, 4.9, 5.4, 5.1, 4.9, 5.2, 5.4, 6.2, 5.2, 5.1, 5.5, 5.9, 5, 5.8, 6.7, 5.3, 5.3, 6.2, 5.2, 5.3, 5.2, 4.9, 5.7, 7.2, 5.2, 5.2, 5.2, 5.7, 5.6, 5.1, 5.8, 5.9, 5.6, 5.1, 6, 5.4, 5.2, 5, 5, 6.5, 5, 5, 5.3, 4.8, 5.7, 6.5, 5.3, 4.9, 5, 5, 5.5, 5.3, 5.6, 6.1, 4.9, 5.2, 5, 5.1, 5.7, 5.1, 5, 5, 5.2, 5.4, 5, 5.3, 6.4, 5.2, 5.1, 5.5, 5.2, 5.2, 6.4, 5.7, 6.1, 5.6, 5, 4.9, 4.9, 5.1, 5.6, 5.7, 4.9, 5.4, 5, 5.5, 5.2, 6, 5.3, 6.6, 5.2, 5.2, 6.2, 5.1, 5, 5.2, 5.3, 5.4, 5.1, 5.1, 5.8, 5.1, 5, 5.5, 5.5, 5.4, 5.7, 5.5, 5.7, 5.1, 5.2, 6.3, 5.4, 5.1, 5.4, 5.4, 6.4, 5.2, 5, 5.3, 5.4, 5, 5.8, 5.6, 5.2, 5.1, 5.4, 5.2, 5.4, 5, 5.6, 6.3, 5.6, 5.6, 6.3, 6, 5.9, 5.3, 4.9, 5.1, 5.4, 5.2, 5.3, 5.2, 5.2, 5.2, 5.3, 5.4, 5.1, 5.1, 5.5, 5.3, 5, 6.5, 5.9, 4.9, 5.4, 5.3, 5.7, 5.9, 5.5, 5.6, 6.1, 5.7, 6.6, 5.9, 5.2, 5.6, 5.5, 5.1, 5.4, 5.4, 5.3, 5.2, 5.5, 6.1, 5.8, 7.8, 5.2, 5.7, 4.9, 4.9, 5.1, 5.7, 5.2, 5, 5.7, 5.1, 5.2, 6, 5.3, 5, 6.4, 5, 5.1, 5, 5.2, 4.9, 5.5, 6.1, 6.7, 5.6, 5.5, 4.9, 5.9, 5.2, 5.4, 5.6, 5.7, 5.1, 5.2, 5.5, 5.6, 6, 5.1, 5.2, 5.8, 7, 4.8, 5, 4.8, 5, 4.9, 6.1, 4.9, 5.2, 5.4, 4.9, 5.7, 4.9, 5.4, 5.4, 5.2, 5, 6.1, 5.4, 5.8, 5.3, 5.6, 4.8, 4.9, 5.5, 5.6, 5, 4.9, 5.6, 5.1, 5, 6.1, 6.8, 5.2, 6.6, 6.7, 5, 5.6, 5, 5.3, 5.4, 7.2, 6.1, 7, 6.4, 5.5, 5.2, 5.5, 5.2, 6.5, 4.9, 5.2, 5.5, 5.2, 5.4, 5.1, 5.2, 5.3, 5.1, 5.5, 5.1, 6.1, 5.2, 5, 5.6, 7.8, 5.2, 5, 5, 5.7, 5.1, 5.6, 5.8, 5.8, 5.4, 5, 7.1, 6.2, 7.3, 6, 5.2, 5.4, 5, 5, 5.2, 5, 5, 5.2, 5.9, 4.9, 5.5, 5.5, 4.9, 5.2, 5.8, 4.9, 5.1, 5, 5.6, 5.2, 5.7, 5.1, 5.6, 5.3, 5.3, 5.1, 5.3, 5.4, 5.5, 7.6, 4.9, 5, 5.7, 5, 6, 4.9, 5.4, 5.1, 5.9, 5.6, 5.4, 5.2, 5.2, 6.1, 5.7, 5.1, 5.3, 6.6, 7.5, 6.6, 5.5, 6, 4.8, 5.1, 5.7, 5.7, 5.7, 5.4, 5.4, 5.2, 5.3, 5.4, 5, 4.9, 5.1, 5.1, 5.2, 5.4, 5.4, 5, 8.1, 6.2, 6], "colorbar": {"title": {"text": "Magnitude"}}, "colorscale": [[0, "rgb(253, 237, 176)"], [0.09090909090909091, "rgb(250, 205, 145)"], [0.18181818181818182, "rgb(246, 173, 119)"], [0.2727272727272727, "rgb(240, 142, 98)"], [0.36363636363636365, "rgb(231, 109, 84)"], [0.45454545454545453, "rgb(216, 80, 83)"], [0.5454545454545454, "rgb(195, 56, 90)"], [0.6363636363636364, "rgb(168, 40, 96)"], [0.7272727272727273, "rgb(138, 29, 99)"], [0.8181818181818182, "rgb(107, 24, 93)"], [0.9090909090909091, "rgb(76, 21, 80)"], [1, "rgb(47, 15, 61)"]], "size": 5}, "mode": "markers", "type": "scatter3d", "x": [182.31, 183.3, 183.19, 182.84, 183.57, 182.57, 180.27, 183.3, 182.33, 181.61, 182.87, 182.3, 182.74, 182.45, 181.96, 182.33, 182.44, 182.17, 182.9, 182.34, 182.85, 182.21, 182.42, 183.28, 182.55, 182.87, 181.88, 183.54, 182.33, 182.65, 182.62, 183.47, 182.34, 182.38, 182.33, 180.51, 183.42, 182.44, 182, 182.41, 182.39, 182.54, 180.92, 182.61, 182.47, 182.08, 182.08, 182.43, 182.54, 183.33, 183.39, 182.49, 183.09, 182.54, 182.33, 182.77, 180.81, 182.57, 182.36, 182.48, 182.17, 181.81, 182.46, 182.09, 182.47, 182.45, 182.81, 182.81, 180.81, 182.52, 182.4, 183.71, 182.64, 181.97, 182.49, 182.12, 182.86, 182.47, 182.32, 181.76, 182.45, 183.04, 180.8, 182.83, 181.71, 182.55, 182.54, 182.98, 182.1, 182.39, 182.67, 182.59, 182.45, 181.53, 182.4, 181.6, 182.22, 182.45, 182.66, 182.29, 182.54, 182.83, 180.6, 183.37, 183.01, 182.12, 182.38, 182.53, 182.51, 182.57, 182.15, 182.46, 182.76, 182.11, 182.44, 183.14, 182.43, 182.45, 183.21, 182.68, 182.23, 165.91, 182.55, 182.35, 182.01, 182.84, 182.36, 183.11, 183.06, 182.28, 182.23, 180.83, 182.28, 183.25, 182.44, 182.71, 181.14, 182.51, 182.02, 182.68, 183.32, 182.76, 182.28, 180.78, 183.7, 181.03, 182.15, 180.94, 182.86, 182.23, 181.88, 182.56, 183.33, 183.33, 182.68, 183.83, 182.25, 182.27, 180.99, 165.52, 180.16, 180.51, 182.24, 182.47, 182.36, 182.82, 182, 182.23, 182.46, 182.56, 182.68, 182.43, 181.52, 182.66, 183.15, 180.22, 183.12, 183.14, 182.81, 183.7, 182.73, 180.88, 182.33, 181.15, 180.86, 182.54, 182.7, 182.69, 182.29, 180.6, 182.64, 180.42, 182.68, 182.47, 182.78, 181.94, 182.54, 181.71, 181.42, 182.07, 182.52, 182.38, 183.56, 182.64, 182.7, 182.15, 182.68, 181.29, 183.59, 180.79, 182.87, 183.49, 182.25, 181.07, 182.16, 180.94, 183.24, 180.84, 182.47, 182.14, 182.4, 182.28, 182.62, 182.13, 182.22, 182.49, 182.79, 181.46, 182.52, 181.57, 182.81, 182.25, 182.98, 182.99, 182.11, 182.03, 182.27, 182.16, 182.71, 182.85, 182.85, 182.35, 181.76, 181.85, 182.21, 182.27, 182.5, 183.06, 183, 182.12, 182.11, 182.31, 181.87, 183.06, 182.06, 182.19, 181.84, 182.1, 180.44, 182.13, 180.15, 180.16, 182.06, 183.32, 180.67, 180.62, 183.62, 182.12, 182.02, 182.89, 180.45, 181.87, 182.87, 182.08, 182.04, 182.38, 181.65, 183.18, 182.06, 182.15, 182.21, 182.77, 182.58, 182.06, 182.92, 181.96, 182.04, 182.82, 180.18, 181.44, 182.01, 181.06, 181.11, 182.13, 181.58, 180.02, 180.56, 182.78, 181.82, 180, 182.7, 182.05, 181.92, 182.27, 182.19, 182.92, 180.98, 183.01, 183.75, 183.33, 181.57, 180.34, 180.66, 182.76, 180.62, 183.32, 181.76, 180.08, 182.21, 180.27, 182.88, 183.05, 183.07, 183.45, 180.2, 182.56, 182.69, 181.4, 182.68, 180.28, 182.11, 183.46, 182.24, 181.76, 183.26, 182.68, 181.88, 180.49, 183.04, 180.02, 182.59, 183.46, 182.63, 182.21, 179.71, 179.46, 180.01, 183.68, 180.13, 180.06, 182.6, 182.85, 180, 180.09, 182.6, 181.39, 182.54, 182.8, 182.81, 182.93, 181.05, 182.31, 182.67, 182.34, 182.82, 181.97, 182.72, 180.36, 182.73, 182.95, 181.44, 182.64, 182.89, 179.9, 182.23, 182.02, 182.36, 182.12, 181.93, 182.42, 182.44, 182.89, 180.3, 180.88, 182.32, 183.47, 182.47, 181.66, 182.36, 181.74, 182.59, 183.22, 180.51, 182, 182.07, 182.76, 182.07, 179.93, 181.28, 182.81, 182.7, 182.52, 182.14, 182.68, 180.08, 179.7, 182.46, 181.62, 182.59, 181.08, 181.81, 182.64, 181.99, 181.82, 180.82, 182.46, 181.09, 182.7, 180.5, 180.05, 182.6, 182.66, 181.84, 180.91, 180.51, 182.87, 182.87, 180.43, 179.66, 180.29, 180.66, 182.77, 182.82, 181.65, 179.3, 182.59, 181.7, 182.14, 179.61, 182.28, 181.88, 179.93, 181.88, 179.73, 179.92, 182.29, 182.81, 182.44, 179.82, 181.13, 181.2, 182.52, 179.18, 180.79, 182.84, 182.23, 182.82, 179.99, 181.89, 182.02, 182.66, 181.44, 179.66, 181.63, 182.69, 181.45, 181.59, 179.78, 181.02, 181.67, 183.99, 182.49, 182.53, 182.5, 181.59, 180.94, 182.26, 182.81, 183.92, 179.56, 180.06, 180.34, 181.8, 182.31, 182.25, 181.79, 181.21, 182.53, 181.6, 182.48, 182.58, 182.04, 180.12, 181.45, 179.82, 181.42, 181.69, 182.29, 181.6, 182.44, 182.16, 182.28, 182.41, 183.14, 182.09, 180.84, 182.42, 182.24, 181.95, 182.46, 182.59, 182.33, 181.45, 182.45, 181.72, 182.41, 182.25, 182.3, 182.45, 180.57, 182.33, 180.05, 182.5, 181.45, 182.38, 182.6, 180.14, 182.31, 182.01, 182.38, 182.82, 182.62, 180.02, 182.28, 182.33, 179.43, 181.44, 181.32, 181.93, 181.68, 182.38, 182.85, 179.88, 180.92, 183.05, 182.4, 182.35, 181.69, 182.19, 182.37, 182.4, 181.8, 181.3, 182.32, 180.49, 179.23, 180.1, 182.47, 182.31, 180.3, 181.43, 182.38, 182.42, 181.86, 182.39, 180.55, 182.29, 182.35, 182.34, 180.41, 182.42, 182.73, 180.4, 179.76, 180.45, 182.45, 180.47, 181.52, 182.23, 180.89, 182.37, 182.38, 182.51, 180.92, 181.37, 180.25, 180.5, 180.39, 182.48, 181.86, 181.46, 182.36, 180.39, 181.38, 182.45, 181.63, 182.75, 182.75, 180.62, 182.36, 182.18, 182.28, 181.95, 182.05, 182.42, 181.99, 182, 182.05, 182.03, 182.27, 181.96, 182.73, 181.63, 182.11, 182.03, 181.26, 182.3, 182.25, 182.14, 182.19, 182.61, 182.49, 182.25, 182.31, 182.26, 182.4, 181.23, 182.1, 181.27, 182.3, 182.33, 182.15, 182.21, 180.25, 182.57, 181.29, 182.29, 182.5, 181.28, 180.53, 181.14, 180.2, 181.27, 179.57, 182.27, 182.25, 182.44, 180.6, 181.91, 181.78, 182.2, 182.1, 180.87, 180.92, 181.56, 181.89, 181.94, 180.91, 181.56, 182.01, 181.42, 181.75, 182.29, 181.58, 181.14, 181.49, 181.42, 181.75, 181.91, 181.16, 181.83, 181.85, 179.74, 181.14, 179.07, 181.88, 182.2, 181.9, 181.38, 181.83, 181.93, 181.14, 181.22, 181.94, 181.32, 180.02, 181.66, 181.94, 181.97, 182.23, 181.86, 181.15, 182.09, 182.27, 182.08, 181.29, 181.98, 180.72, 182.3, 181.97, 181.82, 181.17, 181.83, 181.32, 181.95, 180.99, 182.26, 181.14, 181.71, 181.19, 181.96, 182.07, 179.94, 181.81, 182.06, 179.96, 181.98, 180.95, 182.04, 182.24, 180.98, 181.87, 181.97, 182.12, 182.29, 181.23, 182.24, 182.31, 181.05, 179.77, 182.27, 179.8, 179.87, 181.94, 182.29, 181.99, 180.89, 182, 181.46, 182.2, 180.99, 181.75, 180.68, 182.16, 181.83, 182.18, 182.09, 181.98, 181.05, 182.17, 180.07, 182.45, 182.14, 182.13, 180.57, 183.3, 182.11, 182.15, 179.92, 181.85, 180.43, 181.94, 181.73, 181.92, 180.6, 182.07, 181.02, 181.28, 181.89, 180.76, 183.44, 181.38, 182.23, 181.76, 182.36, 181.22, 179.95, 181.04, 182, 180.92, 180.93, 181.52, 180.84, 182.71, 180.59, 181.34, 182.33, 180.48, 181.54, 182.55, 179.95, 180.85, 182.25, 180.85, 180.96, 181.95, 181.28, 180.79, 179.37, 181.09, 182.22, 181.1, 182.35, 180.79, 181.97, 180.83, 181.96, 181.47, 180.94, 181.01, 181.83, 182.45, 181.86, 182.22, 182.22, 181.57, 180.74, 180.14, 181.79, 181.62, 181.73, 181, 181.71, 182.37, 182.26, 179.62, 181.92, 180.32, 180.84, 179.59, 181.61, 182.03, 181.86, 182.29, 182.16, 180.2, 181.85, 181.71, 182.37, 181.32, 181.73, 181.88, 180.84, 180.99, 181.77, 181.63, 179.8, 181.56, 181.76, 180.49, 181.6, 179.51, 179.87, 181.84, 180.83, 179.59, 182.26, 181.4, 180.85, 179.65, 180.83, 181.5, 181.84, 179.68, 181.59, 179.48, 179.63, 179.46, 179.46, 180.87, 181.81, 180.91, 178.81, 181.88, 179.58, 182.5, 180.82, 180.81, 179.53, 181.74, 178.69, 181.72, 181.46, 181.61, 181.87, 180.87, 182.91, 179.51, 179.57, 179.48, 181.06, 180.14, 181.49, 178.99, 179.76, 179.3, 179.41, 178.8, 181.1, 180.24, 182.28, 181.89, 179.7, 180.31, 181.69, 181.43, 181.51, 179.59, 179.71, 180.17, 179.18, 180.9, 181.4, 181.5, 181.44, 181.29, 181.26, 179.33, 181, 181.31, 180.55, 179.25, 181.49, 180.34, 180.33, 181.73, 178.3, 181.2, 181.79, 181.96, 180.21, 180.32, 179.15, 179.98, 180.27, 181.51, 181.05, 181.32, 181.29, 179.7, 179.14, 181.6, 180.62, 181.93, 180.07, 178.82, 181.05, 180.3, 182.02, 181.1, 180.49, 181.06, 178.84, 181.06, 178.82, 179.19, 181.32, 181.21, 181.25, 180.24, 181.24, 180.91, 179.63, 180.97, 177.27, 180.22, 181.1, 178.86, 180.98, 180.92, 179.13, 181.4, 179.47, 178.75, 181.14, 180.86, 180.15, 178.82, 180.98, 181.64, 181.32, 180.76, 180.93, 180.94, 181.02, 180.86, 179.65, 180.18, 180.3, 180.8, 180.95, 181.38, 180.72, 180.3, 178.91, 178.47, 178.5, 178.61, 179.12, 180.75, 180.73, 180.83, 178.35, 178.5, 180.75, 180.76, 178.57, 179.42, 180.99, 180.74, 178.42, 178.45, 178.4, 178.58, 178.39, 178.31, 179.26, 180.69, 178.89, 179.72, 177.89, 180.29, 178.2, 180.06, 177.49, 177.6, 180.78, 177.62, 177.58, 177.48, 177.62, 177.53, 179.08, 177.59, 176.91, 177.41, 177.4, 178.78, 177.35, 180.77, 180.87, 181.02, 177.26, 178.89, 181.15, 177.47, 176.72, 179.82, 178.35, 180.92, 180.91, 176.92, 177.2, 180.14, 176.59, 177.85, 180.72, 176.78, 180.96, 177.85, 179.82, 176.57, 179.07, 180.66, 177.86, 177.6, 180.12, 180.59, 177.22, 176.69, 180.03, 181.53, 179.31, 179.82, 177.11, 179.1, 178.85, 178.85, 179.08, 178.58, 177.45, 179.05, 179.09, 177.13, 178.85, 179.61, 179.05, 179.03, 178.8, 177.42, 177.3, 180.5, 178.96, 178.84, 180.43, 179.12, 177.34, 177.19, 179.44, 176.64, 177.34, 179.97, 178.88, 179.53, 178.93, 178.79, 180.38, 179.99, 178.87, 177.3, 176.94, 178.82, 179.98, 179.64, 178.69, 177.29, 179.62, 179.74, 179.74, 176.68, 179.84, 176.69, 177.17, 177.31, 177.28, 179.65, 179.4, 178.76, 180.89, 179.18, 179.2, 179.36, 180.53, 180.04, 179.24, 179.29, 176.58, 179.33, 179.49, 176.93, 177.87, 177.59, 177.03, 177.91, 177.66, 179.28, 177.69, 179.16, 179.17, 176.01, 178.3, 176.62, 177.81, 176.58, 178.9, 178.19, 177.32, 177.8, 175.82, 176.68, 176.7, 178.53, 179.67, 176.45, 177.63, 177.78, 180.33, 175.9, 177.51, 176.08, 176.18, 177.77, 175.4, 176.29, 176.42, 178.06, 175.29, 175.78, 176.03, 176.56, 176.17, 176.09, 180.35, 175.68, 176.12, 178.58, 174.86, 177.55, 178.85, 176.01, 177.01, 176.09, 178.4, 178.13, 177.42, 174.94, 177.86, 175.74, 180.69, 175.88, 175.91, 178.78, 175.19, 174.22, 178.5, 175.46, 177.68, 175.96, 176.91, 176.83, 176.76, 176.49, 174.71, 176.66, 173.63, 176.33, 179.01, 173.66, 175.27, 176.53, 173.68, 175.06, 176.13, 176.66, 176.98, 174.98, 174.09, 176.28, 173.42, 176.02, 176.07, 175.66, 174.46, 176.29, 175.8, 174.94, 176.47, 176.09, 177.58, 174.17, 175.47, 175.32, 178.68, 175.48, 173.34, 175.16, 173.4, 174.08, 176.02, 174.33, 175.35, 176.14, 175.79, 174.37, 172.52, 174.29, 174.17, 173.71, 174.47, 174.13, 174.1, 174.2, 174, 174.26, 174.25, 174.29, 171.7, 174.04, 174.17, 174.03, 173.93, 175.62, 174.32, 174.22, 173.96, 171.43, 173.14, 172.82, 173.07, 171.86, 173.85, 173.81, 172.74, 177.92, 173.75, 173.95, 173.86, 172.98, 173.69, 173.74, 173.43, 173.62, 172.78, 172.9, 173.73, 173.07, 171.54, 173.89, 172.67, 172.97, 173.95, 172.85, 171.76, 171.47, 171.18, 171.61, 173.04, 171.54, 171.48, 171.81, 171.8, 172.54, 172.31, 172.62, 172.56, 172.55, 172.62, 172.78, 172.69, 172.58, 172.12, 172.28, 172.31, 172.7, 172.73, 171.91, 172.52, 172.74, 172.44, 172.69, 172.85, 172.56, 172.68, 169.62, 168.81, 169.23, 168.75, 170.66, 168.42, 168.55, 167.91, 166.93, 167.66, 169.97, 167.71, 168.73, 167.51, 167.38, 167.39, 167.34, 167.21, 167.25, 167.24, 166.15, 167.63, 167.05, 167.54, 167, 166.59, 167.32, 167.23, 166.87, 166.7, 166.73, 166.6, 166.52, 166.62, 166.68, 166.68, 166.59, 166.44, 166.44, 167.64, 166.61, 166.46, 166.36, 165.97, 166.07, 166.75, 166.02, 166.42, 166.13, 166.72, 166.12, 166.73, 166.26, 165.82, 165.76, 165.72, 165.82, 165.84, 166.09, 165.74, 165.85, 165.75, 165.67, 164.91, 164.64, 165.77, 165.38, 165.22, 165.27, 165.32, 165.04, 165.69, 165.43, 165.04, 165.96, 165.14, 165.43, 164.59, 164.62, 165.1, 165.11, 165.08, 165.26, 164.74, 164.42, 164.53, 165.5, 163.65, 164.19, 164.51, 164.51, 164.56, 164.24, 164.2, 163.86, 164.15, 164.39, 164.13, 163.89, 164.11, 164.26, 164.03, 161.07, 163.89, 164.32, 164.03, 164.01, 164.33, 164.24, 163.98, 164.19, 164.14, 164.38, 164.27, 163.99, 164.1, 164.01, 162.99, 163.79, 175.17, 163.47, 163.8, 163.71, 163.88, 163.35, 160.85, 163.5, 163.47, 162.91, 163.47, 163.26, 163.48, 163.33, 163.07, 163.35, 163.92, 163.47, 161.25, 163.25, 163.2], "y": [-30, -30, -30.01, -30.01, -30.01, -30.02, -30.03, -30.03, -30.03, -30.03, -30.03, -30.03, -30.03, -30.04, -30.04, -30.04, -30.05, -30.05, -30.05, -30.06, -30.06, -30.06, -30.06, -30.06, -30.06, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.08, -30.08, -30.08, -30.08, -30.09, -30.09, -30.1, -30.1, -30.11, -30.11, -30.11, -30.12, -30.12, -30.12, -30.12, -30.12, -30.12, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.14, -30.14, -30.14, -30.14, -30.15, -30.15, -30.15, -30.15, -30.15, -30.15, -30.16, -30.16, -30.17, -30.17, -30.17, -30.17, -30.18, -30.18, -30.19, -30.19, -30.19, -30.19, -30.19, -30.19, -30.19, -30.2, -30.2, -30.2, -30.2, -30.2, -30.21, -30.21, -30.21, -30.22, -30.22, -30.22, -30.23, -30.23, -30.23, -30.23, -30.23, -30.24, -30.24, -30.24, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.26, -30.26, -30.26, -30.27, -30.27, -30.27, -30.27, -30.27, -30.28, -30.28, -30.29, -30.29, -30.29, -30.3, -30.31, -30.31, -30.31, -30.31, -30.32, -30.32, -30.32, -30.33, -30.33, -30.33, -30.34, -30.34, -30.34, -30.34, -30.34, -30.34, -30.35, -30.35, -30.35, -30.36, -30.36, -30.36, -30.36, -30.37, -30.37, -30.37, -30.37, -30.37, -30.38, -30.38, -30.38, -30.38, -30.39, -30.39, -30.39, -30.39, -30.39, -30.39, -30.4, -30.4, -30.4, -30.4, -30.41, -30.41, -30.42, -30.42, -30.42, -30.43, -30.43, -30.43, -30.43, -30.43, -30.44, -30.44, -30.44, -30.44, -30.45, -30.45, -30.45, -30.45, -30.45, -30.46, -30.46, -30.46, -30.46, -30.46, -30.46, -30.47, -30.47, -30.48, -30.48, -30.49, -30.49, -30.49, -30.49, -30.49, -30.5, -30.5, -30.5, -30.51, -30.51, -30.52, -30.52, -30.52, -30.53, -30.53, -30.53, -30.53, -30.54, -30.54, -30.54, -30.55, -30.55, -30.55, -30.56, -30.56, -30.56, -30.56, -30.56, -30.56, -30.57, -30.57, -30.59, -30.59, -30.6, -30.6, -30.6, -30.61, -30.62, -30.62, -30.63, -30.63, -30.63, -30.64, -30.64, -30.64, -30.64, -30.65, -30.65, -30.66, -30.66, -30.66, -30.66, -30.67, -30.68, -30.68, -30.68, -30.68, -30.69, -30.69, -30.69, -30.69, -30.69, -30.69, -30.7, -30.7, -30.71, -30.71, -30.71, -30.71, -30.71, -30.71, -30.72, -30.74, -30.74, -30.74, -30.74, -30.75, -30.76, -30.76, -30.78, -30.78, -30.78, -30.79, -30.79, -30.79, -30.8, -30.81, -30.81, -30.81, -30.81, -30.82, -30.83, -30.83, -30.83, -30.84, -30.84, -30.84, -30.85, -30.85, -30.86, -30.86, -30.86, -30.86, -30.86, -30.87, -30.87, -30.87, -30.88, -30.88, -30.89, -30.9, -30.9, -30.9, -30.91, -30.91, -30.91, -30.91, -30.93, -30.93, -30.93, -30.95, -30.95, -30.96, -30.96, -30.98, -30.98, -30.98, -30.98, -31, -31, -31.01, -31.03, -31.03, -31.04, -31.05, -31.05, -31.05, -31.05, -31.06, -31.06, -31.07, -31.07, -31.07, -31.07, -31.07, -31.07, -31.07, -31.08, -31.08, -31.08, -31.09, -31.09, -31.09, -31.09, -31.1, -31.11, -31.11, -31.11, -31.11, -31.12, -31.12, -31.13, -31.14, -31.14, -31.15, -31.15, -31.15, -31.16, -31.17, -31.17, -31.17, -31.18, -31.18, -31.18, -31.18, -31.19, -31.19, -31.21, -31.22, -31.22, -31.22, -31.23, -31.23, -31.25, -31.25, -31.25, -31.25, -31.26, -31.26, -31.26, -31.27, -31.27, -31.27, -31.27, -31.28, -31.29, -31.29, -31.29, -31.29, -31.3, -31.31, -31.32, -31.32, -31.34, -31.34, -31.35, -31.35, -31.36, -31.36, -31.36, -31.36, -31.38, -31.38, -31.39, -31.39, -31.39, -31.41, -31.41, -31.41, -31.41, -31.42, -31.42, -31.43, -31.43, -31.43, -31.44, -31.44, -31.46, -31.46, -31.47, -31.48, -31.5, -31.5, -31.5, -31.51, -31.52, -31.53, -31.53, -31.53, -31.53, -31.54, -31.55, -31.55, -31.56, -31.57, -31.57, -31.58, -31.58, -31.58, -31.58, -31.6, -31.6, -31.6, -31.6, -31.61, -31.61, -31.61, -31.62, -31.62, -31.63, -31.63, -31.63, -31.63, -31.63, -31.64, -31.64, -31.65, -31.65, -31.65, -31.66, -31.66, -31.66, -31.67, -31.68, -31.68, -31.69, -31.7, -31.7, -31.71, -31.71, -31.72, -31.73, -31.73, -31.75, -31.75, -31.78, -31.79, -31.79, -31.79, -31.8, -31.81, -31.82, -31.83, -31.83, -31.84, -31.84, -31.85, -31.85, -31.85, -31.87, -31.87, -31.87, -31.9, -31.91, -31.91, -31.92, -31.92, -31.92, -31.92, -31.93, -31.93, -31.93, -31.93, -31.94, -31.95, -31.96, -31.98, -31.99, -31.99, -31.99, -32.01, -32.01, -32.02, -32.02, -32.04, -32.04, -32.05, -32.05, -32.05, -32.06, -32.06, -32.06, -32.06, -32.07, -32.07, -32.07, -32.07, -32.08, -32.08, -32.09, -32.09, -32.09, -32.09, -32.09, -32.1, -32.1, -32.11, -32.11, -32.12, -32.13, -32.13, -32.15, -32.15, -32.15, -32.15, -32.16, -32.16, -32.17, -32.17, -32.17, -32.18, -32.19, -32.2, -32.2, -32.21, -32.21, -32.21, -32.22, -32.22, -32.23, -32.23, -32.23, -32.25, -32.25, -32.25, -32.26, -32.26, -32.26, -32.26, -32.28, -32.28, -32.28, -32.28, -32.28, -32.28, -32.29, -32.29, -32.3, -32.3, -32.31, -32.32, -32.32, -32.33, -32.34, -32.35, -32.35, -32.36, -32.37, -32.39, -32.39, -32.39, -32.39, -32.39, -32.39, -32.39, -32.39, -32.4, -32.4, -32.4, -32.4, -32.41, -32.41, -32.42, -32.42, -32.42, -32.42, -32.42, -32.42, -32.43, -32.44, -32.45, -32.45, -32.46, -32.46, -32.47, -32.48, -32.48, -32.49, -32.49, -32.49, -32.49, -32.5, -32.5, -32.51, -32.52, -32.53, -32.54, -32.54, -32.54, -32.54, -32.55, -32.58, -32.59, -32.6, -32.6, -32.61, -32.62, -32.62, -32.63, -32.63, -32.64, -32.65, -32.65, -32.67, -32.68, -32.68, -32.69, -32.69, -32.7, -32.71, -32.71, -32.71, -32.72, -32.72, -32.73, -32.73, -32.73, -32.73, -32.73, -32.73, -32.73, -32.74, -32.75, -32.75, -32.76, -32.76, -32.77, -32.77, -32.77, -32.77, -32.77, -32.78, -32.78, -32.78, -32.79, -32.79, -32.79, -32.8, -32.8, -32.8, -32.81, -32.81, -32.83, -32.83, -32.83, -32.83, -32.84, -32.84, -32.85, -32.85, -32.85, -32.85, -32.86, -32.86, -32.87, -32.88, -32.89, -32.89, -32.9, -32.9, -32.9, -32.9, -32.9, -32.9, -32.92, -32.92, -32.93, -32.94, -32.94, -32.94, -32.94, -32.94, -32.95, -32.95, -32.96, -32.96, -32.96, -32.96, -32.97, -32.97, -32.97, -32.98, -32.98, -32.98, -32.99, -32.99, -32.99, -33, -33, -33.01, -33.02, -33.02, -33.03, -33.03, -33.03, -33.03, -33.03, -33.03, -33.03, -33.04, -33.04, -33.04, -33.05, -33.05, -33.05, -33.06, -33.06, -33.06, -33.06, -33.06, -33.07, -33.08, -33.08, -33.08, -33.09, -33.09, -33.1, -33.1, -33.11, -33.11, -33.12, -33.12, -33.12, -33.14, -33.14, -33.15, -33.15, -33.15, -33.16, -33.16, -33.16, -33.17, -33.18, -33.18, -33.18, -33.19, -33.19, -33.19, -33.2, -33.2, -33.22, -33.22, -33.23, -33.23, -33.24, -33.25, -33.25, -33.27, -33.27, -33.27, -33.28, -33.28, -33.28, -33.28, -33.3, -33.32, -33.32, -33.33, -33.34, -33.35, -33.35, -33.38, -33.39, -33.41, -33.42, -33.43, -33.44, -33.47, -33.5, -33.5, -33.5, -33.52, -33.53, -33.53, -33.53, -33.53, -33.53, -33.56, -33.57, -33.58, -33.59, -33.6, -33.6, -33.61, -33.61, -33.61, -33.62, -33.62, -33.62, -33.63, -33.63, -33.63, -33.63, -33.65, -33.65, -33.65, -33.66, -33.66, -33.68, -33.69, -33.7, -33.7, -33.7, -33.7, -33.71, -33.71, -33.71, -33.72, -33.73, -33.74, -33.74, -33.76, -33.78, -33.79, -33.79, -33.8, -33.8, -33.82, -33.84, -33.86, -33.88, -33.88, -33.89, -33.89, -33.9, -33.9, -33.91, -33.91, -33.92, -33.92, -33.94, -33.94, -33.96, -33.97, -33.97, -34.03, -34.03, -34.05, -34.05, -34.06, -34.07, -34.08, -34.08, -34.14, -34.14, -34.15, -34.16, -34.16, -34.22, -34.23, -34.24, -34.25, -34.26, -34.27, -34.29, -34.3, -34.32, -34.33, -34.35, -34.36, -34.4, -34.4, -34.42, -34.42, -34.43, -34.47, -34.49, -34.5, -34.51, -34.53, -34.56, -34.57, -34.6, -34.62, -34.62, -34.64, -34.65, -34.66, -34.67, -34.67, -34.68, -34.69, -34.71, -34.71, -34.72, -34.74, -34.74, -34.76, -34.76, -34.76, -34.77, -34.78, -34.79, -34.79, -34.8, -34.81, -34.81, -34.82, -34.84, -34.85, -34.85, -34.87, -34.87, -34.87, -34.89, -34.89, -34.91, -34.92, -34.93, -34.93, -34.94, -34.97, -34.98, -34.99, -35, -35.01, -35.02, -35.02, -35.03, -35.06, -35.08, -35.08, -35.09, -35.1, -35.12, -35.13, -35.14, -35.15, -35.15, -35.16, -35.17, -35.18, -35.19, -35.19, -35.19, -35.23, -35.23, -35.24, -35.25, -35.27, -35.28, -35.28, -35.34, -35.34, -35.35, -35.38, -35.42, -35.42, -35.43, -35.48, -35.49, -35.49, -35.5, -35.51, -35.52, -35.53, -35.53, -35.6, -35.62, -35.65, -35.65, -35.66, -35.66, -35.66, -35.67, -35.72, -35.75, -35.82, -35.83, -35.86, -35.92, -35.98, -36.07, -36.1, -36.14, -36.19, -36.23, -36.25, -36.25, -36.28, -36.3, -36.31, -36.33, -36.35, -36.37, -36.38, -36.45, -36.45, -36.46, -36.5, -36.52, -36.53, -36.53, -36.56, -36.58, -36.62, -36.65, -36.65, -36.66, -36.69, -36.7, -36.73, -36.75, -36.76, -36.79, -36.79, -36.8, -36.81, -36.85, -36.87, -36.87, -36.87, -36.89, -36.89, -36.91, -36.91, -36.91, -36.92, -36.92, -36.94, -36.95, -37.01, -37.02, -37.03, -37.03, -37.05, -37.05, -37.07, -37.07, -37.08, -37.08, -37.09, -37.09, -37.09, -37.1, -37.1, -37.14, -37.15, -37.19, -37.23, -37.3, -37.31, -37.32, -37.32, -37.32, -37.33, -37.33, -37.33, -37.35, -37.35, -37.36, -37.36, -37.36, -37.37, -37.38, -37.4, -37.43, -37.44, -37.44, -37.44, -37.45, -37.46, -37.46, -37.47, -37.49, -37.5, -37.5, -37.51, -37.51, -37.52, -37.53, -37.55, -37.56, -37.58, -37.59, -37.6, -37.61, -37.61, -37.62, -37.63, -37.64, -37.65, -37.66, -37.67, -37.69, -37.7, -37.7, -37.71, -37.73, -37.76, -37.77, -37.8, -37.82, -37.82, -37.82, -37.85, -37.86, -37.87, -37.89, -37.89, -37.92, -37.93, -37.93, -37.94, -37.98, -38.03, -38.05, -38.1, -38.1, -38.13, -38.13, -38.18, -38.19, -38.24, -38.24, -38.26, -38.28, -38.29, -38.29, -38.3, -38.31, -38.31, -38.39, -38.41, -38.45, -38.45, -38.46, -38.47, -38.49, -38.49, -38.49, -38.49, -38.51, -38.57, -38.63, -38.64, -38.66, -38.76, -38.82, -38.85, -38.86, -38.88, -38.88, -38.92, -38.95, -38.96, -39.07, -39.09, -39.11, -39.13, -39.14, -39.25, -39.33, -39.4, -39.46, -39.47, -39.48, -39.55, -39.6, -39.67, -39.68, -39.7, -39.73, -39.94, -40.04, -40.05, -40.08, -40.13, -40.17, -40.18, -40.23, -40.41, -40.43, -40.44, -40.45, -40.5, -40.52, -40.54, -40.56, -40.56, -40.57, -40.6, -40.63, -40.63, -40.65, -40.67, -40.69, -40.69, -40.76, -40.79, -40.89, -40.93, -41.05, -41.11, -41.15, -41.19, -41.21, -41.28, -41.38, -41.42, -41.55, -41.56, -41.56, -41.56, -41.58, -41.61, -41.61, -41.63, -41.65, -41.65, -41.68, -41.69, -41.71, -41.72, -41.73, -41.75, -41.76, -41.76, -41.76, -41.76, -41.77, -41.82, -41.84, -41.84, -41.84, -41.84, -41.9, -41.91, -41.98, -42.02, -42.03, -42.03, -42.18, -42.19, -42.2, -42.21, -42.25, -42.28, -42.3, -42.31, -42.32, -42.32, -42.4, -42.41, -42.41, -42.42, -42.44, -42.46, -42.47, -42.62, -42.67, -42.72, -42.85, -42.88, -42.94, -42.98, -43.01, -43.19, -43.24, -43.33, -43.38, -43.47, -43.48, -43.49, -43.49, -43.5, -43.5, -43.52, -43.52, -43.53, -43.55, -43.56, -43.56, -43.56, -43.56, -43.59, -43.6, -43.6, -43.6, -43.61, -43.61, -43.67, -43.67, -43.68, -43.8, -43.88, -43.91, -43.93, -43.95, -44.1, -44.13, -44.18, -44.34, -44.38, -44.39, -44.41, -44.42, -44.44, -44.48, -44.56, -44.57, -44.59, -44.62, -44.71, -44.73, -44.75, -44.82, -44.87, -44.88, -44.9, -44.94, -45.01, -45.01, -45.02, -45.04, -45.06, -45.08, -45.1, -45.14, -45.17, -45.2, -45.23, -45.24, -45.25, -45.35, -45.37, -45.38, -45.39, -45.41, -45.43, -45.44, -45.46, -45.48, -45.56, -45.57, -45.6, -45.85, -45.9, -45.91, -46.01, -46.02, -46.04, -46.06, -46.1, -46.12, -46.13, -46.21, -46.36, -46.49, -46.54, -46.62, -46.64, -46.65, -46.73, -46.94, -46.97, -47.16, -47.17, -47.43, -47.48, -47.52, -47.56, -47.64, -47.68, -47.73, -47.8, -47.89, -47.91, -47.94, -47.96, -48.17, -48.33, -48.53, -48.61, -48.62, -48.71, -48.74, -48.74, -48.9, -48.92, -48.94, -48.96, -48.99, -49.01, -49.02, -49.03, -49.04, -49.05, -49.08, -49.12, -49.13, -49.13, -49.13, -49.16, -49.16, -49.16, -49.2, -49.22, -49.24, -49.26, -49.36, -49.38, -49.48, -49.53, -49.54, -49.58, -49.61, -49.61, -49.65, -49.68, -49.71, -49.73, -49.74, -49.74, -49.78, -49.79, -49.79, -49.8, -49.82, -49.83, -49.85, -49.91, -49.93, -49.93], "z": [-44, -14, -22, -17, -35, -15, -340, -18, -55, -128, -26, -12, -32, -15, -15, -61, -15, -33, -35, -47, -23, -48, -52, -23, -42, -15, -29, -12, -40, -40, -42, -30, -52, -83, -35, -351, -18, -46, -20, -56, -39, -39, -36, -43, -47, -46, -51, -45, -42, -24, -20, -16, -21, -47, -57, -18, -16, -44, -49, -54, -54, -87, -55, -45, -46, -36, -28, -24, -16, -35, -50, -15, -31, -159, -40, -46, -28, -44, -44, -152, -54, -19, -322, -33, -27, -46, -56, -23, -55, -28, -44, -42, -18, -129, -49, -51, -49, -41, -30, -39, -44, -31, -30, -15, -15, -54, -38, -26, -51, -37, -58, -38, -28, -48, -51, -15, -44, -39, -20, -29, -45, -12, -41, -38, -46, -40, -46, -12, -15, -53, -61, -13, -49, -28, -48, -33, -243, -12, -45, -18, -15, -29, -50, -12, -49, -12, -62, -185, -41, -34, -72, -32, -28, -29, -31, -46, -49, -47, -12, -15, -319, -231, -37, -30, -32, -29, -28, -51, -38, -41, -15, -39, -92, -43, -22, -441, -15, -29, -29, -45, -24, -237, -87, -227, -15, -38, -26, -26, -47, -370, -32, -348, -27, -40, -28, -48, -29, -64, -14, -59, -57, -41, -18, -25, -29, -55, -31, -154, -15, -224, -15, -46, -24, -65, -29, -15, -15, -258, -37, -44, -52, -48, -51, -62, -47, -31, -31, -12, -32, -156, -34, -48, -23, -46, -52, -52, -50, -50, -22, -24, -36, -40, -34, -49, -46, -41, -35, -15, -12, -51, -52, -45, -45, -21, -55, -49, -53, -50, -364, -40, -421, -412, -56, -20, -139, -157, -15, -51, -42, -19, -15, -39, -19, -45, -51, -42, -138, -12, -38, -53, -58, -15, -42, -54, -12, -46, -53, -19, -391, -128, -51, -13, -15, -44, -144, -418, -15, -15, -28, -337, -15, -52, -62, -46, -86, -21, -51, -17, -12, -12, -129, -329, -15, -18, -263, -16, -108, -409, -48, -367, -18, -17, -12, -15, -398, -24, -20, -30, -19, -298, -33, -19, -37, -16, -52, -22, -56, -10, -12, -394, -28, -12, -19, -35, -433, -413, -342, -32, -388, -341, -15, -13, -361, -428, -21, -122, -22, -14, -15, -28, -24, -22, -29, -41, -13, -53, -31, -15, -14, -20, -36, -24, -17, -453, -23, -39, -35, -33, -80, -18, -40, -12, -247, -187, -13, -20, -26, -61, -34, -15, -16, -14, -217, -143, -41, -22, -40, -391, -104, -13, -13, -21, -27, -14, -351, -454, -20, -15, -32, -94, -38, -14, -43, -49, -168, -15, -151, -14, -228, -367, -22, -23, -64, -12, -178, -12, -10, -230, -437, -194, -15, -18, -20, -55, -425, -10, -15, -15, -421, -27, -15, -428, -48, -232, -356, -20, -12, -24, -351, -43, -108, -33, -509, -151, -12, -23, -10, -15, -36, -37, -24, -103, -370, -59, -12, -67, -57, -352, -116, -62, -17, -14, -14, -20, -61, -119, -23, -12, -23, -439, -231, -240, -48, -28, -25, -52, -104, -23, -15, -18, -21, -38, -297, -54, -226, -35, -57, -21, -53, -21, -22, -17, -15, -26, -39, -117, -12, -18, -15, -28, -30, -20, -51, -14, -50, -23, -20, -20, -29, -65, -14, -345, -16, -49, -18, -39, -222, -16, -10, -16, -12, -13, -25, -15, -21, -455, -15, -54, -10, -53, -18, -12, -300, -36, -18, -31, -19, -15, -17, -18, -10, -14, -52, -28, -12, -353, -15, -14, -23, -263, -50, -15, -30, -10, -15, -15, -10, -14, -15, -12, -23, -10, -12, -15, -15, -12, -12, -53, -14, -123, -21, -30, -24, -12, -15, -15, -12, -13, -10, -15, -54, -22, -12, -47, -19, -15, -10, -10, -105, -33, -15, -13, -19, -25, -28, -19, -20, -18, -19, -15, -21, -15, -15, -23, -16, -51, -21, -20, -15, -15, -25, -12, -20, -36, -15, -13, -47, -16, -49, -19, -12, -29, -22, -160, -33, -37, -17, -12, -50, -129, -35, -252, -26, -360, -17, -28, -22, -90, -20, -30, -14, -22, -130, -38, -24, -24, -24, -40, -12, -22, -46, -15, -15, -15, -42, -12, -46, -28, -23, -47, -28, -20, -12, -44, -212, -15, -15, -18, -51, -28, -15, -50, -46, -18, -42, -20, -10, -23, -23, -15, -20, -43, -18, -12, -17, -63, -21, -42, -15, -21, -17, -53, -33, -49, -19, -29, -15, -47, -20, -48, -21, -17, -205, -13, -22, -31, -15, -59, -20, -15, -52, -15, -23, -15, -15, -46, -47, -51, -51, -249, -23, -254, -12, -15, -15, -22, -40, -32, -37, -15, -56, -15, -121, -12, -23, -27, -19, -18, -55, -18, -168, -86, -17, -12, -67, -33, -20, -12, -12, -18, -60, -15, -21, -26, -23, -21, -47, -41, -21, -42, -15, -45, -24, -19, -15, -39, -10, -24, -19, -49, -56, -15, -49, -22, -17, -30, -17, -87, -18, -15, -12, -20, -22, -45, -58, -22, -30, -56, -223, -15, -15, -15, -19, -63, -13, -54, -24, -33, -57, -56, -16, -37, -20, -12, -21, -15, -44, -20, -15, -17, -24, -15, -15, -21, -19, -18, -22, -15, -59, -27, -53, -12, -18, -21, -21, -33, -22, -14, -55, -49, -21, -22, -42, -39, -27, -12, -154, -15, -15, -14, -12, -15, -161, -15, -43, -15, -12, -21, -56, -19, -12, -18, -21, -13, -17, -18, -200, -16, -12, -48, -50, -45, -282, -16, -12, -15, -41, -41, -12, -13, -262, -14, -15, -18, -12, -41, -15, -12, -13, -222, -222, -52, -15, -15, -111, -19, -27, -183, -15, -35, -15, -12, -119, -54, -63, -15, -15, -110, -155, -100, -15, -79, -27, -22, -17, -15, -24, -15, -28, -17, -45, -203, -54, -64, -85, -29, -188, -32, -14, -12, -27, -15, -160, -110, -15, -63, -22, -25, -27, -39, -109, -61, -31, -15, -30, -220, -17, -28, -38, -20, -15, -20, -162, -21, -201, -183, -58, -15, -22, -43, -19, -48, -86, -30, -528, -42, -15, -18, -12, -56, -33, -12, -105, -220, -20, -20, -15, -16, -12, -15, -12, -15, -19, -23, -27, -25, -49, -41, -25, -18, -21, -21, -26, -15, -164, -15, -216, -171, -97, -19, -18, -25, -12, -194, -28, -22, -18, -85, -31, -21, -12, -12, -14, -12, -12, -14, -68, -15, -110, -15, -214, -26, -185, -25, -15, -24, -14, -10, -10, -10, -10, -10, -53, -10, -265, -12, -14, -83, -12, -15, -15, -17, -296, -15, -15, -19, -318, -15, -88, -59, -15, -39, -17, -20, -333, -185, -41, -210, -23, -130, -19, -283, -17, -15, -120, -153, -15, -15, -136, -360, -15, -33, -15, -15, -202, -37, -20, -12, -21, -33, -15, -27, -47, -163, -15, -24, -32, -28, -26, -152, -20, -27, -39, -36, -15, -23, -131, -15, -15, -183, -156, -17, -37, -15, -29, -25, -16, -28, -22, -146, -15, -22, -12, -12, -18, -21, -12, -21, -12, -288, -10, -165, -13, -15, -104, -12, -15, -15, -15, -15, -15, -15, -24, -15, -15, -49, -15, -15, -15, -163, -49, -94, -15, -63, -50, -15, -65, -15, -15, -293, -21, -12, -50, -12, -46, -15, -78, -77, -169, -93, -164, -22, -12, -150, -33, -33, -33, -175, -43, -165, -184, -31, -248, -33, -122, -15, -276, -158, -159, -100, -138, -134, -12, -159, -119, -14, -216, -25, -16, -13, -40, -68, -30, -28, -33, -226, -20, -104, -18, -96, -49, -21, -116, -216, -12, -63, -26, -30, -26, -22, -17, -21, -131, -21, -230, -27, -24, -153, -45, -16, -94, -48, -38, -15, -31, -26, -114, -32, -185, -25, -55, -15, -88, -30, -24, -70, -24, -32, -12, -90, -46, -29, -34, -15, -79, -31, -60, -69, -19, -15, -20, -27, -18, -17, -93, -15, -12, -75, -20, -17, -17, -13, -15, -18, -19, -26, -15, -12, -17, -19, -12, -15, -28, -25, -21, -15, -52, -64, -48, -15, -19, -19, -15, -28, -26, -22, -12, -12, -16, -19, -19, -21, -15, -31, -19, -12, -59, -20, -12, -12, -22, -12, -15, -15, -12, -15, -12, -15, -10, -15, -15, -12, -12, -12, -12, -12, -12, -17, -12, -12, -12, -12, -14, -12, -12, -12, -12, -12, -12, -12, -13, -12, -16, -15, -12, -15, -12, -10, -15, -15, -15, -15, -21, -12, -15, -14, -24, -24, -17, -18, -27, -19, -19, -15, -15, -62, -86, -14, -40, -116, -15, -32, -20, -15, -15, -49, -12, -27, -101, -18, -23, -24, -122, -15, -18, -17, -14, -12, -93, -12, -22, -12, -112, -31, -15, -23, -25, -21, -13, -20, -26, -15, -23, -18, -21, -29, -40, -10, -20, -19, -23, -18, -33, -32, -41, -22, -29, -33, -15, -18, -15, -15, -12, -13, -12, -19, -17, -21, -15, -15, -15, -14, -22, -21, -30, -18, -12, -15, -15, -33, -21, -14, -15, -33, -18, -14, -12, -38, -12, -15, -24, -39, -15, -26, -34, -42, -35, -32, -13, -31, -15, -15, -20, -12, -15, -25, -23, -15, -12, -12, -19, -15, -21, -25, -12, -22, -15, -14, -15, -21, -27, -12, -19]}], "layout": {"margin": {"b": 0, "l": 0, "r": 0, "t": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "sequentialminus": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}}}, "text/html": ["<div>                            <div id=\"dd254894-08f4-4916-942a-9eeefc2a8efc\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"dd254894-08f4-4916-942a-9eeefc2a8efc\")) {                    Plotly.newPlot(                        \"dd254894-08f4-4916-942a-9eeefc2a8efc\",                        [{\"marker\":{\"cmax\":8,\"cmin\":4.5,\"color\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0,4.8,5.4,5.3,5.4,6.8,5.3,5.7,5.3,5.1,5.4,6.0,5.3,5.6,4.9,5.0,5.0,6.4,5.1,5.4,5.4,5.8,5.4,5.5,5.3,5.2,5.2,5.4,5.6,5.2,5.0,6.0,6.1,5.0,5.6,5.9,5.0,5.1,5.2,5.1,5.0,5.5,5.2,4.8,6.3,5.0,4.9,6.3,6.6,5.2,5.4,5.3,5.1,5.1,5.3,5.4,5.5,4.9,5.6,4.9,5.3,4.9,5.1,5.6,5.3,5.3,5.7,5.4,5.2,4.9,5.2,5.4,5.0,5.2,5.3,5.0,5.1,5.5,5.3,5.7,5.8,5.7,5.1,5.1,5.2,5.0,5.2,5.3,5.1,5.1,7.5,5.8,5.2,6.6,5.0,5.0,5.1,5.3,5.4,5.2,5.5,5.3,6.2,5.3,6.4,5.1,5.1,5.2,5.5,5.8,5.7,5.6,5.2,5.1,5.4,5.6,6.5,5.4,5.7,5.8,5.3,4.9,5.3,5.4,5.3,5.3,5.3,5.1,5.9,5.1,5.5,5.6,5.2,5.1,5.0,5.0,5.8,5.2,5.2,5.1,5.3,5.3,5.0,5.0,5.0,5.5,5.6,5.0,5.1,6.9,5.0,5.8,4.9,5.5,6.5,5.2,5.0,4.9,5.1,5.9,6.5,4.9,5.1,5.2,5.1,5.1,5.8,4.9,6.4,5.4,4.9,5.0,5.2,4.9,4.9,5.2,5.4,5.0,5.0,7.0,6.4,5.4,5.6,5.0,5.0,5.1,5.1,5.0,5.1,5.0,5.2,5.1,5.0,5.4,5.4,7.1,5.1,5.3,5.0,5.1,5.4,5.2,5.5,6.2,5.3,5.9,5.4,4.9,5.1,6.1,5.3,5.2,5.6,5.1,5.4,5.5,5.3,5.3,4.8,5.1,5.0,5.7,5.7,5.3,6.3,5.6,5.1,5.2,5.3,6.1,5.4,5.1,4.9,5.4,5.2,5.8,5.1,5.5,5.5,5.9,6.1,5.9,6.3,5.1,5.0,5.6,5.4,5.2,5.5,5.4,5.2,5.1,5.2,5.3,5.0,5.0,5.0,5.2,5.7,5.4,5.4,5.0,5.4,5.6,5.2,5.1,5.4,5.1,4.9,5.2,5.7,5.2,5.6,5.3,5.5,4.8,5.2,5.2,5.0,5.5,5.3,5.6,5.8,5.7,5.1,5.4,5.4,5.0,5.6,5.1,5.6,5.4,5.8,5.7,5.4,5.4,5.2,5.0,5.8,5.7,6.1,5.2,6.1,5.0,5.8,5.0,5.5,4.9,5.1,5.3,5.2,5.4,6.0,5.6,5.2,5.2,5.6,5.7,5.1,5.5,5.1,5.8,5.0,5.2,5.8,5.1,5.2,5.3,5.5,5.2,5.2,5.3,4.9,5.1,5.1,5.4,6.4,5.2,6.7,5.4,5.4,5.2,5.0,5.8,4.8,5.4,5.2,5.4,5.1,5.9,5.3,5.2,5.1,5.0,5.3,6.1,6.5,5.2,5.3,5.0,5.5,5.3,5.0,6.0,5.7,5.5,5.3,6.2,5.3,5.2,5.1,5.9,5.2,4.9,5.3,5.0,5.0,5.2,5.2,5.4,5.1,5.6,4.9,5.1,4.9,5.4,6.0,5.5,4.9,5.7,5.1,5.5,5.4,5.9,5.5,5.7,5.2,5.0,5.3,5.3,5.1,6.4,5.5,5.5,5.0,5.2,5.2,5.6,5.2,5.1,5.9,5.0,4.9,5.5,5.4,5.7,5.6,5.4,4.9,5.1,5.1,5.7,5.3,5.4,5.5,5.1,5.3,5.3,5.3,5.1,5.0,5.4,5.0,5.8,5.6,5.4,5.0,5.2,5.6,5.2,5.0,5.2,5.6,5.4,5.5,5.0,5.0,5.2,5.5,5.1,5.9,5.4,5.2,4.9,5.4,5.3,5.6,5.0,5.3,5.7,5.1,5.3,5.4,5.9,5.6,5.3,4.9,5.4,5.4,5.1,5.3,5.4,5.2,5.9,5.2,5.3,5.1,5.3,5.1,5.6,5.1,5.1,5.3,5.2,5.1,7.4,5.2,5.8,5.0,5.9,6.0,5.9,5.5,5.9,4.9,5.4,5.5,4.8,4.7,4.8,5.0,5.3,5.5,5.2,5.4,5.5,5.3,5.0,4.9,5.5,5.1,5.0,6.2,5.0,5.0,5.1,5.9,5.1,5.1,5.5,5.3,5.4,5.5,6.0,5.5,5.4,5.9,5.2,5.0,4.9,5.4,5.0,5.1,5.1,5.2,4.9,5.1,5.1,5.2,4.9,6.0,5.6,5.4,5.1,4.9,5.3,6.0,5.3,5.1,5.1,5.9,5.6,5.0,5.0,5.3,5.5,5.4,5.6,5.4,5.0,4.8,5.2,4.9,5.3,5.7,5.5,5.5,5.8,5.1,5.0,5.0,5.4,5.4,5.5,5.3,5.0,5.2,5.6,6.1,5.0,5.1,5.6,5.7,6.6,5.7,5.2,5.1,5.3,5.5,5.3,5.1,6.5,5.2,5.3,4.9,5.6,5.1,5.0,4.9,5.1,5.0,5.0,6.1,5.3,5.6,5.9,5.2,5.6,5.4,5.3,5.4,5.2,5.0,5.2,5.2,6.8,5.6,5.3,6.1,5.3,5.5,5.6,5.9,5.2,5.4,5.4,5.4,5.2,5.7,5.1,5.4,5.6,5.1,5.0,5.2,5.5,5.1,5.6,5.2,5.3,5.7,4.9,5.3,6.5,5.4,5.8,5.3,5.0,5.1,5.1,5.9,5.1,5.3,5.8,6.1,5.8,5.6,4.9,5.2,5.3,5.1,4.9,5.4,5.4,5.1,4.9,5.6,5.2,5.4,5.6,5.4,5.1,5.8,5.4,5.3,5.3,5.4,5.0,5.7,5.2,5.0,5.2,5.0,5.2,5.2,5.2,5.2,5.2,5.4,5.4,5.3,5.6,6.3,5.3,5.4,5.1,5.9,5.1,5.4,5.4,5.4,5.6,5.6,5.7,5.7,5.8,5.3,5.4,5.3,5.1,5.0,6.1,5.4,5.4,5.8,5.1,5.4,5.7,5.1,6.8,5.2,5.3,5.0,7.1,5.6,5.4,4.9,5.4,5.4,5.1,4.9,5.6,4.9,5.2,5.5,5.4,5.0,5.3,5.3,5.7,5.3,5.5,5.4,5.4,5.7,5.3,5.2,6.7,5.0,5.1,5.8,5.4,6.0,5.2,6.3,5.8,5.1,5.0,5.2,5.0,5.1,7.1,5.8,5.0,5.9,5.0,4.9,5.0,5.1,4.9,6.0,5.6,5.3,5.2,5.0,5.1,5.9,5.2,4.9,5.4,5.1,4.9,5.2,5.4,6.2,5.2,5.1,5.5,5.9,5.0,5.8,6.7,5.3,5.3,6.2,5.2,5.3,5.2,4.9,5.7,7.2,5.2,5.2,5.2,5.7,5.6,5.1,5.8,5.9,5.6,5.1,6.0,5.4,5.2,5.0,5.0,6.5,5.0,5.0,5.3,4.8,5.7,6.5,5.3,4.9,5.0,5.0,5.5,5.3,5.6,6.1,4.9,5.2,5.0,5.1,5.7,5.1,5.0,5.0,5.2,5.4,5.0,5.3,6.4,5.2,5.1,5.5,5.2,5.2,6.4,5.7,6.1,5.6,5.0,4.9,4.9,5.1,5.6,5.7,4.9,5.4,5.0,5.5,5.2,6.0,5.3,6.6,5.2,5.2,6.2,5.1,5.0,5.2,5.3,5.4,5.1,5.1,5.8,5.1,5.0,5.5,5.5,5.4,5.7,5.5,5.7,5.1,5.2,6.3,5.4,5.1,5.4,5.4,6.4,5.2,5.0,5.3,5.4,5.0,5.8,5.6,5.2,5.1,5.4,5.2,5.4,5.0,5.6,6.3,5.6,5.6,6.3,6.0,5.9,5.3,4.9,5.1,5.4,5.2,5.3,5.2,5.2,5.2,5.3,5.4,5.1,5.1,5.5,5.3,5.0,6.5,5.9,4.9,5.4,5.3,5.7,5.9,5.5,5.6,6.1,5.7,6.6,5.9,5.2,5.6,5.5,5.1,5.4,5.4,5.3,5.2,5.5,6.1,5.8,7.8,5.2,5.7,4.9,4.9,5.1,5.7,5.2,5.0,5.7,5.1,5.2,6.0,5.3,5.0,6.4,5.0,5.1,5.0,5.2,4.9,5.5,6.1,6.7,5.6,5.5,4.9,5.9,5.2,5.4,5.6,5.7,5.1,5.2,5.5,5.6,6.0,5.1,5.2,5.8,7.0,4.8,5.0,4.8,5.0,4.9,6.1,4.9,5.2,5.4,4.9,5.7,4.9,5.4,5.4,5.2,5.0,6.1,5.4,5.8,5.3,5.6,4.8,4.9,5.5,5.6,5.0,4.9,5.6,5.1,5.0,6.1,6.8,5.2,6.6,6.7,5.0,5.6,5.0,5.3,5.4,7.2,6.1,7.0,6.4,5.5,5.2,5.5,5.2,6.5,4.9,5.2,5.5,5.2,5.4,5.1,5.2,5.3,5.1,5.5,5.1,6.1,5.2,5.0,5.6,7.8,5.2,5.0,5.0,5.7,5.1,5.6,5.8,5.8,5.4,5.0,7.1,6.2,7.3,6.0,5.2,5.4,5.0,5.0,5.2,5.0,5.0,5.2,5.9,4.9,5.5,5.5,4.9,5.2,5.8,4.9,5.1,5.0,5.6,5.2,5.7,5.1,5.6,5.3,5.3,5.1,5.3,5.4,5.5,7.6,4.9,5.0,5.7,5.0,6.0,4.9,5.4,5.1,5.9,5.6,5.4,5.2,5.2,6.1,5.7,5.1,5.3,6.6,7.5,6.6,5.5,6.0,4.8,5.1,5.7,5.7,5.7,5.4,5.4,5.2,5.3,5.4,5.0,4.9,5.1,5.1,5.2,5.4,5.4,5.0,8.1,6.2,6.0],\"colorbar\":{\"title\":{\"text\":\"Magnitude\"}},\"colorscale\":[[0.0,\"rgb(253, 237, 176)\"],[0.09090909090909091,\"rgb(250, 205, 145)\"],[0.18181818181818182,\"rgb(246, 173, 119)\"],[0.2727272727272727,\"rgb(240, 142, 98)\"],[0.36363636363636365,\"rgb(231, 109, 84)\"],[0.45454545454545453,\"rgb(216, 80, 83)\"],[0.5454545454545454,\"rgb(195, 56, 90)\"],[0.6363636363636364,\"rgb(168, 40, 96)\"],[0.7272727272727273,\"rgb(138, 29, 99)\"],[0.8181818181818182,\"rgb(107, 24, 93)\"],[0.9090909090909091,\"rgb(76, 21, 80)\"],[1.0,\"rgb(47, 15, 61)\"]],\"size\":5},\"mode\":\"markers\",\"x\":[182.31,183.3,183.19,182.84,183.57,182.57,180.27,183.3,182.33,181.61,182.87,182.3,182.74,182.45,181.96,182.33,182.44,182.17,182.9,182.34,182.85,182.21,182.42,183.28,182.55,182.87,181.88,183.54,182.33,182.65,182.62,183.47,182.34,182.38,182.33,180.51,183.42,182.44,182.0,182.41,182.39,182.54,180.92,182.61,182.47,182.08,182.08,182.43,182.54,183.33,183.39,182.49,183.09,182.54,182.33,182.77,180.81,182.57,182.36,182.48,182.17,181.81,182.46,182.09,182.47,182.45,182.81,182.81,180.81,182.52,182.4,183.71,182.64,181.97,182.49,182.12,182.86,182.47,182.32,181.76,182.45,183.04,180.8,182.83,181.71,182.55,182.54,182.98,182.1,182.39,182.67,182.59,182.45,181.53,182.4,181.6,182.22,182.45,182.66,182.29,182.54,182.83,180.6,183.37,183.01,182.12,182.38,182.53,182.51,182.57,182.15,182.46,182.76,182.11,182.44,183.14,182.43,182.45,183.21,182.68,182.23,165.91,182.55,182.35,182.01,182.84,182.36,183.11,183.06,182.28,182.23,180.83,182.28,183.25,182.44,182.71,181.14,182.51,182.02,182.68,183.32,182.76,182.28,180.78,183.7,181.03,182.15,180.94,182.86,182.23,181.88,182.56,183.33,183.33,182.68,183.83,182.25,182.27,180.99,165.52,180.16,180.51,182.24,182.47,182.36,182.82,182.0,182.23,182.46,182.56,182.68,182.43,181.52,182.66,183.15,180.22,183.12,183.14,182.81,183.7,182.73,180.88,182.33,181.15,180.86,182.54,182.7,182.69,182.29,180.6,182.64,180.42,182.68,182.47,182.78,181.94,182.54,181.71,181.42,182.07,182.52,182.38,183.56,182.64,182.7,182.15,182.68,181.29,183.59,180.79,182.87,183.49,182.25,181.07,182.16,180.94,183.24,180.84,182.47,182.14,182.4,182.28,182.62,182.13,182.22,182.49,182.79,181.46,182.52,181.57,182.81,182.25,182.98,182.99,182.11,182.03,182.27,182.16,182.71,182.85,182.85,182.35,181.76,181.85,182.21,182.27,182.5,183.06,183.0,182.12,182.11,182.31,181.87,183.06,182.06,182.19,181.84,182.1,180.44,182.13,180.15,180.16,182.06,183.32,180.67,180.62,183.62,182.12,182.02,182.89,180.45,181.87,182.87,182.08,182.04,182.38,181.65,183.18,182.06,182.15,182.21,182.77,182.58,182.06,182.92,181.96,182.04,182.82,180.18,181.44,182.01,181.06,181.11,182.13,181.58,180.02,180.56,182.78,181.82,180.0,182.7,182.05,181.92,182.27,182.19,182.92,180.98,183.01,183.75,183.33,181.57,180.34,180.66,182.76,180.62,183.32,181.76,180.08,182.21,180.27,182.88,183.05,183.07,183.45,180.2,182.56,182.69,181.4,182.68,180.28,182.11,183.46,182.24,181.76,183.26,182.68,181.88,180.49,183.04,180.02,182.59,183.46,182.63,182.21,179.71,179.46,180.01,183.68,180.13,180.06,182.6,182.85,180.0,180.09,182.6,181.39,182.54,182.8,182.81,182.93,181.05,182.31,182.67,182.34,182.82,181.97,182.72,180.36,182.73,182.95,181.44,182.64,182.89,179.9,182.23,182.02,182.36,182.12,181.93,182.42,182.44,182.89,180.3,180.88,182.32,183.47,182.47,181.66,182.36,181.74,182.59,183.22,180.51,182.0,182.07,182.76,182.07,179.93,181.28,182.81,182.7,182.52,182.14,182.68,180.08,179.7,182.46,181.62,182.59,181.08,181.81,182.64,181.99,181.82,180.82,182.46,181.09,182.7,180.5,180.05,182.6,182.66,181.84,180.91,180.51,182.87,182.87,180.43,179.66,180.29,180.66,182.77,182.82,181.65,179.3,182.59,181.7,182.14,179.61,182.28,181.88,179.93,181.88,179.73,179.92,182.29,182.81,182.44,179.82,181.13,181.2,182.52,179.18,180.79,182.84,182.23,182.82,179.99,181.89,182.02,182.66,181.44,179.66,181.63,182.69,181.45,181.59,179.78,181.02,181.67,183.99,182.49,182.53,182.5,181.59,180.94,182.26,182.81,183.92,179.56,180.06,180.34,181.8,182.31,182.25,181.79,181.21,182.53,181.6,182.48,182.58,182.04,180.12,181.45,179.82,181.42,181.69,182.29,181.6,182.44,182.16,182.28,182.41,183.14,182.09,180.84,182.42,182.24,181.95,182.46,182.59,182.33,181.45,182.45,181.72,182.41,182.25,182.3,182.45,180.57,182.33,180.05,182.5,181.45,182.38,182.6,180.14,182.31,182.01,182.38,182.82,182.62,180.02,182.28,182.33,179.43,181.44,181.32,181.93,181.68,182.38,182.85,179.88,180.92,183.05,182.4,182.35,181.69,182.19,182.37,182.4,181.8,181.3,182.32,180.49,179.23,180.1,182.47,182.31,180.3,181.43,182.38,182.42,181.86,182.39,180.55,182.29,182.35,182.34,180.41,182.42,182.73,180.4,179.76,180.45,182.45,180.47,181.52,182.23,180.89,182.37,182.38,182.51,180.92,181.37,180.25,180.5,180.39,182.48,181.86,181.46,182.36,180.39,181.38,182.45,181.63,182.75,182.75,180.62,182.36,182.18,182.28,181.95,182.05,182.42,181.99,182.0,182.05,182.03,182.27,181.96,182.73,181.63,182.11,182.03,181.26,182.3,182.25,182.14,182.19,182.61,182.49,182.25,182.31,182.26,182.4,181.23,182.1,181.27,182.3,182.33,182.15,182.21,180.25,182.57,181.29,182.29,182.5,181.28,180.53,181.14,180.2,181.27,179.57,182.27,182.25,182.44,180.6,181.91,181.78,182.2,182.1,180.87,180.92,181.56,181.89,181.94,180.91,181.56,182.01,181.42,181.75,182.29,181.58,181.14,181.49,181.42,181.75,181.91,181.16,181.83,181.85,179.74,181.14,179.07,181.88,182.2,181.9,181.38,181.83,181.93,181.14,181.22,181.94,181.32,180.02,181.66,181.94,181.97,182.23,181.86,181.15,182.09,182.27,182.08,181.29,181.98,180.72,182.3,181.97,181.82,181.17,181.83,181.32,181.95,180.99,182.26,181.14,181.71,181.19,181.96,182.07,179.94,181.81,182.06,179.96,181.98,180.95,182.04,182.24,180.98,181.87,181.97,182.12,182.29,181.23,182.24,182.31,181.05,179.77,182.27,179.8,179.87,181.94,182.29,181.99,180.89,182.0,181.46,182.2,180.99,181.75,180.68,182.16,181.83,182.18,182.09,181.98,181.05,182.17,180.07,182.45,182.14,182.13,180.57,183.3,182.11,182.15,179.92,181.85,180.43,181.94,181.73,181.92,180.6,182.07,181.02,181.28,181.89,180.76,183.44,181.38,182.23,181.76,182.36,181.22,179.95,181.04,182.0,180.92,180.93,181.52,180.84,182.71,180.59,181.34,182.33,180.48,181.54,182.55,179.95,180.85,182.25,180.85,180.96,181.95,181.28,180.79,179.37,181.09,182.22,181.1,182.35,180.79,181.97,180.83,181.96,181.47,180.94,181.01,181.83,182.45,181.86,182.22,182.22,181.57,180.74,180.14,181.79,181.62,181.73,181.0,181.71,182.37,182.26,179.62,181.92,180.32,180.84,179.59,181.61,182.03,181.86,182.29,182.16,180.2,181.85,181.71,182.37,181.32,181.73,181.88,180.84,180.99,181.77,181.63,179.8,181.56,181.76,180.49,181.6,179.51,179.87,181.84,180.83,179.59,182.26,181.4,180.85,179.65,180.83,181.5,181.84,179.68,181.59,179.48,179.63,179.46,179.46,180.87,181.81,180.91,178.81,181.88,179.58,182.5,180.82,180.81,179.53,181.74,178.69,181.72,181.46,181.61,181.87,180.87,182.91,179.51,179.57,179.48,181.06,180.14,181.49,178.99,179.76,179.3,179.41,178.8,181.1,180.24,182.28,181.89,179.7,180.31,181.69,181.43,181.51,179.59,179.71,180.17,179.18,180.9,181.4,181.5,181.44,181.29,181.26,179.33,181.0,181.31,180.55,179.25,181.49,180.34,180.33,181.73,178.3,181.2,181.79,181.96,180.21,180.32,179.15,179.98,180.27,181.51,181.05,181.32,181.29,179.7,179.14,181.6,180.62,181.93,180.07,178.82,181.05,180.3,182.02,181.1,180.49,181.06,178.84,181.06,178.82,179.19,181.32,181.21,181.25,180.24,181.24,180.91,179.63,180.97,177.27,180.22,181.1,178.86,180.98,180.92,179.13,181.4,179.47,178.75,181.14,180.86,180.15,178.82,180.98,181.64,181.32,180.76,180.93,180.94,181.02,180.86,179.65,180.18,180.3,180.8,180.95,181.38,180.72,180.3,178.91,178.47,178.5,178.61,179.12,180.75,180.73,180.83,178.35,178.5,180.75,180.76,178.57,179.42,180.99,180.74,178.42,178.45,178.4,178.58,178.39,178.31,179.26,180.69,178.89,179.72,177.89,180.29,178.2,180.06,177.49,177.6,180.78,177.62,177.58,177.48,177.62,177.53,179.08,177.59,176.91,177.41,177.4,178.78,177.35,180.77,180.87,181.02,177.26,178.89,181.15,177.47,176.72,179.82,178.35,180.92,180.91,176.92,177.2,180.14,176.59,177.85,180.72,176.78,180.96,177.85,179.82,176.57,179.07,180.66,177.86,177.6,180.12,180.59,177.22,176.69,180.03,181.53,179.31,179.82,177.11,179.1,178.85,178.85,179.08,178.58,177.45,179.05,179.09,177.13,178.85,179.61,179.05,179.03,178.8,177.42,177.3,180.5,178.96,178.84,180.43,179.12,177.34,177.19,179.44,176.64,177.34,179.97,178.88,179.53,178.93,178.79,180.38,179.99,178.87,177.3,176.94,178.82,179.98,179.64,178.69,177.29,179.62,179.74,179.74,176.68,179.84,176.69,177.17,177.31,177.28,179.65,179.4,178.76,180.89,179.18,179.2,179.36,180.53,180.04,179.24,179.29,176.58,179.33,179.49,176.93,177.87,177.59,177.03,177.91,177.66,179.28,177.69,179.16,179.17,176.01,178.3,176.62,177.81,176.58,178.9,178.19,177.32,177.8,175.82,176.68,176.7,178.53,179.67,176.45,177.63,177.78,180.33,175.9,177.51,176.08,176.18,177.77,175.4,176.29,176.42,178.06,175.29,175.78,176.03,176.56,176.17,176.09,180.35,175.68,176.12,178.58,174.86,177.55,178.85,176.01,177.01,176.09,178.4,178.13,177.42,174.94,177.86,175.74,180.69,175.88,175.91,178.78,175.19,174.22,178.5,175.46,177.68,175.96,176.91,176.83,176.76,176.49,174.71,176.66,173.63,176.33,179.01,173.66,175.27,176.53,173.68,175.06,176.13,176.66,176.98,174.98,174.09,176.28,173.42,176.02,176.07,175.66,174.46,176.29,175.8,174.94,176.47,176.09,177.58,174.17,175.47,175.32,178.68,175.48,173.34,175.16,173.4,174.08,176.02,174.33,175.35,176.14,175.79,174.37,172.52,174.29,174.17,173.71,174.47,174.13,174.1,174.2,174.0,174.26,174.25,174.29,171.7,174.04,174.17,174.03,173.93,175.62,174.32,174.22,173.96,171.43,173.14,172.82,173.07,171.86,173.85,173.81,172.74,177.92,173.75,173.95,173.86,172.98,173.69,173.74,173.43,173.62,172.78,172.9,173.73,173.07,171.54,173.89,172.67,172.97,173.95,172.85,171.76,171.47,171.18,171.61,173.04,171.54,171.48,171.81,171.8,172.54,172.31,172.62,172.56,172.55,172.62,172.78,172.69,172.58,172.12,172.28,172.31,172.7,172.73,171.91,172.52,172.74,172.44,172.69,172.85,172.56,172.68,169.62,168.81,169.23,168.75,170.66,168.42,168.55,167.91,166.93,167.66,169.97,167.71,168.73,167.51,167.38,167.39,167.34,167.21,167.25,167.24,166.15,167.63,167.05,167.54,167.0,166.59,167.32,167.23,166.87,166.7,166.73,166.6,166.52,166.62,166.68,166.68,166.59,166.44,166.44,167.64,166.61,166.46,166.36,165.97,166.07,166.75,166.02,166.42,166.13,166.72,166.12,166.73,166.26,165.82,165.76,165.72,165.82,165.84,166.09,165.74,165.85,165.75,165.67,164.91,164.64,165.77,165.38,165.22,165.27,165.32,165.04,165.69,165.43,165.04,165.96,165.14,165.43,164.59,164.62,165.1,165.11,165.08,165.26,164.74,164.42,164.53,165.5,163.65,164.19,164.51,164.51,164.56,164.24,164.2,163.86,164.15,164.39,164.13,163.89,164.11,164.26,164.03,161.07,163.89,164.32,164.03,164.01,164.33,164.24,163.98,164.19,164.14,164.38,164.27,163.99,164.1,164.01,162.99,163.79,175.17,163.47,163.8,163.71,163.88,163.35,160.85,163.5,163.47,162.91,163.47,163.26,163.48,163.33,163.07,163.35,163.92,163.47,161.25,163.25,163.2],\"y\":[-30.0,-30.0,-30.01,-30.01,-30.01,-30.02,-30.03,-30.03,-30.03,-30.03,-30.03,-30.03,-30.03,-30.04,-30.04,-30.04,-30.05,-30.05,-30.05,-30.06,-30.06,-30.06,-30.06,-30.06,-30.06,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.08,-30.08,-30.08,-30.08,-30.09,-30.09,-30.1,-30.1,-30.11,-30.11,-30.11,-30.12,-30.12,-30.12,-30.12,-30.12,-30.12,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.14,-30.14,-30.14,-30.14,-30.15,-30.15,-30.15,-30.15,-30.15,-30.15,-30.16,-30.16,-30.17,-30.17,-30.17,-30.17,-30.18,-30.18,-30.19,-30.19,-30.19,-30.19,-30.19,-30.19,-30.19,-30.2,-30.2,-30.2,-30.2,-30.2,-30.21,-30.21,-30.21,-30.22,-30.22,-30.22,-30.23,-30.23,-30.23,-30.23,-30.23,-30.24,-30.24,-30.24,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.26,-30.26,-30.26,-30.27,-30.27,-30.27,-30.27,-30.27,-30.28,-30.28,-30.29,-30.29,-30.29,-30.3,-30.31,-30.31,-30.31,-30.31,-30.32,-30.32,-30.32,-30.33,-30.33,-30.33,-30.34,-30.34,-30.34,-30.34,-30.34,-30.34,-30.35,-30.35,-30.35,-30.36,-30.36,-30.36,-30.36,-30.37,-30.37,-30.37,-30.37,-30.37,-30.38,-30.38,-30.38,-30.38,-30.39,-30.39,-30.39,-30.39,-30.39,-30.39,-30.4,-30.4,-30.4,-30.4,-30.41,-30.41,-30.42,-30.42,-30.42,-30.43,-30.43,-30.43,-30.43,-30.43,-30.44,-30.44,-30.44,-30.44,-30.45,-30.45,-30.45,-30.45,-30.45,-30.46,-30.46,-30.46,-30.46,-30.46,-30.46,-30.47,-30.47,-30.48,-30.48,-30.49,-30.49,-30.49,-30.49,-30.49,-30.5,-30.5,-30.5,-30.51,-30.51,-30.52,-30.52,-30.52,-30.53,-30.53,-30.53,-30.53,-30.54,-30.54,-30.54,-30.55,-30.55,-30.55,-30.56,-30.56,-30.56,-30.56,-30.56,-30.56,-30.57,-30.57,-30.59,-30.59,-30.6,-30.6,-30.6,-30.61,-30.62,-30.62,-30.63,-30.63,-30.63,-30.64,-30.64,-30.64,-30.64,-30.65,-30.65,-30.66,-30.66,-30.66,-30.66,-30.67,-30.68,-30.68,-30.68,-30.68,-30.69,-30.69,-30.69,-30.69,-30.69,-30.69,-30.7,-30.7,-30.71,-30.71,-30.71,-30.71,-30.71,-30.71,-30.72,-30.74,-30.74,-30.74,-30.74,-30.75,-30.76,-30.76,-30.78,-30.78,-30.78,-30.79,-30.79,-30.79,-30.8,-30.81,-30.81,-30.81,-30.81,-30.82,-30.83,-30.83,-30.83,-30.84,-30.84,-30.84,-30.85,-30.85,-30.86,-30.86,-30.86,-30.86,-30.86,-30.87,-30.87,-30.87,-30.88,-30.88,-30.89,-30.9,-30.9,-30.9,-30.91,-30.91,-30.91,-30.91,-30.93,-30.93,-30.93,-30.95,-30.95,-30.96,-30.96,-30.98,-30.98,-30.98,-30.98,-31.0,-31.0,-31.01,-31.03,-31.03,-31.04,-31.05,-31.05,-31.05,-31.05,-31.06,-31.06,-31.07,-31.07,-31.07,-31.07,-31.07,-31.07,-31.07,-31.08,-31.08,-31.08,-31.09,-31.09,-31.09,-31.09,-31.1,-31.11,-31.11,-31.11,-31.11,-31.12,-31.12,-31.13,-31.14,-31.14,-31.15,-31.15,-31.15,-31.16,-31.17,-31.17,-31.17,-31.18,-31.18,-31.18,-31.18,-31.19,-31.19,-31.21,-31.22,-31.22,-31.22,-31.23,-31.23,-31.25,-31.25,-31.25,-31.25,-31.26,-31.26,-31.26,-31.27,-31.27,-31.27,-31.27,-31.28,-31.29,-31.29,-31.29,-31.29,-31.3,-31.31,-31.32,-31.32,-31.34,-31.34,-31.35,-31.35,-31.36,-31.36,-31.36,-31.36,-31.38,-31.38,-31.39,-31.39,-31.39,-31.41,-31.41,-31.41,-31.41,-31.42,-31.42,-31.43,-31.43,-31.43,-31.44,-31.44,-31.46,-31.46,-31.47,-31.48,-31.5,-31.5,-31.5,-31.51,-31.52,-31.53,-31.53,-31.53,-31.53,-31.54,-31.55,-31.55,-31.56,-31.57,-31.57,-31.58,-31.58,-31.58,-31.58,-31.6,-31.6,-31.6,-31.6,-31.61,-31.61,-31.61,-31.62,-31.62,-31.63,-31.63,-31.63,-31.63,-31.63,-31.64,-31.64,-31.65,-31.65,-31.65,-31.66,-31.66,-31.66,-31.67,-31.68,-31.68,-31.69,-31.7,-31.7,-31.71,-31.71,-31.72,-31.73,-31.73,-31.75,-31.75,-31.78,-31.79,-31.79,-31.79,-31.8,-31.81,-31.82,-31.83,-31.83,-31.84,-31.84,-31.85,-31.85,-31.85,-31.87,-31.87,-31.87,-31.9,-31.91,-31.91,-31.92,-31.92,-31.92,-31.92,-31.93,-31.93,-31.93,-31.93,-31.94,-31.95,-31.96,-31.98,-31.99,-31.99,-31.99,-32.01,-32.01,-32.02,-32.02,-32.04,-32.04,-32.05,-32.05,-32.05,-32.06,-32.06,-32.06,-32.06,-32.07,-32.07,-32.07,-32.07,-32.08,-32.08,-32.09,-32.09,-32.09,-32.09,-32.09,-32.1,-32.1,-32.11,-32.11,-32.12,-32.13,-32.13,-32.15,-32.15,-32.15,-32.15,-32.16,-32.16,-32.17,-32.17,-32.17,-32.18,-32.19,-32.2,-32.2,-32.21,-32.21,-32.21,-32.22,-32.22,-32.23,-32.23,-32.23,-32.25,-32.25,-32.25,-32.26,-32.26,-32.26,-32.26,-32.28,-32.28,-32.28,-32.28,-32.28,-32.28,-32.29,-32.29,-32.3,-32.3,-32.31,-32.32,-32.32,-32.33,-32.34,-32.35,-32.35,-32.36,-32.37,-32.39,-32.39,-32.39,-32.39,-32.39,-32.39,-32.39,-32.39,-32.4,-32.4,-32.4,-32.4,-32.41,-32.41,-32.42,-32.42,-32.42,-32.42,-32.42,-32.42,-32.43,-32.44,-32.45,-32.45,-32.46,-32.46,-32.47,-32.48,-32.48,-32.49,-32.49,-32.49,-32.49,-32.5,-32.5,-32.51,-32.52,-32.53,-32.54,-32.54,-32.54,-32.54,-32.55,-32.58,-32.59,-32.6,-32.6,-32.61,-32.62,-32.62,-32.63,-32.63,-32.64,-32.65,-32.65,-32.67,-32.68,-32.68,-32.69,-32.69,-32.7,-32.71,-32.71,-32.71,-32.72,-32.72,-32.73,-32.73,-32.73,-32.73,-32.73,-32.73,-32.73,-32.74,-32.75,-32.75,-32.76,-32.76,-32.77,-32.77,-32.77,-32.77,-32.77,-32.78,-32.78,-32.78,-32.79,-32.79,-32.79,-32.8,-32.8,-32.8,-32.81,-32.81,-32.83,-32.83,-32.83,-32.83,-32.84,-32.84,-32.85,-32.85,-32.85,-32.85,-32.86,-32.86,-32.87,-32.88,-32.89,-32.89,-32.9,-32.9,-32.9,-32.9,-32.9,-32.9,-32.92,-32.92,-32.93,-32.94,-32.94,-32.94,-32.94,-32.94,-32.95,-32.95,-32.96,-32.96,-32.96,-32.96,-32.97,-32.97,-32.97,-32.98,-32.98,-32.98,-32.99,-32.99,-32.99,-33.0,-33.0,-33.01,-33.02,-33.02,-33.03,-33.03,-33.03,-33.03,-33.03,-33.03,-33.03,-33.04,-33.04,-33.04,-33.05,-33.05,-33.05,-33.06,-33.06,-33.06,-33.06,-33.06,-33.07,-33.08,-33.08,-33.08,-33.09,-33.09,-33.1,-33.1,-33.11,-33.11,-33.12,-33.12,-33.12,-33.14,-33.14,-33.15,-33.15,-33.15,-33.16,-33.16,-33.16,-33.17,-33.18,-33.18,-33.18,-33.19,-33.19,-33.19,-33.2,-33.2,-33.22,-33.22,-33.23,-33.23,-33.24,-33.25,-33.25,-33.27,-33.27,-33.27,-33.28,-33.28,-33.28,-33.28,-33.3,-33.32,-33.32,-33.33,-33.34,-33.35,-33.35,-33.38,-33.39,-33.41,-33.42,-33.43,-33.44,-33.47,-33.5,-33.5,-33.5,-33.52,-33.53,-33.53,-33.53,-33.53,-33.53,-33.56,-33.57,-33.58,-33.59,-33.6,-33.6,-33.61,-33.61,-33.61,-33.62,-33.62,-33.62,-33.63,-33.63,-33.63,-33.63,-33.65,-33.65,-33.65,-33.66,-33.66,-33.68,-33.69,-33.7,-33.7,-33.7,-33.7,-33.71,-33.71,-33.71,-33.72,-33.73,-33.74,-33.74,-33.76,-33.78,-33.79,-33.79,-33.8,-33.8,-33.82,-33.84,-33.86,-33.88,-33.88,-33.89,-33.89,-33.9,-33.9,-33.91,-33.91,-33.92,-33.92,-33.94,-33.94,-33.96,-33.97,-33.97,-34.03,-34.03,-34.05,-34.05,-34.06,-34.07,-34.08,-34.08,-34.14,-34.14,-34.15,-34.16,-34.16,-34.22,-34.23,-34.24,-34.25,-34.26,-34.27,-34.29,-34.3,-34.32,-34.33,-34.35,-34.36,-34.4,-34.4,-34.42,-34.42,-34.43,-34.47,-34.49,-34.5,-34.51,-34.53,-34.56,-34.57,-34.6,-34.62,-34.62,-34.64,-34.65,-34.66,-34.67,-34.67,-34.68,-34.69,-34.71,-34.71,-34.72,-34.74,-34.74,-34.76,-34.76,-34.76,-34.77,-34.78,-34.79,-34.79,-34.8,-34.81,-34.81,-34.82,-34.84,-34.85,-34.85,-34.87,-34.87,-34.87,-34.89,-34.89,-34.91,-34.92,-34.93,-34.93,-34.94,-34.97,-34.98,-34.99,-35.0,-35.01,-35.02,-35.02,-35.03,-35.06,-35.08,-35.08,-35.09,-35.1,-35.12,-35.13,-35.14,-35.15,-35.15,-35.16,-35.17,-35.18,-35.19,-35.19,-35.19,-35.23,-35.23,-35.24,-35.25,-35.27,-35.28,-35.28,-35.34,-35.34,-35.35,-35.38,-35.42,-35.42,-35.43,-35.48,-35.49,-35.49,-35.5,-35.51,-35.52,-35.53,-35.53,-35.6,-35.62,-35.65,-35.65,-35.66,-35.66,-35.66,-35.67,-35.72,-35.75,-35.82,-35.83,-35.86,-35.92,-35.98,-36.07,-36.1,-36.14,-36.19,-36.23,-36.25,-36.25,-36.28,-36.3,-36.31,-36.33,-36.35,-36.37,-36.38,-36.45,-36.45,-36.46,-36.5,-36.52,-36.53,-36.53,-36.56,-36.58,-36.62,-36.65,-36.65,-36.66,-36.69,-36.7,-36.73,-36.75,-36.76,-36.79,-36.79,-36.8,-36.81,-36.85,-36.87,-36.87,-36.87,-36.89,-36.89,-36.91,-36.91,-36.91,-36.92,-36.92,-36.94,-36.95,-37.01,-37.02,-37.03,-37.03,-37.05,-37.05,-37.07,-37.07,-37.08,-37.08,-37.09,-37.09,-37.09,-37.1,-37.1,-37.14,-37.15,-37.19,-37.23,-37.3,-37.31,-37.32,-37.32,-37.32,-37.33,-37.33,-37.33,-37.35,-37.35,-37.36,-37.36,-37.36,-37.37,-37.38,-37.4,-37.43,-37.44,-37.44,-37.44,-37.45,-37.46,-37.46,-37.47,-37.49,-37.5,-37.5,-37.51,-37.51,-37.52,-37.53,-37.55,-37.56,-37.58,-37.59,-37.6,-37.61,-37.61,-37.62,-37.63,-37.64,-37.65,-37.66,-37.67,-37.69,-37.7,-37.7,-37.71,-37.73,-37.76,-37.77,-37.8,-37.82,-37.82,-37.82,-37.85,-37.86,-37.87,-37.89,-37.89,-37.92,-37.93,-37.93,-37.94,-37.98,-38.03,-38.05,-38.1,-38.1,-38.13,-38.13,-38.18,-38.19,-38.24,-38.24,-38.26,-38.28,-38.29,-38.29,-38.3,-38.31,-38.31,-38.39,-38.41,-38.45,-38.45,-38.46,-38.47,-38.49,-38.49,-38.49,-38.49,-38.51,-38.57,-38.63,-38.64,-38.66,-38.76,-38.82,-38.85,-38.86,-38.88,-38.88,-38.92,-38.95,-38.96,-39.07,-39.09,-39.11,-39.13,-39.14,-39.25,-39.33,-39.4,-39.46,-39.47,-39.48,-39.55,-39.6,-39.67,-39.68,-39.7,-39.73,-39.94,-40.04,-40.05,-40.08,-40.13,-40.17,-40.18,-40.23,-40.41,-40.43,-40.44,-40.45,-40.5,-40.52,-40.54,-40.56,-40.56,-40.57,-40.6,-40.63,-40.63,-40.65,-40.67,-40.69,-40.69,-40.76,-40.79,-40.89,-40.93,-41.05,-41.11,-41.15,-41.19,-41.21,-41.28,-41.38,-41.42,-41.55,-41.56,-41.56,-41.56,-41.58,-41.61,-41.61,-41.63,-41.65,-41.65,-41.68,-41.69,-41.71,-41.72,-41.73,-41.75,-41.76,-41.76,-41.76,-41.76,-41.77,-41.82,-41.84,-41.84,-41.84,-41.84,-41.9,-41.91,-41.98,-42.02,-42.03,-42.03,-42.18,-42.19,-42.2,-42.21,-42.25,-42.28,-42.3,-42.31,-42.32,-42.32,-42.4,-42.41,-42.41,-42.42,-42.44,-42.46,-42.47,-42.62,-42.67,-42.72,-42.85,-42.88,-42.94,-42.98,-43.01,-43.19,-43.24,-43.33,-43.38,-43.47,-43.48,-43.49,-43.49,-43.5,-43.5,-43.52,-43.52,-43.53,-43.55,-43.56,-43.56,-43.56,-43.56,-43.59,-43.6,-43.6,-43.6,-43.61,-43.61,-43.67,-43.67,-43.68,-43.8,-43.88,-43.91,-43.93,-43.95,-44.1,-44.13,-44.18,-44.34,-44.38,-44.39,-44.41,-44.42,-44.44,-44.48,-44.56,-44.57,-44.59,-44.62,-44.71,-44.73,-44.75,-44.82,-44.87,-44.88,-44.9,-44.94,-45.01,-45.01,-45.02,-45.04,-45.06,-45.08,-45.1,-45.14,-45.17,-45.2,-45.23,-45.24,-45.25,-45.35,-45.37,-45.38,-45.39,-45.41,-45.43,-45.44,-45.46,-45.48,-45.56,-45.57,-45.6,-45.85,-45.9,-45.91,-46.01,-46.02,-46.04,-46.06,-46.1,-46.12,-46.13,-46.21,-46.36,-46.49,-46.54,-46.62,-46.64,-46.65,-46.73,-46.94,-46.97,-47.16,-47.17,-47.43,-47.48,-47.52,-47.56,-47.64,-47.68,-47.73,-47.8,-47.89,-47.91,-47.94,-47.96,-48.17,-48.33,-48.53,-48.61,-48.62,-48.71,-48.74,-48.74,-48.9,-48.92,-48.94,-48.96,-48.99,-49.01,-49.02,-49.03,-49.04,-49.05,-49.08,-49.12,-49.13,-49.13,-49.13,-49.16,-49.16,-49.16,-49.2,-49.22,-49.24,-49.26,-49.36,-49.38,-49.48,-49.53,-49.54,-49.58,-49.61,-49.61,-49.65,-49.68,-49.71,-49.73,-49.74,-49.74,-49.78,-49.79,-49.79,-49.8,-49.82,-49.83,-49.85,-49.91,-49.93,-49.93],\"z\":[-44,-14,-22,-17,-35,-15,-340,-18,-55,-128,-26,-12,-32,-15,-15,-61,-15,-33,-35,-47,-23,-48,-52,-23,-42,-15,-29,-12,-40,-40,-42,-30,-52,-83,-35,-351,-18,-46,-20,-56,-39,-39,-36,-43,-47,-46,-51,-45,-42,-24,-20,-16,-21,-47,-57,-18,-16,-44,-49,-54,-54,-87,-55,-45,-46,-36,-28,-24,-16,-35,-50,-15,-31,-159,-40,-46,-28,-44,-44,-152,-54,-19,-322,-33,-27,-46,-56,-23,-55,-28,-44,-42,-18,-129,-49,-51,-49,-41,-30,-39,-44,-31,-30,-15,-15,-54,-38,-26,-51,-37,-58,-38,-28,-48,-51,-15,-44,-39,-20,-29,-45,-12,-41,-38,-46,-40,-46,-12,-15,-53,-61,-13,-49,-28,-48,-33,-243,-12,-45,-18,-15,-29,-50,-12,-49,-12,-62,-185,-41,-34,-72,-32,-28,-29,-31,-46,-49,-47,-12,-15,-319,-231,-37,-30,-32,-29,-28,-51,-38,-41,-15,-39,-92,-43,-22,-441,-15,-29,-29,-45,-24,-237,-87,-227,-15,-38,-26,-26,-47,-370,-32,-348,-27,-40,-28,-48,-29,-64,-14,-59,-57,-41,-18,-25,-29,-55,-31,-154,-15,-224,-15,-46,-24,-65,-29,-15,-15,-258,-37,-44,-52,-48,-51,-62,-47,-31,-31,-12,-32,-156,-34,-48,-23,-46,-52,-52,-50,-50,-22,-24,-36,-40,-34,-49,-46,-41,-35,-15,-12,-51,-52,-45,-45,-21,-55,-49,-53,-50,-364,-40,-421,-412,-56,-20,-139,-157,-15,-51,-42,-19,-15,-39,-19,-45,-51,-42,-138,-12,-38,-53,-58,-15,-42,-54,-12,-46,-53,-19,-391,-128,-51,-13,-15,-44,-144,-418,-15,-15,-28,-337,-15,-52,-62,-46,-86,-21,-51,-17,-12,-12,-129,-329,-15,-18,-263,-16,-108,-409,-48,-367,-18,-17,-12,-15,-398,-24,-20,-30,-19,-298,-33,-19,-37,-16,-52,-22,-56,-10,-12,-394,-28,-12,-19,-35,-433,-413,-342,-32,-388,-341,-15,-13,-361,-428,-21,-122,-22,-14,-15,-28,-24,-22,-29,-41,-13,-53,-31,-15,-14,-20,-36,-24,-17,-453,-23,-39,-35,-33,-80,-18,-40,-12,-247,-187,-13,-20,-26,-61,-34,-15,-16,-14,-217,-143,-41,-22,-40,-391,-104,-13,-13,-21,-27,-14,-351,-454,-20,-15,-32,-94,-38,-14,-43,-49,-168,-15,-151,-14,-228,-367,-22,-23,-64,-12,-178,-12,-10,-230,-437,-194,-15,-18,-20,-55,-425,-10,-15,-15,-421,-27,-15,-428,-48,-232,-356,-20,-12,-24,-351,-43,-108,-33,-509,-151,-12,-23,-10,-15,-36,-37,-24,-103,-370,-59,-12,-67,-57,-352,-116,-62,-17,-14,-14,-20,-61,-119,-23,-12,-23,-439,-231,-240,-48,-28,-25,-52,-104,-23,-15,-18,-21,-38,-297,-54,-226,-35,-57,-21,-53,-21,-22,-17,-15,-26,-39,-117,-12,-18,-15,-28,-30,-20,-51,-14,-50,-23,-20,-20,-29,-65,-14,-345,-16,-49,-18,-39,-222,-16,-10,-16,-12,-13,-25,-15,-21,-455,-15,-54,-10,-53,-18,-12,-300,-36,-18,-31,-19,-15,-17,-18,-10,-14,-52,-28,-12,-353,-15,-14,-23,-263,-50,-15,-30,-10,-15,-15,-10,-14,-15,-12,-23,-10,-12,-15,-15,-12,-12,-53,-14,-123,-21,-30,-24,-12,-15,-15,-12,-13,-10,-15,-54,-22,-12,-47,-19,-15,-10,-10,-105,-33,-15,-13,-19,-25,-28,-19,-20,-18,-19,-15,-21,-15,-15,-23,-16,-51,-21,-20,-15,-15,-25,-12,-20,-36,-15,-13,-47,-16,-49,-19,-12,-29,-22,-160,-33,-37,-17,-12,-50,-129,-35,-252,-26,-360,-17,-28,-22,-90,-20,-30,-14,-22,-130,-38,-24,-24,-24,-40,-12,-22,-46,-15,-15,-15,-42,-12,-46,-28,-23,-47,-28,-20,-12,-44,-212,-15,-15,-18,-51,-28,-15,-50,-46,-18,-42,-20,-10,-23,-23,-15,-20,-43,-18,-12,-17,-63,-21,-42,-15,-21,-17,-53,-33,-49,-19,-29,-15,-47,-20,-48,-21,-17,-205,-13,-22,-31,-15,-59,-20,-15,-52,-15,-23,-15,-15,-46,-47,-51,-51,-249,-23,-254,-12,-15,-15,-22,-40,-32,-37,-15,-56,-15,-121,-12,-23,-27,-19,-18,-55,-18,-168,-86,-17,-12,-67,-33,-20,-12,-12,-18,-60,-15,-21,-26,-23,-21,-47,-41,-21,-42,-15,-45,-24,-19,-15,-39,-10,-24,-19,-49,-56,-15,-49,-22,-17,-30,-17,-87,-18,-15,-12,-20,-22,-45,-58,-22,-30,-56,-223,-15,-15,-15,-19,-63,-13,-54,-24,-33,-57,-56,-16,-37,-20,-12,-21,-15,-44,-20,-15,-17,-24,-15,-15,-21,-19,-18,-22,-15,-59,-27,-53,-12,-18,-21,-21,-33,-22,-14,-55,-49,-21,-22,-42,-39,-27,-12,-154,-15,-15,-14,-12,-15,-161,-15,-43,-15,-12,-21,-56,-19,-12,-18,-21,-13,-17,-18,-200,-16,-12,-48,-50,-45,-282,-16,-12,-15,-41,-41,-12,-13,-262,-14,-15,-18,-12,-41,-15,-12,-13,-222,-222,-52,-15,-15,-111,-19,-27,-183,-15,-35,-15,-12,-119,-54,-63,-15,-15,-110,-155,-100,-15,-79,-27,-22,-17,-15,-24,-15,-28,-17,-45,-203,-54,-64,-85,-29,-188,-32,-14,-12,-27,-15,-160,-110,-15,-63,-22,-25,-27,-39,-109,-61,-31,-15,-30,-220,-17,-28,-38,-20,-15,-20,-162,-21,-201,-183,-58,-15,-22,-43,-19,-48,-86,-30,-528,-42,-15,-18,-12,-56,-33,-12,-105,-220,-20,-20,-15,-16,-12,-15,-12,-15,-19,-23,-27,-25,-49,-41,-25,-18,-21,-21,-26,-15,-164,-15,-216,-171,-97,-19,-18,-25,-12,-194,-28,-22,-18,-85,-31,-21,-12,-12,-14,-12,-12,-14,-68,-15,-110,-15,-214,-26,-185,-25,-15,-24,-14,-10,-10,-10,-10,-10,-53,-10,-265,-12,-14,-83,-12,-15,-15,-17,-296,-15,-15,-19,-318,-15,-88,-59,-15,-39,-17,-20,-333,-185,-41,-210,-23,-130,-19,-283,-17,-15,-120,-153,-15,-15,-136,-360,-15,-33,-15,-15,-202,-37,-20,-12,-21,-33,-15,-27,-47,-163,-15,-24,-32,-28,-26,-152,-20,-27,-39,-36,-15,-23,-131,-15,-15,-183,-156,-17,-37,-15,-29,-25,-16,-28,-22,-146,-15,-22,-12,-12,-18,-21,-12,-21,-12,-288,-10,-165,-13,-15,-104,-12,-15,-15,-15,-15,-15,-15,-24,-15,-15,-49,-15,-15,-15,-163,-49,-94,-15,-63,-50,-15,-65,-15,-15,-293,-21,-12,-50,-12,-46,-15,-78,-77,-169,-93,-164,-22,-12,-150,-33,-33,-33,-175,-43,-165,-184,-31,-248,-33,-122,-15,-276,-158,-159,-100,-138,-134,-12,-159,-119,-14,-216,-25,-16,-13,-40,-68,-30,-28,-33,-226,-20,-104,-18,-96,-49,-21,-116,-216,-12,-63,-26,-30,-26,-22,-17,-21,-131,-21,-230,-27,-24,-153,-45,-16,-94,-48,-38,-15,-31,-26,-114,-32,-185,-25,-55,-15,-88,-30,-24,-70,-24,-32,-12,-90,-46,-29,-34,-15,-79,-31,-60,-69,-19,-15,-20,-27,-18,-17,-93,-15,-12,-75,-20,-17,-17,-13,-15,-18,-19,-26,-15,-12,-17,-19,-12,-15,-28,-25,-21,-15,-52,-64,-48,-15,-19,-19,-15,-28,-26,-22,-12,-12,-16,-19,-19,-21,-15,-31,-19,-12,-59,-20,-12,-12,-22,-12,-15,-15,-12,-15,-12,-15,-10,-15,-15,-12,-12,-12,-12,-12,-12,-17,-12,-12,-12,-12,-14,-12,-12,-12,-12,-12,-12,-12,-13,-12,-16,-15,-12,-15,-12,-10,-15,-15,-15,-15,-21,-12,-15,-14,-24,-24,-17,-18,-27,-19,-19,-15,-15,-62,-86,-14,-40,-116,-15,-32,-20,-15,-15,-49,-12,-27,-101,-18,-23,-24,-122,-15,-18,-17,-14,-12,-93,-12,-22,-12,-112,-31,-15,-23,-25,-21,-13,-20,-26,-15,-23,-18,-21,-29,-40,-10,-20,-19,-23,-18,-33,-32,-41,-22,-29,-33,-15,-18,-15,-15,-12,-13,-12,-19,-17,-21,-15,-15,-15,-14,-22,-21,-30,-18,-12,-15,-15,-33,-21,-14,-15,-33,-18,-14,-12,-38,-12,-15,-24,-39,-15,-26,-34,-42,-35,-32,-13,-31,-15,-15,-20,-12,-15,-25,-23,-15,-12,-12,-19,-15,-21,-25,-12,-22,-15,-14,-15,-21,-27,-12,-19],\"type\":\"scatter3d\"}],                        {\"margin\":{\"b\":0,\"l\":0,\"r\":0,\"t\":0},\"template\":{\"data\":{\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"choropleth\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"contourcarpet\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"contour\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmapgl\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmap\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2dcontour\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2d\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattermapbox\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolargl\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolar\"}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]],\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"ternary\":{\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2}}}},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('dd254894-08f4-4916-942a-9eeefc2a8efc');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["table = df.loc[:,['Longitude','Latitude','Depth(km)','Mag']]\n", "plot_scatter = go.Scatter3d(\n", "    x = table['Longitude'],\n", "    y = table['Latitude'],\n", "    z = table['Depth(km)'],\n", "    mode = 'markers',\n", "    marker = dict(\n", "        size = 5,\n", "        cmax = 8,\n", "        cmin = 4.5,\n", "        color = table['Mag'],\n", "        colorbar = dict(title = 'Magnitude'),\n", "        colorscale = 'matter'\n", "    )\n", "    #title = 'Earthquake focal mechanism data from 1976 to 2020',\n", "    #labels = {'Longitude': 'Longitude'},\n", "    #labels = {'Latitude': 'Latitude'},\n", "    #labels = {'Depth(km)': 'Depth(km)'},\n", ")\n", "\n", "plotdata = [plot_scatter]\n", "layout = go.Layout(\n", "    margin = dict(\n", "        l = 0,\n", "        r = 0,\n", "        b = 0,\n", "        t = 0,\n", "    )\n", ")\n", "fig = go.Figure()\n", "fig.update_layout(scene = dict(\n", "    xaxis_title='Longitude',\n", "    yaxis_title='Latitude',\n", "    zaxis_title='Depth'),\n", "    width=700,\n", "    margin=dict(r=0, b=0, l=0, t=0))\n", "\n", "\n", "fig = go.Figure(data = plotdata, layout = layout)\n", "iplot(fig, filename = 'meca3D')"]}, {"cell_type": "code", "execution_count": 4, "metadata": {}, "outputs": [], "source": ["import pandas as pd  # (version 1.0.0)\n", "import plotly.express as px  # (version 4.7.0)\n", "import plotly.io as pio\n", "import numpy as np\n", "import plotly.graph_objects as go\n"]}, {"cell_type": "markdown", "metadata": {}, "source": ["### Latitude-migrated 3D focus plot ###\n", "You could see the subducting plate changes dip direction from westward to eastward down the latitude."]}, {"cell_type": "code", "execution_count": 5, "metadata": {}, "outputs": [{"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"hovertemplate": "Lat=-30<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5], "coloraxis": "coloraxis", "size": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [182.31, 183.3, 183.19, 182.84, 183.57, 182.57, 180.27, 183.3, 182.33, 181.61, 182.87, 182.3, 182.74, 182.45, 181.96, 182.33, 182.44, 182.17, 182.9, 182.34, 182.85, 182.21, 182.42, 183.28, 182.55, 182.87, 181.88, 183.54, 182.33, 182.65, 182.62, 183.47, 182.34, 182.38, 182.33, 180.51, 183.42, 182.44, 182, 182.41, 182.39, 182.54, 180.92, 182.61, 182.47, 182.08, 182.08, 182.43, 182.54, 183.33, 183.39, 182.49, 183.09, 182.54, 182.33, 182.77, 180.81, 182.57, 182.36, 182.48, 182.17, 181.81, 182.46, 182.09, 182.47, 182.45, 182.81, 182.81, 180.81, 182.52, 182.4, 183.71, 182.64, 181.97, 182.49, 182.12, 182.86, 182.47, 182.32, 181.76, 182.45, 183.04, 180.8, 182.83, 181.71, 182.55, 182.54, 182.98, 182.1, 182.39, 182.67, 182.59, 182.45, 181.53, 182.4, 181.6, 182.22, 182.45, 182.66, 182.29, 182.54, 182.83, 180.6, 183.37, 183.01, 182.12, 182.38, 182.53, 182.51, 182.57, 182.15, 182.46, 182.76, 182.11, 182.44, 183.14, 182.43, 182.45, 183.21, 182.68, 182.23, 165.91, 182.55, 182.35, 182.01, 182.84, 182.36, 183.11, 183.06, 182.28, 182.23, 180.83, 182.28, 183.25, 182.44, 182.71, 181.14, 182.51, 182.02, 182.68, 183.32, 182.76, 182.28, 180.78, 183.7, 181.03, 182.15, 180.94, 182.86, 182.23, 181.88, 182.56, 183.33, 183.33, 182.68, 183.83, 182.25, 182.27, 180.99, 165.52, 180.16, 180.51, 182.24, 182.47, 182.36, 182.82, 182, 182.23, 182.46, 182.56, 182.68, 182.43, 181.52, 182.66, 183.15, 180.22, 183.12, 183.14, 182.81, 183.7, 182.73, 180.88, 182.33, 181.15, 180.86, 182.54, 182.7, 182.69, 182.29, 180.6, 182.64, 180.42, 182.68, 182.47, 182.78, 181.94, 182.54, 181.71, 181.42, 182.07, 182.52, 182.38, 183.56, 182.64, 182.7, 182.15, 182.68, 181.29, 183.59, 180.79, 182.87, 183.49, 182.25, 181.07, 182.16, 180.94, 183.24, 180.84, 182.47, 182.14, 182.4, 182.28, 182.62, 182.13, 182.22, 182.49, 182.79, 181.46, 182.52, 181.57, 182.81, 182.25, 182.98, 182.99, 182.11, 182.03, 182.27, 182.16, 182.71, 182.85, 182.85, 182.35, 181.76, 181.85, 182.21, 182.27, 182.5, 183.06, 183, 182.12, 182.11, 182.31, 181.87, 183.06, 182.06, 182.19, 181.84, 182.1, 180.44, 182.13, 180.15, 180.16, 182.06, 183.32, 180.67, 180.62, 183.62, 182.12, 182.02, 182.89, 180.45, 181.87, 182.87, 182.08, 182.04, 182.38, 181.65, 183.18, 182.06, 182.15, 182.21, 182.77, 182.58, 182.06, 182.92, 181.96, 182.04, 182.82, 180.18, 181.44, 182.01, 181.06, 181.11, 182.13, 181.58, 180.02, 180.56, 182.78, 181.82, 180, 182.7, 182.05, 181.92, 182.27, 182.19, 182.92, 180.98, 183.01, 183.75, 183.33, 181.57, 180.34, 180.66, 182.76, 180.62, 183.32, 181.76, 180.08, 182.21, 180.27, 182.88, 183.05, 183.07, 183.45, 180.2, 182.56, 182.69], "y": [-30, -30, -30.01, -30.01, -30.01, -30.02, -30.03, -30.03, -30.03, -30.03, -30.03, -30.03, -30.03, -30.04, -30.04, -30.04, -30.05, -30.05, -30.05, -30.06, -30.06, -30.06, -30.06, -30.06, -30.06, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.08, -30.08, -30.08, -30.08, -30.09, -30.09, -30.1, -30.1, -30.11, -30.11, -30.11, -30.12, -30.12, -30.12, -30.12, -30.12, -30.12, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.14, -30.14, -30.14, -30.14, -30.15, -30.15, -30.15, -30.15, -30.15, -30.15, -30.16, -30.16, -30.17, -30.17, -30.17, -30.17, -30.18, -30.18, -30.19, -30.19, -30.19, -30.19, -30.19, -30.19, -30.19, -30.2, -30.2, -30.2, -30.2, -30.2, -30.21, -30.21, -30.21, -30.22, -30.22, -30.22, -30.23, -30.23, -30.23, -30.23, -30.23, -30.24, -30.24, -30.24, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.26, -30.26, -30.26, -30.27, -30.27, -30.27, -30.27, -30.27, -30.28, -30.28, -30.29, -30.29, -30.29, -30.3, -30.31, -30.31, -30.31, -30.31, -30.32, -30.32, -30.32, -30.33, -30.33, -30.33, -30.34, -30.34, -30.34, -30.34, -30.34, -30.34, -30.35, -30.35, -30.35, -30.36, -30.36, -30.36, -30.36, -30.37, -30.37, -30.37, -30.37, -30.37, -30.38, -30.38, -30.38, -30.38, -30.39, -30.39, -30.39, -30.39, -30.39, -30.39, -30.4, -30.4, -30.4, -30.4, -30.41, -30.41, -30.42, -30.42, -30.42, -30.43, -30.43, -30.43, -30.43, -30.43, -30.44, -30.44, -30.44, -30.44, -30.45, -30.45, -30.45, -30.45, -30.45, -30.46, -30.46, -30.46, -30.46, -30.46, -30.46, -30.47, -30.47, -30.48, -30.48, -30.49, -30.49, -30.49, -30.49, -30.49, -30.5, -30.5, -30.5, -30.51, -30.51, -30.52, -30.52, -30.52, -30.53, -30.53, -30.53, -30.53, -30.54, -30.54, -30.54, -30.55, -30.55, -30.55, -30.56, -30.56, -30.56, -30.56, -30.56, -30.56, -30.57, -30.57, -30.59, -30.59, -30.6, -30.6, -30.6, -30.61, -30.62, -30.62, -30.63, -30.63, -30.63, -30.64, -30.64, -30.64, -30.64, -30.65, -30.65, -30.66, -30.66, -30.66, -30.66, -30.67, -30.68, -30.68, -30.68, -30.68, -30.69, -30.69, -30.69, -30.69, -30.69, -30.69, -30.7, -30.7, -30.71, -30.71, -30.71, -30.71, -30.71, -30.71, -30.72, -30.74, -30.74, -30.74, -30.74, -30.75, -30.76, -30.76, -30.78, -30.78, -30.78, -30.79, -30.79, -30.79, -30.8, -30.81, -30.81, -30.81, -30.81, -30.82, -30.83, -30.83, -30.83, -30.84, -30.84, -30.84, -30.85, -30.85, -30.86, -30.86, -30.86, -30.86, -30.86, -30.87, -30.87, -30.87, -30.88, -30.88, -30.89, -30.9, -30.9, -30.9, -30.91, -30.91, -30.91, -30.91, -30.93, -30.93, -30.93, -30.95, -30.95, -30.96, -30.96, -30.98, -30.98, -30.98, -30.98], "z": [-44, -14, -22, -17, -35, -15, -340, -18, -55, -128, -26, -12, -32, -15, -15, -61, -15, -33, -35, -47, -23, -48, -52, -23, -42, -15, -29, -12, -40, -40, -42, -30, -52, -83, -35, -351, -18, -46, -20, -56, -39, -39, -36, -43, -47, -46, -51, -45, -42, -24, -20, -16, -21, -47, -57, -18, -16, -44, -49, -54, -54, -87, -55, -45, -46, -36, -28, -24, -16, -35, -50, -15, -31, -159, -40, -46, -28, -44, -44, -152, -54, -19, -322, -33, -27, -46, -56, -23, -55, -28, -44, -42, -18, -129, -49, -51, -49, -41, -30, -39, -44, -31, -30, -15, -15, -54, -38, -26, -51, -37, -58, -38, -28, -48, -51, -15, -44, -39, -20, -29, -45, -12, -41, -38, -46, -40, -46, -12, -15, -53, -61, -13, -49, -28, -48, -33, -243, -12, -45, -18, -15, -29, -50, -12, -49, -12, -62, -185, -41, -34, -72, -32, -28, -29, -31, -46, -49, -47, -12, -15, -319, -231, -37, -30, -32, -29, -28, -51, -38, -41, -15, -39, -92, -43, -22, -441, -15, -29, -29, -45, -24, -237, -87, -227, -15, -38, -26, -26, -47, -370, -32, -348, -27, -40, -28, -48, -29, -64, -14, -59, -57, -41, -18, -25, -29, -55, -31, -154, -15, -224, -15, -46, -24, -65, -29, -15, -15, -258, -37, -44, -52, -48, -51, -62, -47, -31, -31, -12, -32, -156, -34, -48, -23, -46, -52, -52, -50, -50, -22, -24, -36, -40, -34, -49, -46, -41, -35, -15, -12, -51, -52, -45, -45, -21, -55, -49, -53, -50, -364, -40, -421, -412, -56, -20, -139, -157, -15, -51, -42, -19, -15, -39, -19, -45, -51, -42, -138, -12, -38, -53, -58, -15, -42, -54, -12, -46, -53, -19, -391, -128, -51, -13, -15, -44, -144, -418, -15, -15, -28, -337, -15, -52, -62, -46, -86, -21, -51, -17, -12, -12, -129, -329, -15, -18, -263, -16, -108, -409, -48, -367, -18, -17, -12, -15, -398, -24, -20]}], "frames": [{"data": [{"hovertemplate": "Lat=-30<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5], "coloraxis": "coloraxis", "size": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [182.31, 183.3, 183.19, 182.84, 183.57, 182.57, 180.27, 183.3, 182.33, 181.61, 182.87, 182.3, 182.74, 182.45, 181.96, 182.33, 182.44, 182.17, 182.9, 182.34, 182.85, 182.21, 182.42, 183.28, 182.55, 182.87, 181.88, 183.54, 182.33, 182.65, 182.62, 183.47, 182.34, 182.38, 182.33, 180.51, 183.42, 182.44, 182, 182.41, 182.39, 182.54, 180.92, 182.61, 182.47, 182.08, 182.08, 182.43, 182.54, 183.33, 183.39, 182.49, 183.09, 182.54, 182.33, 182.77, 180.81, 182.57, 182.36, 182.48, 182.17, 181.81, 182.46, 182.09, 182.47, 182.45, 182.81, 182.81, 180.81, 182.52, 182.4, 183.71, 182.64, 181.97, 182.49, 182.12, 182.86, 182.47, 182.32, 181.76, 182.45, 183.04, 180.8, 182.83, 181.71, 182.55, 182.54, 182.98, 182.1, 182.39, 182.67, 182.59, 182.45, 181.53, 182.4, 181.6, 182.22, 182.45, 182.66, 182.29, 182.54, 182.83, 180.6, 183.37, 183.01, 182.12, 182.38, 182.53, 182.51, 182.57, 182.15, 182.46, 182.76, 182.11, 182.44, 183.14, 182.43, 182.45, 183.21, 182.68, 182.23, 165.91, 182.55, 182.35, 182.01, 182.84, 182.36, 183.11, 183.06, 182.28, 182.23, 180.83, 182.28, 183.25, 182.44, 182.71, 181.14, 182.51, 182.02, 182.68, 183.32, 182.76, 182.28, 180.78, 183.7, 181.03, 182.15, 180.94, 182.86, 182.23, 181.88, 182.56, 183.33, 183.33, 182.68, 183.83, 182.25, 182.27, 180.99, 165.52, 180.16, 180.51, 182.24, 182.47, 182.36, 182.82, 182, 182.23, 182.46, 182.56, 182.68, 182.43, 181.52, 182.66, 183.15, 180.22, 183.12, 183.14, 182.81, 183.7, 182.73, 180.88, 182.33, 181.15, 180.86, 182.54, 182.7, 182.69, 182.29, 180.6, 182.64, 180.42, 182.68, 182.47, 182.78, 181.94, 182.54, 181.71, 181.42, 182.07, 182.52, 182.38, 183.56, 182.64, 182.7, 182.15, 182.68, 181.29, 183.59, 180.79, 182.87, 183.49, 182.25, 181.07, 182.16, 180.94, 183.24, 180.84, 182.47, 182.14, 182.4, 182.28, 182.62, 182.13, 182.22, 182.49, 182.79, 181.46, 182.52, 181.57, 182.81, 182.25, 182.98, 182.99, 182.11, 182.03, 182.27, 182.16, 182.71, 182.85, 182.85, 182.35, 181.76, 181.85, 182.21, 182.27, 182.5, 183.06, 183, 182.12, 182.11, 182.31, 181.87, 183.06, 182.06, 182.19, 181.84, 182.1, 180.44, 182.13, 180.15, 180.16, 182.06, 183.32, 180.67, 180.62, 183.62, 182.12, 182.02, 182.89, 180.45, 181.87, 182.87, 182.08, 182.04, 182.38, 181.65, 183.18, 182.06, 182.15, 182.21, 182.77, 182.58, 182.06, 182.92, 181.96, 182.04, 182.82, 180.18, 181.44, 182.01, 181.06, 181.11, 182.13, 181.58, 180.02, 180.56, 182.78, 181.82, 180, 182.7, 182.05, 181.92, 182.27, 182.19, 182.92, 180.98, 183.01, 183.75, 183.33, 181.57, 180.34, 180.66, 182.76, 180.62, 183.32, 181.76, 180.08, 182.21, 180.27, 182.88, 183.05, 183.07, 183.45, 180.2, 182.56, 182.69], "y": [-30, -30, -30.01, -30.01, -30.01, -30.02, -30.03, -30.03, -30.03, -30.03, -30.03, -30.03, -30.03, -30.04, -30.04, -30.04, -30.05, -30.05, -30.05, -30.06, -30.06, -30.06, -30.06, -30.06, -30.06, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.07, -30.08, -30.08, -30.08, -30.08, -30.09, -30.09, -30.1, -30.1, -30.11, -30.11, -30.11, -30.12, -30.12, -30.12, -30.12, -30.12, -30.12, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.13, -30.14, -30.14, -30.14, -30.14, -30.15, -30.15, -30.15, -30.15, -30.15, -30.15, -30.16, -30.16, -30.17, -30.17, -30.17, -30.17, -30.18, -30.18, -30.19, -30.19, -30.19, -30.19, -30.19, -30.19, -30.19, -30.2, -30.2, -30.2, -30.2, -30.2, -30.21, -30.21, -30.21, -30.22, -30.22, -30.22, -30.23, -30.23, -30.23, -30.23, -30.23, -30.24, -30.24, -30.24, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.25, -30.26, -30.26, -30.26, -30.27, -30.27, -30.27, -30.27, -30.27, -30.28, -30.28, -30.29, -30.29, -30.29, -30.3, -30.31, -30.31, -30.31, -30.31, -30.32, -30.32, -30.32, -30.33, -30.33, -30.33, -30.34, -30.34, -30.34, -30.34, -30.34, -30.34, -30.35, -30.35, -30.35, -30.36, -30.36, -30.36, -30.36, -30.37, -30.37, -30.37, -30.37, -30.37, -30.38, -30.38, -30.38, -30.38, -30.39, -30.39, -30.39, -30.39, -30.39, -30.39, -30.4, -30.4, -30.4, -30.4, -30.41, -30.41, -30.42, -30.42, -30.42, -30.43, -30.43, -30.43, -30.43, -30.43, -30.44, -30.44, -30.44, -30.44, -30.45, -30.45, -30.45, -30.45, -30.45, -30.46, -30.46, -30.46, -30.46, -30.46, -30.46, -30.47, -30.47, -30.48, -30.48, -30.49, -30.49, -30.49, -30.49, -30.49, -30.5, -30.5, -30.5, -30.51, -30.51, -30.52, -30.52, -30.52, -30.53, -30.53, -30.53, -30.53, -30.54, -30.54, -30.54, -30.55, -30.55, -30.55, -30.56, -30.56, -30.56, -30.56, -30.56, -30.56, -30.57, -30.57, -30.59, -30.59, -30.6, -30.6, -30.6, -30.61, -30.62, -30.62, -30.63, -30.63, -30.63, -30.64, -30.64, -30.64, -30.64, -30.65, -30.65, -30.66, -30.66, -30.66, -30.66, -30.67, -30.68, -30.68, -30.68, -30.68, -30.69, -30.69, -30.69, -30.69, -30.69, -30.69, -30.7, -30.7, -30.71, -30.71, -30.71, -30.71, -30.71, -30.71, -30.72, -30.74, -30.74, -30.74, -30.74, -30.75, -30.76, -30.76, -30.78, -30.78, -30.78, -30.79, -30.79, -30.79, -30.8, -30.81, -30.81, -30.81, -30.81, -30.82, -30.83, -30.83, -30.83, -30.84, -30.84, -30.84, -30.85, -30.85, -30.86, -30.86, -30.86, -30.86, -30.86, -30.87, -30.87, -30.87, -30.88, -30.88, -30.89, -30.9, -30.9, -30.9, -30.91, -30.91, -30.91, -30.91, -30.93, -30.93, -30.93, -30.95, -30.95, -30.96, -30.96, -30.98, -30.98, -30.98, -30.98], "z": [-44, -14, -22, -17, -35, -15, -340, -18, -55, -128, -26, -12, -32, -15, -15, -61, -15, -33, -35, -47, -23, -48, -52, -23, -42, -15, -29, -12, -40, -40, -42, -30, -52, -83, -35, -351, -18, -46, -20, -56, -39, -39, -36, -43, -47, -46, -51, -45, -42, -24, -20, -16, -21, -47, -57, -18, -16, -44, -49, -54, -54, -87, -55, -45, -46, -36, -28, -24, -16, -35, -50, -15, -31, -159, -40, -46, -28, -44, -44, -152, -54, -19, -322, -33, -27, -46, -56, -23, -55, -28, -44, -42, -18, -129, -49, -51, -49, -41, -30, -39, -44, -31, -30, -15, -15, -54, -38, -26, -51, -37, -58, -38, -28, -48, -51, -15, -44, -39, -20, -29, -45, -12, -41, -38, -46, -40, -46, -12, -15, -53, -61, -13, -49, -28, -48, -33, -243, -12, -45, -18, -15, -29, -50, -12, -49, -12, -62, -185, -41, -34, -72, -32, -28, -29, -31, -46, -49, -47, -12, -15, -319, -231, -37, -30, -32, -29, -28, -51, -38, -41, -15, -39, -92, -43, -22, -441, -15, -29, -29, -45, -24, -237, -87, -227, -15, -38, -26, -26, -47, -370, -32, -348, -27, -40, -28, -48, -29, -64, -14, -59, -57, -41, -18, -25, -29, -55, -31, -154, -15, -224, -15, -46, -24, -65, -29, -15, -15, -258, -37, -44, -52, -48, -51, -62, -47, -31, -31, -12, -32, -156, -34, -48, -23, -46, -52, -52, -50, -50, -22, -24, -36, -40, -34, -49, -46, -41, -35, -15, -12, -51, -52, -45, -45, -21, -55, -49, -53, -50, -364, -40, -421, -412, -56, -20, -139, -157, -15, -51, -42, -19, -15, -39, -19, -45, -51, -42, -138, -12, -38, -53, -58, -15, -42, -54, -12, -46, -53, -19, -391, -128, -51, -13, -15, -44, -144, -418, -15, -15, -28, -337, -15, -52, -62, -46, -86, -21, -51, -17, -12, -12, -129, -329, -15, -18, -263, -16, -108, -409, -48, -367, -18, -17, -12, -15, -398, -24, -20]}], "name": "-30"}, {"data": [{"hovertemplate": "Lat=-31<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [4.8, 5.4, 5.3, 5.4, 6.8, 5.3, 5.7, 5.3, 5.1, 5.4, 6, 5.3, 5.6, 4.9, 5, 5, 6.4, 5.1, 5.4, 5.4, 5.8, 5.4, 5.5, 5.3, 5.2, 5.2, 5.4, 5.6, 5.2, 5, 6, 6.1, 5, 5.6, 5.9, 5, 5.1, 5.2, 5.1, 5, 5.5, 5.2, 4.8, 6.3, 5, 4.9, 6.3, 6.6, 5.2, 5.4, 5.3, 5.1, 5.1, 5.3, 5.4, 5.5, 4.9, 5.6, 4.9, 5.3, 4.9, 5.1, 5.6, 5.3, 5.3, 5.7, 5.4, 5.2, 4.9, 5.2, 5.4, 5, 5.2, 5.3, 5, 5.1, 5.5, 5.3, 5.7, 5.8, 5.7, 5.1, 5.1, 5.2, 5, 5.2, 5.3, 5.1, 5.1, 7.5, 5.8, 5.2, 6.6, 5, 5, 5.1, 5.3, 5.4, 5.2, 5.5, 5.3, 6.2, 5.3, 6.4, 5.1, 5.1, 5.2, 5.5, 5.8, 5.7, 5.6, 5.2, 5.1, 5.4, 5.6, 6.5, 5.4, 5.7, 5.8, 5.3, 4.9, 5.3, 5.4, 5.3, 5.3, 5.3, 5.1, 5.9, 5.1, 5.5, 5.6, 5.2, 5.1, 5, 5, 5.8, 5.2, 5.2, 5.1, 5.3, 5.3, 5, 5, 5, 5.5, 5.6, 5, 5.1, 6.9, 5, 5.8, 4.9, 5.5, 6.5, 5.2, 5, 4.9, 5.1, 5.9, 6.5, 4.9, 5.1, 5.2, 5.1, 5.1, 5.8, 4.9, 6.4, 5.4, 4.9, 5, 5.2, 4.9, 4.9, 5.2, 5.4, 5, 5, 7, 6.4, 5.4, 5.6, 5, 5, 5.1, 5.1, 5, 5.1, 5, 5.2, 5.1, 5], "coloraxis": "coloraxis", "size": [4.8, 5.4, 5.3, 5.4, 6.8, 5.3, 5.7, 5.3, 5.1, 5.4, 6, 5.3, 5.6, 4.9, 5, 5, 6.4, 5.1, 5.4, 5.4, 5.8, 5.4, 5.5, 5.3, 5.2, 5.2, 5.4, 5.6, 5.2, 5, 6, 6.1, 5, 5.6, 5.9, 5, 5.1, 5.2, 5.1, 5, 5.5, 5.2, 4.8, 6.3, 5, 4.9, 6.3, 6.6, 5.2, 5.4, 5.3, 5.1, 5.1, 5.3, 5.4, 5.5, 4.9, 5.6, 4.9, 5.3, 4.9, 5.1, 5.6, 5.3, 5.3, 5.7, 5.4, 5.2, 4.9, 5.2, 5.4, 5, 5.2, 5.3, 5, 5.1, 5.5, 5.3, 5.7, 5.8, 5.7, 5.1, 5.1, 5.2, 5, 5.2, 5.3, 5.1, 5.1, 7.5, 5.8, 5.2, 6.6, 5, 5, 5.1, 5.3, 5.4, 5.2, 5.5, 5.3, 6.2, 5.3, 6.4, 5.1, 5.1, 5.2, 5.5, 5.8, 5.7, 5.6, 5.2, 5.1, 5.4, 5.6, 6.5, 5.4, 5.7, 5.8, 5.3, 4.9, 5.3, 5.4, 5.3, 5.3, 5.3, 5.1, 5.9, 5.1, 5.5, 5.6, 5.2, 5.1, 5, 5, 5.8, 5.2, 5.2, 5.1, 5.3, 5.3, 5, 5, 5, 5.5, 5.6, 5, 5.1, 6.9, 5, 5.8, 4.9, 5.5, 6.5, 5.2, 5, 4.9, 5.1, 5.9, 6.5, 4.9, 5.1, 5.2, 5.1, 5.1, 5.8, 4.9, 6.4, 5.4, 4.9, 5, 5.2, 4.9, 4.9, 5.2, 5.4, 5, 5, 7, 6.4, 5.4, 5.6, 5, 5, 5.1, 5.1, 5, 5.1, 5, 5.2, 5.1, 5], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [181.4, 182.68, 180.28, 182.11, 183.46, 182.24, 181.76, 183.26, 182.68, 181.88, 180.49, 183.04, 180.02, 182.59, 183.46, 182.63, 182.21, 179.71, 179.46, 180.01, 183.68, 180.13, 180.06, 182.6, 182.85, 180, 180.09, 182.6, 181.39, 182.54, 182.8, 182.81, 182.93, 181.05, 182.31, 182.67, 182.34, 182.82, 181.97, 182.72, 180.36, 182.73, 182.95, 181.44, 182.64, 182.89, 179.9, 182.23, 182.02, 182.36, 182.12, 181.93, 182.42, 182.44, 182.89, 180.3, 180.88, 182.32, 183.47, 182.47, 181.66, 182.36, 181.74, 182.59, 183.22, 180.51, 182, 182.07, 182.76, 182.07, 179.93, 181.28, 182.81, 182.7, 182.52, 182.14, 182.68, 180.08, 179.7, 182.46, 181.62, 182.59, 181.08, 181.81, 182.64, 181.99, 181.82, 180.82, 182.46, 181.09, 182.7, 180.5, 180.05, 182.6, 182.66, 181.84, 180.91, 180.51, 182.87, 182.87, 180.43, 179.66, 180.29, 180.66, 182.77, 182.82, 181.65, 179.3, 182.59, 181.7, 182.14, 179.61, 182.28, 181.88, 179.93, 181.88, 179.73, 179.92, 182.29, 182.81, 182.44, 179.82, 181.13, 181.2, 182.52, 179.18, 180.79, 182.84, 182.23, 182.82, 179.99, 181.89, 182.02, 182.66, 181.44, 179.66, 181.63, 182.69, 181.45, 181.59, 179.78, 181.02, 181.67, 183.99, 182.49, 182.53, 182.5, 181.59, 180.94, 182.26, 182.81, 183.92, 179.56, 180.06, 180.34, 181.8, 182.31, 182.25, 181.79, 181.21, 182.53, 181.6, 182.48, 182.58, 182.04, 180.12, 181.45, 179.82, 181.42, 181.69, 182.29, 181.6, 182.44, 182.16, 182.28, 182.41, 183.14, 182.09, 180.84, 182.42, 182.24, 181.95, 182.46, 182.59, 182.33, 181.45, 182.45, 181.72, 182.41, 182.25, 182.3, 182.45], "y": [-31, -31, -31.01, -31.03, -31.03, -31.04, -31.05, -31.05, -31.05, -31.05, -31.06, -31.06, -31.07, -31.07, -31.07, -31.07, -31.07, -31.07, -31.07, -31.08, -31.08, -31.08, -31.09, -31.09, -31.09, -31.09, -31.1, -31.11, -31.11, -31.11, -31.11, -31.12, -31.12, -31.13, -31.14, -31.14, -31.15, -31.15, -31.15, -31.16, -31.17, -31.17, -31.17, -31.18, -31.18, -31.18, -31.18, -31.19, -31.19, -31.21, -31.22, -31.22, -31.22, -31.23, -31.23, -31.25, -31.25, -31.25, -31.25, -31.26, -31.26, -31.26, -31.27, -31.27, -31.27, -31.27, -31.28, -31.29, -31.29, -31.29, -31.29, -31.3, -31.31, -31.32, -31.32, -31.34, -31.34, -31.35, -31.35, -31.36, -31.36, -31.36, -31.36, -31.38, -31.38, -31.39, -31.39, -31.39, -31.41, -31.41, -31.41, -31.41, -31.42, -31.42, -31.43, -31.43, -31.43, -31.44, -31.44, -31.46, -31.46, -31.47, -31.48, -31.5, -31.5, -31.5, -31.51, -31.52, -31.53, -31.53, -31.53, -31.53, -31.54, -31.55, -31.55, -31.56, -31.57, -31.57, -31.58, -31.58, -31.58, -31.58, -31.6, -31.6, -31.6, -31.6, -31.61, -31.61, -31.61, -31.62, -31.62, -31.63, -31.63, -31.63, -31.63, -31.63, -31.64, -31.64, -31.65, -31.65, -31.65, -31.66, -31.66, -31.66, -31.67, -31.68, -31.68, -31.69, -31.7, -31.7, -31.71, -31.71, -31.72, -31.73, -31.73, -31.75, -31.75, -31.78, -31.79, -31.79, -31.79, -31.8, -31.81, -31.82, -31.83, -31.83, -31.84, -31.84, -31.85, -31.85, -31.85, -31.87, -31.87, -31.87, -31.9, -31.91, -31.91, -31.92, -31.92, -31.92, -31.92, -31.93, -31.93, -31.93, -31.93, -31.94, -31.95, -31.96, -31.98, -31.99, -31.99, -31.99], "z": [-30, -19, -298, -33, -19, -37, -16, -52, -22, -56, -10, -12, -394, -28, -12, -19, -35, -433, -413, -342, -32, -388, -341, -15, -13, -361, -428, -21, -122, -22, -14, -15, -28, -24, -22, -29, -41, -13, -53, -31, -15, -14, -20, -36, -24, -17, -453, -23, -39, -35, -33, -80, -18, -40, -12, -247, -187, -13, -20, -26, -61, -34, -15, -16, -14, -217, -143, -41, -22, -40, -391, -104, -13, -13, -21, -27, -14, -351, -454, -20, -15, -32, -94, -38, -14, -43, -49, -168, -15, -151, -14, -228, -367, -22, -23, -64, -12, -178, -12, -10, -230, -437, -194, -15, -18, -20, -55, -425, -10, -15, -15, -421, -27, -15, -428, -48, -232, -356, -20, -12, -24, -351, -43, -108, -33, -509, -151, -12, -23, -10, -15, -36, -37, -24, -103, -370, -59, -12, -67, -57, -352, -116, -62, -17, -14, -14, -20, -61, -119, -23, -12, -23, -439, -231, -240, -48, -28, -25, -52, -104, -23, -15, -18, -21, -38, -297, -54, -226, -35, -57, -21, -53, -21, -22, -17, -15, -26, -39, -117, -12, -18, -15, -28, -30, -20, -51, -14, -50, -23, -20, -20, -29]}], "name": "-31"}, {"data": [{"hovertemplate": "Lat=-32<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.4, 5.4, 7.1, 5.1, 5.3, 5, 5.1, 5.4, 5.2, 5.5, 6.2, 5.3, 5.9, 5.4, 4.9, 5.1, 6.1, 5.3, 5.2, 5.6, 5.1, 5.4, 5.5, 5.3, 5.3, 4.8, 5.1, 5, 5.7, 5.7, 5.3, 6.3, 5.6, 5.1, 5.2, 5.3, 6.1, 5.4, 5.1, 4.9, 5.4, 5.2, 5.8, 5.1, 5.5, 5.5, 5.9, 6.1, 5.9, 6.3, 5.1, 5, 5.6, 5.4, 5.2, 5.5, 5.4, 5.2, 5.1, 5.2, 5.3, 5, 5, 5, 5.2, 5.7, 5.4, 5.4, 5, 5.4, 5.6, 5.2, 5.1, 5.4, 5.1, 4.9, 5.2, 5.7, 5.2, 5.6, 5.3, 5.5, 4.8, 5.2, 5.2, 5, 5.5, 5.3, 5.6, 5.8, 5.7, 5.1, 5.4, 5.4, 5, 5.6, 5.1, 5.6, 5.4, 5.8, 5.7, 5.4, 5.4, 5.2, 5, 5.8, 5.7, 6.1, 5.2, 6.1, 5, 5.8, 5, 5.5, 4.9, 5.1, 5.3, 5.2, 5.4, 6, 5.6, 5.2, 5.2, 5.6, 5.7, 5.1, 5.5, 5.1, 5.8, 5, 5.2, 5.8, 5.1, 5.2, 5.3, 5.5, 5.2, 5.2, 5.3, 4.9, 5.1, 5.1, 5.4, 6.4, 5.2, 6.7, 5.4, 5.4, 5.2, 5, 5.8, 4.8, 5.4, 5.2, 5.4, 5.1, 5.9, 5.3, 5.2, 5.1, 5, 5.3, 6.1, 6.5, 5.2, 5.3, 5, 5.5, 5.3, 5, 6, 5.7, 5.5, 5.3, 6.2, 5.3, 5.2, 5.1, 5.9, 5.2, 4.9, 5.3, 5, 5, 5.2, 5.2, 5.4, 5.1, 5.6, 4.9, 5.1, 4.9, 5.4, 6, 5.5, 4.9, 5.7, 5.1, 5.5, 5.4, 5.9, 5.5, 5.7, 5.2, 5, 5.3, 5.3, 5.1, 6.4, 5.5, 5.5, 5, 5.2, 5.2, 5.6, 5.2, 5.1], "coloraxis": "coloraxis", "size": [5.4, 5.4, 7.1, 5.1, 5.3, 5, 5.1, 5.4, 5.2, 5.5, 6.2, 5.3, 5.9, 5.4, 4.9, 5.1, 6.1, 5.3, 5.2, 5.6, 5.1, 5.4, 5.5, 5.3, 5.3, 4.8, 5.1, 5, 5.7, 5.7, 5.3, 6.3, 5.6, 5.1, 5.2, 5.3, 6.1, 5.4, 5.1, 4.9, 5.4, 5.2, 5.8, 5.1, 5.5, 5.5, 5.9, 6.1, 5.9, 6.3, 5.1, 5, 5.6, 5.4, 5.2, 5.5, 5.4, 5.2, 5.1, 5.2, 5.3, 5, 5, 5, 5.2, 5.7, 5.4, 5.4, 5, 5.4, 5.6, 5.2, 5.1, 5.4, 5.1, 4.9, 5.2, 5.7, 5.2, 5.6, 5.3, 5.5, 4.8, 5.2, 5.2, 5, 5.5, 5.3, 5.6, 5.8, 5.7, 5.1, 5.4, 5.4, 5, 5.6, 5.1, 5.6, 5.4, 5.8, 5.7, 5.4, 5.4, 5.2, 5, 5.8, 5.7, 6.1, 5.2, 6.1, 5, 5.8, 5, 5.5, 4.9, 5.1, 5.3, 5.2, 5.4, 6, 5.6, 5.2, 5.2, 5.6, 5.7, 5.1, 5.5, 5.1, 5.8, 5, 5.2, 5.8, 5.1, 5.2, 5.3, 5.5, 5.2, 5.2, 5.3, 4.9, 5.1, 5.1, 5.4, 6.4, 5.2, 6.7, 5.4, 5.4, 5.2, 5, 5.8, 4.8, 5.4, 5.2, 5.4, 5.1, 5.9, 5.3, 5.2, 5.1, 5, 5.3, 6.1, 6.5, 5.2, 5.3, 5, 5.5, 5.3, 5, 6, 5.7, 5.5, 5.3, 6.2, 5.3, 5.2, 5.1, 5.9, 5.2, 4.9, 5.3, 5, 5, 5.2, 5.2, 5.4, 5.1, 5.6, 4.9, 5.1, 4.9, 5.4, 6, 5.5, 4.9, 5.7, 5.1, 5.5, 5.4, 5.9, 5.5, 5.7, 5.2, 5, 5.3, 5.3, 5.1, 6.4, 5.5, 5.5, 5, 5.2, 5.2, 5.6, 5.2, 5.1], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [180.57, 182.33, 180.05, 182.5, 181.45, 182.38, 182.6, 180.14, 182.31, 182.01, 182.38, 182.82, 182.62, 180.02, 182.28, 182.33, 179.43, 181.44, 181.32, 181.93, 181.68, 182.38, 182.85, 179.88, 180.92, 183.05, 182.4, 182.35, 181.69, 182.19, 182.37, 182.4, 181.8, 181.3, 182.32, 180.49, 179.23, 180.1, 182.47, 182.31, 180.3, 181.43, 182.38, 182.42, 181.86, 182.39, 180.55, 182.29, 182.35, 182.34, 180.41, 182.42, 182.73, 180.4, 179.76, 180.45, 182.45, 180.47, 181.52, 182.23, 180.89, 182.37, 182.38, 182.51, 180.92, 181.37, 180.25, 180.5, 180.39, 182.48, 181.86, 181.46, 182.36, 180.39, 181.38, 182.45, 181.63, 182.75, 182.75, 180.62, 182.36, 182.18, 182.28, 181.95, 182.05, 182.42, 181.99, 182, 182.05, 182.03, 182.27, 181.96, 182.73, 181.63, 182.11, 182.03, 181.26, 182.3, 182.25, 182.14, 182.19, 182.61, 182.49, 182.25, 182.31, 182.26, 182.4, 181.23, 182.1, 181.27, 182.3, 182.33, 182.15, 182.21, 180.25, 182.57, 181.29, 182.29, 182.5, 181.28, 180.53, 181.14, 180.2, 181.27, 179.57, 182.27, 182.25, 182.44, 180.6, 181.91, 181.78, 182.2, 182.1, 180.87, 180.92, 181.56, 181.89, 181.94, 180.91, 181.56, 182.01, 181.42, 181.75, 182.29, 181.58, 181.14, 181.49, 181.42, 181.75, 181.91, 181.16, 181.83, 181.85, 179.74, 181.14, 179.07, 181.88, 182.2, 181.9, 181.38, 181.83, 181.93, 181.14, 181.22, 181.94, 181.32, 180.02, 181.66, 181.94, 181.97, 182.23, 181.86, 181.15, 182.09, 182.27, 182.08, 181.29, 181.98, 180.72, 182.3, 181.97, 181.82, 181.17, 181.83, 181.32, 181.95, 180.99, 182.26, 181.14, 181.71, 181.19, 181.96, 182.07, 179.94, 181.81, 182.06, 179.96, 181.98, 180.95, 182.04, 182.24, 180.98, 181.87, 181.97, 182.12, 182.29, 181.23, 182.24, 182.31, 181.05, 179.77, 182.27, 179.8, 179.87, 181.94, 182.29, 181.99], "y": [-32.01, -32.01, -32.02, -32.02, -32.04, -32.04, -32.05, -32.05, -32.05, -32.06, -32.06, -32.06, -32.06, -32.07, -32.07, -32.07, -32.07, -32.08, -32.08, -32.09, -32.09, -32.09, -32.09, -32.09, -32.1, -32.1, -32.11, -32.11, -32.12, -32.13, -32.13, -32.15, -32.15, -32.15, -32.15, -32.16, -32.16, -32.17, -32.17, -32.17, -32.18, -32.19, -32.2, -32.2, -32.21, -32.21, -32.21, -32.22, -32.22, -32.23, -32.23, -32.23, -32.25, -32.25, -32.25, -32.26, -32.26, -32.26, -32.26, -32.28, -32.28, -32.28, -32.28, -32.28, -32.28, -32.29, -32.29, -32.3, -32.3, -32.31, -32.32, -32.32, -32.33, -32.34, -32.35, -32.35, -32.36, -32.37, -32.39, -32.39, -32.39, -32.39, -32.39, -32.39, -32.39, -32.39, -32.4, -32.4, -32.4, -32.4, -32.41, -32.41, -32.42, -32.42, -32.42, -32.42, -32.42, -32.42, -32.43, -32.44, -32.45, -32.45, -32.46, -32.46, -32.47, -32.48, -32.48, -32.49, -32.49, -32.49, -32.49, -32.5, -32.5, -32.51, -32.52, -32.53, -32.54, -32.54, -32.54, -32.54, -32.55, -32.58, -32.59, -32.6, -32.6, -32.61, -32.62, -32.62, -32.63, -32.63, -32.64, -32.65, -32.65, -32.67, -32.68, -32.68, -32.69, -32.69, -32.7, -32.71, -32.71, -32.71, -32.72, -32.72, -32.73, -32.73, -32.73, -32.73, -32.73, -32.73, -32.73, -32.74, -32.75, -32.75, -32.76, -32.76, -32.77, -32.77, -32.77, -32.77, -32.77, -32.78, -32.78, -32.78, -32.79, -32.79, -32.79, -32.8, -32.8, -32.8, -32.81, -32.81, -32.83, -32.83, -32.83, -32.83, -32.84, -32.84, -32.85, -32.85, -32.85, -32.85, -32.86, -32.86, -32.87, -32.88, -32.89, -32.89, -32.9, -32.9, -32.9, -32.9, -32.9, -32.9, -32.92, -32.92, -32.93, -32.94, -32.94, -32.94, -32.94, -32.94, -32.95, -32.95, -32.96, -32.96, -32.96, -32.96, -32.97, -32.97, -32.97, -32.98, -32.98, -32.98, -32.99, -32.99, -32.99], "z": [-65, -14, -345, -16, -49, -18, -39, -222, -16, -10, -16, -12, -13, -25, -15, -21, -455, -15, -54, -10, -53, -18, -12, -300, -36, -18, -31, -19, -15, -17, -18, -10, -14, -52, -28, -12, -353, -15, -14, -23, -263, -50, -15, -30, -10, -15, -15, -10, -14, -15, -12, -23, -10, -12, -15, -15, -12, -12, -53, -14, -123, -21, -30, -24, -12, -15, -15, -12, -13, -10, -15, -54, -22, -12, -47, -19, -15, -10, -10, -105, -33, -15, -13, -19, -25, -28, -19, -20, -18, -19, -15, -21, -15, -15, -23, -16, -51, -21, -20, -15, -15, -25, -12, -20, -36, -15, -13, -47, -16, -49, -19, -12, -29, -22, -160, -33, -37, -17, -12, -50, -129, -35, -252, -26, -360, -17, -28, -22, -90, -20, -30, -14, -22, -130, -38, -24, -24, -24, -40, -12, -22, -46, -15, -15, -15, -42, -12, -46, -28, -23, -47, -28, -20, -12, -44, -212, -15, -15, -18, -51, -28, -15, -50, -46, -18, -42, -20, -10, -23, -23, -15, -20, -43, -18, -12, -17, -63, -21, -42, -15, -21, -17, -53, -33, -49, -19, -29, -15, -47, -20, -48, -21, -17, -205, -13, -22, -31, -15, -59, -20, -15, -52, -15, -23, -15, -15, -46, -47, -51, -51, -249, -23, -254, -12, -15, -15, -22]}], "name": "-32"}, {"data": [{"hovertemplate": "Lat=-33<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.9, 5, 4.9, 5.5, 5.4, 5.7, 5.6, 5.4, 4.9, 5.1, 5.1, 5.7, 5.3, 5.4, 5.5, 5.1, 5.3, 5.3, 5.3, 5.1, 5, 5.4, 5, 5.8, 5.6, 5.4, 5, 5.2, 5.6, 5.2, 5, 5.2, 5.6, 5.4, 5.5, 5, 5, 5.2, 5.5, 5.1, 5.9, 5.4, 5.2, 4.9, 5.4, 5.3, 5.6, 5, 5.3, 5.7, 5.1, 5.3, 5.4, 5.9, 5.6, 5.3, 4.9, 5.4, 5.4, 5.1, 5.3, 5.4, 5.2, 5.9, 5.2, 5.3, 5.1, 5.3, 5.1, 5.6, 5.1, 5.1, 5.3, 5.2, 5.1, 7.4, 5.2, 5.8, 5, 5.9, 6, 5.9, 5.5, 5.9, 4.9, 5.4, 5.5, 4.8, 4.7, 4.8, 5, 5.3, 5.5, 5.2, 5.4, 5.5, 5.3, 5, 4.9, 5.5, 5.1, 5, 6.2, 5, 5, 5.1, 5.9, 5.1, 5.1, 5.5, 5.3, 5.4, 5.5, 6, 5.5, 5.4, 5.9, 5.2, 5, 4.9, 5.4, 5, 5.1, 5.1, 5.2, 4.9, 5.1, 5.1, 5.2, 4.9, 6, 5.6, 5.4, 5.1, 4.9, 5.3, 6, 5.3, 5.1, 5.1, 5.9, 5.6, 5, 5, 5.3, 5.5, 5.4, 5.6], "coloraxis": "coloraxis", "size": [5.9, 5, 4.9, 5.5, 5.4, 5.7, 5.6, 5.4, 4.9, 5.1, 5.1, 5.7, 5.3, 5.4, 5.5, 5.1, 5.3, 5.3, 5.3, 5.1, 5, 5.4, 5, 5.8, 5.6, 5.4, 5, 5.2, 5.6, 5.2, 5, 5.2, 5.6, 5.4, 5.5, 5, 5, 5.2, 5.5, 5.1, 5.9, 5.4, 5.2, 4.9, 5.4, 5.3, 5.6, 5, 5.3, 5.7, 5.1, 5.3, 5.4, 5.9, 5.6, 5.3, 4.9, 5.4, 5.4, 5.1, 5.3, 5.4, 5.2, 5.9, 5.2, 5.3, 5.1, 5.3, 5.1, 5.6, 5.1, 5.1, 5.3, 5.2, 5.1, 7.4, 5.2, 5.8, 5, 5.9, 6, 5.9, 5.5, 5.9, 4.9, 5.4, 5.5, 4.8, 4.7, 4.8, 5, 5.3, 5.5, 5.2, 5.4, 5.5, 5.3, 5, 4.9, 5.5, 5.1, 5, 6.2, 5, 5, 5.1, 5.9, 5.1, 5.1, 5.5, 5.3, 5.4, 5.5, 6, 5.5, 5.4, 5.9, 5.2, 5, 4.9, 5.4, 5, 5.1, 5.1, 5.2, 4.9, 5.1, 5.1, 5.2, 4.9, 6, 5.6, 5.4, 5.1, 4.9, 5.3, 6, 5.3, 5.1, 5.1, 5.9, 5.6, 5, 5, 5.3, 5.5, 5.4, 5.6], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [180.89, 182, 181.46, 182.2, 180.99, 181.75, 180.68, 182.16, 181.83, 182.18, 182.09, 181.98, 181.05, 182.17, 180.07, 182.45, 182.14, 182.13, 180.57, 183.3, 182.11, 182.15, 179.92, 181.85, 180.43, 181.94, 181.73, 181.92, 180.6, 182.07, 181.02, 181.28, 181.89, 180.76, 183.44, 181.38, 182.23, 181.76, 182.36, 181.22, 179.95, 181.04, 182, 180.92, 180.93, 181.52, 180.84, 182.71, 180.59, 181.34, 182.33, 180.48, 181.54, 182.55, 179.95, 180.85, 182.25, 180.85, 180.96, 181.95, 181.28, 180.79, 179.37, 181.09, 182.22, 181.1, 182.35, 180.79, 181.97, 180.83, 181.96, 181.47, 180.94, 181.01, 181.83, 182.45, 181.86, 182.22, 182.22, 181.57, 180.74, 180.14, 181.79, 181.62, 181.73, 181, 181.71, 182.37, 182.26, 179.62, 181.92, 180.32, 180.84, 179.59, 181.61, 182.03, 181.86, 182.29, 182.16, 180.2, 181.85, 181.71, 182.37, 181.32, 181.73, 181.88, 180.84, 180.99, 181.77, 181.63, 179.8, 181.56, 181.76, 180.49, 181.6, 179.51, 179.87, 181.84, 180.83, 179.59, 182.26, 181.4, 180.85, 179.65, 180.83, 181.5, 181.84, 179.68, 181.59, 179.48, 179.63, 179.46, 179.46, 180.87, 181.81, 180.91, 178.81, 181.88, 179.58, 182.5, 180.82, 180.81, 179.53, 181.74, 178.69, 181.72, 181.46, 181.61], "y": [-33, -33, -33.01, -33.02, -33.02, -33.03, -33.03, -33.03, -33.03, -33.03, -33.03, -33.03, -33.04, -33.04, -33.04, -33.05, -33.05, -33.05, -33.06, -33.06, -33.06, -33.06, -33.06, -33.07, -33.08, -33.08, -33.08, -33.09, -33.09, -33.1, -33.1, -33.11, -33.11, -33.12, -33.12, -33.12, -33.14, -33.14, -33.15, -33.15, -33.15, -33.16, -33.16, -33.16, -33.17, -33.18, -33.18, -33.18, -33.19, -33.19, -33.19, -33.2, -33.2, -33.22, -33.22, -33.23, -33.23, -33.24, -33.25, -33.25, -33.27, -33.27, -33.27, -33.28, -33.28, -33.28, -33.28, -33.3, -33.32, -33.32, -33.33, -33.34, -33.35, -33.35, -33.38, -33.39, -33.41, -33.42, -33.43, -33.44, -33.47, -33.5, -33.5, -33.5, -33.52, -33.53, -33.53, -33.53, -33.53, -33.53, -33.56, -33.57, -33.58, -33.59, -33.6, -33.6, -33.61, -33.61, -33.61, -33.62, -33.62, -33.62, -33.63, -33.63, -33.63, -33.63, -33.65, -33.65, -33.65, -33.66, -33.66, -33.68, -33.69, -33.7, -33.7, -33.7, -33.7, -33.71, -33.71, -33.71, -33.72, -33.73, -33.74, -33.74, -33.76, -33.78, -33.79, -33.79, -33.8, -33.8, -33.82, -33.84, -33.86, -33.88, -33.88, -33.89, -33.89, -33.9, -33.9, -33.91, -33.91, -33.92, -33.92, -33.94, -33.94, -33.96, -33.97, -33.97], "z": [-40, -32, -37, -15, -56, -15, -121, -12, -23, -27, -19, -18, -55, -18, -168, -86, -17, -12, -67, -33, -20, -12, -12, -18, -60, -15, -21, -26, -23, -21, -47, -41, -21, -42, -15, -45, -24, -19, -15, -39, -10, -24, -19, -49, -56, -15, -49, -22, -17, -30, -17, -87, -18, -15, -12, -20, -22, -45, -58, -22, -30, -56, -223, -15, -15, -15, -19, -63, -13, -54, -24, -33, -57, -56, -16, -37, -20, -12, -21, -15, -44, -20, -15, -17, -24, -15, -15, -21, -19, -18, -22, -15, -59, -27, -53, -12, -18, -21, -21, -33, -22, -14, -55, -49, -21, -22, -42, -39, -27, -12, -154, -15, -15, -14, -12, -15, -161, -15, -43, -15, -12, -21, -56, -19, -12, -18, -21, -13, -17, -18, -200, -16, -12, -48, -50, -45, -282, -16, -12, -15, -41, -41, -12, -13, -262, -14, -15, -18]}], "name": "-33"}, {"data": [{"hovertemplate": "Lat=-34<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.4, 5, 4.8, 5.2, 4.9, 5.3, 5.7, 5.5, 5.5, 5.8, 5.1, 5, 5, 5.4, 5.4, 5.5, 5.3, 5, 5.2, 5.6, 6.1, 5, 5.1, 5.6, 5.7, 6.6, 5.7, 5.2, 5.1, 5.3, 5.5, 5.3, 5.1, 6.5, 5.2, 5.3, 4.9, 5.6, 5.1, 5, 4.9, 5.1, 5, 5, 6.1, 5.3, 5.6, 5.9, 5.2, 5.6, 5.4, 5.3, 5.4, 5.2, 5, 5.2, 5.2, 6.8, 5.6, 5.3, 6.1, 5.3, 5.5, 5.6, 5.9, 5.2, 5.4, 5.4, 5.4, 5.2, 5.7, 5.1, 5.4, 5.6, 5.1, 5, 5.2, 5.5, 5.1], "coloraxis": "coloraxis", "size": [5.4, 5, 4.8, 5.2, 4.9, 5.3, 5.7, 5.5, 5.5, 5.8, 5.1, 5, 5, 5.4, 5.4, 5.5, 5.3, 5, 5.2, 5.6, 6.1, 5, 5.1, 5.6, 5.7, 6.6, 5.7, 5.2, 5.1, 5.3, 5.5, 5.3, 5.1, 6.5, 5.2, 5.3, 4.9, 5.6, 5.1, 5, 4.9, 5.1, 5, 5, 6.1, 5.3, 5.6, 5.9, 5.2, 5.6, 5.4, 5.3, 5.4, 5.2, 5, 5.2, 5.2, 6.8, 5.6, 5.3, 6.1, 5.3, 5.5, 5.6, 5.9, 5.2, 5.4, 5.4, 5.4, 5.2, 5.7, 5.1, 5.4, 5.6, 5.1, 5, 5.2, 5.5, 5.1], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [181.87, 180.87, 182.91, 179.51, 179.57, 179.48, 181.06, 180.14, 181.49, 178.99, 179.76, 179.3, 179.41, 178.8, 181.1, 180.24, 182.28, 181.89, 179.7, 180.31, 181.69, 181.43, 181.51, 179.59, 179.71, 180.17, 179.18, 180.9, 181.4, 181.5, 181.44, 181.29, 181.26, 179.33, 181, 181.31, 180.55, 179.25, 181.49, 180.34, 180.33, 181.73, 178.3, 181.2, 181.79, 181.96, 180.21, 180.32, 179.15, 179.98, 180.27, 181.51, 181.05, 181.32, 181.29, 179.7, 179.14, 181.6, 180.62, 181.93, 180.07, 178.82, 181.05, 180.3, 182.02, 181.1, 180.49, 181.06, 178.84, 181.06, 178.82, 179.19, 181.32, 181.21, 181.25, 180.24, 181.24, 180.91, 179.63], "y": [-34.03, -34.03, -34.05, -34.05, -34.06, -34.07, -34.08, -34.08, -34.14, -34.14, -34.15, -34.16, -34.16, -34.22, -34.23, -34.24, -34.25, -34.26, -34.27, -34.29, -34.3, -34.32, -34.33, -34.35, -34.36, -34.4, -34.4, -34.42, -34.42, -34.43, -34.47, -34.49, -34.5, -34.51, -34.53, -34.56, -34.57, -34.6, -34.62, -34.62, -34.64, -34.65, -34.66, -34.67, -34.67, -34.68, -34.69, -34.71, -34.71, -34.72, -34.74, -34.74, -34.76, -34.76, -34.76, -34.77, -34.78, -34.79, -34.79, -34.8, -34.81, -34.81, -34.82, -34.84, -34.85, -34.85, -34.87, -34.87, -34.87, -34.89, -34.89, -34.91, -34.92, -34.93, -34.93, -34.94, -34.97, -34.98, -34.99], "z": [-12, -41, -15, -12, -13, -222, -222, -52, -15, -15, -111, -19, -27, -183, -15, -35, -15, -12, -119, -54, -63, -15, -15, -110, -155, -100, -15, -79, -27, -22, -17, -15, -24, -15, -28, -17, -45, -203, -54, -64, -85, -29, -188, -32, -14, -12, -27, -15, -160, -110, -15, -63, -22, -25, -27, -39, -109, -61, -31, -15, -30, -220, -17, -28, -38, -20, -15, -20, -162, -21, -201, -183, -58, -15, -22, -43, -19, -48, -86]}], "name": "-34"}, {"data": [{"hovertemplate": "Lat=-35<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.6, 5.2, 5.3, 5.7, 4.9, 5.3, 6.5, 5.4, 5.8, 5.3, 5, 5.1, 5.1, 5.9, 5.1, 5.3, 5.8, 6.1, 5.8, 5.6, 4.9, 5.2, 5.3, 5.1, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 5.2, 5.4, 5.6, 5.4, 5.1, 5.8, 5.4, 5.3, 5.3, 5.4, 5, 5.7, 5.2, 5, 5.2, 5, 5.2, 5.2, 5.2, 5.2, 5.2, 5.4, 5.4, 5.3, 5.6, 6.3, 5.3, 5.4], "coloraxis": "coloraxis", "size": [5.6, 5.2, 5.3, 5.7, 4.9, 5.3, 6.5, 5.4, 5.8, 5.3, 5, 5.1, 5.1, 5.9, 5.1, 5.3, 5.8, 6.1, 5.8, 5.6, 4.9, 5.2, 5.3, 5.1, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 5.2, 5.4, 5.6, 5.4, 5.1, 5.8, 5.4, 5.3, 5.3, 5.4, 5, 5.7, 5.2, 5, 5.2, 5, 5.2, 5.2, 5.2, 5.2, 5.2, 5.4, 5.4, 5.3, 5.6, 6.3, 5.3, 5.4], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [180.97, 177.27, 180.22, 181.1, 178.86, 180.98, 180.92, 179.13, 181.4, 179.47, 178.75, 181.14, 180.86, 180.15, 178.82, 180.98, 181.64, 181.32, 180.76, 180.93, 180.94, 181.02, 180.86, 179.65, 180.18, 180.3, 180.8, 180.95, 181.38, 180.72, 180.3, 178.91, 178.47, 178.5, 178.61, 179.12, 180.75, 180.73, 180.83, 178.35, 178.5, 180.75, 180.76, 178.57, 179.42, 180.99, 180.74, 178.42, 178.45, 178.4, 178.58, 178.39, 178.31, 179.26, 180.69, 178.89, 179.72, 177.89], "y": [-35, -35.01, -35.02, -35.02, -35.03, -35.06, -35.08, -35.08, -35.09, -35.1, -35.12, -35.13, -35.14, -35.15, -35.15, -35.16, -35.17, -35.18, -35.19, -35.19, -35.19, -35.23, -35.23, -35.24, -35.25, -35.27, -35.28, -35.28, -35.34, -35.34, -35.35, -35.38, -35.42, -35.42, -35.43, -35.48, -35.49, -35.49, -35.5, -35.51, -35.52, -35.53, -35.53, -35.6, -35.62, -35.65, -35.65, -35.66, -35.66, -35.66, -35.67, -35.72, -35.75, -35.82, -35.83, -35.86, -35.92, -35.98], "z": [-30, -528, -42, -15, -18, -12, -56, -33, -12, -105, -220, -20, -20, -15, -16, -12, -15, -12, -15, -19, -23, -27, -25, -49, -41, -25, -18, -21, -21, -26, -15, -164, -15, -216, -171, -97, -19, -18, -25, -12, -194, -28, -22, -18, -85, -31, -21, -12, -12, -14, -12, -12, -14, -68, -15, -110, -15, -214]}], "name": "-35"}, {"data": [{"hovertemplate": "Lat=-36<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.1, 5.9, 5.1, 5.4, 5.4, 5.4, 5.6, 5.6, 5.7, 5.7, 5.8, 5.3, 5.4, 5.3, 5.1, 5, 6.1, 5.4, 5.4, 5.8, 5.1, 5.4, 5.7, 5.1, 6.8, 5.2, 5.3, 5, 7.1, 5.6, 5.4, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 4.9, 5.2, 5.5, 5.4, 5, 5.3, 5.3, 5.7, 5.3, 5.5, 5.4, 5.4], "coloraxis": "coloraxis", "size": [5.1, 5.9, 5.1, 5.4, 5.4, 5.4, 5.6, 5.6, 5.7, 5.7, 5.8, 5.3, 5.4, 5.3, 5.1, 5, 6.1, 5.4, 5.4, 5.8, 5.1, 5.4, 5.7, 5.1, 6.8, 5.2, 5.3, 5, 7.1, 5.6, 5.4, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 4.9, 5.2, 5.5, 5.4, 5, 5.3, 5.3, 5.7, 5.3, 5.5, 5.4, 5.4], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [180.29, 178.2, 180.06, 177.49, 177.6, 180.78, 177.62, 177.58, 177.48, 177.62, 177.53, 179.08, 177.59, 176.91, 177.41, 177.4, 178.78, 177.35, 180.77, 180.87, 181.02, 177.26, 178.89, 181.15, 177.47, 176.72, 179.82, 178.35, 180.92, 180.91, 176.92, 177.2, 180.14, 176.59, 177.85, 180.72, 176.78, 180.96, 177.85, 179.82, 176.57, 179.07, 180.66, 177.86, 177.6, 180.12, 180.59, 177.22, 176.69], "y": [-36.07, -36.1, -36.14, -36.19, -36.23, -36.25, -36.25, -36.28, -36.3, -36.31, -36.33, -36.35, -36.37, -36.38, -36.45, -36.45, -36.46, -36.5, -36.52, -36.53, -36.53, -36.56, -36.58, -36.62, -36.65, -36.65, -36.66, -36.69, -36.7, -36.73, -36.75, -36.76, -36.79, -36.79, -36.8, -36.81, -36.85, -36.87, -36.87, -36.87, -36.89, -36.89, -36.91, -36.91, -36.91, -36.92, -36.92, -36.94, -36.95], "z": [-26, -185, -25, -15, -24, -14, -10, -10, -10, -10, -10, -53, -10, -265, -12, -14, -83, -12, -15, -15, -17, -296, -15, -15, -19, -318, -15, -88, -59, -15, -39, -17, -20, -333, -185, -41, -210, -23, -130, -19, -283, -17, -15, -120, -153, -15, -15, -136, -360]}], "name": "-36"}, {"data": [{"hovertemplate": "Lat=-37<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.7, 5.3, 5.2, 6.7, 5, 5.1, 5.8, 5.4, 6, 5.2, 6.3, 5.8, 5.1, 5, 5.2, 5, 5.1, 7.1, 5.8, 5, 5.9, 5, 4.9, 5, 5.1, 4.9, 6, 5.6, 5.3, 5.2, 5, 5.1, 5.9, 5.2, 4.9, 5.4, 5.1, 4.9, 5.2, 5.4, 6.2, 5.2, 5.1, 5.5, 5.9, 5, 5.8, 6.7, 5.3, 5.3, 6.2, 5.2, 5.3, 5.2, 4.9, 5.7, 7.2, 5.2, 5.2, 5.2, 5.7, 5.6, 5.1, 5.8, 5.9, 5.6, 5.1, 6, 5.4, 5.2, 5, 5, 6.5, 5, 5, 5.3, 4.8, 5.7, 6.5, 5.3, 4.9, 5, 5, 5.5], "coloraxis": "coloraxis", "size": [5.7, 5.3, 5.2, 6.7, 5, 5.1, 5.8, 5.4, 6, 5.2, 6.3, 5.8, 5.1, 5, 5.2, 5, 5.1, 7.1, 5.8, 5, 5.9, 5, 4.9, 5, 5.1, 4.9, 6, 5.6, 5.3, 5.2, 5, 5.1, 5.9, 5.2, 4.9, 5.4, 5.1, 4.9, 5.2, 5.4, 6.2, 5.2, 5.1, 5.5, 5.9, 5, 5.8, 6.7, 5.3, 5.3, 6.2, 5.2, 5.3, 5.2, 4.9, 5.7, 7.2, 5.2, 5.2, 5.2, 5.7, 5.6, 5.1, 5.8, 5.9, 5.6, 5.1, 6, 5.4, 5.2, 5, 5, 6.5, 5, 5, 5.3, 4.8, 5.7, 6.5, 5.3, 4.9, 5, 5, 5.5], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [180.03, 181.53, 179.31, 179.82, 177.11, 179.1, 178.85, 178.85, 179.08, 178.58, 177.45, 179.05, 179.09, 177.13, 178.85, 179.61, 179.05, 179.03, 178.8, 177.42, 177.3, 180.5, 178.96, 178.84, 180.43, 179.12, 177.34, 177.19, 179.44, 176.64, 177.34, 179.97, 178.88, 179.53, 178.93, 178.79, 180.38, 179.99, 178.87, 177.3, 176.94, 178.82, 179.98, 179.64, 178.69, 177.29, 179.62, 179.74, 179.74, 176.68, 179.84, 176.69, 177.17, 177.31, 177.28, 179.65, 179.4, 178.76, 180.89, 179.18, 179.2, 179.36, 180.53, 180.04, 179.24, 179.29, 176.58, 179.33, 179.49, 176.93, 177.87, 177.59, 177.03, 177.91, 177.66, 179.28, 177.69, 179.16, 179.17, 176.01, 178.3, 176.62, 177.81, 176.58], "y": [-37.01, -37.02, -37.03, -37.03, -37.05, -37.05, -37.07, -37.07, -37.08, -37.08, -37.09, -37.09, -37.09, -37.1, -37.1, -37.14, -37.15, -37.19, -37.23, -37.3, -37.31, -37.32, -37.32, -37.32, -37.33, -37.33, -37.33, -37.35, -37.35, -37.36, -37.36, -37.36, -37.37, -37.38, -37.4, -37.43, -37.44, -37.44, -37.44, -37.45, -37.46, -37.46, -37.47, -37.49, -37.5, -37.5, -37.51, -37.51, -37.52, -37.53, -37.55, -37.56, -37.58, -37.59, -37.6, -37.61, -37.61, -37.62, -37.63, -37.64, -37.65, -37.66, -37.67, -37.69, -37.7, -37.7, -37.71, -37.73, -37.76, -37.77, -37.8, -37.82, -37.82, -37.82, -37.85, -37.86, -37.87, -37.89, -37.89, -37.92, -37.93, -37.93, -37.94, -37.98], "z": [-15, -33, -15, -15, -202, -37, -20, -12, -21, -33, -15, -27, -47, -163, -15, -24, -32, -28, -26, -152, -20, -27, -39, -36, -15, -23, -131, -15, -15, -183, -156, -17, -37, -15, -29, -25, -16, -28, -22, -146, -15, -22, -12, -12, -18, -21, -12, -21, -12, -288, -10, -165, -13, -15, -104, -12, -15, -15, -15, -15, -15, -15, -24, -15, -15, -49, -15, -15, -15, -163, -49, -94, -15, -63, -50, -15, -65, -15, -15, -293, -21, -12, -50, -12]}], "name": "-37"}, {"data": [{"hovertemplate": "Lat=-38<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.3, 5.6, 6.1, 4.9, 5.2, 5, 5.1, 5.7, 5.1, 5, 5, 5.2, 5.4, 5, 5.3, 6.4, 5.2, 5.1, 5.5, 5.2, 5.2, 6.4, 5.7, 6.1, 5.6, 5, 4.9, 4.9, 5.1, 5.6, 5.7, 4.9, 5.4, 5, 5.5, 5.2, 6, 5.3, 6.6, 5.2, 5.2], "coloraxis": "coloraxis", "size": [5.3, 5.6, 6.1, 4.9, 5.2, 5, 5.1, 5.7, 5.1, 5, 5, 5.2, 5.4, 5, 5.3, 6.4, 5.2, 5.1, 5.5, 5.2, 5.2, 6.4, 5.7, 6.1, 5.6, 5, 4.9, 4.9, 5.1, 5.6, 5.7, 4.9, 5.4, 5, 5.5, 5.2, 6, 5.3, 6.6, 5.2, 5.2], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [178.9, 178.19, 177.32, 177.8, 175.82, 176.68, 176.7, 178.53, 179.67, 176.45, 177.63, 177.78, 180.33, 175.9, 177.51, 176.08, 176.18, 177.77, 175.4, 176.29, 176.42, 178.06, 175.29, 175.78, 176.03, 176.56, 176.17, 176.09, 180.35, 175.68, 176.12, 178.58, 174.86, 177.55, 178.85, 176.01, 177.01, 176.09, 178.4, 178.13, 177.42], "y": [-38.03, -38.05, -38.1, -38.1, -38.13, -38.13, -38.18, -38.19, -38.24, -38.24, -38.26, -38.28, -38.29, -38.29, -38.3, -38.31, -38.31, -38.39, -38.41, -38.45, -38.45, -38.46, -38.47, -38.49, -38.49, -38.49, -38.49, -38.51, -38.57, -38.63, -38.64, -38.66, -38.76, -38.82, -38.85, -38.86, -38.88, -38.88, -38.92, -38.95, -38.96], "z": [-46, -15, -78, -77, -169, -93, -164, -22, -12, -150, -33, -33, -33, -175, -43, -165, -184, -31, -248, -33, -122, -15, -276, -158, -159, -100, -138, -134, -12, -159, -119, -14, -216, -25, -16, -13, -40, -68, -30, -28, -33]}], "name": "-38"}, {"data": [{"hovertemplate": "Lat=-39<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [6.2, 5.1, 5, 5.2, 5.3, 5.4, 5.1, 5.1, 5.8, 5.1, 5, 5.5, 5.5, 5.4, 5.7, 5.5, 5.7, 5.1], "coloraxis": "coloraxis", "size": [6.2, 5.1, 5, 5.2, 5.3, 5.4, 5.1, 5.1, 5.8, 5.1, 5, 5.5, 5.5, 5.4, 5.7, 5.5, 5.7, 5.1], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [174.94, 177.86, 175.74, 180.69, 175.88, 175.91, 178.78, 175.19, 174.22, 178.5, 175.46, 177.68, 175.96, 176.91, 176.83, 176.76, 176.49, 174.71], "y": [-39.07, -39.09, -39.11, -39.13, -39.14, -39.25, -39.33, -39.4, -39.46, -39.47, -39.48, -39.55, -39.6, -39.67, -39.68, -39.7, -39.73, -39.94], "z": [-226, -20, -104, -18, -96, -49, -21, -116, -216, -12, -63, -26, -30, -26, -22, -17, -21, -131]}], "name": "-39"}, {"data": [{"hovertemplate": "Lat=-40<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.2, 6.3, 5.4, 5.1, 5.4, 5.4, 6.4, 5.2, 5, 5.3, 5.4, 5, 5.8, 5.6, 5.2, 5.1, 5.4, 5.2, 5.4, 5, 5.6, 6.3, 5.6, 5.6, 6.3, 6, 5.9, 5.3], "coloraxis": "coloraxis", "size": [5.2, 6.3, 5.4, 5.1, 5.4, 5.4, 6.4, 5.2, 5, 5.3, 5.4, 5, 5.8, 5.6, 5.2, 5.1, 5.4, 5.2, 5.4, 5, 5.6, 6.3, 5.6, 5.6, 6.3, 6, 5.9, 5.3], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [176.66, 173.63, 176.33, 179.01, 173.66, 175.27, 176.53, 173.68, 175.06, 176.13, 176.66, 176.98, 174.98, 174.09, 176.28, 173.42, 176.02, 176.07, 175.66, 174.46, 176.29, 175.8, 174.94, 176.47, 176.09, 177.58, 174.17, 175.47], "y": [-40.04, -40.05, -40.08, -40.13, -40.17, -40.18, -40.23, -40.41, -40.43, -40.44, -40.45, -40.5, -40.52, -40.54, -40.56, -40.56, -40.57, -40.6, -40.63, -40.63, -40.65, -40.67, -40.69, -40.69, -40.76, -40.79, -40.89, -40.93], "z": [-21, -230, -27, -24, -153, -45, -16, -94, -48, -38, -15, -31, -26, -114, -32, -185, -25, -55, -15, -88, -30, -24, -70, -24, -32, -12, -90, -46]}], "name": "-40"}, {"data": [{"hovertemplate": "Lat=-41<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [4.9, 5.1, 5.4, 5.2, 5.3, 5.2, 5.2, 5.2, 5.3, 5.4, 5.1, 5.1, 5.5, 5.3, 5, 6.5, 5.9, 4.9, 5.4, 5.3, 5.7, 5.9, 5.5, 5.6, 6.1, 5.7, 6.6, 5.9, 5.2, 5.6, 5.5, 5.1, 5.4, 5.4, 5.3, 5.2, 5.5], "coloraxis": "coloraxis", "size": [4.9, 5.1, 5.4, 5.2, 5.3, 5.2, 5.2, 5.2, 5.3, 5.4, 5.1, 5.1, 5.5, 5.3, 5, 6.5, 5.9, 4.9, 5.4, 5.3, 5.7, 5.9, 5.5, 5.6, 6.1, 5.7, 6.6, 5.9, 5.2, 5.6, 5.5, 5.1, 5.4, 5.4, 5.3, 5.2, 5.5], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [175.32, 178.68, 175.48, 173.34, 175.16, 173.4, 174.08, 176.02, 174.33, 175.35, 176.14, 175.79, 174.37, 172.52, 174.29, 174.17, 173.71, 174.47, 174.13, 174.1, 174.2, 174, 174.26, 174.25, 174.29, 171.7, 174.04, 174.17, 174.03, 173.93, 175.62, 174.32, 174.22, 173.96, 171.43, 173.14, 172.82], "y": [-41.05, -41.11, -41.15, -41.19, -41.21, -41.28, -41.38, -41.42, -41.55, -41.56, -41.56, -41.56, -41.58, -41.61, -41.61, -41.63, -41.65, -41.65, -41.68, -41.69, -41.71, -41.72, -41.73, -41.75, -41.76, -41.76, -41.76, -41.76, -41.77, -41.82, -41.84, -41.84, -41.84, -41.84, -41.9, -41.91, -41.98], "z": [-29, -34, -15, -79, -31, -60, -69, -19, -15, -20, -27, -18, -17, -93, -15, -12, -75, -20, -17, -17, -13, -15, -18, -19, -26, -15, -12, -17, -19, -12, -15, -28, -25, -21, -15, -52, -64]}], "name": "-41"}, {"data": [{"hovertemplate": "Lat=-42<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [6.1, 5.8, 7.8, 5.2, 5.7, 4.9, 4.9, 5.1, 5.7, 5.2, 5, 5.7, 5.1, 5.2, 6, 5.3, 5, 6.4, 5, 5.1, 5, 5.2, 4.9, 5.5, 6.1, 6.7, 5.6], "coloraxis": "coloraxis", "size": [6.1, 5.8, 7.8, 5.2, 5.7, 4.9, 4.9, 5.1, 5.7, 5.2, 5, 5.7, 5.1, 5.2, 6, 5.3, 5, 6.4, 5, 5.1, 5, 5.2, 4.9, 5.5, 6.1, 6.7, 5.6], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [173.07, 171.86, 173.85, 173.81, 172.74, 177.92, 173.75, 173.95, 173.86, 172.98, 173.69, 173.74, 173.43, 173.62, 172.78, 172.9, 173.73, 173.07, 171.54, 173.89, 172.67, 172.97, 173.95, 172.85, 171.76, 171.47, 171.18], "y": [-42.02, -42.03, -42.03, -42.18, -42.19, -42.2, -42.21, -42.25, -42.28, -42.3, -42.31, -42.32, -42.32, -42.4, -42.41, -42.41, -42.42, -42.44, -42.46, -42.47, -42.62, -42.67, -42.72, -42.85, -42.88, -42.94, -42.98], "z": [-48, -15, -19, -19, -15, -28, -26, -22, -12, -12, -16, -19, -19, -21, -15, -31, -19, -12, -59, -20, -12, -12, -22, -12, -15, -15, -12]}], "name": "-42"}, {"data": [{"hovertemplate": "Lat=-43<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.5, 4.9, 5.9, 5.2, 5.4, 5.6, 5.7, 5.1, 5.2, 5.5, 5.6, 6, 5.1, 5.2, 5.8, 7, 4.8, 5, 4.8, 5, 4.9, 6.1, 4.9, 5.2, 5.4, 4.9, 5.7, 4.9, 5.4, 5.4, 5.2, 5, 6.1], "coloraxis": "coloraxis", "size": [5.5, 4.9, 5.9, 5.2, 5.4, 5.6, 5.7, 5.1, 5.2, 5.5, 5.6, 6, 5.1, 5.2, 5.8, 7, 4.8, 5, 4.8, 5, 4.9, 6.1, 4.9, 5.2, 5.4, 4.9, 5.7, 4.9, 5.4, 5.4, 5.2, 5, 6.1], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [171.61, 173.04, 171.54, 171.48, 171.81, 171.8, 172.54, 172.31, 172.62, 172.56, 172.55, 172.62, 172.78, 172.69, 172.58, 172.12, 172.28, 172.31, 172.7, 172.73, 171.91, 172.52, 172.74, 172.44, 172.69, 172.85, 172.56, 172.68, 169.62, 168.81, 169.23, 168.75, 170.66], "y": [-43.01, -43.19, -43.24, -43.33, -43.38, -43.47, -43.48, -43.49, -43.49, -43.5, -43.5, -43.52, -43.52, -43.53, -43.55, -43.56, -43.56, -43.56, -43.56, -43.59, -43.6, -43.6, -43.6, -43.61, -43.61, -43.67, -43.67, -43.68, -43.8, -43.88, -43.91, -43.93, -43.95], "z": [-15, -12, -15, -10, -15, -15, -12, -12, -12, -12, -12, -12, -17, -12, -12, -12, -12, -14, -12, -12, -12, -12, -12, -12, -12, -13, -12, -16, -15, -12, -15, -12, -10]}], "name": "-43"}, {"data": [{"hovertemplate": "Lat=-44<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.4, 5.8, 5.3, 5.6, 4.8, 4.9, 5.5, 5.6, 5, 4.9, 5.6, 5.1, 5, 6.1, 6.8, 5.2, 6.6, 6.7, 5, 5.6, 5, 5.3], "coloraxis": "coloraxis", "size": [5.4, 5.8, 5.3, 5.6, 4.8, 4.9, 5.5, 5.6, 5, 4.9, 5.6, 5.1, 5, 6.1, 6.8, 5.2, 6.6, 6.7, 5, 5.6, 5, 5.3], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [168.42, 168.55, 167.91, 166.93, 167.66, 169.97, 167.71, 168.73, 167.51, 167.38, 167.39, 167.34, 167.21, 167.25, 167.24, 166.15, 167.63, 167.05, 167.54, 167, 166.59, 167.32], "y": [-44.1, -44.13, -44.18, -44.34, -44.38, -44.39, -44.41, -44.42, -44.44, -44.48, -44.56, -44.57, -44.59, -44.62, -44.71, -44.73, -44.75, -44.82, -44.87, -44.88, -44.9, -44.94], "z": [-15, -15, -15, -15, -21, -12, -15, -14, -24, -24, -17, -18, -27, -19, -19, -15, -15, -62, -86, -14, -40, -116]}], "name": "-44"}, {"data": [{"hovertemplate": "Lat=-45<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.4, 7.2, 6.1, 7, 6.4, 5.5, 5.2, 5.5, 5.2, 6.5, 4.9, 5.2, 5.5, 5.2, 5.4, 5.1, 5.2, 5.3, 5.1, 5.5, 5.1, 6.1, 5.2, 5, 5.6, 7.8, 5.2, 5], "coloraxis": "coloraxis", "size": [5.4, 7.2, 6.1, 7, 6.4, 5.5, 5.2, 5.5, 5.2, 6.5, 4.9, 5.2, 5.5, 5.2, 5.4, 5.1, 5.2, 5.3, 5.1, 5.5, 5.1, 6.1, 5.2, 5, 5.6, 7.8, 5.2, 5], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [167.23, 166.87, 166.7, 166.73, 166.6, 166.52, 166.62, 166.68, 166.68, 166.59, 166.44, 166.44, 167.64, 166.61, 166.46, 166.36, 165.97, 166.07, 166.75, 166.02, 166.42, 166.13, 166.72, 166.12, 166.73, 166.26, 165.82, 165.76], "y": [-45.01, -45.01, -45.02, -45.04, -45.06, -45.08, -45.1, -45.14, -45.17, -45.2, -45.23, -45.24, -45.25, -45.35, -45.37, -45.38, -45.39, -45.41, -45.43, -45.44, -45.46, -45.48, -45.56, -45.57, -45.6, -45.85, -45.9, -45.91], "z": [-15, -32, -20, -15, -15, -49, -12, -27, -101, -18, -23, -24, -122, -15, -18, -17, -14, -12, -93, -12, -22, -12, -112, -31, -15, -23, -25, -21]}], "name": "-45"}, {"data": [{"hovertemplate": "Lat=-46<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5, 5.7, 5.1, 5.6, 5.8, 5.8, 5.4, 5, 7.1, 6.2, 7.3, 6, 5.2, 5.4, 5, 5, 5.2], "coloraxis": "coloraxis", "size": [5, 5.7, 5.1, 5.6, 5.8, 5.8, 5.4, 5, 7.1, 6.2, 7.3, 6, 5.2, 5.4, 5, 5, 5.2], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [165.72, 165.82, 165.84, 166.09, 165.74, 165.85, 165.75, 165.67, 164.91, 164.64, 165.77, 165.38, 165.22, 165.27, 165.32, 165.04, 165.69], "y": [-46.01, -46.02, -46.04, -46.06, -46.1, -46.12, -46.13, -46.21, -46.36, -46.49, -46.54, -46.62, -46.64, -46.65, -46.73, -46.94, -46.97], "z": [-13, -20, -26, -15, -23, -18, -21, -29, -40, -10, -20, -19, -23, -18, -33, -32, -41]}], "name": "-46"}, {"data": [{"hovertemplate": "Lat=-47<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5, 5, 5.2, 5.9, 4.9, 5.5, 5.5, 4.9, 5.2, 5.8, 4.9, 5.1, 5, 5.6], "coloraxis": "coloraxis", "size": [5, 5, 5.2, 5.9, 4.9, 5.5, 5.5, 4.9, 5.2, 5.8, 4.9, 5.1, 5, 5.6], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [165.43, 165.04, 165.96, 165.14, 165.43, 164.59, 164.62, 165.1, 165.11, 165.08, 165.26, 164.74, 164.42, 164.53], "y": [-47.16, -47.17, -47.43, -47.48, -47.52, -47.56, -47.64, -47.68, -47.73, -47.8, -47.89, -47.91, -47.94, -47.96], "z": [-22, -29, -33, -15, -18, -15, -15, -12, -13, -12, -19, -17, -21, -15]}], "name": "-47"}, {"data": [{"hovertemplate": "Lat=-48<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.2, 5.7, 5.1, 5.6, 5.3, 5.3, 5.1, 5.3, 5.4, 5.5, 7.6, 4.9, 5], "coloraxis": "coloraxis", "size": [5.2, 5.7, 5.1, 5.6, 5.3, 5.3, 5.1, 5.3, 5.4, 5.5, 7.6, 4.9, 5], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [165.5, 163.65, 164.19, 164.51, 164.51, 164.56, 164.24, 164.2, 163.86, 164.15, 164.39, 164.13, 163.89], "y": [-48.17, -48.33, -48.53, -48.61, -48.62, -48.71, -48.74, -48.74, -48.9, -48.92, -48.94, -48.96, -48.99], "z": [-15, -15, -14, -22, -21, -30, -18, -12, -15, -15, -33, -21, -14]}], "name": "-48"}, {"data": [{"hovertemplate": "Lat=-49<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.7, 5, 6, 4.9, 5.4, 5.1, 5.9, 5.6, 5.4, 5.2, 5.2, 6.1, 5.7, 5.1, 5.3, 6.6, 7.5, 6.6, 5.5, 6, 4.8, 5.1, 5.7, 5.7, 5.7, 5.4, 5.4, 5.2, 5.3, 5.4, 5, 4.9, 5.1, 5.1, 5.2, 5.4, 5.4, 5, 8.1, 6.2, 6], "coloraxis": "coloraxis", "size": [5.7, 5, 6, 4.9, 5.4, 5.1, 5.9, 5.6, 5.4, 5.2, 5.2, 6.1, 5.7, 5.1, 5.3, 6.6, 7.5, 6.6, 5.5, 6, 4.8, 5.1, 5.7, 5.7, 5.7, 5.4, 5.4, 5.2, 5.3, 5.4, 5, 4.9, 5.1, 5.1, 5.2, 5.4, 5.4, 5, 8.1, 6.2, 6], "sizemode": "area", "sizeref": 0.036, "symbol": "circle"}, "mode": "markers", "name": "", "scene": "scene", "showlegend": false, "type": "scatter3d", "x": [164.11, 164.26, 164.03, 161.07, 163.89, 164.32, 164.03, 164.01, 164.33, 164.24, 163.98, 164.19, 164.14, 164.38, 164.27, 163.99, 164.1, 164.01, 162.99, 163.79, 175.17, 163.47, 163.8, 163.71, 163.88, 163.35, 160.85, 163.5, 163.47, 162.91, 163.47, 163.26, 163.48, 163.33, 163.07, 163.35, 163.92, 163.47, 161.25, 163.25, 163.2], "y": [-49.01, -49.02, -49.03, -49.04, -49.05, -49.08, -49.12, -49.13, -49.13, -49.13, -49.16, -49.16, -49.16, -49.2, -49.22, -49.24, -49.26, -49.36, -49.38, -49.48, -49.53, -49.54, -49.58, -49.61, -49.61, -49.65, -49.68, -49.71, -49.73, -49.74, -49.74, -49.78, -49.79, -49.79, -49.8, -49.82, -49.83, -49.85, -49.91, -49.93, -49.93], "z": [-15, -33, -18, -14, -12, -38, -12, -15, -24, -39, -15, -26, -34, -42, -35, -32, -13, -31, -15, -15, -20, -12, -15, -25, -23, -15, -12, -12, -19, -15, -21, -25, -12, -22, -15, -14, -15, -21, -27, -12, -19]}], "name": "-49"}], "layout": {"coloraxis": {"colorbar": {"title": {"text": "Mag"}}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]]}, "legend": {"itemsizing": "constant", "tracegroupgap": 0}, "margin": {"t": 60}, "scene": {"domain": {"x": [0, 1], "y": [0, 1]}, "xaxis": {"range": [160, 184], "title": {"text": "Longitude"}}, "yaxis": {"range": [-50, -30], "title": {"text": "Latitude"}}, "zaxis": {"range": [-600, 0], "title": {"text": "Depth(km)"}}}, "sliders": [{"active": 0, "currentvalue": {"prefix": "Lat="}, "len": 0.9, "pad": {"b": 10, "t": 60}, "steps": [{"args": [["-30"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-30", "method": "animate"}, {"args": [["-31"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-31", "method": "animate"}, {"args": [["-32"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-32", "method": "animate"}, {"args": [["-33"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-33", "method": "animate"}, {"args": [["-34"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-34", "method": "animate"}, {"args": [["-35"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-35", "method": "animate"}, {"args": [["-36"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-36", "method": "animate"}, {"args": [["-37"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-37", "method": "animate"}, {"args": [["-38"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-38", "method": "animate"}, {"args": [["-39"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-39", "method": "animate"}, {"args": [["-40"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-40", "method": "animate"}, {"args": [["-41"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-41", "method": "animate"}, {"args": [["-42"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-42", "method": "animate"}, {"args": [["-43"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-43", "method": "animate"}, {"args": [["-44"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-44", "method": "animate"}, {"args": [["-45"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-45", "method": "animate"}, {"args": [["-46"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-46", "method": "animate"}, {"args": [["-47"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-47", "method": "animate"}, {"args": [["-48"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-48", "method": "animate"}, {"args": [["-49"], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-49", "method": "animate"}], "x": 0.1, "xanchor": "left", "y": 0, "yanchor": "top"}], "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "sequentialminus": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "updatemenus": [{"buttons": [{"args": [null, {"frame": {"duration": 500, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 500, "easing": "linear"}}], "label": "&#9654;", "method": "animate"}, {"args": [[null], {"frame": {"duration": 0, "redraw": true}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "&#9724;", "method": "animate"}], "direction": "left", "pad": {"r": 10, "t": 70}, "showactive": false, "type": "buttons", "x": 0.1, "xanchor": "right", "y": 0, "yanchor": "top"}]}}, "text/html": ["<div>                            <div id=\"30fefac8-13ae-475a-9192-d2a68edc0e9e\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"30fefac8-13ae-475a-9192-d2a68edc0e9e\")) {                    Plotly.newPlot(                        \"30fefac8-13ae-475a-9192-d2a68edc0e9e\",                        [{\"hovertemplate\":\"Lat=-30<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0],\"coloraxis\":\"coloraxis\",\"size\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[182.31,183.3,183.19,182.84,183.57,182.57,180.27,183.3,182.33,181.61,182.87,182.3,182.74,182.45,181.96,182.33,182.44,182.17,182.9,182.34,182.85,182.21,182.42,183.28,182.55,182.87,181.88,183.54,182.33,182.65,182.62,183.47,182.34,182.38,182.33,180.51,183.42,182.44,182.0,182.41,182.39,182.54,180.92,182.61,182.47,182.08,182.08,182.43,182.54,183.33,183.39,182.49,183.09,182.54,182.33,182.77,180.81,182.57,182.36,182.48,182.17,181.81,182.46,182.09,182.47,182.45,182.81,182.81,180.81,182.52,182.4,183.71,182.64,181.97,182.49,182.12,182.86,182.47,182.32,181.76,182.45,183.04,180.8,182.83,181.71,182.55,182.54,182.98,182.1,182.39,182.67,182.59,182.45,181.53,182.4,181.6,182.22,182.45,182.66,182.29,182.54,182.83,180.6,183.37,183.01,182.12,182.38,182.53,182.51,182.57,182.15,182.46,182.76,182.11,182.44,183.14,182.43,182.45,183.21,182.68,182.23,165.91,182.55,182.35,182.01,182.84,182.36,183.11,183.06,182.28,182.23,180.83,182.28,183.25,182.44,182.71,181.14,182.51,182.02,182.68,183.32,182.76,182.28,180.78,183.7,181.03,182.15,180.94,182.86,182.23,181.88,182.56,183.33,183.33,182.68,183.83,182.25,182.27,180.99,165.52,180.16,180.51,182.24,182.47,182.36,182.82,182.0,182.23,182.46,182.56,182.68,182.43,181.52,182.66,183.15,180.22,183.12,183.14,182.81,183.7,182.73,180.88,182.33,181.15,180.86,182.54,182.7,182.69,182.29,180.6,182.64,180.42,182.68,182.47,182.78,181.94,182.54,181.71,181.42,182.07,182.52,182.38,183.56,182.64,182.7,182.15,182.68,181.29,183.59,180.79,182.87,183.49,182.25,181.07,182.16,180.94,183.24,180.84,182.47,182.14,182.4,182.28,182.62,182.13,182.22,182.49,182.79,181.46,182.52,181.57,182.81,182.25,182.98,182.99,182.11,182.03,182.27,182.16,182.71,182.85,182.85,182.35,181.76,181.85,182.21,182.27,182.5,183.06,183.0,182.12,182.11,182.31,181.87,183.06,182.06,182.19,181.84,182.1,180.44,182.13,180.15,180.16,182.06,183.32,180.67,180.62,183.62,182.12,182.02,182.89,180.45,181.87,182.87,182.08,182.04,182.38,181.65,183.18,182.06,182.15,182.21,182.77,182.58,182.06,182.92,181.96,182.04,182.82,180.18,181.44,182.01,181.06,181.11,182.13,181.58,180.02,180.56,182.78,181.82,180.0,182.7,182.05,181.92,182.27,182.19,182.92,180.98,183.01,183.75,183.33,181.57,180.34,180.66,182.76,180.62,183.32,181.76,180.08,182.21,180.27,182.88,183.05,183.07,183.45,180.2,182.56,182.69],\"y\":[-30.0,-30.0,-30.01,-30.01,-30.01,-30.02,-30.03,-30.03,-30.03,-30.03,-30.03,-30.03,-30.03,-30.04,-30.04,-30.04,-30.05,-30.05,-30.05,-30.06,-30.06,-30.06,-30.06,-30.06,-30.06,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.08,-30.08,-30.08,-30.08,-30.09,-30.09,-30.1,-30.1,-30.11,-30.11,-30.11,-30.12,-30.12,-30.12,-30.12,-30.12,-30.12,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.14,-30.14,-30.14,-30.14,-30.15,-30.15,-30.15,-30.15,-30.15,-30.15,-30.16,-30.16,-30.17,-30.17,-30.17,-30.17,-30.18,-30.18,-30.19,-30.19,-30.19,-30.19,-30.19,-30.19,-30.19,-30.2,-30.2,-30.2,-30.2,-30.2,-30.21,-30.21,-30.21,-30.22,-30.22,-30.22,-30.23,-30.23,-30.23,-30.23,-30.23,-30.24,-30.24,-30.24,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.26,-30.26,-30.26,-30.27,-30.27,-30.27,-30.27,-30.27,-30.28,-30.28,-30.29,-30.29,-30.29,-30.3,-30.31,-30.31,-30.31,-30.31,-30.32,-30.32,-30.32,-30.33,-30.33,-30.33,-30.34,-30.34,-30.34,-30.34,-30.34,-30.34,-30.35,-30.35,-30.35,-30.36,-30.36,-30.36,-30.36,-30.37,-30.37,-30.37,-30.37,-30.37,-30.38,-30.38,-30.38,-30.38,-30.39,-30.39,-30.39,-30.39,-30.39,-30.39,-30.4,-30.4,-30.4,-30.4,-30.41,-30.41,-30.42,-30.42,-30.42,-30.43,-30.43,-30.43,-30.43,-30.43,-30.44,-30.44,-30.44,-30.44,-30.45,-30.45,-30.45,-30.45,-30.45,-30.46,-30.46,-30.46,-30.46,-30.46,-30.46,-30.47,-30.47,-30.48,-30.48,-30.49,-30.49,-30.49,-30.49,-30.49,-30.5,-30.5,-30.5,-30.51,-30.51,-30.52,-30.52,-30.52,-30.53,-30.53,-30.53,-30.53,-30.54,-30.54,-30.54,-30.55,-30.55,-30.55,-30.56,-30.56,-30.56,-30.56,-30.56,-30.56,-30.57,-30.57,-30.59,-30.59,-30.6,-30.6,-30.6,-30.61,-30.62,-30.62,-30.63,-30.63,-30.63,-30.64,-30.64,-30.64,-30.64,-30.65,-30.65,-30.66,-30.66,-30.66,-30.66,-30.67,-30.68,-30.68,-30.68,-30.68,-30.69,-30.69,-30.69,-30.69,-30.69,-30.69,-30.7,-30.7,-30.71,-30.71,-30.71,-30.71,-30.71,-30.71,-30.72,-30.74,-30.74,-30.74,-30.74,-30.75,-30.76,-30.76,-30.78,-30.78,-30.78,-30.79,-30.79,-30.79,-30.8,-30.81,-30.81,-30.81,-30.81,-30.82,-30.83,-30.83,-30.83,-30.84,-30.84,-30.84,-30.85,-30.85,-30.86,-30.86,-30.86,-30.86,-30.86,-30.87,-30.87,-30.87,-30.88,-30.88,-30.89,-30.9,-30.9,-30.9,-30.91,-30.91,-30.91,-30.91,-30.93,-30.93,-30.93,-30.95,-30.95,-30.96,-30.96,-30.98,-30.98,-30.98,-30.98],\"z\":[-44,-14,-22,-17,-35,-15,-340,-18,-55,-128,-26,-12,-32,-15,-15,-61,-15,-33,-35,-47,-23,-48,-52,-23,-42,-15,-29,-12,-40,-40,-42,-30,-52,-83,-35,-351,-18,-46,-20,-56,-39,-39,-36,-43,-47,-46,-51,-45,-42,-24,-20,-16,-21,-47,-57,-18,-16,-44,-49,-54,-54,-87,-55,-45,-46,-36,-28,-24,-16,-35,-50,-15,-31,-159,-40,-46,-28,-44,-44,-152,-54,-19,-322,-33,-27,-46,-56,-23,-55,-28,-44,-42,-18,-129,-49,-51,-49,-41,-30,-39,-44,-31,-30,-15,-15,-54,-38,-26,-51,-37,-58,-38,-28,-48,-51,-15,-44,-39,-20,-29,-45,-12,-41,-38,-46,-40,-46,-12,-15,-53,-61,-13,-49,-28,-48,-33,-243,-12,-45,-18,-15,-29,-50,-12,-49,-12,-62,-185,-41,-34,-72,-32,-28,-29,-31,-46,-49,-47,-12,-15,-319,-231,-37,-30,-32,-29,-28,-51,-38,-41,-15,-39,-92,-43,-22,-441,-15,-29,-29,-45,-24,-237,-87,-227,-15,-38,-26,-26,-47,-370,-32,-348,-27,-40,-28,-48,-29,-64,-14,-59,-57,-41,-18,-25,-29,-55,-31,-154,-15,-224,-15,-46,-24,-65,-29,-15,-15,-258,-37,-44,-52,-48,-51,-62,-47,-31,-31,-12,-32,-156,-34,-48,-23,-46,-52,-52,-50,-50,-22,-24,-36,-40,-34,-49,-46,-41,-35,-15,-12,-51,-52,-45,-45,-21,-55,-49,-53,-50,-364,-40,-421,-412,-56,-20,-139,-157,-15,-51,-42,-19,-15,-39,-19,-45,-51,-42,-138,-12,-38,-53,-58,-15,-42,-54,-12,-46,-53,-19,-391,-128,-51,-13,-15,-44,-144,-418,-15,-15,-28,-337,-15,-52,-62,-46,-86,-21,-51,-17,-12,-12,-129,-329,-15,-18,-263,-16,-108,-409,-48,-367,-18,-17,-12,-15,-398,-24,-20],\"type\":\"scatter3d\"}],                        {\"template\":{\"data\":{\"histogram2dcontour\":[{\"type\":\"histogram2dcontour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"choropleth\":[{\"type\":\"choropleth\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"histogram2d\":[{\"type\":\"histogram2d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmap\":[{\"type\":\"heatmap\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmapgl\":[{\"type\":\"heatmapgl\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"contourcarpet\":[{\"type\":\"contourcarpet\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"contour\":[{\"type\":\"contour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"surface\":[{\"type\":\"surface\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"mesh3d\":[{\"type\":\"mesh3d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"parcoords\":[{\"type\":\"parcoords\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolargl\":[{\"type\":\"scatterpolargl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"scattergeo\":[{\"type\":\"scattergeo\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolar\":[{\"type\":\"scatterpolar\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"scattergl\":[{\"type\":\"scattergl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatter3d\":[{\"type\":\"scatter3d\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattermapbox\":[{\"type\":\"scattermapbox\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterternary\":[{\"type\":\"scatterternary\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattercarpet\":[{\"type\":\"scattercarpet\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}]},\"layout\":{\"autotypenumbers\":\"strict\",\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"hovermode\":\"closest\",\"hoverlabel\":{\"align\":\"left\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"bgcolor\":\"#E5ECF6\",\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"ternary\":{\"bgcolor\":\"#E5ECF6\",\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]]},\"xaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"yaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"geo\":{\"bgcolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"subunitcolor\":\"white\",\"showland\":true,\"showlakes\":true,\"lakecolor\":\"white\"},\"title\":{\"x\":0.05},\"mapbox\":{\"style\":\"light\"}}},\"scene\":{\"domain\":{\"x\":[0.0,1.0],\"y\":[0.0,1.0]},\"xaxis\":{\"title\":{\"text\":\"Longitude\"},\"range\":[160,184]},\"yaxis\":{\"title\":{\"text\":\"Latitude\"},\"range\":[-50,-30]},\"zaxis\":{\"title\":{\"text\":\"Depth(km)\"},\"range\":[-600,0]}},\"coloraxis\":{\"colorbar\":{\"title\":{\"text\":\"Mag\"}},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"legend\":{\"tracegroupgap\":0,\"itemsizing\":\"constant\"},\"margin\":{\"t\":60},\"updatemenus\":[{\"buttons\":[{\"args\":[null,{\"frame\":{\"duration\":500,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":500,\"easing\":\"linear\"}}],\"label\":\"&#9654;\",\"method\":\"animate\"},{\"args\":[[null],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"&#9724;\",\"method\":\"animate\"}],\"direction\":\"left\",\"pad\":{\"r\":10,\"t\":70},\"showactive\":false,\"type\":\"buttons\",\"x\":0.1,\"xanchor\":\"right\",\"y\":0,\"yanchor\":\"top\"}],\"sliders\":[{\"active\":0,\"currentvalue\":{\"prefix\":\"Lat=\"},\"len\":0.9,\"pad\":{\"b\":10,\"t\":60},\"steps\":[{\"args\":[[\"-30\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-30\",\"method\":\"animate\"},{\"args\":[[\"-31\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-31\",\"method\":\"animate\"},{\"args\":[[\"-32\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-32\",\"method\":\"animate\"},{\"args\":[[\"-33\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-33\",\"method\":\"animate\"},{\"args\":[[\"-34\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-34\",\"method\":\"animate\"},{\"args\":[[\"-35\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-35\",\"method\":\"animate\"},{\"args\":[[\"-36\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-36\",\"method\":\"animate\"},{\"args\":[[\"-37\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-37\",\"method\":\"animate\"},{\"args\":[[\"-38\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-38\",\"method\":\"animate\"},{\"args\":[[\"-39\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-39\",\"method\":\"animate\"},{\"args\":[[\"-40\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-40\",\"method\":\"animate\"},{\"args\":[[\"-41\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-41\",\"method\":\"animate\"},{\"args\":[[\"-42\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-42\",\"method\":\"animate\"},{\"args\":[[\"-43\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-43\",\"method\":\"animate\"},{\"args\":[[\"-44\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-44\",\"method\":\"animate\"},{\"args\":[[\"-45\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-45\",\"method\":\"animate\"},{\"args\":[[\"-46\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-46\",\"method\":\"animate\"},{\"args\":[[\"-47\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-47\",\"method\":\"animate\"},{\"args\":[[\"-48\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-48\",\"method\":\"animate\"},{\"args\":[[\"-49\"],{\"frame\":{\"duration\":0,\"redraw\":true},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-49\",\"method\":\"animate\"}],\"x\":0.1,\"xanchor\":\"left\",\"y\":0,\"yanchor\":\"top\"}]},                        {\"responsive\": true}                    ).then(function(){\n", "                            Plotly.addFrames('30fefac8-13ae-475a-9192-d2a68edc0e9e', [{\"data\":[{\"hovertemplate\":\"Lat=-30<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0],\"coloraxis\":\"coloraxis\",\"size\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[182.31,183.3,183.19,182.84,183.57,182.57,180.27,183.3,182.33,181.61,182.87,182.3,182.74,182.45,181.96,182.33,182.44,182.17,182.9,182.34,182.85,182.21,182.42,183.28,182.55,182.87,181.88,183.54,182.33,182.65,182.62,183.47,182.34,182.38,182.33,180.51,183.42,182.44,182.0,182.41,182.39,182.54,180.92,182.61,182.47,182.08,182.08,182.43,182.54,183.33,183.39,182.49,183.09,182.54,182.33,182.77,180.81,182.57,182.36,182.48,182.17,181.81,182.46,182.09,182.47,182.45,182.81,182.81,180.81,182.52,182.4,183.71,182.64,181.97,182.49,182.12,182.86,182.47,182.32,181.76,182.45,183.04,180.8,182.83,181.71,182.55,182.54,182.98,182.1,182.39,182.67,182.59,182.45,181.53,182.4,181.6,182.22,182.45,182.66,182.29,182.54,182.83,180.6,183.37,183.01,182.12,182.38,182.53,182.51,182.57,182.15,182.46,182.76,182.11,182.44,183.14,182.43,182.45,183.21,182.68,182.23,165.91,182.55,182.35,182.01,182.84,182.36,183.11,183.06,182.28,182.23,180.83,182.28,183.25,182.44,182.71,181.14,182.51,182.02,182.68,183.32,182.76,182.28,180.78,183.7,181.03,182.15,180.94,182.86,182.23,181.88,182.56,183.33,183.33,182.68,183.83,182.25,182.27,180.99,165.52,180.16,180.51,182.24,182.47,182.36,182.82,182.0,182.23,182.46,182.56,182.68,182.43,181.52,182.66,183.15,180.22,183.12,183.14,182.81,183.7,182.73,180.88,182.33,181.15,180.86,182.54,182.7,182.69,182.29,180.6,182.64,180.42,182.68,182.47,182.78,181.94,182.54,181.71,181.42,182.07,182.52,182.38,183.56,182.64,182.7,182.15,182.68,181.29,183.59,180.79,182.87,183.49,182.25,181.07,182.16,180.94,183.24,180.84,182.47,182.14,182.4,182.28,182.62,182.13,182.22,182.49,182.79,181.46,182.52,181.57,182.81,182.25,182.98,182.99,182.11,182.03,182.27,182.16,182.71,182.85,182.85,182.35,181.76,181.85,182.21,182.27,182.5,183.06,183.0,182.12,182.11,182.31,181.87,183.06,182.06,182.19,181.84,182.1,180.44,182.13,180.15,180.16,182.06,183.32,180.67,180.62,183.62,182.12,182.02,182.89,180.45,181.87,182.87,182.08,182.04,182.38,181.65,183.18,182.06,182.15,182.21,182.77,182.58,182.06,182.92,181.96,182.04,182.82,180.18,181.44,182.01,181.06,181.11,182.13,181.58,180.02,180.56,182.78,181.82,180.0,182.7,182.05,181.92,182.27,182.19,182.92,180.98,183.01,183.75,183.33,181.57,180.34,180.66,182.76,180.62,183.32,181.76,180.08,182.21,180.27,182.88,183.05,183.07,183.45,180.2,182.56,182.69],\"y\":[-30.0,-30.0,-30.01,-30.01,-30.01,-30.02,-30.03,-30.03,-30.03,-30.03,-30.03,-30.03,-30.03,-30.04,-30.04,-30.04,-30.05,-30.05,-30.05,-30.06,-30.06,-30.06,-30.06,-30.06,-30.06,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.07,-30.08,-30.08,-30.08,-30.08,-30.09,-30.09,-30.1,-30.1,-30.11,-30.11,-30.11,-30.12,-30.12,-30.12,-30.12,-30.12,-30.12,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.13,-30.14,-30.14,-30.14,-30.14,-30.15,-30.15,-30.15,-30.15,-30.15,-30.15,-30.16,-30.16,-30.17,-30.17,-30.17,-30.17,-30.18,-30.18,-30.19,-30.19,-30.19,-30.19,-30.19,-30.19,-30.19,-30.2,-30.2,-30.2,-30.2,-30.2,-30.21,-30.21,-30.21,-30.22,-30.22,-30.22,-30.23,-30.23,-30.23,-30.23,-30.23,-30.24,-30.24,-30.24,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.25,-30.26,-30.26,-30.26,-30.27,-30.27,-30.27,-30.27,-30.27,-30.28,-30.28,-30.29,-30.29,-30.29,-30.3,-30.31,-30.31,-30.31,-30.31,-30.32,-30.32,-30.32,-30.33,-30.33,-30.33,-30.34,-30.34,-30.34,-30.34,-30.34,-30.34,-30.35,-30.35,-30.35,-30.36,-30.36,-30.36,-30.36,-30.37,-30.37,-30.37,-30.37,-30.37,-30.38,-30.38,-30.38,-30.38,-30.39,-30.39,-30.39,-30.39,-30.39,-30.39,-30.4,-30.4,-30.4,-30.4,-30.41,-30.41,-30.42,-30.42,-30.42,-30.43,-30.43,-30.43,-30.43,-30.43,-30.44,-30.44,-30.44,-30.44,-30.45,-30.45,-30.45,-30.45,-30.45,-30.46,-30.46,-30.46,-30.46,-30.46,-30.46,-30.47,-30.47,-30.48,-30.48,-30.49,-30.49,-30.49,-30.49,-30.49,-30.5,-30.5,-30.5,-30.51,-30.51,-30.52,-30.52,-30.52,-30.53,-30.53,-30.53,-30.53,-30.54,-30.54,-30.54,-30.55,-30.55,-30.55,-30.56,-30.56,-30.56,-30.56,-30.56,-30.56,-30.57,-30.57,-30.59,-30.59,-30.6,-30.6,-30.6,-30.61,-30.62,-30.62,-30.63,-30.63,-30.63,-30.64,-30.64,-30.64,-30.64,-30.65,-30.65,-30.66,-30.66,-30.66,-30.66,-30.67,-30.68,-30.68,-30.68,-30.68,-30.69,-30.69,-30.69,-30.69,-30.69,-30.69,-30.7,-30.7,-30.71,-30.71,-30.71,-30.71,-30.71,-30.71,-30.72,-30.74,-30.74,-30.74,-30.74,-30.75,-30.76,-30.76,-30.78,-30.78,-30.78,-30.79,-30.79,-30.79,-30.8,-30.81,-30.81,-30.81,-30.81,-30.82,-30.83,-30.83,-30.83,-30.84,-30.84,-30.84,-30.85,-30.85,-30.86,-30.86,-30.86,-30.86,-30.86,-30.87,-30.87,-30.87,-30.88,-30.88,-30.89,-30.9,-30.9,-30.9,-30.91,-30.91,-30.91,-30.91,-30.93,-30.93,-30.93,-30.95,-30.95,-30.96,-30.96,-30.98,-30.98,-30.98,-30.98],\"z\":[-44,-14,-22,-17,-35,-15,-340,-18,-55,-128,-26,-12,-32,-15,-15,-61,-15,-33,-35,-47,-23,-48,-52,-23,-42,-15,-29,-12,-40,-40,-42,-30,-52,-83,-35,-351,-18,-46,-20,-56,-39,-39,-36,-43,-47,-46,-51,-45,-42,-24,-20,-16,-21,-47,-57,-18,-16,-44,-49,-54,-54,-87,-55,-45,-46,-36,-28,-24,-16,-35,-50,-15,-31,-159,-40,-46,-28,-44,-44,-152,-54,-19,-322,-33,-27,-46,-56,-23,-55,-28,-44,-42,-18,-129,-49,-51,-49,-41,-30,-39,-44,-31,-30,-15,-15,-54,-38,-26,-51,-37,-58,-38,-28,-48,-51,-15,-44,-39,-20,-29,-45,-12,-41,-38,-46,-40,-46,-12,-15,-53,-61,-13,-49,-28,-48,-33,-243,-12,-45,-18,-15,-29,-50,-12,-49,-12,-62,-185,-41,-34,-72,-32,-28,-29,-31,-46,-49,-47,-12,-15,-319,-231,-37,-30,-32,-29,-28,-51,-38,-41,-15,-39,-92,-43,-22,-441,-15,-29,-29,-45,-24,-237,-87,-227,-15,-38,-26,-26,-47,-370,-32,-348,-27,-40,-28,-48,-29,-64,-14,-59,-57,-41,-18,-25,-29,-55,-31,-154,-15,-224,-15,-46,-24,-65,-29,-15,-15,-258,-37,-44,-52,-48,-51,-62,-47,-31,-31,-12,-32,-156,-34,-48,-23,-46,-52,-52,-50,-50,-22,-24,-36,-40,-34,-49,-46,-41,-35,-15,-12,-51,-52,-45,-45,-21,-55,-49,-53,-50,-364,-40,-421,-412,-56,-20,-139,-157,-15,-51,-42,-19,-15,-39,-19,-45,-51,-42,-138,-12,-38,-53,-58,-15,-42,-54,-12,-46,-53,-19,-391,-128,-51,-13,-15,-44,-144,-418,-15,-15,-28,-337,-15,-52,-62,-46,-86,-21,-51,-17,-12,-12,-129,-329,-15,-18,-263,-16,-108,-409,-48,-367,-18,-17,-12,-15,-398,-24,-20],\"type\":\"scatter3d\"}],\"name\":\"-30\"},{\"data\":[{\"hovertemplate\":\"Lat=-31<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[4.8,5.4,5.3,5.4,6.8,5.3,5.7,5.3,5.1,5.4,6.0,5.3,5.6,4.9,5.0,5.0,6.4,5.1,5.4,5.4,5.8,5.4,5.5,5.3,5.2,5.2,5.4,5.6,5.2,5.0,6.0,6.1,5.0,5.6,5.9,5.0,5.1,5.2,5.1,5.0,5.5,5.2,4.8,6.3,5.0,4.9,6.3,6.6,5.2,5.4,5.3,5.1,5.1,5.3,5.4,5.5,4.9,5.6,4.9,5.3,4.9,5.1,5.6,5.3,5.3,5.7,5.4,5.2,4.9,5.2,5.4,5.0,5.2,5.3,5.0,5.1,5.5,5.3,5.7,5.8,5.7,5.1,5.1,5.2,5.0,5.2,5.3,5.1,5.1,7.5,5.8,5.2,6.6,5.0,5.0,5.1,5.3,5.4,5.2,5.5,5.3,6.2,5.3,6.4,5.1,5.1,5.2,5.5,5.8,5.7,5.6,5.2,5.1,5.4,5.6,6.5,5.4,5.7,5.8,5.3,4.9,5.3,5.4,5.3,5.3,5.3,5.1,5.9,5.1,5.5,5.6,5.2,5.1,5.0,5.0,5.8,5.2,5.2,5.1,5.3,5.3,5.0,5.0,5.0,5.5,5.6,5.0,5.1,6.9,5.0,5.8,4.9,5.5,6.5,5.2,5.0,4.9,5.1,5.9,6.5,4.9,5.1,5.2,5.1,5.1,5.8,4.9,6.4,5.4,4.9,5.0,5.2,4.9,4.9,5.2,5.4,5.0,5.0,7.0,6.4,5.4,5.6,5.0,5.0,5.1,5.1,5.0,5.1,5.0,5.2,5.1,5.0],\"coloraxis\":\"coloraxis\",\"size\":[4.8,5.4,5.3,5.4,6.8,5.3,5.7,5.3,5.1,5.4,6.0,5.3,5.6,4.9,5.0,5.0,6.4,5.1,5.4,5.4,5.8,5.4,5.5,5.3,5.2,5.2,5.4,5.6,5.2,5.0,6.0,6.1,5.0,5.6,5.9,5.0,5.1,5.2,5.1,5.0,5.5,5.2,4.8,6.3,5.0,4.9,6.3,6.6,5.2,5.4,5.3,5.1,5.1,5.3,5.4,5.5,4.9,5.6,4.9,5.3,4.9,5.1,5.6,5.3,5.3,5.7,5.4,5.2,4.9,5.2,5.4,5.0,5.2,5.3,5.0,5.1,5.5,5.3,5.7,5.8,5.7,5.1,5.1,5.2,5.0,5.2,5.3,5.1,5.1,7.5,5.8,5.2,6.6,5.0,5.0,5.1,5.3,5.4,5.2,5.5,5.3,6.2,5.3,6.4,5.1,5.1,5.2,5.5,5.8,5.7,5.6,5.2,5.1,5.4,5.6,6.5,5.4,5.7,5.8,5.3,4.9,5.3,5.4,5.3,5.3,5.3,5.1,5.9,5.1,5.5,5.6,5.2,5.1,5.0,5.0,5.8,5.2,5.2,5.1,5.3,5.3,5.0,5.0,5.0,5.5,5.6,5.0,5.1,6.9,5.0,5.8,4.9,5.5,6.5,5.2,5.0,4.9,5.1,5.9,6.5,4.9,5.1,5.2,5.1,5.1,5.8,4.9,6.4,5.4,4.9,5.0,5.2,4.9,4.9,5.2,5.4,5.0,5.0,7.0,6.4,5.4,5.6,5.0,5.0,5.1,5.1,5.0,5.1,5.0,5.2,5.1,5.0],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[181.4,182.68,180.28,182.11,183.46,182.24,181.76,183.26,182.68,181.88,180.49,183.04,180.02,182.59,183.46,182.63,182.21,179.71,179.46,180.01,183.68,180.13,180.06,182.6,182.85,180.0,180.09,182.6,181.39,182.54,182.8,182.81,182.93,181.05,182.31,182.67,182.34,182.82,181.97,182.72,180.36,182.73,182.95,181.44,182.64,182.89,179.9,182.23,182.02,182.36,182.12,181.93,182.42,182.44,182.89,180.3,180.88,182.32,183.47,182.47,181.66,182.36,181.74,182.59,183.22,180.51,182.0,182.07,182.76,182.07,179.93,181.28,182.81,182.7,182.52,182.14,182.68,180.08,179.7,182.46,181.62,182.59,181.08,181.81,182.64,181.99,181.82,180.82,182.46,181.09,182.7,180.5,180.05,182.6,182.66,181.84,180.91,180.51,182.87,182.87,180.43,179.66,180.29,180.66,182.77,182.82,181.65,179.3,182.59,181.7,182.14,179.61,182.28,181.88,179.93,181.88,179.73,179.92,182.29,182.81,182.44,179.82,181.13,181.2,182.52,179.18,180.79,182.84,182.23,182.82,179.99,181.89,182.02,182.66,181.44,179.66,181.63,182.69,181.45,181.59,179.78,181.02,181.67,183.99,182.49,182.53,182.5,181.59,180.94,182.26,182.81,183.92,179.56,180.06,180.34,181.8,182.31,182.25,181.79,181.21,182.53,181.6,182.48,182.58,182.04,180.12,181.45,179.82,181.42,181.69,182.29,181.6,182.44,182.16,182.28,182.41,183.14,182.09,180.84,182.42,182.24,181.95,182.46,182.59,182.33,181.45,182.45,181.72,182.41,182.25,182.3,182.45],\"y\":[-31.0,-31.0,-31.01,-31.03,-31.03,-31.04,-31.05,-31.05,-31.05,-31.05,-31.06,-31.06,-31.07,-31.07,-31.07,-31.07,-31.07,-31.07,-31.07,-31.08,-31.08,-31.08,-31.09,-31.09,-31.09,-31.09,-31.1,-31.11,-31.11,-31.11,-31.11,-31.12,-31.12,-31.13,-31.14,-31.14,-31.15,-31.15,-31.15,-31.16,-31.17,-31.17,-31.17,-31.18,-31.18,-31.18,-31.18,-31.19,-31.19,-31.21,-31.22,-31.22,-31.22,-31.23,-31.23,-31.25,-31.25,-31.25,-31.25,-31.26,-31.26,-31.26,-31.27,-31.27,-31.27,-31.27,-31.28,-31.29,-31.29,-31.29,-31.29,-31.3,-31.31,-31.32,-31.32,-31.34,-31.34,-31.35,-31.35,-31.36,-31.36,-31.36,-31.36,-31.38,-31.38,-31.39,-31.39,-31.39,-31.41,-31.41,-31.41,-31.41,-31.42,-31.42,-31.43,-31.43,-31.43,-31.44,-31.44,-31.46,-31.46,-31.47,-31.48,-31.5,-31.5,-31.5,-31.51,-31.52,-31.53,-31.53,-31.53,-31.53,-31.54,-31.55,-31.55,-31.56,-31.57,-31.57,-31.58,-31.58,-31.58,-31.58,-31.6,-31.6,-31.6,-31.6,-31.61,-31.61,-31.61,-31.62,-31.62,-31.63,-31.63,-31.63,-31.63,-31.63,-31.64,-31.64,-31.65,-31.65,-31.65,-31.66,-31.66,-31.66,-31.67,-31.68,-31.68,-31.69,-31.7,-31.7,-31.71,-31.71,-31.72,-31.73,-31.73,-31.75,-31.75,-31.78,-31.79,-31.79,-31.79,-31.8,-31.81,-31.82,-31.83,-31.83,-31.84,-31.84,-31.85,-31.85,-31.85,-31.87,-31.87,-31.87,-31.9,-31.91,-31.91,-31.92,-31.92,-31.92,-31.92,-31.93,-31.93,-31.93,-31.93,-31.94,-31.95,-31.96,-31.98,-31.99,-31.99,-31.99],\"z\":[-30,-19,-298,-33,-19,-37,-16,-52,-22,-56,-10,-12,-394,-28,-12,-19,-35,-433,-413,-342,-32,-388,-341,-15,-13,-361,-428,-21,-122,-22,-14,-15,-28,-24,-22,-29,-41,-13,-53,-31,-15,-14,-20,-36,-24,-17,-453,-23,-39,-35,-33,-80,-18,-40,-12,-247,-187,-13,-20,-26,-61,-34,-15,-16,-14,-217,-143,-41,-22,-40,-391,-104,-13,-13,-21,-27,-14,-351,-454,-20,-15,-32,-94,-38,-14,-43,-49,-168,-15,-151,-14,-228,-367,-22,-23,-64,-12,-178,-12,-10,-230,-437,-194,-15,-18,-20,-55,-425,-10,-15,-15,-421,-27,-15,-428,-48,-232,-356,-20,-12,-24,-351,-43,-108,-33,-509,-151,-12,-23,-10,-15,-36,-37,-24,-103,-370,-59,-12,-67,-57,-352,-116,-62,-17,-14,-14,-20,-61,-119,-23,-12,-23,-439,-231,-240,-48,-28,-25,-52,-104,-23,-15,-18,-21,-38,-297,-54,-226,-35,-57,-21,-53,-21,-22,-17,-15,-26,-39,-117,-12,-18,-15,-28,-30,-20,-51,-14,-50,-23,-20,-20,-29],\"type\":\"scatter3d\"}],\"name\":\"-31\"},{\"data\":[{\"hovertemplate\":\"Lat=-32<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.4,5.4,7.1,5.1,5.3,5.0,5.1,5.4,5.2,5.5,6.2,5.3,5.9,5.4,4.9,5.1,6.1,5.3,5.2,5.6,5.1,5.4,5.5,5.3,5.3,4.8,5.1,5.0,5.7,5.7,5.3,6.3,5.6,5.1,5.2,5.3,6.1,5.4,5.1,4.9,5.4,5.2,5.8,5.1,5.5,5.5,5.9,6.1,5.9,6.3,5.1,5.0,5.6,5.4,5.2,5.5,5.4,5.2,5.1,5.2,5.3,5.0,5.0,5.0,5.2,5.7,5.4,5.4,5.0,5.4,5.6,5.2,5.1,5.4,5.1,4.9,5.2,5.7,5.2,5.6,5.3,5.5,4.8,5.2,5.2,5.0,5.5,5.3,5.6,5.8,5.7,5.1,5.4,5.4,5.0,5.6,5.1,5.6,5.4,5.8,5.7,5.4,5.4,5.2,5.0,5.8,5.7,6.1,5.2,6.1,5.0,5.8,5.0,5.5,4.9,5.1,5.3,5.2,5.4,6.0,5.6,5.2,5.2,5.6,5.7,5.1,5.5,5.1,5.8,5.0,5.2,5.8,5.1,5.2,5.3,5.5,5.2,5.2,5.3,4.9,5.1,5.1,5.4,6.4,5.2,6.7,5.4,5.4,5.2,5.0,5.8,4.8,5.4,5.2,5.4,5.1,5.9,5.3,5.2,5.1,5.0,5.3,6.1,6.5,5.2,5.3,5.0,5.5,5.3,5.0,6.0,5.7,5.5,5.3,6.2,5.3,5.2,5.1,5.9,5.2,4.9,5.3,5.0,5.0,5.2,5.2,5.4,5.1,5.6,4.9,5.1,4.9,5.4,6.0,5.5,4.9,5.7,5.1,5.5,5.4,5.9,5.5,5.7,5.2,5.0,5.3,5.3,5.1,6.4,5.5,5.5,5.0,5.2,5.2,5.6,5.2,5.1],\"coloraxis\":\"coloraxis\",\"size\":[5.4,5.4,7.1,5.1,5.3,5.0,5.1,5.4,5.2,5.5,6.2,5.3,5.9,5.4,4.9,5.1,6.1,5.3,5.2,5.6,5.1,5.4,5.5,5.3,5.3,4.8,5.1,5.0,5.7,5.7,5.3,6.3,5.6,5.1,5.2,5.3,6.1,5.4,5.1,4.9,5.4,5.2,5.8,5.1,5.5,5.5,5.9,6.1,5.9,6.3,5.1,5.0,5.6,5.4,5.2,5.5,5.4,5.2,5.1,5.2,5.3,5.0,5.0,5.0,5.2,5.7,5.4,5.4,5.0,5.4,5.6,5.2,5.1,5.4,5.1,4.9,5.2,5.7,5.2,5.6,5.3,5.5,4.8,5.2,5.2,5.0,5.5,5.3,5.6,5.8,5.7,5.1,5.4,5.4,5.0,5.6,5.1,5.6,5.4,5.8,5.7,5.4,5.4,5.2,5.0,5.8,5.7,6.1,5.2,6.1,5.0,5.8,5.0,5.5,4.9,5.1,5.3,5.2,5.4,6.0,5.6,5.2,5.2,5.6,5.7,5.1,5.5,5.1,5.8,5.0,5.2,5.8,5.1,5.2,5.3,5.5,5.2,5.2,5.3,4.9,5.1,5.1,5.4,6.4,5.2,6.7,5.4,5.4,5.2,5.0,5.8,4.8,5.4,5.2,5.4,5.1,5.9,5.3,5.2,5.1,5.0,5.3,6.1,6.5,5.2,5.3,5.0,5.5,5.3,5.0,6.0,5.7,5.5,5.3,6.2,5.3,5.2,5.1,5.9,5.2,4.9,5.3,5.0,5.0,5.2,5.2,5.4,5.1,5.6,4.9,5.1,4.9,5.4,6.0,5.5,4.9,5.7,5.1,5.5,5.4,5.9,5.5,5.7,5.2,5.0,5.3,5.3,5.1,6.4,5.5,5.5,5.0,5.2,5.2,5.6,5.2,5.1],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[180.57,182.33,180.05,182.5,181.45,182.38,182.6,180.14,182.31,182.01,182.38,182.82,182.62,180.02,182.28,182.33,179.43,181.44,181.32,181.93,181.68,182.38,182.85,179.88,180.92,183.05,182.4,182.35,181.69,182.19,182.37,182.4,181.8,181.3,182.32,180.49,179.23,180.1,182.47,182.31,180.3,181.43,182.38,182.42,181.86,182.39,180.55,182.29,182.35,182.34,180.41,182.42,182.73,180.4,179.76,180.45,182.45,180.47,181.52,182.23,180.89,182.37,182.38,182.51,180.92,181.37,180.25,180.5,180.39,182.48,181.86,181.46,182.36,180.39,181.38,182.45,181.63,182.75,182.75,180.62,182.36,182.18,182.28,181.95,182.05,182.42,181.99,182.0,182.05,182.03,182.27,181.96,182.73,181.63,182.11,182.03,181.26,182.3,182.25,182.14,182.19,182.61,182.49,182.25,182.31,182.26,182.4,181.23,182.1,181.27,182.3,182.33,182.15,182.21,180.25,182.57,181.29,182.29,182.5,181.28,180.53,181.14,180.2,181.27,179.57,182.27,182.25,182.44,180.6,181.91,181.78,182.2,182.1,180.87,180.92,181.56,181.89,181.94,180.91,181.56,182.01,181.42,181.75,182.29,181.58,181.14,181.49,181.42,181.75,181.91,181.16,181.83,181.85,179.74,181.14,179.07,181.88,182.2,181.9,181.38,181.83,181.93,181.14,181.22,181.94,181.32,180.02,181.66,181.94,181.97,182.23,181.86,181.15,182.09,182.27,182.08,181.29,181.98,180.72,182.3,181.97,181.82,181.17,181.83,181.32,181.95,180.99,182.26,181.14,181.71,181.19,181.96,182.07,179.94,181.81,182.06,179.96,181.98,180.95,182.04,182.24,180.98,181.87,181.97,182.12,182.29,181.23,182.24,182.31,181.05,179.77,182.27,179.8,179.87,181.94,182.29,181.99],\"y\":[-32.01,-32.01,-32.02,-32.02,-32.04,-32.04,-32.05,-32.05,-32.05,-32.06,-32.06,-32.06,-32.06,-32.07,-32.07,-32.07,-32.07,-32.08,-32.08,-32.09,-32.09,-32.09,-32.09,-32.09,-32.1,-32.1,-32.11,-32.11,-32.12,-32.13,-32.13,-32.15,-32.15,-32.15,-32.15,-32.16,-32.16,-32.17,-32.17,-32.17,-32.18,-32.19,-32.2,-32.2,-32.21,-32.21,-32.21,-32.22,-32.22,-32.23,-32.23,-32.23,-32.25,-32.25,-32.25,-32.26,-32.26,-32.26,-32.26,-32.28,-32.28,-32.28,-32.28,-32.28,-32.28,-32.29,-32.29,-32.3,-32.3,-32.31,-32.32,-32.32,-32.33,-32.34,-32.35,-32.35,-32.36,-32.37,-32.39,-32.39,-32.39,-32.39,-32.39,-32.39,-32.39,-32.39,-32.4,-32.4,-32.4,-32.4,-32.41,-32.41,-32.42,-32.42,-32.42,-32.42,-32.42,-32.42,-32.43,-32.44,-32.45,-32.45,-32.46,-32.46,-32.47,-32.48,-32.48,-32.49,-32.49,-32.49,-32.49,-32.5,-32.5,-32.51,-32.52,-32.53,-32.54,-32.54,-32.54,-32.54,-32.55,-32.58,-32.59,-32.6,-32.6,-32.61,-32.62,-32.62,-32.63,-32.63,-32.64,-32.65,-32.65,-32.67,-32.68,-32.68,-32.69,-32.69,-32.7,-32.71,-32.71,-32.71,-32.72,-32.72,-32.73,-32.73,-32.73,-32.73,-32.73,-32.73,-32.73,-32.74,-32.75,-32.75,-32.76,-32.76,-32.77,-32.77,-32.77,-32.77,-32.77,-32.78,-32.78,-32.78,-32.79,-32.79,-32.79,-32.8,-32.8,-32.8,-32.81,-32.81,-32.83,-32.83,-32.83,-32.83,-32.84,-32.84,-32.85,-32.85,-32.85,-32.85,-32.86,-32.86,-32.87,-32.88,-32.89,-32.89,-32.9,-32.9,-32.9,-32.9,-32.9,-32.9,-32.92,-32.92,-32.93,-32.94,-32.94,-32.94,-32.94,-32.94,-32.95,-32.95,-32.96,-32.96,-32.96,-32.96,-32.97,-32.97,-32.97,-32.98,-32.98,-32.98,-32.99,-32.99,-32.99],\"z\":[-65,-14,-345,-16,-49,-18,-39,-222,-16,-10,-16,-12,-13,-25,-15,-21,-455,-15,-54,-10,-53,-18,-12,-300,-36,-18,-31,-19,-15,-17,-18,-10,-14,-52,-28,-12,-353,-15,-14,-23,-263,-50,-15,-30,-10,-15,-15,-10,-14,-15,-12,-23,-10,-12,-15,-15,-12,-12,-53,-14,-123,-21,-30,-24,-12,-15,-15,-12,-13,-10,-15,-54,-22,-12,-47,-19,-15,-10,-10,-105,-33,-15,-13,-19,-25,-28,-19,-20,-18,-19,-15,-21,-15,-15,-23,-16,-51,-21,-20,-15,-15,-25,-12,-20,-36,-15,-13,-47,-16,-49,-19,-12,-29,-22,-160,-33,-37,-17,-12,-50,-129,-35,-252,-26,-360,-17,-28,-22,-90,-20,-30,-14,-22,-130,-38,-24,-24,-24,-40,-12,-22,-46,-15,-15,-15,-42,-12,-46,-28,-23,-47,-28,-20,-12,-44,-212,-15,-15,-18,-51,-28,-15,-50,-46,-18,-42,-20,-10,-23,-23,-15,-20,-43,-18,-12,-17,-63,-21,-42,-15,-21,-17,-53,-33,-49,-19,-29,-15,-47,-20,-48,-21,-17,-205,-13,-22,-31,-15,-59,-20,-15,-52,-15,-23,-15,-15,-46,-47,-51,-51,-249,-23,-254,-12,-15,-15,-22],\"type\":\"scatter3d\"}],\"name\":\"-32\"},{\"data\":[{\"hovertemplate\":\"Lat=-33<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.9,5.0,4.9,5.5,5.4,5.7,5.6,5.4,4.9,5.1,5.1,5.7,5.3,5.4,5.5,5.1,5.3,5.3,5.3,5.1,5.0,5.4,5.0,5.8,5.6,5.4,5.0,5.2,5.6,5.2,5.0,5.2,5.6,5.4,5.5,5.0,5.0,5.2,5.5,5.1,5.9,5.4,5.2,4.9,5.4,5.3,5.6,5.0,5.3,5.7,5.1,5.3,5.4,5.9,5.6,5.3,4.9,5.4,5.4,5.1,5.3,5.4,5.2,5.9,5.2,5.3,5.1,5.3,5.1,5.6,5.1,5.1,5.3,5.2,5.1,7.4,5.2,5.8,5.0,5.9,6.0,5.9,5.5,5.9,4.9,5.4,5.5,4.8,4.7,4.8,5.0,5.3,5.5,5.2,5.4,5.5,5.3,5.0,4.9,5.5,5.1,5.0,6.2,5.0,5.0,5.1,5.9,5.1,5.1,5.5,5.3,5.4,5.5,6.0,5.5,5.4,5.9,5.2,5.0,4.9,5.4,5.0,5.1,5.1,5.2,4.9,5.1,5.1,5.2,4.9,6.0,5.6,5.4,5.1,4.9,5.3,6.0,5.3,5.1,5.1,5.9,5.6,5.0,5.0,5.3,5.5,5.4,5.6],\"coloraxis\":\"coloraxis\",\"size\":[5.9,5.0,4.9,5.5,5.4,5.7,5.6,5.4,4.9,5.1,5.1,5.7,5.3,5.4,5.5,5.1,5.3,5.3,5.3,5.1,5.0,5.4,5.0,5.8,5.6,5.4,5.0,5.2,5.6,5.2,5.0,5.2,5.6,5.4,5.5,5.0,5.0,5.2,5.5,5.1,5.9,5.4,5.2,4.9,5.4,5.3,5.6,5.0,5.3,5.7,5.1,5.3,5.4,5.9,5.6,5.3,4.9,5.4,5.4,5.1,5.3,5.4,5.2,5.9,5.2,5.3,5.1,5.3,5.1,5.6,5.1,5.1,5.3,5.2,5.1,7.4,5.2,5.8,5.0,5.9,6.0,5.9,5.5,5.9,4.9,5.4,5.5,4.8,4.7,4.8,5.0,5.3,5.5,5.2,5.4,5.5,5.3,5.0,4.9,5.5,5.1,5.0,6.2,5.0,5.0,5.1,5.9,5.1,5.1,5.5,5.3,5.4,5.5,6.0,5.5,5.4,5.9,5.2,5.0,4.9,5.4,5.0,5.1,5.1,5.2,4.9,5.1,5.1,5.2,4.9,6.0,5.6,5.4,5.1,4.9,5.3,6.0,5.3,5.1,5.1,5.9,5.6,5.0,5.0,5.3,5.5,5.4,5.6],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[180.89,182.0,181.46,182.2,180.99,181.75,180.68,182.16,181.83,182.18,182.09,181.98,181.05,182.17,180.07,182.45,182.14,182.13,180.57,183.3,182.11,182.15,179.92,181.85,180.43,181.94,181.73,181.92,180.6,182.07,181.02,181.28,181.89,180.76,183.44,181.38,182.23,181.76,182.36,181.22,179.95,181.04,182.0,180.92,180.93,181.52,180.84,182.71,180.59,181.34,182.33,180.48,181.54,182.55,179.95,180.85,182.25,180.85,180.96,181.95,181.28,180.79,179.37,181.09,182.22,181.1,182.35,180.79,181.97,180.83,181.96,181.47,180.94,181.01,181.83,182.45,181.86,182.22,182.22,181.57,180.74,180.14,181.79,181.62,181.73,181.0,181.71,182.37,182.26,179.62,181.92,180.32,180.84,179.59,181.61,182.03,181.86,182.29,182.16,180.2,181.85,181.71,182.37,181.32,181.73,181.88,180.84,180.99,181.77,181.63,179.8,181.56,181.76,180.49,181.6,179.51,179.87,181.84,180.83,179.59,182.26,181.4,180.85,179.65,180.83,181.5,181.84,179.68,181.59,179.48,179.63,179.46,179.46,180.87,181.81,180.91,178.81,181.88,179.58,182.5,180.82,180.81,179.53,181.74,178.69,181.72,181.46,181.61],\"y\":[-33.0,-33.0,-33.01,-33.02,-33.02,-33.03,-33.03,-33.03,-33.03,-33.03,-33.03,-33.03,-33.04,-33.04,-33.04,-33.05,-33.05,-33.05,-33.06,-33.06,-33.06,-33.06,-33.06,-33.07,-33.08,-33.08,-33.08,-33.09,-33.09,-33.1,-33.1,-33.11,-33.11,-33.12,-33.12,-33.12,-33.14,-33.14,-33.15,-33.15,-33.15,-33.16,-33.16,-33.16,-33.17,-33.18,-33.18,-33.18,-33.19,-33.19,-33.19,-33.2,-33.2,-33.22,-33.22,-33.23,-33.23,-33.24,-33.25,-33.25,-33.27,-33.27,-33.27,-33.28,-33.28,-33.28,-33.28,-33.3,-33.32,-33.32,-33.33,-33.34,-33.35,-33.35,-33.38,-33.39,-33.41,-33.42,-33.43,-33.44,-33.47,-33.5,-33.5,-33.5,-33.52,-33.53,-33.53,-33.53,-33.53,-33.53,-33.56,-33.57,-33.58,-33.59,-33.6,-33.6,-33.61,-33.61,-33.61,-33.62,-33.62,-33.62,-33.63,-33.63,-33.63,-33.63,-33.65,-33.65,-33.65,-33.66,-33.66,-33.68,-33.69,-33.7,-33.7,-33.7,-33.7,-33.71,-33.71,-33.71,-33.72,-33.73,-33.74,-33.74,-33.76,-33.78,-33.79,-33.79,-33.8,-33.8,-33.82,-33.84,-33.86,-33.88,-33.88,-33.89,-33.89,-33.9,-33.9,-33.91,-33.91,-33.92,-33.92,-33.94,-33.94,-33.96,-33.97,-33.97],\"z\":[-40,-32,-37,-15,-56,-15,-121,-12,-23,-27,-19,-18,-55,-18,-168,-86,-17,-12,-67,-33,-20,-12,-12,-18,-60,-15,-21,-26,-23,-21,-47,-41,-21,-42,-15,-45,-24,-19,-15,-39,-10,-24,-19,-49,-56,-15,-49,-22,-17,-30,-17,-87,-18,-15,-12,-20,-22,-45,-58,-22,-30,-56,-223,-15,-15,-15,-19,-63,-13,-54,-24,-33,-57,-56,-16,-37,-20,-12,-21,-15,-44,-20,-15,-17,-24,-15,-15,-21,-19,-18,-22,-15,-59,-27,-53,-12,-18,-21,-21,-33,-22,-14,-55,-49,-21,-22,-42,-39,-27,-12,-154,-15,-15,-14,-12,-15,-161,-15,-43,-15,-12,-21,-56,-19,-12,-18,-21,-13,-17,-18,-200,-16,-12,-48,-50,-45,-282,-16,-12,-15,-41,-41,-12,-13,-262,-14,-15,-18],\"type\":\"scatter3d\"}],\"name\":\"-33\"},{\"data\":[{\"hovertemplate\":\"Lat=-34<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.4,5.0,4.8,5.2,4.9,5.3,5.7,5.5,5.5,5.8,5.1,5.0,5.0,5.4,5.4,5.5,5.3,5.0,5.2,5.6,6.1,5.0,5.1,5.6,5.7,6.6,5.7,5.2,5.1,5.3,5.5,5.3,5.1,6.5,5.2,5.3,4.9,5.6,5.1,5.0,4.9,5.1,5.0,5.0,6.1,5.3,5.6,5.9,5.2,5.6,5.4,5.3,5.4,5.2,5.0,5.2,5.2,6.8,5.6,5.3,6.1,5.3,5.5,5.6,5.9,5.2,5.4,5.4,5.4,5.2,5.7,5.1,5.4,5.6,5.1,5.0,5.2,5.5,5.1],\"coloraxis\":\"coloraxis\",\"size\":[5.4,5.0,4.8,5.2,4.9,5.3,5.7,5.5,5.5,5.8,5.1,5.0,5.0,5.4,5.4,5.5,5.3,5.0,5.2,5.6,6.1,5.0,5.1,5.6,5.7,6.6,5.7,5.2,5.1,5.3,5.5,5.3,5.1,6.5,5.2,5.3,4.9,5.6,5.1,5.0,4.9,5.1,5.0,5.0,6.1,5.3,5.6,5.9,5.2,5.6,5.4,5.3,5.4,5.2,5.0,5.2,5.2,6.8,5.6,5.3,6.1,5.3,5.5,5.6,5.9,5.2,5.4,5.4,5.4,5.2,5.7,5.1,5.4,5.6,5.1,5.0,5.2,5.5,5.1],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[181.87,180.87,182.91,179.51,179.57,179.48,181.06,180.14,181.49,178.99,179.76,179.3,179.41,178.8,181.1,180.24,182.28,181.89,179.7,180.31,181.69,181.43,181.51,179.59,179.71,180.17,179.18,180.9,181.4,181.5,181.44,181.29,181.26,179.33,181.0,181.31,180.55,179.25,181.49,180.34,180.33,181.73,178.3,181.2,181.79,181.96,180.21,180.32,179.15,179.98,180.27,181.51,181.05,181.32,181.29,179.7,179.14,181.6,180.62,181.93,180.07,178.82,181.05,180.3,182.02,181.1,180.49,181.06,178.84,181.06,178.82,179.19,181.32,181.21,181.25,180.24,181.24,180.91,179.63],\"y\":[-34.03,-34.03,-34.05,-34.05,-34.06,-34.07,-34.08,-34.08,-34.14,-34.14,-34.15,-34.16,-34.16,-34.22,-34.23,-34.24,-34.25,-34.26,-34.27,-34.29,-34.3,-34.32,-34.33,-34.35,-34.36,-34.4,-34.4,-34.42,-34.42,-34.43,-34.47,-34.49,-34.5,-34.51,-34.53,-34.56,-34.57,-34.6,-34.62,-34.62,-34.64,-34.65,-34.66,-34.67,-34.67,-34.68,-34.69,-34.71,-34.71,-34.72,-34.74,-34.74,-34.76,-34.76,-34.76,-34.77,-34.78,-34.79,-34.79,-34.8,-34.81,-34.81,-34.82,-34.84,-34.85,-34.85,-34.87,-34.87,-34.87,-34.89,-34.89,-34.91,-34.92,-34.93,-34.93,-34.94,-34.97,-34.98,-34.99],\"z\":[-12,-41,-15,-12,-13,-222,-222,-52,-15,-15,-111,-19,-27,-183,-15,-35,-15,-12,-119,-54,-63,-15,-15,-110,-155,-100,-15,-79,-27,-22,-17,-15,-24,-15,-28,-17,-45,-203,-54,-64,-85,-29,-188,-32,-14,-12,-27,-15,-160,-110,-15,-63,-22,-25,-27,-39,-109,-61,-31,-15,-30,-220,-17,-28,-38,-20,-15,-20,-162,-21,-201,-183,-58,-15,-22,-43,-19,-48,-86],\"type\":\"scatter3d\"}],\"name\":\"-34\"},{\"data\":[{\"hovertemplate\":\"Lat=-35<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.6,5.2,5.3,5.7,4.9,5.3,6.5,5.4,5.8,5.3,5.0,5.1,5.1,5.9,5.1,5.3,5.8,6.1,5.8,5.6,4.9,5.2,5.3,5.1,4.9,5.4,5.4,5.1,4.9,5.6,5.2,5.4,5.6,5.4,5.1,5.8,5.4,5.3,5.3,5.4,5.0,5.7,5.2,5.0,5.2,5.0,5.2,5.2,5.2,5.2,5.2,5.4,5.4,5.3,5.6,6.3,5.3,5.4],\"coloraxis\":\"coloraxis\",\"size\":[5.6,5.2,5.3,5.7,4.9,5.3,6.5,5.4,5.8,5.3,5.0,5.1,5.1,5.9,5.1,5.3,5.8,6.1,5.8,5.6,4.9,5.2,5.3,5.1,4.9,5.4,5.4,5.1,4.9,5.6,5.2,5.4,5.6,5.4,5.1,5.8,5.4,5.3,5.3,5.4,5.0,5.7,5.2,5.0,5.2,5.0,5.2,5.2,5.2,5.2,5.2,5.4,5.4,5.3,5.6,6.3,5.3,5.4],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[180.97,177.27,180.22,181.1,178.86,180.98,180.92,179.13,181.4,179.47,178.75,181.14,180.86,180.15,178.82,180.98,181.64,181.32,180.76,180.93,180.94,181.02,180.86,179.65,180.18,180.3,180.8,180.95,181.38,180.72,180.3,178.91,178.47,178.5,178.61,179.12,180.75,180.73,180.83,178.35,178.5,180.75,180.76,178.57,179.42,180.99,180.74,178.42,178.45,178.4,178.58,178.39,178.31,179.26,180.69,178.89,179.72,177.89],\"y\":[-35.0,-35.01,-35.02,-35.02,-35.03,-35.06,-35.08,-35.08,-35.09,-35.1,-35.12,-35.13,-35.14,-35.15,-35.15,-35.16,-35.17,-35.18,-35.19,-35.19,-35.19,-35.23,-35.23,-35.24,-35.25,-35.27,-35.28,-35.28,-35.34,-35.34,-35.35,-35.38,-35.42,-35.42,-35.43,-35.48,-35.49,-35.49,-35.5,-35.51,-35.52,-35.53,-35.53,-35.6,-35.62,-35.65,-35.65,-35.66,-35.66,-35.66,-35.67,-35.72,-35.75,-35.82,-35.83,-35.86,-35.92,-35.98],\"z\":[-30,-528,-42,-15,-18,-12,-56,-33,-12,-105,-220,-20,-20,-15,-16,-12,-15,-12,-15,-19,-23,-27,-25,-49,-41,-25,-18,-21,-21,-26,-15,-164,-15,-216,-171,-97,-19,-18,-25,-12,-194,-28,-22,-18,-85,-31,-21,-12,-12,-14,-12,-12,-14,-68,-15,-110,-15,-214],\"type\":\"scatter3d\"}],\"name\":\"-35\"},{\"data\":[{\"hovertemplate\":\"Lat=-36<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.1,5.9,5.1,5.4,5.4,5.4,5.6,5.6,5.7,5.7,5.8,5.3,5.4,5.3,5.1,5.0,6.1,5.4,5.4,5.8,5.1,5.4,5.7,5.1,6.8,5.2,5.3,5.0,7.1,5.6,5.4,4.9,5.4,5.4,5.1,4.9,5.6,4.9,5.2,5.5,5.4,5.0,5.3,5.3,5.7,5.3,5.5,5.4,5.4],\"coloraxis\":\"coloraxis\",\"size\":[5.1,5.9,5.1,5.4,5.4,5.4,5.6,5.6,5.7,5.7,5.8,5.3,5.4,5.3,5.1,5.0,6.1,5.4,5.4,5.8,5.1,5.4,5.7,5.1,6.8,5.2,5.3,5.0,7.1,5.6,5.4,4.9,5.4,5.4,5.1,4.9,5.6,4.9,5.2,5.5,5.4,5.0,5.3,5.3,5.7,5.3,5.5,5.4,5.4],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[180.29,178.2,180.06,177.49,177.6,180.78,177.62,177.58,177.48,177.62,177.53,179.08,177.59,176.91,177.41,177.4,178.78,177.35,180.77,180.87,181.02,177.26,178.89,181.15,177.47,176.72,179.82,178.35,180.92,180.91,176.92,177.2,180.14,176.59,177.85,180.72,176.78,180.96,177.85,179.82,176.57,179.07,180.66,177.86,177.6,180.12,180.59,177.22,176.69],\"y\":[-36.07,-36.1,-36.14,-36.19,-36.23,-36.25,-36.25,-36.28,-36.3,-36.31,-36.33,-36.35,-36.37,-36.38,-36.45,-36.45,-36.46,-36.5,-36.52,-36.53,-36.53,-36.56,-36.58,-36.62,-36.65,-36.65,-36.66,-36.69,-36.7,-36.73,-36.75,-36.76,-36.79,-36.79,-36.8,-36.81,-36.85,-36.87,-36.87,-36.87,-36.89,-36.89,-36.91,-36.91,-36.91,-36.92,-36.92,-36.94,-36.95],\"z\":[-26,-185,-25,-15,-24,-14,-10,-10,-10,-10,-10,-53,-10,-265,-12,-14,-83,-12,-15,-15,-17,-296,-15,-15,-19,-318,-15,-88,-59,-15,-39,-17,-20,-333,-185,-41,-210,-23,-130,-19,-283,-17,-15,-120,-153,-15,-15,-136,-360],\"type\":\"scatter3d\"}],\"name\":\"-36\"},{\"data\":[{\"hovertemplate\":\"Lat=-37<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.7,5.3,5.2,6.7,5.0,5.1,5.8,5.4,6.0,5.2,6.3,5.8,5.1,5.0,5.2,5.0,5.1,7.1,5.8,5.0,5.9,5.0,4.9,5.0,5.1,4.9,6.0,5.6,5.3,5.2,5.0,5.1,5.9,5.2,4.9,5.4,5.1,4.9,5.2,5.4,6.2,5.2,5.1,5.5,5.9,5.0,5.8,6.7,5.3,5.3,6.2,5.2,5.3,5.2,4.9,5.7,7.2,5.2,5.2,5.2,5.7,5.6,5.1,5.8,5.9,5.6,5.1,6.0,5.4,5.2,5.0,5.0,6.5,5.0,5.0,5.3,4.8,5.7,6.5,5.3,4.9,5.0,5.0,5.5],\"coloraxis\":\"coloraxis\",\"size\":[5.7,5.3,5.2,6.7,5.0,5.1,5.8,5.4,6.0,5.2,6.3,5.8,5.1,5.0,5.2,5.0,5.1,7.1,5.8,5.0,5.9,5.0,4.9,5.0,5.1,4.9,6.0,5.6,5.3,5.2,5.0,5.1,5.9,5.2,4.9,5.4,5.1,4.9,5.2,5.4,6.2,5.2,5.1,5.5,5.9,5.0,5.8,6.7,5.3,5.3,6.2,5.2,5.3,5.2,4.9,5.7,7.2,5.2,5.2,5.2,5.7,5.6,5.1,5.8,5.9,5.6,5.1,6.0,5.4,5.2,5.0,5.0,6.5,5.0,5.0,5.3,4.8,5.7,6.5,5.3,4.9,5.0,5.0,5.5],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[180.03,181.53,179.31,179.82,177.11,179.1,178.85,178.85,179.08,178.58,177.45,179.05,179.09,177.13,178.85,179.61,179.05,179.03,178.8,177.42,177.3,180.5,178.96,178.84,180.43,179.12,177.34,177.19,179.44,176.64,177.34,179.97,178.88,179.53,178.93,178.79,180.38,179.99,178.87,177.3,176.94,178.82,179.98,179.64,178.69,177.29,179.62,179.74,179.74,176.68,179.84,176.69,177.17,177.31,177.28,179.65,179.4,178.76,180.89,179.18,179.2,179.36,180.53,180.04,179.24,179.29,176.58,179.33,179.49,176.93,177.87,177.59,177.03,177.91,177.66,179.28,177.69,179.16,179.17,176.01,178.3,176.62,177.81,176.58],\"y\":[-37.01,-37.02,-37.03,-37.03,-37.05,-37.05,-37.07,-37.07,-37.08,-37.08,-37.09,-37.09,-37.09,-37.1,-37.1,-37.14,-37.15,-37.19,-37.23,-37.3,-37.31,-37.32,-37.32,-37.32,-37.33,-37.33,-37.33,-37.35,-37.35,-37.36,-37.36,-37.36,-37.37,-37.38,-37.4,-37.43,-37.44,-37.44,-37.44,-37.45,-37.46,-37.46,-37.47,-37.49,-37.5,-37.5,-37.51,-37.51,-37.52,-37.53,-37.55,-37.56,-37.58,-37.59,-37.6,-37.61,-37.61,-37.62,-37.63,-37.64,-37.65,-37.66,-37.67,-37.69,-37.7,-37.7,-37.71,-37.73,-37.76,-37.77,-37.8,-37.82,-37.82,-37.82,-37.85,-37.86,-37.87,-37.89,-37.89,-37.92,-37.93,-37.93,-37.94,-37.98],\"z\":[-15,-33,-15,-15,-202,-37,-20,-12,-21,-33,-15,-27,-47,-163,-15,-24,-32,-28,-26,-152,-20,-27,-39,-36,-15,-23,-131,-15,-15,-183,-156,-17,-37,-15,-29,-25,-16,-28,-22,-146,-15,-22,-12,-12,-18,-21,-12,-21,-12,-288,-10,-165,-13,-15,-104,-12,-15,-15,-15,-15,-15,-15,-24,-15,-15,-49,-15,-15,-15,-163,-49,-94,-15,-63,-50,-15,-65,-15,-15,-293,-21,-12,-50,-12],\"type\":\"scatter3d\"}],\"name\":\"-37\"},{\"data\":[{\"hovertemplate\":\"Lat=-38<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.3,5.6,6.1,4.9,5.2,5.0,5.1,5.7,5.1,5.0,5.0,5.2,5.4,5.0,5.3,6.4,5.2,5.1,5.5,5.2,5.2,6.4,5.7,6.1,5.6,5.0,4.9,4.9,5.1,5.6,5.7,4.9,5.4,5.0,5.5,5.2,6.0,5.3,6.6,5.2,5.2],\"coloraxis\":\"coloraxis\",\"size\":[5.3,5.6,6.1,4.9,5.2,5.0,5.1,5.7,5.1,5.0,5.0,5.2,5.4,5.0,5.3,6.4,5.2,5.1,5.5,5.2,5.2,6.4,5.7,6.1,5.6,5.0,4.9,4.9,5.1,5.6,5.7,4.9,5.4,5.0,5.5,5.2,6.0,5.3,6.6,5.2,5.2],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[178.9,178.19,177.32,177.8,175.82,176.68,176.7,178.53,179.67,176.45,177.63,177.78,180.33,175.9,177.51,176.08,176.18,177.77,175.4,176.29,176.42,178.06,175.29,175.78,176.03,176.56,176.17,176.09,180.35,175.68,176.12,178.58,174.86,177.55,178.85,176.01,177.01,176.09,178.4,178.13,177.42],\"y\":[-38.03,-38.05,-38.1,-38.1,-38.13,-38.13,-38.18,-38.19,-38.24,-38.24,-38.26,-38.28,-38.29,-38.29,-38.3,-38.31,-38.31,-38.39,-38.41,-38.45,-38.45,-38.46,-38.47,-38.49,-38.49,-38.49,-38.49,-38.51,-38.57,-38.63,-38.64,-38.66,-38.76,-38.82,-38.85,-38.86,-38.88,-38.88,-38.92,-38.95,-38.96],\"z\":[-46,-15,-78,-77,-169,-93,-164,-22,-12,-150,-33,-33,-33,-175,-43,-165,-184,-31,-248,-33,-122,-15,-276,-158,-159,-100,-138,-134,-12,-159,-119,-14,-216,-25,-16,-13,-40,-68,-30,-28,-33],\"type\":\"scatter3d\"}],\"name\":\"-38\"},{\"data\":[{\"hovertemplate\":\"Lat=-39<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[6.2,5.1,5.0,5.2,5.3,5.4,5.1,5.1,5.8,5.1,5.0,5.5,5.5,5.4,5.7,5.5,5.7,5.1],\"coloraxis\":\"coloraxis\",\"size\":[6.2,5.1,5.0,5.2,5.3,5.4,5.1,5.1,5.8,5.1,5.0,5.5,5.5,5.4,5.7,5.5,5.7,5.1],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[174.94,177.86,175.74,180.69,175.88,175.91,178.78,175.19,174.22,178.5,175.46,177.68,175.96,176.91,176.83,176.76,176.49,174.71],\"y\":[-39.07,-39.09,-39.11,-39.13,-39.14,-39.25,-39.33,-39.4,-39.46,-39.47,-39.48,-39.55,-39.6,-39.67,-39.68,-39.7,-39.73,-39.94],\"z\":[-226,-20,-104,-18,-96,-49,-21,-116,-216,-12,-63,-26,-30,-26,-22,-17,-21,-131],\"type\":\"scatter3d\"}],\"name\":\"-39\"},{\"data\":[{\"hovertemplate\":\"Lat=-40<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.2,6.3,5.4,5.1,5.4,5.4,6.4,5.2,5.0,5.3,5.4,5.0,5.8,5.6,5.2,5.1,5.4,5.2,5.4,5.0,5.6,6.3,5.6,5.6,6.3,6.0,5.9,5.3],\"coloraxis\":\"coloraxis\",\"size\":[5.2,6.3,5.4,5.1,5.4,5.4,6.4,5.2,5.0,5.3,5.4,5.0,5.8,5.6,5.2,5.1,5.4,5.2,5.4,5.0,5.6,6.3,5.6,5.6,6.3,6.0,5.9,5.3],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[176.66,173.63,176.33,179.01,173.66,175.27,176.53,173.68,175.06,176.13,176.66,176.98,174.98,174.09,176.28,173.42,176.02,176.07,175.66,174.46,176.29,175.8,174.94,176.47,176.09,177.58,174.17,175.47],\"y\":[-40.04,-40.05,-40.08,-40.13,-40.17,-40.18,-40.23,-40.41,-40.43,-40.44,-40.45,-40.5,-40.52,-40.54,-40.56,-40.56,-40.57,-40.6,-40.63,-40.63,-40.65,-40.67,-40.69,-40.69,-40.76,-40.79,-40.89,-40.93],\"z\":[-21,-230,-27,-24,-153,-45,-16,-94,-48,-38,-15,-31,-26,-114,-32,-185,-25,-55,-15,-88,-30,-24,-70,-24,-32,-12,-90,-46],\"type\":\"scatter3d\"}],\"name\":\"-40\"},{\"data\":[{\"hovertemplate\":\"Lat=-41<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[4.9,5.1,5.4,5.2,5.3,5.2,5.2,5.2,5.3,5.4,5.1,5.1,5.5,5.3,5.0,6.5,5.9,4.9,5.4,5.3,5.7,5.9,5.5,5.6,6.1,5.7,6.6,5.9,5.2,5.6,5.5,5.1,5.4,5.4,5.3,5.2,5.5],\"coloraxis\":\"coloraxis\",\"size\":[4.9,5.1,5.4,5.2,5.3,5.2,5.2,5.2,5.3,5.4,5.1,5.1,5.5,5.3,5.0,6.5,5.9,4.9,5.4,5.3,5.7,5.9,5.5,5.6,6.1,5.7,6.6,5.9,5.2,5.6,5.5,5.1,5.4,5.4,5.3,5.2,5.5],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[175.32,178.68,175.48,173.34,175.16,173.4,174.08,176.02,174.33,175.35,176.14,175.79,174.37,172.52,174.29,174.17,173.71,174.47,174.13,174.1,174.2,174.0,174.26,174.25,174.29,171.7,174.04,174.17,174.03,173.93,175.62,174.32,174.22,173.96,171.43,173.14,172.82],\"y\":[-41.05,-41.11,-41.15,-41.19,-41.21,-41.28,-41.38,-41.42,-41.55,-41.56,-41.56,-41.56,-41.58,-41.61,-41.61,-41.63,-41.65,-41.65,-41.68,-41.69,-41.71,-41.72,-41.73,-41.75,-41.76,-41.76,-41.76,-41.76,-41.77,-41.82,-41.84,-41.84,-41.84,-41.84,-41.9,-41.91,-41.98],\"z\":[-29,-34,-15,-79,-31,-60,-69,-19,-15,-20,-27,-18,-17,-93,-15,-12,-75,-20,-17,-17,-13,-15,-18,-19,-26,-15,-12,-17,-19,-12,-15,-28,-25,-21,-15,-52,-64],\"type\":\"scatter3d\"}],\"name\":\"-41\"},{\"data\":[{\"hovertemplate\":\"Lat=-42<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[6.1,5.8,7.8,5.2,5.7,4.9,4.9,5.1,5.7,5.2,5.0,5.7,5.1,5.2,6.0,5.3,5.0,6.4,5.0,5.1,5.0,5.2,4.9,5.5,6.1,6.7,5.6],\"coloraxis\":\"coloraxis\",\"size\":[6.1,5.8,7.8,5.2,5.7,4.9,4.9,5.1,5.7,5.2,5.0,5.7,5.1,5.2,6.0,5.3,5.0,6.4,5.0,5.1,5.0,5.2,4.9,5.5,6.1,6.7,5.6],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[173.07,171.86,173.85,173.81,172.74,177.92,173.75,173.95,173.86,172.98,173.69,173.74,173.43,173.62,172.78,172.9,173.73,173.07,171.54,173.89,172.67,172.97,173.95,172.85,171.76,171.47,171.18],\"y\":[-42.02,-42.03,-42.03,-42.18,-42.19,-42.2,-42.21,-42.25,-42.28,-42.3,-42.31,-42.32,-42.32,-42.4,-42.41,-42.41,-42.42,-42.44,-42.46,-42.47,-42.62,-42.67,-42.72,-42.85,-42.88,-42.94,-42.98],\"z\":[-48,-15,-19,-19,-15,-28,-26,-22,-12,-12,-16,-19,-19,-21,-15,-31,-19,-12,-59,-20,-12,-12,-22,-12,-15,-15,-12],\"type\":\"scatter3d\"}],\"name\":\"-42\"},{\"data\":[{\"hovertemplate\":\"Lat=-43<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.5,4.9,5.9,5.2,5.4,5.6,5.7,5.1,5.2,5.5,5.6,6.0,5.1,5.2,5.8,7.0,4.8,5.0,4.8,5.0,4.9,6.1,4.9,5.2,5.4,4.9,5.7,4.9,5.4,5.4,5.2,5.0,6.1],\"coloraxis\":\"coloraxis\",\"size\":[5.5,4.9,5.9,5.2,5.4,5.6,5.7,5.1,5.2,5.5,5.6,6.0,5.1,5.2,5.8,7.0,4.8,5.0,4.8,5.0,4.9,6.1,4.9,5.2,5.4,4.9,5.7,4.9,5.4,5.4,5.2,5.0,6.1],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[171.61,173.04,171.54,171.48,171.81,171.8,172.54,172.31,172.62,172.56,172.55,172.62,172.78,172.69,172.58,172.12,172.28,172.31,172.7,172.73,171.91,172.52,172.74,172.44,172.69,172.85,172.56,172.68,169.62,168.81,169.23,168.75,170.66],\"y\":[-43.01,-43.19,-43.24,-43.33,-43.38,-43.47,-43.48,-43.49,-43.49,-43.5,-43.5,-43.52,-43.52,-43.53,-43.55,-43.56,-43.56,-43.56,-43.56,-43.59,-43.6,-43.6,-43.6,-43.61,-43.61,-43.67,-43.67,-43.68,-43.8,-43.88,-43.91,-43.93,-43.95],\"z\":[-15,-12,-15,-10,-15,-15,-12,-12,-12,-12,-12,-12,-17,-12,-12,-12,-12,-14,-12,-12,-12,-12,-12,-12,-12,-13,-12,-16,-15,-12,-15,-12,-10],\"type\":\"scatter3d\"}],\"name\":\"-43\"},{\"data\":[{\"hovertemplate\":\"Lat=-44<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.4,5.8,5.3,5.6,4.8,4.9,5.5,5.6,5.0,4.9,5.6,5.1,5.0,6.1,6.8,5.2,6.6,6.7,5.0,5.6,5.0,5.3],\"coloraxis\":\"coloraxis\",\"size\":[5.4,5.8,5.3,5.6,4.8,4.9,5.5,5.6,5.0,4.9,5.6,5.1,5.0,6.1,6.8,5.2,6.6,6.7,5.0,5.6,5.0,5.3],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[168.42,168.55,167.91,166.93,167.66,169.97,167.71,168.73,167.51,167.38,167.39,167.34,167.21,167.25,167.24,166.15,167.63,167.05,167.54,167.0,166.59,167.32],\"y\":[-44.1,-44.13,-44.18,-44.34,-44.38,-44.39,-44.41,-44.42,-44.44,-44.48,-44.56,-44.57,-44.59,-44.62,-44.71,-44.73,-44.75,-44.82,-44.87,-44.88,-44.9,-44.94],\"z\":[-15,-15,-15,-15,-21,-12,-15,-14,-24,-24,-17,-18,-27,-19,-19,-15,-15,-62,-86,-14,-40,-116],\"type\":\"scatter3d\"}],\"name\":\"-44\"},{\"data\":[{\"hovertemplate\":\"Lat=-45<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.4,7.2,6.1,7.0,6.4,5.5,5.2,5.5,5.2,6.5,4.9,5.2,5.5,5.2,5.4,5.1,5.2,5.3,5.1,5.5,5.1,6.1,5.2,5.0,5.6,7.8,5.2,5.0],\"coloraxis\":\"coloraxis\",\"size\":[5.4,7.2,6.1,7.0,6.4,5.5,5.2,5.5,5.2,6.5,4.9,5.2,5.5,5.2,5.4,5.1,5.2,5.3,5.1,5.5,5.1,6.1,5.2,5.0,5.6,7.8,5.2,5.0],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[167.23,166.87,166.7,166.73,166.6,166.52,166.62,166.68,166.68,166.59,166.44,166.44,167.64,166.61,166.46,166.36,165.97,166.07,166.75,166.02,166.42,166.13,166.72,166.12,166.73,166.26,165.82,165.76],\"y\":[-45.01,-45.01,-45.02,-45.04,-45.06,-45.08,-45.1,-45.14,-45.17,-45.2,-45.23,-45.24,-45.25,-45.35,-45.37,-45.38,-45.39,-45.41,-45.43,-45.44,-45.46,-45.48,-45.56,-45.57,-45.6,-45.85,-45.9,-45.91],\"z\":[-15,-32,-20,-15,-15,-49,-12,-27,-101,-18,-23,-24,-122,-15,-18,-17,-14,-12,-93,-12,-22,-12,-112,-31,-15,-23,-25,-21],\"type\":\"scatter3d\"}],\"name\":\"-45\"},{\"data\":[{\"hovertemplate\":\"Lat=-46<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.0,5.7,5.1,5.6,5.8,5.8,5.4,5.0,7.1,6.2,7.3,6.0,5.2,5.4,5.0,5.0,5.2],\"coloraxis\":\"coloraxis\",\"size\":[5.0,5.7,5.1,5.6,5.8,5.8,5.4,5.0,7.1,6.2,7.3,6.0,5.2,5.4,5.0,5.0,5.2],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[165.72,165.82,165.84,166.09,165.74,165.85,165.75,165.67,164.91,164.64,165.77,165.38,165.22,165.27,165.32,165.04,165.69],\"y\":[-46.01,-46.02,-46.04,-46.06,-46.1,-46.12,-46.13,-46.21,-46.36,-46.49,-46.54,-46.62,-46.64,-46.65,-46.73,-46.94,-46.97],\"z\":[-13,-20,-26,-15,-23,-18,-21,-29,-40,-10,-20,-19,-23,-18,-33,-32,-41],\"type\":\"scatter3d\"}],\"name\":\"-46\"},{\"data\":[{\"hovertemplate\":\"Lat=-47<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.0,5.0,5.2,5.9,4.9,5.5,5.5,4.9,5.2,5.8,4.9,5.1,5.0,5.6],\"coloraxis\":\"coloraxis\",\"size\":[5.0,5.0,5.2,5.9,4.9,5.5,5.5,4.9,5.2,5.8,4.9,5.1,5.0,5.6],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[165.43,165.04,165.96,165.14,165.43,164.59,164.62,165.1,165.11,165.08,165.26,164.74,164.42,164.53],\"y\":[-47.16,-47.17,-47.43,-47.48,-47.52,-47.56,-47.64,-47.68,-47.73,-47.8,-47.89,-47.91,-47.94,-47.96],\"z\":[-22,-29,-33,-15,-18,-15,-15,-12,-13,-12,-19,-17,-21,-15],\"type\":\"scatter3d\"}],\"name\":\"-47\"},{\"data\":[{\"hovertemplate\":\"Lat=-48<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.2,5.7,5.1,5.6,5.3,5.3,5.1,5.3,5.4,5.5,7.6,4.9,5.0],\"coloraxis\":\"coloraxis\",\"size\":[5.2,5.7,5.1,5.6,5.3,5.3,5.1,5.3,5.4,5.5,7.6,4.9,5.0],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[165.5,163.65,164.19,164.51,164.51,164.56,164.24,164.2,163.86,164.15,164.39,164.13,163.89],\"y\":[-48.17,-48.33,-48.53,-48.61,-48.62,-48.71,-48.74,-48.74,-48.9,-48.92,-48.94,-48.96,-48.99],\"z\":[-15,-15,-14,-22,-21,-30,-18,-12,-15,-15,-33,-21,-14],\"type\":\"scatter3d\"}],\"name\":\"-48\"},{\"data\":[{\"hovertemplate\":\"Lat=-49<br>Longitude=%{x}<br>Latitude=%{y}<br>Depth(km)=%{z}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.7,5.0,6.0,4.9,5.4,5.1,5.9,5.6,5.4,5.2,5.2,6.1,5.7,5.1,5.3,6.6,7.5,6.6,5.5,6.0,4.8,5.1,5.7,5.7,5.7,5.4,5.4,5.2,5.3,5.4,5.0,4.9,5.1,5.1,5.2,5.4,5.4,5.0,8.1,6.2,6.0],\"coloraxis\":\"coloraxis\",\"size\":[5.7,5.0,6.0,4.9,5.4,5.1,5.9,5.6,5.4,5.2,5.2,6.1,5.7,5.1,5.3,6.6,7.5,6.6,5.5,6.0,4.8,5.1,5.7,5.7,5.7,5.4,5.4,5.2,5.3,5.4,5.0,4.9,5.1,5.1,5.2,5.4,5.4,5.0,8.1,6.2,6.0],\"sizemode\":\"area\",\"sizeref\":0.036,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"scene\":\"scene\",\"showlegend\":false,\"x\":[164.11,164.26,164.03,161.07,163.89,164.32,164.03,164.01,164.33,164.24,163.98,164.19,164.14,164.38,164.27,163.99,164.1,164.01,162.99,163.79,175.17,163.47,163.8,163.71,163.88,163.35,160.85,163.5,163.47,162.91,163.47,163.26,163.48,163.33,163.07,163.35,163.92,163.47,161.25,163.25,163.2],\"y\":[-49.01,-49.02,-49.03,-49.04,-49.05,-49.08,-49.12,-49.13,-49.13,-49.13,-49.16,-49.16,-49.16,-49.2,-49.22,-49.24,-49.26,-49.36,-49.38,-49.48,-49.53,-49.54,-49.58,-49.61,-49.61,-49.65,-49.68,-49.71,-49.73,-49.74,-49.74,-49.78,-49.79,-49.79,-49.8,-49.82,-49.83,-49.85,-49.91,-49.93,-49.93],\"z\":[-15,-33,-18,-14,-12,-38,-12,-15,-24,-39,-15,-26,-34,-42,-35,-32,-13,-31,-15,-15,-20,-12,-15,-25,-23,-15,-12,-12,-19,-15,-21,-25,-12,-22,-15,-14,-15,-21,-27,-12,-19],\"type\":\"scatter3d\"}],\"name\":\"-49\"}]);\n", "                        }).then(function(){\n", "                            \n", "var gd = document.getElementById('30fefac8-13ae-475a-9192-d2a68edc0e9e');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["import plotly.express as px\n", "df = pd.read_excel('data/meca_all.xlsx')\n", "px.scatter_3d(df, x=\"Longitude\", y=\"Latitude\", z=\"Depth(km)\", animation_frame=\"Lat\", \n", "           size=\"Mag\", color=\"Mag\", size_max=15, range_x=[160,184], range_y=[-50,-30], range_z=[-600,0])"]}, {"cell_type": "markdown", "metadata": {}, "source": ["### 3. Create a Latitude-migrated focus cross section plot \n", "You could see the subducting plate changes dip direction from westward to eastward down the latitude."]}, {"cell_type": "code", "execution_count": 6, "metadata": {}, "outputs": [{"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"hovertemplate": "Lat=-30<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5], "coloraxis": "coloraxis", "size": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [182.31, 183.3, 183.19, 182.84, 183.57, 182.57, 180.27, 183.3, 182.33, 181.61, 182.87, 182.3, 182.74, 182.45, 181.96, 182.33, 182.44, 182.17, 182.9, 182.34, 182.85, 182.21, 182.42, 183.28, 182.55, 182.87, 181.88, 183.54, 182.33, 182.65, 182.62, 183.47, 182.34, 182.38, 182.33, 180.51, 183.42, 182.44, 182, 182.41, 182.39, 182.54, 180.92, 182.61, 182.47, 182.08, 182.08, 182.43, 182.54, 183.33, 183.39, 182.49, 183.09, 182.54, 182.33, 182.77, 180.81, 182.57, 182.36, 182.48, 182.17, 181.81, 182.46, 182.09, 182.47, 182.45, 182.81, 182.81, 180.81, 182.52, 182.4, 183.71, 182.64, 181.97, 182.49, 182.12, 182.86, 182.47, 182.32, 181.76, 182.45, 183.04, 180.8, 182.83, 181.71, 182.55, 182.54, 182.98, 182.1, 182.39, 182.67, 182.59, 182.45, 181.53, 182.4, 181.6, 182.22, 182.45, 182.66, 182.29, 182.54, 182.83, 180.6, 183.37, 183.01, 182.12, 182.38, 182.53, 182.51, 182.57, 182.15, 182.46, 182.76, 182.11, 182.44, 183.14, 182.43, 182.45, 183.21, 182.68, 182.23, 165.91, 182.55, 182.35, 182.01, 182.84, 182.36, 183.11, 183.06, 182.28, 182.23, 180.83, 182.28, 183.25, 182.44, 182.71, 181.14, 182.51, 182.02, 182.68, 183.32, 182.76, 182.28, 180.78, 183.7, 181.03, 182.15, 180.94, 182.86, 182.23, 181.88, 182.56, 183.33, 183.33, 182.68, 183.83, 182.25, 182.27, 180.99, 165.52, 180.16, 180.51, 182.24, 182.47, 182.36, 182.82, 182, 182.23, 182.46, 182.56, 182.68, 182.43, 181.52, 182.66, 183.15, 180.22, 183.12, 183.14, 182.81, 183.7, 182.73, 180.88, 182.33, 181.15, 180.86, 182.54, 182.7, 182.69, 182.29, 180.6, 182.64, 180.42, 182.68, 182.47, 182.78, 181.94, 182.54, 181.71, 181.42, 182.07, 182.52, 182.38, 183.56, 182.64, 182.7, 182.15, 182.68, 181.29, 183.59, 180.79, 182.87, 183.49, 182.25, 181.07, 182.16, 180.94, 183.24, 180.84, 182.47, 182.14, 182.4, 182.28, 182.62, 182.13, 182.22, 182.49, 182.79, 181.46, 182.52, 181.57, 182.81, 182.25, 182.98, 182.99, 182.11, 182.03, 182.27, 182.16, 182.71, 182.85, 182.85, 182.35, 181.76, 181.85, 182.21, 182.27, 182.5, 183.06, 183, 182.12, 182.11, 182.31, 181.87, 183.06, 182.06, 182.19, 181.84, 182.1, 180.44, 182.13, 180.15, 180.16, 182.06, 183.32, 180.67, 180.62, 183.62, 182.12, 182.02, 182.89, 180.45, 181.87, 182.87, 182.08, 182.04, 182.38, 181.65, 183.18, 182.06, 182.15, 182.21, 182.77, 182.58, 182.06, 182.92, 181.96, 182.04, 182.82, 180.18, 181.44, 182.01, 181.06, 181.11, 182.13, 181.58, 180.02, 180.56, 182.78, 181.82, 180, 182.7, 182.05, 181.92, 182.27, 182.19, 182.92, 180.98, 183.01, 183.75, 183.33, 181.57, 180.34, 180.66, 182.76, 180.62, 183.32, 181.76, 180.08, 182.21, 180.27, 182.88, 183.05, 183.07, 183.45, 180.2, 182.56, 182.69], "xaxis": "x", "y": [-44, -14, -22, -17, -35, -15, -340, -18, -55, -128, -26, -12, -32, -15, -15, -61, -15, -33, -35, -47, -23, -48, -52, -23, -42, -15, -29, -12, -40, -40, -42, -30, -52, -83, -35, -351, -18, -46, -20, -56, -39, -39, -36, -43, -47, -46, -51, -45, -42, -24, -20, -16, -21, -47, -57, -18, -16, -44, -49, -54, -54, -87, -55, -45, -46, -36, -28, -24, -16, -35, -50, -15, -31, -159, -40, -46, -28, -44, -44, -152, -54, -19, -322, -33, -27, -46, -56, -23, -55, -28, -44, -42, -18, -129, -49, -51, -49, -41, -30, -39, -44, -31, -30, -15, -15, -54, -38, -26, -51, -37, -58, -38, -28, -48, -51, -15, -44, -39, -20, -29, -45, -12, -41, -38, -46, -40, -46, -12, -15, -53, -61, -13, -49, -28, -48, -33, -243, -12, -45, -18, -15, -29, -50, -12, -49, -12, -62, -185, -41, -34, -72, -32, -28, -29, -31, -46, -49, -47, -12, -15, -319, -231, -37, -30, -32, -29, -28, -51, -38, -41, -15, -39, -92, -43, -22, -441, -15, -29, -29, -45, -24, -237, -87, -227, -15, -38, -26, -26, -47, -370, -32, -348, -27, -40, -28, -48, -29, -64, -14, -59, -57, -41, -18, -25, -29, -55, -31, -154, -15, -224, -15, -46, -24, -65, -29, -15, -15, -258, -37, -44, -52, -48, -51, -62, -47, -31, -31, -12, -32, -156, -34, -48, -23, -46, -52, -52, -50, -50, -22, -24, -36, -40, -34, -49, -46, -41, -35, -15, -12, -51, -52, -45, -45, -21, -55, -49, -53, -50, -364, -40, -421, -412, -56, -20, -139, -157, -15, -51, -42, -19, -15, -39, -19, -45, -51, -42, -138, -12, -38, -53, -58, -15, -42, -54, -12, -46, -53, -19, -391, -128, -51, -13, -15, -44, -144, -418, -15, -15, -28, -337, -15, -52, -62, -46, -86, -21, -51, -17, -12, -12, -129, -329, -15, -18, -263, -16, -108, -409, -48, -367, -18, -17, -12, -15, -398, -24, -20], "yaxis": "y"}], "frames": [{"data": [{"hovertemplate": "Lat=-30<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5], "coloraxis": "coloraxis", "size": [5.2, 6.1, 5.3, 5.4, 5.5, 6.2, 5.4, 5.3, 5.2, 4.9, 6.9, 6.5, 5.7, 5.8, 5.4, 6, 5.6, 5.4, 5.3, 5.6, 5.5, 5.2, 6.4, 5.4, 5.7, 5.3, 5, 5, 5.9, 5.1, 5.6, 5.1, 5.4, 5.2, 5.4, 5.4, 5, 5.9, 5.3, 5.2, 5.8, 5.5, 5.4, 5, 5.3, 5.4, 5.9, 5.7, 5, 5.2, 5, 6.3, 6.4, 6.7, 5.1, 5.9, 5.2, 5.2, 6.1, 5.2, 5.5, 5.3, 5, 6.5, 6.6, 6.3, 5.5, 5.9, 5, 5.3, 5.3, 6.2, 5.3, 5, 5.2, 5.3, 5.7, 5.1, 5.3, 6.1, 5.1, 5.2, 5.5, 5.1, 5.8, 5.2, 4.8, 5.2, 5.3, 5.2, 5, 5.4, 6.2, 5.6, 5.2, 5.3, 5.2, 5.4, 5.5, 6.2, 5.1, 5.1, 5.2, 6.1, 5.9, 5.9, 5.9, 5.1, 5.1, 5.5, 5.6, 5.5, 5.3, 5, 6.5, 5.6, 5, 5.3, 5, 6.1, 5.1, 5.4, 5.1, 4.9, 5.2, 5.1, 5.6, 5, 5.5, 5.1, 5.2, 5.1, 5.1, 5, 5.1, 5.1, 6, 5.2, 5.4, 6.5, 5.1, 5, 5.2, 6.3, 6.3, 5.4, 5.6, 5.6, 5.4, 5.5, 5, 5, 5, 5, 5, 6, 5.4, 5.2, 5.3, 5.2, 5.1, 5.2, 5.5, 5.2, 5.6, 5, 6, 5, 5.3, 5, 6.6, 5.5, 5.6, 5.1, 4.9, 5.2, 6.4, 5, 5, 5.8, 5, 5.1, 5.3, 5.6, 6.1, 5.8, 5.3, 5.3, 5.4, 6.1, 5.6, 6.2, 5.2, 5.5, 5.1, 5.3, 5.5, 5.5, 5.9, 5.1, 5.1, 5, 4.9, 5.1, 5.2, 4.9, 5.3, 6.9, 5.3, 6.9, 5.3, 5.3, 5.8, 4.9, 5.8, 6, 6, 5.3, 5.7, 5.6, 5.2, 5.3, 5.2, 5.2, 6.4, 5.3, 5.1, 5.9, 5.3, 6.2, 5, 5.2, 7, 5, 5.3, 5.4, 6, 6, 4.8, 5, 5.1, 5.3, 5.2, 6.2, 6.1, 6.7, 5.1, 5.6, 5.2, 5.8, 5.5, 5.3, 5.1, 5, 5.1, 6.5, 5.2, 5.5, 5.8, 5.2, 6.2, 5.3, 5.2, 4.9, 5.3, 6.6, 5.3, 5.1, 5.2, 5.1, 5.8, 5.5, 5, 5.2, 5.2, 5.4, 5.4, 6, 5.2, 5.3, 5, 5.4, 4.7, 5.1, 6.3, 5.9, 5.9, 5, 6.3, 5.7, 6.4, 5.8, 5.8, 6.9, 5.5, 5.2, 5.1, 6.1, 5.7, 5.5, 6.1, 5.4, 5.6, 6.7, 5.5, 5.1, 5.3, 5, 5, 5.9, 5.5, 5.7, 5.1, 5, 5.3, 4.9, 5.6, 6.1, 7.3, 6.7, 5.6, 5, 5.4, 5.6, 6.2, 5.1, 5], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [182.31, 183.3, 183.19, 182.84, 183.57, 182.57, 180.27, 183.3, 182.33, 181.61, 182.87, 182.3, 182.74, 182.45, 181.96, 182.33, 182.44, 182.17, 182.9, 182.34, 182.85, 182.21, 182.42, 183.28, 182.55, 182.87, 181.88, 183.54, 182.33, 182.65, 182.62, 183.47, 182.34, 182.38, 182.33, 180.51, 183.42, 182.44, 182, 182.41, 182.39, 182.54, 180.92, 182.61, 182.47, 182.08, 182.08, 182.43, 182.54, 183.33, 183.39, 182.49, 183.09, 182.54, 182.33, 182.77, 180.81, 182.57, 182.36, 182.48, 182.17, 181.81, 182.46, 182.09, 182.47, 182.45, 182.81, 182.81, 180.81, 182.52, 182.4, 183.71, 182.64, 181.97, 182.49, 182.12, 182.86, 182.47, 182.32, 181.76, 182.45, 183.04, 180.8, 182.83, 181.71, 182.55, 182.54, 182.98, 182.1, 182.39, 182.67, 182.59, 182.45, 181.53, 182.4, 181.6, 182.22, 182.45, 182.66, 182.29, 182.54, 182.83, 180.6, 183.37, 183.01, 182.12, 182.38, 182.53, 182.51, 182.57, 182.15, 182.46, 182.76, 182.11, 182.44, 183.14, 182.43, 182.45, 183.21, 182.68, 182.23, 165.91, 182.55, 182.35, 182.01, 182.84, 182.36, 183.11, 183.06, 182.28, 182.23, 180.83, 182.28, 183.25, 182.44, 182.71, 181.14, 182.51, 182.02, 182.68, 183.32, 182.76, 182.28, 180.78, 183.7, 181.03, 182.15, 180.94, 182.86, 182.23, 181.88, 182.56, 183.33, 183.33, 182.68, 183.83, 182.25, 182.27, 180.99, 165.52, 180.16, 180.51, 182.24, 182.47, 182.36, 182.82, 182, 182.23, 182.46, 182.56, 182.68, 182.43, 181.52, 182.66, 183.15, 180.22, 183.12, 183.14, 182.81, 183.7, 182.73, 180.88, 182.33, 181.15, 180.86, 182.54, 182.7, 182.69, 182.29, 180.6, 182.64, 180.42, 182.68, 182.47, 182.78, 181.94, 182.54, 181.71, 181.42, 182.07, 182.52, 182.38, 183.56, 182.64, 182.7, 182.15, 182.68, 181.29, 183.59, 180.79, 182.87, 183.49, 182.25, 181.07, 182.16, 180.94, 183.24, 180.84, 182.47, 182.14, 182.4, 182.28, 182.62, 182.13, 182.22, 182.49, 182.79, 181.46, 182.52, 181.57, 182.81, 182.25, 182.98, 182.99, 182.11, 182.03, 182.27, 182.16, 182.71, 182.85, 182.85, 182.35, 181.76, 181.85, 182.21, 182.27, 182.5, 183.06, 183, 182.12, 182.11, 182.31, 181.87, 183.06, 182.06, 182.19, 181.84, 182.1, 180.44, 182.13, 180.15, 180.16, 182.06, 183.32, 180.67, 180.62, 183.62, 182.12, 182.02, 182.89, 180.45, 181.87, 182.87, 182.08, 182.04, 182.38, 181.65, 183.18, 182.06, 182.15, 182.21, 182.77, 182.58, 182.06, 182.92, 181.96, 182.04, 182.82, 180.18, 181.44, 182.01, 181.06, 181.11, 182.13, 181.58, 180.02, 180.56, 182.78, 181.82, 180, 182.7, 182.05, 181.92, 182.27, 182.19, 182.92, 180.98, 183.01, 183.75, 183.33, 181.57, 180.34, 180.66, 182.76, 180.62, 183.32, 181.76, 180.08, 182.21, 180.27, 182.88, 183.05, 183.07, 183.45, 180.2, 182.56, 182.69], "xaxis": "x", "y": [-44, -14, -22, -17, -35, -15, -340, -18, -55, -128, -26, -12, -32, -15, -15, -61, -15, -33, -35, -47, -23, -48, -52, -23, -42, -15, -29, -12, -40, -40, -42, -30, -52, -83, -35, -351, -18, -46, -20, -56, -39, -39, -36, -43, -47, -46, -51, -45, -42, -24, -20, -16, -21, -47, -57, -18, -16, -44, -49, -54, -54, -87, -55, -45, -46, -36, -28, -24, -16, -35, -50, -15, -31, -159, -40, -46, -28, -44, -44, -152, -54, -19, -322, -33, -27, -46, -56, -23, -55, -28, -44, -42, -18, -129, -49, -51, -49, -41, -30, -39, -44, -31, -30, -15, -15, -54, -38, -26, -51, -37, -58, -38, -28, -48, -51, -15, -44, -39, -20, -29, -45, -12, -41, -38, -46, -40, -46, -12, -15, -53, -61, -13, -49, -28, -48, -33, -243, -12, -45, -18, -15, -29, -50, -12, -49, -12, -62, -185, -41, -34, -72, -32, -28, -29, -31, -46, -49, -47, -12, -15, -319, -231, -37, -30, -32, -29, -28, -51, -38, -41, -15, -39, -92, -43, -22, -441, -15, -29, -29, -45, -24, -237, -87, -227, -15, -38, -26, -26, -47, -370, -32, -348, -27, -40, -28, -48, -29, -64, -14, -59, -57, -41, -18, -25, -29, -55, -31, -154, -15, -224, -15, -46, -24, -65, -29, -15, -15, -258, -37, -44, -52, -48, -51, -62, -47, -31, -31, -12, -32, -156, -34, -48, -23, -46, -52, -52, -50, -50, -22, -24, -36, -40, -34, -49, -46, -41, -35, -15, -12, -51, -52, -45, -45, -21, -55, -49, -53, -50, -364, -40, -421, -412, -56, -20, -139, -157, -15, -51, -42, -19, -15, -39, -19, -45, -51, -42, -138, -12, -38, -53, -58, -15, -42, -54, -12, -46, -53, -19, -391, -128, -51, -13, -15, -44, -144, -418, -15, -15, -28, -337, -15, -52, -62, -46, -86, -21, -51, -17, -12, -12, -129, -329, -15, -18, -263, -16, -108, -409, -48, -367, -18, -17, -12, -15, -398, -24, -20], "yaxis": "y"}], "name": "-30"}, {"data": [{"hovertemplate": "Lat=-31<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [4.8, 5.4, 5.3, 5.4, 6.8, 5.3, 5.7, 5.3, 5.1, 5.4, 6, 5.3, 5.6, 4.9, 5, 5, 6.4, 5.1, 5.4, 5.4, 5.8, 5.4, 5.5, 5.3, 5.2, 5.2, 5.4, 5.6, 5.2, 5, 6, 6.1, 5, 5.6, 5.9, 5, 5.1, 5.2, 5.1, 5, 5.5, 5.2, 4.8, 6.3, 5, 4.9, 6.3, 6.6, 5.2, 5.4, 5.3, 5.1, 5.1, 5.3, 5.4, 5.5, 4.9, 5.6, 4.9, 5.3, 4.9, 5.1, 5.6, 5.3, 5.3, 5.7, 5.4, 5.2, 4.9, 5.2, 5.4, 5, 5.2, 5.3, 5, 5.1, 5.5, 5.3, 5.7, 5.8, 5.7, 5.1, 5.1, 5.2, 5, 5.2, 5.3, 5.1, 5.1, 7.5, 5.8, 5.2, 6.6, 5, 5, 5.1, 5.3, 5.4, 5.2, 5.5, 5.3, 6.2, 5.3, 6.4, 5.1, 5.1, 5.2, 5.5, 5.8, 5.7, 5.6, 5.2, 5.1, 5.4, 5.6, 6.5, 5.4, 5.7, 5.8, 5.3, 4.9, 5.3, 5.4, 5.3, 5.3, 5.3, 5.1, 5.9, 5.1, 5.5, 5.6, 5.2, 5.1, 5, 5, 5.8, 5.2, 5.2, 5.1, 5.3, 5.3, 5, 5, 5, 5.5, 5.6, 5, 5.1, 6.9, 5, 5.8, 4.9, 5.5, 6.5, 5.2, 5, 4.9, 5.1, 5.9, 6.5, 4.9, 5.1, 5.2, 5.1, 5.1, 5.8, 4.9, 6.4, 5.4, 4.9, 5, 5.2, 4.9, 4.9, 5.2, 5.4, 5, 5, 7, 6.4, 5.4, 5.6, 5, 5, 5.1, 5.1, 5, 5.1, 5, 5.2, 5.1, 5], "coloraxis": "coloraxis", "size": [4.8, 5.4, 5.3, 5.4, 6.8, 5.3, 5.7, 5.3, 5.1, 5.4, 6, 5.3, 5.6, 4.9, 5, 5, 6.4, 5.1, 5.4, 5.4, 5.8, 5.4, 5.5, 5.3, 5.2, 5.2, 5.4, 5.6, 5.2, 5, 6, 6.1, 5, 5.6, 5.9, 5, 5.1, 5.2, 5.1, 5, 5.5, 5.2, 4.8, 6.3, 5, 4.9, 6.3, 6.6, 5.2, 5.4, 5.3, 5.1, 5.1, 5.3, 5.4, 5.5, 4.9, 5.6, 4.9, 5.3, 4.9, 5.1, 5.6, 5.3, 5.3, 5.7, 5.4, 5.2, 4.9, 5.2, 5.4, 5, 5.2, 5.3, 5, 5.1, 5.5, 5.3, 5.7, 5.8, 5.7, 5.1, 5.1, 5.2, 5, 5.2, 5.3, 5.1, 5.1, 7.5, 5.8, 5.2, 6.6, 5, 5, 5.1, 5.3, 5.4, 5.2, 5.5, 5.3, 6.2, 5.3, 6.4, 5.1, 5.1, 5.2, 5.5, 5.8, 5.7, 5.6, 5.2, 5.1, 5.4, 5.6, 6.5, 5.4, 5.7, 5.8, 5.3, 4.9, 5.3, 5.4, 5.3, 5.3, 5.3, 5.1, 5.9, 5.1, 5.5, 5.6, 5.2, 5.1, 5, 5, 5.8, 5.2, 5.2, 5.1, 5.3, 5.3, 5, 5, 5, 5.5, 5.6, 5, 5.1, 6.9, 5, 5.8, 4.9, 5.5, 6.5, 5.2, 5, 4.9, 5.1, 5.9, 6.5, 4.9, 5.1, 5.2, 5.1, 5.1, 5.8, 4.9, 6.4, 5.4, 4.9, 5, 5.2, 4.9, 4.9, 5.2, 5.4, 5, 5, 7, 6.4, 5.4, 5.6, 5, 5, 5.1, 5.1, 5, 5.1, 5, 5.2, 5.1, 5], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [181.4, 182.68, 180.28, 182.11, 183.46, 182.24, 181.76, 183.26, 182.68, 181.88, 180.49, 183.04, 180.02, 182.59, 183.46, 182.63, 182.21, 179.71, 179.46, 180.01, 183.68, 180.13, 180.06, 182.6, 182.85, 180, 180.09, 182.6, 181.39, 182.54, 182.8, 182.81, 182.93, 181.05, 182.31, 182.67, 182.34, 182.82, 181.97, 182.72, 180.36, 182.73, 182.95, 181.44, 182.64, 182.89, 179.9, 182.23, 182.02, 182.36, 182.12, 181.93, 182.42, 182.44, 182.89, 180.3, 180.88, 182.32, 183.47, 182.47, 181.66, 182.36, 181.74, 182.59, 183.22, 180.51, 182, 182.07, 182.76, 182.07, 179.93, 181.28, 182.81, 182.7, 182.52, 182.14, 182.68, 180.08, 179.7, 182.46, 181.62, 182.59, 181.08, 181.81, 182.64, 181.99, 181.82, 180.82, 182.46, 181.09, 182.7, 180.5, 180.05, 182.6, 182.66, 181.84, 180.91, 180.51, 182.87, 182.87, 180.43, 179.66, 180.29, 180.66, 182.77, 182.82, 181.65, 179.3, 182.59, 181.7, 182.14, 179.61, 182.28, 181.88, 179.93, 181.88, 179.73, 179.92, 182.29, 182.81, 182.44, 179.82, 181.13, 181.2, 182.52, 179.18, 180.79, 182.84, 182.23, 182.82, 179.99, 181.89, 182.02, 182.66, 181.44, 179.66, 181.63, 182.69, 181.45, 181.59, 179.78, 181.02, 181.67, 183.99, 182.49, 182.53, 182.5, 181.59, 180.94, 182.26, 182.81, 183.92, 179.56, 180.06, 180.34, 181.8, 182.31, 182.25, 181.79, 181.21, 182.53, 181.6, 182.48, 182.58, 182.04, 180.12, 181.45, 179.82, 181.42, 181.69, 182.29, 181.6, 182.44, 182.16, 182.28, 182.41, 183.14, 182.09, 180.84, 182.42, 182.24, 181.95, 182.46, 182.59, 182.33, 181.45, 182.45, 181.72, 182.41, 182.25, 182.3, 182.45], "xaxis": "x", "y": [-30, -19, -298, -33, -19, -37, -16, -52, -22, -56, -10, -12, -394, -28, -12, -19, -35, -433, -413, -342, -32, -388, -341, -15, -13, -361, -428, -21, -122, -22, -14, -15, -28, -24, -22, -29, -41, -13, -53, -31, -15, -14, -20, -36, -24, -17, -453, -23, -39, -35, -33, -80, -18, -40, -12, -247, -187, -13, -20, -26, -61, -34, -15, -16, -14, -217, -143, -41, -22, -40, -391, -104, -13, -13, -21, -27, -14, -351, -454, -20, -15, -32, -94, -38, -14, -43, -49, -168, -15, -151, -14, -228, -367, -22, -23, -64, -12, -178, -12, -10, -230, -437, -194, -15, -18, -20, -55, -425, -10, -15, -15, -421, -27, -15, -428, -48, -232, -356, -20, -12, -24, -351, -43, -108, -33, -509, -151, -12, -23, -10, -15, -36, -37, -24, -103, -370, -59, -12, -67, -57, -352, -116, -62, -17, -14, -14, -20, -61, -119, -23, -12, -23, -439, -231, -240, -48, -28, -25, -52, -104, -23, -15, -18, -21, -38, -297, -54, -226, -35, -57, -21, -53, -21, -22, -17, -15, -26, -39, -117, -12, -18, -15, -28, -30, -20, -51, -14, -50, -23, -20, -20, -29], "yaxis": "y"}], "name": "-31"}, {"data": [{"hovertemplate": "Lat=-32<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.4, 5.4, 7.1, 5.1, 5.3, 5, 5.1, 5.4, 5.2, 5.5, 6.2, 5.3, 5.9, 5.4, 4.9, 5.1, 6.1, 5.3, 5.2, 5.6, 5.1, 5.4, 5.5, 5.3, 5.3, 4.8, 5.1, 5, 5.7, 5.7, 5.3, 6.3, 5.6, 5.1, 5.2, 5.3, 6.1, 5.4, 5.1, 4.9, 5.4, 5.2, 5.8, 5.1, 5.5, 5.5, 5.9, 6.1, 5.9, 6.3, 5.1, 5, 5.6, 5.4, 5.2, 5.5, 5.4, 5.2, 5.1, 5.2, 5.3, 5, 5, 5, 5.2, 5.7, 5.4, 5.4, 5, 5.4, 5.6, 5.2, 5.1, 5.4, 5.1, 4.9, 5.2, 5.7, 5.2, 5.6, 5.3, 5.5, 4.8, 5.2, 5.2, 5, 5.5, 5.3, 5.6, 5.8, 5.7, 5.1, 5.4, 5.4, 5, 5.6, 5.1, 5.6, 5.4, 5.8, 5.7, 5.4, 5.4, 5.2, 5, 5.8, 5.7, 6.1, 5.2, 6.1, 5, 5.8, 5, 5.5, 4.9, 5.1, 5.3, 5.2, 5.4, 6, 5.6, 5.2, 5.2, 5.6, 5.7, 5.1, 5.5, 5.1, 5.8, 5, 5.2, 5.8, 5.1, 5.2, 5.3, 5.5, 5.2, 5.2, 5.3, 4.9, 5.1, 5.1, 5.4, 6.4, 5.2, 6.7, 5.4, 5.4, 5.2, 5, 5.8, 4.8, 5.4, 5.2, 5.4, 5.1, 5.9, 5.3, 5.2, 5.1, 5, 5.3, 6.1, 6.5, 5.2, 5.3, 5, 5.5, 5.3, 5, 6, 5.7, 5.5, 5.3, 6.2, 5.3, 5.2, 5.1, 5.9, 5.2, 4.9, 5.3, 5, 5, 5.2, 5.2, 5.4, 5.1, 5.6, 4.9, 5.1, 4.9, 5.4, 6, 5.5, 4.9, 5.7, 5.1, 5.5, 5.4, 5.9, 5.5, 5.7, 5.2, 5, 5.3, 5.3, 5.1, 6.4, 5.5, 5.5, 5, 5.2, 5.2, 5.6, 5.2, 5.1], "coloraxis": "coloraxis", "size": [5.4, 5.4, 7.1, 5.1, 5.3, 5, 5.1, 5.4, 5.2, 5.5, 6.2, 5.3, 5.9, 5.4, 4.9, 5.1, 6.1, 5.3, 5.2, 5.6, 5.1, 5.4, 5.5, 5.3, 5.3, 4.8, 5.1, 5, 5.7, 5.7, 5.3, 6.3, 5.6, 5.1, 5.2, 5.3, 6.1, 5.4, 5.1, 4.9, 5.4, 5.2, 5.8, 5.1, 5.5, 5.5, 5.9, 6.1, 5.9, 6.3, 5.1, 5, 5.6, 5.4, 5.2, 5.5, 5.4, 5.2, 5.1, 5.2, 5.3, 5, 5, 5, 5.2, 5.7, 5.4, 5.4, 5, 5.4, 5.6, 5.2, 5.1, 5.4, 5.1, 4.9, 5.2, 5.7, 5.2, 5.6, 5.3, 5.5, 4.8, 5.2, 5.2, 5, 5.5, 5.3, 5.6, 5.8, 5.7, 5.1, 5.4, 5.4, 5, 5.6, 5.1, 5.6, 5.4, 5.8, 5.7, 5.4, 5.4, 5.2, 5, 5.8, 5.7, 6.1, 5.2, 6.1, 5, 5.8, 5, 5.5, 4.9, 5.1, 5.3, 5.2, 5.4, 6, 5.6, 5.2, 5.2, 5.6, 5.7, 5.1, 5.5, 5.1, 5.8, 5, 5.2, 5.8, 5.1, 5.2, 5.3, 5.5, 5.2, 5.2, 5.3, 4.9, 5.1, 5.1, 5.4, 6.4, 5.2, 6.7, 5.4, 5.4, 5.2, 5, 5.8, 4.8, 5.4, 5.2, 5.4, 5.1, 5.9, 5.3, 5.2, 5.1, 5, 5.3, 6.1, 6.5, 5.2, 5.3, 5, 5.5, 5.3, 5, 6, 5.7, 5.5, 5.3, 6.2, 5.3, 5.2, 5.1, 5.9, 5.2, 4.9, 5.3, 5, 5, 5.2, 5.2, 5.4, 5.1, 5.6, 4.9, 5.1, 4.9, 5.4, 6, 5.5, 4.9, 5.7, 5.1, 5.5, 5.4, 5.9, 5.5, 5.7, 5.2, 5, 5.3, 5.3, 5.1, 6.4, 5.5, 5.5, 5, 5.2, 5.2, 5.6, 5.2, 5.1], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [180.57, 182.33, 180.05, 182.5, 181.45, 182.38, 182.6, 180.14, 182.31, 182.01, 182.38, 182.82, 182.62, 180.02, 182.28, 182.33, 179.43, 181.44, 181.32, 181.93, 181.68, 182.38, 182.85, 179.88, 180.92, 183.05, 182.4, 182.35, 181.69, 182.19, 182.37, 182.4, 181.8, 181.3, 182.32, 180.49, 179.23, 180.1, 182.47, 182.31, 180.3, 181.43, 182.38, 182.42, 181.86, 182.39, 180.55, 182.29, 182.35, 182.34, 180.41, 182.42, 182.73, 180.4, 179.76, 180.45, 182.45, 180.47, 181.52, 182.23, 180.89, 182.37, 182.38, 182.51, 180.92, 181.37, 180.25, 180.5, 180.39, 182.48, 181.86, 181.46, 182.36, 180.39, 181.38, 182.45, 181.63, 182.75, 182.75, 180.62, 182.36, 182.18, 182.28, 181.95, 182.05, 182.42, 181.99, 182, 182.05, 182.03, 182.27, 181.96, 182.73, 181.63, 182.11, 182.03, 181.26, 182.3, 182.25, 182.14, 182.19, 182.61, 182.49, 182.25, 182.31, 182.26, 182.4, 181.23, 182.1, 181.27, 182.3, 182.33, 182.15, 182.21, 180.25, 182.57, 181.29, 182.29, 182.5, 181.28, 180.53, 181.14, 180.2, 181.27, 179.57, 182.27, 182.25, 182.44, 180.6, 181.91, 181.78, 182.2, 182.1, 180.87, 180.92, 181.56, 181.89, 181.94, 180.91, 181.56, 182.01, 181.42, 181.75, 182.29, 181.58, 181.14, 181.49, 181.42, 181.75, 181.91, 181.16, 181.83, 181.85, 179.74, 181.14, 179.07, 181.88, 182.2, 181.9, 181.38, 181.83, 181.93, 181.14, 181.22, 181.94, 181.32, 180.02, 181.66, 181.94, 181.97, 182.23, 181.86, 181.15, 182.09, 182.27, 182.08, 181.29, 181.98, 180.72, 182.3, 181.97, 181.82, 181.17, 181.83, 181.32, 181.95, 180.99, 182.26, 181.14, 181.71, 181.19, 181.96, 182.07, 179.94, 181.81, 182.06, 179.96, 181.98, 180.95, 182.04, 182.24, 180.98, 181.87, 181.97, 182.12, 182.29, 181.23, 182.24, 182.31, 181.05, 179.77, 182.27, 179.8, 179.87, 181.94, 182.29, 181.99], "xaxis": "x", "y": [-65, -14, -345, -16, -49, -18, -39, -222, -16, -10, -16, -12, -13, -25, -15, -21, -455, -15, -54, -10, -53, -18, -12, -300, -36, -18, -31, -19, -15, -17, -18, -10, -14, -52, -28, -12, -353, -15, -14, -23, -263, -50, -15, -30, -10, -15, -15, -10, -14, -15, -12, -23, -10, -12, -15, -15, -12, -12, -53, -14, -123, -21, -30, -24, -12, -15, -15, -12, -13, -10, -15, -54, -22, -12, -47, -19, -15, -10, -10, -105, -33, -15, -13, -19, -25, -28, -19, -20, -18, -19, -15, -21, -15, -15, -23, -16, -51, -21, -20, -15, -15, -25, -12, -20, -36, -15, -13, -47, -16, -49, -19, -12, -29, -22, -160, -33, -37, -17, -12, -50, -129, -35, -252, -26, -360, -17, -28, -22, -90, -20, -30, -14, -22, -130, -38, -24, -24, -24, -40, -12, -22, -46, -15, -15, -15, -42, -12, -46, -28, -23, -47, -28, -20, -12, -44, -212, -15, -15, -18, -51, -28, -15, -50, -46, -18, -42, -20, -10, -23, -23, -15, -20, -43, -18, -12, -17, -63, -21, -42, -15, -21, -17, -53, -33, -49, -19, -29, -15, -47, -20, -48, -21, -17, -205, -13, -22, -31, -15, -59, -20, -15, -52, -15, -23, -15, -15, -46, -47, -51, -51, -249, -23, -254, -12, -15, -15, -22], "yaxis": "y"}], "name": "-32"}, {"data": [{"hovertemplate": "Lat=-33<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.9, 5, 4.9, 5.5, 5.4, 5.7, 5.6, 5.4, 4.9, 5.1, 5.1, 5.7, 5.3, 5.4, 5.5, 5.1, 5.3, 5.3, 5.3, 5.1, 5, 5.4, 5, 5.8, 5.6, 5.4, 5, 5.2, 5.6, 5.2, 5, 5.2, 5.6, 5.4, 5.5, 5, 5, 5.2, 5.5, 5.1, 5.9, 5.4, 5.2, 4.9, 5.4, 5.3, 5.6, 5, 5.3, 5.7, 5.1, 5.3, 5.4, 5.9, 5.6, 5.3, 4.9, 5.4, 5.4, 5.1, 5.3, 5.4, 5.2, 5.9, 5.2, 5.3, 5.1, 5.3, 5.1, 5.6, 5.1, 5.1, 5.3, 5.2, 5.1, 7.4, 5.2, 5.8, 5, 5.9, 6, 5.9, 5.5, 5.9, 4.9, 5.4, 5.5, 4.8, 4.7, 4.8, 5, 5.3, 5.5, 5.2, 5.4, 5.5, 5.3, 5, 4.9, 5.5, 5.1, 5, 6.2, 5, 5, 5.1, 5.9, 5.1, 5.1, 5.5, 5.3, 5.4, 5.5, 6, 5.5, 5.4, 5.9, 5.2, 5, 4.9, 5.4, 5, 5.1, 5.1, 5.2, 4.9, 5.1, 5.1, 5.2, 4.9, 6, 5.6, 5.4, 5.1, 4.9, 5.3, 6, 5.3, 5.1, 5.1, 5.9, 5.6, 5, 5, 5.3, 5.5, 5.4, 5.6], "coloraxis": "coloraxis", "size": [5.9, 5, 4.9, 5.5, 5.4, 5.7, 5.6, 5.4, 4.9, 5.1, 5.1, 5.7, 5.3, 5.4, 5.5, 5.1, 5.3, 5.3, 5.3, 5.1, 5, 5.4, 5, 5.8, 5.6, 5.4, 5, 5.2, 5.6, 5.2, 5, 5.2, 5.6, 5.4, 5.5, 5, 5, 5.2, 5.5, 5.1, 5.9, 5.4, 5.2, 4.9, 5.4, 5.3, 5.6, 5, 5.3, 5.7, 5.1, 5.3, 5.4, 5.9, 5.6, 5.3, 4.9, 5.4, 5.4, 5.1, 5.3, 5.4, 5.2, 5.9, 5.2, 5.3, 5.1, 5.3, 5.1, 5.6, 5.1, 5.1, 5.3, 5.2, 5.1, 7.4, 5.2, 5.8, 5, 5.9, 6, 5.9, 5.5, 5.9, 4.9, 5.4, 5.5, 4.8, 4.7, 4.8, 5, 5.3, 5.5, 5.2, 5.4, 5.5, 5.3, 5, 4.9, 5.5, 5.1, 5, 6.2, 5, 5, 5.1, 5.9, 5.1, 5.1, 5.5, 5.3, 5.4, 5.5, 6, 5.5, 5.4, 5.9, 5.2, 5, 4.9, 5.4, 5, 5.1, 5.1, 5.2, 4.9, 5.1, 5.1, 5.2, 4.9, 6, 5.6, 5.4, 5.1, 4.9, 5.3, 6, 5.3, 5.1, 5.1, 5.9, 5.6, 5, 5, 5.3, 5.5, 5.4, 5.6], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [180.89, 182, 181.46, 182.2, 180.99, 181.75, 180.68, 182.16, 181.83, 182.18, 182.09, 181.98, 181.05, 182.17, 180.07, 182.45, 182.14, 182.13, 180.57, 183.3, 182.11, 182.15, 179.92, 181.85, 180.43, 181.94, 181.73, 181.92, 180.6, 182.07, 181.02, 181.28, 181.89, 180.76, 183.44, 181.38, 182.23, 181.76, 182.36, 181.22, 179.95, 181.04, 182, 180.92, 180.93, 181.52, 180.84, 182.71, 180.59, 181.34, 182.33, 180.48, 181.54, 182.55, 179.95, 180.85, 182.25, 180.85, 180.96, 181.95, 181.28, 180.79, 179.37, 181.09, 182.22, 181.1, 182.35, 180.79, 181.97, 180.83, 181.96, 181.47, 180.94, 181.01, 181.83, 182.45, 181.86, 182.22, 182.22, 181.57, 180.74, 180.14, 181.79, 181.62, 181.73, 181, 181.71, 182.37, 182.26, 179.62, 181.92, 180.32, 180.84, 179.59, 181.61, 182.03, 181.86, 182.29, 182.16, 180.2, 181.85, 181.71, 182.37, 181.32, 181.73, 181.88, 180.84, 180.99, 181.77, 181.63, 179.8, 181.56, 181.76, 180.49, 181.6, 179.51, 179.87, 181.84, 180.83, 179.59, 182.26, 181.4, 180.85, 179.65, 180.83, 181.5, 181.84, 179.68, 181.59, 179.48, 179.63, 179.46, 179.46, 180.87, 181.81, 180.91, 178.81, 181.88, 179.58, 182.5, 180.82, 180.81, 179.53, 181.74, 178.69, 181.72, 181.46, 181.61], "xaxis": "x", "y": [-40, -32, -37, -15, -56, -15, -121, -12, -23, -27, -19, -18, -55, -18, -168, -86, -17, -12, -67, -33, -20, -12, -12, -18, -60, -15, -21, -26, -23, -21, -47, -41, -21, -42, -15, -45, -24, -19, -15, -39, -10, -24, -19, -49, -56, -15, -49, -22, -17, -30, -17, -87, -18, -15, -12, -20, -22, -45, -58, -22, -30, -56, -223, -15, -15, -15, -19, -63, -13, -54, -24, -33, -57, -56, -16, -37, -20, -12, -21, -15, -44, -20, -15, -17, -24, -15, -15, -21, -19, -18, -22, -15, -59, -27, -53, -12, -18, -21, -21, -33, -22, -14, -55, -49, -21, -22, -42, -39, -27, -12, -154, -15, -15, -14, -12, -15, -161, -15, -43, -15, -12, -21, -56, -19, -12, -18, -21, -13, -17, -18, -200, -16, -12, -48, -50, -45, -282, -16, -12, -15, -41, -41, -12, -13, -262, -14, -15, -18], "yaxis": "y"}], "name": "-33"}, {"data": [{"hovertemplate": "Lat=-34<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.4, 5, 4.8, 5.2, 4.9, 5.3, 5.7, 5.5, 5.5, 5.8, 5.1, 5, 5, 5.4, 5.4, 5.5, 5.3, 5, 5.2, 5.6, 6.1, 5, 5.1, 5.6, 5.7, 6.6, 5.7, 5.2, 5.1, 5.3, 5.5, 5.3, 5.1, 6.5, 5.2, 5.3, 4.9, 5.6, 5.1, 5, 4.9, 5.1, 5, 5, 6.1, 5.3, 5.6, 5.9, 5.2, 5.6, 5.4, 5.3, 5.4, 5.2, 5, 5.2, 5.2, 6.8, 5.6, 5.3, 6.1, 5.3, 5.5, 5.6, 5.9, 5.2, 5.4, 5.4, 5.4, 5.2, 5.7, 5.1, 5.4, 5.6, 5.1, 5, 5.2, 5.5, 5.1], "coloraxis": "coloraxis", "size": [5.4, 5, 4.8, 5.2, 4.9, 5.3, 5.7, 5.5, 5.5, 5.8, 5.1, 5, 5, 5.4, 5.4, 5.5, 5.3, 5, 5.2, 5.6, 6.1, 5, 5.1, 5.6, 5.7, 6.6, 5.7, 5.2, 5.1, 5.3, 5.5, 5.3, 5.1, 6.5, 5.2, 5.3, 4.9, 5.6, 5.1, 5, 4.9, 5.1, 5, 5, 6.1, 5.3, 5.6, 5.9, 5.2, 5.6, 5.4, 5.3, 5.4, 5.2, 5, 5.2, 5.2, 6.8, 5.6, 5.3, 6.1, 5.3, 5.5, 5.6, 5.9, 5.2, 5.4, 5.4, 5.4, 5.2, 5.7, 5.1, 5.4, 5.6, 5.1, 5, 5.2, 5.5, 5.1], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [181.87, 180.87, 182.91, 179.51, 179.57, 179.48, 181.06, 180.14, 181.49, 178.99, 179.76, 179.3, 179.41, 178.8, 181.1, 180.24, 182.28, 181.89, 179.7, 180.31, 181.69, 181.43, 181.51, 179.59, 179.71, 180.17, 179.18, 180.9, 181.4, 181.5, 181.44, 181.29, 181.26, 179.33, 181, 181.31, 180.55, 179.25, 181.49, 180.34, 180.33, 181.73, 178.3, 181.2, 181.79, 181.96, 180.21, 180.32, 179.15, 179.98, 180.27, 181.51, 181.05, 181.32, 181.29, 179.7, 179.14, 181.6, 180.62, 181.93, 180.07, 178.82, 181.05, 180.3, 182.02, 181.1, 180.49, 181.06, 178.84, 181.06, 178.82, 179.19, 181.32, 181.21, 181.25, 180.24, 181.24, 180.91, 179.63], "xaxis": "x", "y": [-12, -41, -15, -12, -13, -222, -222, -52, -15, -15, -111, -19, -27, -183, -15, -35, -15, -12, -119, -54, -63, -15, -15, -110, -155, -100, -15, -79, -27, -22, -17, -15, -24, -15, -28, -17, -45, -203, -54, -64, -85, -29, -188, -32, -14, -12, -27, -15, -160, -110, -15, -63, -22, -25, -27, -39, -109, -61, -31, -15, -30, -220, -17, -28, -38, -20, -15, -20, -162, -21, -201, -183, -58, -15, -22, -43, -19, -48, -86], "yaxis": "y"}], "name": "-34"}, {"data": [{"hovertemplate": "Lat=-35<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.6, 5.2, 5.3, 5.7, 4.9, 5.3, 6.5, 5.4, 5.8, 5.3, 5, 5.1, 5.1, 5.9, 5.1, 5.3, 5.8, 6.1, 5.8, 5.6, 4.9, 5.2, 5.3, 5.1, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 5.2, 5.4, 5.6, 5.4, 5.1, 5.8, 5.4, 5.3, 5.3, 5.4, 5, 5.7, 5.2, 5, 5.2, 5, 5.2, 5.2, 5.2, 5.2, 5.2, 5.4, 5.4, 5.3, 5.6, 6.3, 5.3, 5.4], "coloraxis": "coloraxis", "size": [5.6, 5.2, 5.3, 5.7, 4.9, 5.3, 6.5, 5.4, 5.8, 5.3, 5, 5.1, 5.1, 5.9, 5.1, 5.3, 5.8, 6.1, 5.8, 5.6, 4.9, 5.2, 5.3, 5.1, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 5.2, 5.4, 5.6, 5.4, 5.1, 5.8, 5.4, 5.3, 5.3, 5.4, 5, 5.7, 5.2, 5, 5.2, 5, 5.2, 5.2, 5.2, 5.2, 5.2, 5.4, 5.4, 5.3, 5.6, 6.3, 5.3, 5.4], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [180.97, 177.27, 180.22, 181.1, 178.86, 180.98, 180.92, 179.13, 181.4, 179.47, 178.75, 181.14, 180.86, 180.15, 178.82, 180.98, 181.64, 181.32, 180.76, 180.93, 180.94, 181.02, 180.86, 179.65, 180.18, 180.3, 180.8, 180.95, 181.38, 180.72, 180.3, 178.91, 178.47, 178.5, 178.61, 179.12, 180.75, 180.73, 180.83, 178.35, 178.5, 180.75, 180.76, 178.57, 179.42, 180.99, 180.74, 178.42, 178.45, 178.4, 178.58, 178.39, 178.31, 179.26, 180.69, 178.89, 179.72, 177.89], "xaxis": "x", "y": [-30, -528, -42, -15, -18, -12, -56, -33, -12, -105, -220, -20, -20, -15, -16, -12, -15, -12, -15, -19, -23, -27, -25, -49, -41, -25, -18, -21, -21, -26, -15, -164, -15, -216, -171, -97, -19, -18, -25, -12, -194, -28, -22, -18, -85, -31, -21, -12, -12, -14, -12, -12, -14, -68, -15, -110, -15, -214], "yaxis": "y"}], "name": "-35"}, {"data": [{"hovertemplate": "Lat=-36<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.1, 5.9, 5.1, 5.4, 5.4, 5.4, 5.6, 5.6, 5.7, 5.7, 5.8, 5.3, 5.4, 5.3, 5.1, 5, 6.1, 5.4, 5.4, 5.8, 5.1, 5.4, 5.7, 5.1, 6.8, 5.2, 5.3, 5, 7.1, 5.6, 5.4, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 4.9, 5.2, 5.5, 5.4, 5, 5.3, 5.3, 5.7, 5.3, 5.5, 5.4, 5.4], "coloraxis": "coloraxis", "size": [5.1, 5.9, 5.1, 5.4, 5.4, 5.4, 5.6, 5.6, 5.7, 5.7, 5.8, 5.3, 5.4, 5.3, 5.1, 5, 6.1, 5.4, 5.4, 5.8, 5.1, 5.4, 5.7, 5.1, 6.8, 5.2, 5.3, 5, 7.1, 5.6, 5.4, 4.9, 5.4, 5.4, 5.1, 4.9, 5.6, 4.9, 5.2, 5.5, 5.4, 5, 5.3, 5.3, 5.7, 5.3, 5.5, 5.4, 5.4], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [180.29, 178.2, 180.06, 177.49, 177.6, 180.78, 177.62, 177.58, 177.48, 177.62, 177.53, 179.08, 177.59, 176.91, 177.41, 177.4, 178.78, 177.35, 180.77, 180.87, 181.02, 177.26, 178.89, 181.15, 177.47, 176.72, 179.82, 178.35, 180.92, 180.91, 176.92, 177.2, 180.14, 176.59, 177.85, 180.72, 176.78, 180.96, 177.85, 179.82, 176.57, 179.07, 180.66, 177.86, 177.6, 180.12, 180.59, 177.22, 176.69], "xaxis": "x", "y": [-26, -185, -25, -15, -24, -14, -10, -10, -10, -10, -10, -53, -10, -265, -12, -14, -83, -12, -15, -15, -17, -296, -15, -15, -19, -318, -15, -88, -59, -15, -39, -17, -20, -333, -185, -41, -210, -23, -130, -19, -283, -17, -15, -120, -153, -15, -15, -136, -360], "yaxis": "y"}], "name": "-36"}, {"data": [{"hovertemplate": "Lat=-37<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.7, 5.3, 5.2, 6.7, 5, 5.1, 5.8, 5.4, 6, 5.2, 6.3, 5.8, 5.1, 5, 5.2, 5, 5.1, 7.1, 5.8, 5, 5.9, 5, 4.9, 5, 5.1, 4.9, 6, 5.6, 5.3, 5.2, 5, 5.1, 5.9, 5.2, 4.9, 5.4, 5.1, 4.9, 5.2, 5.4, 6.2, 5.2, 5.1, 5.5, 5.9, 5, 5.8, 6.7, 5.3, 5.3, 6.2, 5.2, 5.3, 5.2, 4.9, 5.7, 7.2, 5.2, 5.2, 5.2, 5.7, 5.6, 5.1, 5.8, 5.9, 5.6, 5.1, 6, 5.4, 5.2, 5, 5, 6.5, 5, 5, 5.3, 4.8, 5.7, 6.5, 5.3, 4.9, 5, 5, 5.5], "coloraxis": "coloraxis", "size": [5.7, 5.3, 5.2, 6.7, 5, 5.1, 5.8, 5.4, 6, 5.2, 6.3, 5.8, 5.1, 5, 5.2, 5, 5.1, 7.1, 5.8, 5, 5.9, 5, 4.9, 5, 5.1, 4.9, 6, 5.6, 5.3, 5.2, 5, 5.1, 5.9, 5.2, 4.9, 5.4, 5.1, 4.9, 5.2, 5.4, 6.2, 5.2, 5.1, 5.5, 5.9, 5, 5.8, 6.7, 5.3, 5.3, 6.2, 5.2, 5.3, 5.2, 4.9, 5.7, 7.2, 5.2, 5.2, 5.2, 5.7, 5.6, 5.1, 5.8, 5.9, 5.6, 5.1, 6, 5.4, 5.2, 5, 5, 6.5, 5, 5, 5.3, 4.8, 5.7, 6.5, 5.3, 4.9, 5, 5, 5.5], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [180.03, 181.53, 179.31, 179.82, 177.11, 179.1, 178.85, 178.85, 179.08, 178.58, 177.45, 179.05, 179.09, 177.13, 178.85, 179.61, 179.05, 179.03, 178.8, 177.42, 177.3, 180.5, 178.96, 178.84, 180.43, 179.12, 177.34, 177.19, 179.44, 176.64, 177.34, 179.97, 178.88, 179.53, 178.93, 178.79, 180.38, 179.99, 178.87, 177.3, 176.94, 178.82, 179.98, 179.64, 178.69, 177.29, 179.62, 179.74, 179.74, 176.68, 179.84, 176.69, 177.17, 177.31, 177.28, 179.65, 179.4, 178.76, 180.89, 179.18, 179.2, 179.36, 180.53, 180.04, 179.24, 179.29, 176.58, 179.33, 179.49, 176.93, 177.87, 177.59, 177.03, 177.91, 177.66, 179.28, 177.69, 179.16, 179.17, 176.01, 178.3, 176.62, 177.81, 176.58], "xaxis": "x", "y": [-15, -33, -15, -15, -202, -37, -20, -12, -21, -33, -15, -27, -47, -163, -15, -24, -32, -28, -26, -152, -20, -27, -39, -36, -15, -23, -131, -15, -15, -183, -156, -17, -37, -15, -29, -25, -16, -28, -22, -146, -15, -22, -12, -12, -18, -21, -12, -21, -12, -288, -10, -165, -13, -15, -104, -12, -15, -15, -15, -15, -15, -15, -24, -15, -15, -49, -15, -15, -15, -163, -49, -94, -15, -63, -50, -15, -65, -15, -15, -293, -21, -12, -50, -12], "yaxis": "y"}], "name": "-37"}, {"data": [{"hovertemplate": "Lat=-38<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.3, 5.6, 6.1, 4.9, 5.2, 5, 5.1, 5.7, 5.1, 5, 5, 5.2, 5.4, 5, 5.3, 6.4, 5.2, 5.1, 5.5, 5.2, 5.2, 6.4, 5.7, 6.1, 5.6, 5, 4.9, 4.9, 5.1, 5.6, 5.7, 4.9, 5.4, 5, 5.5, 5.2, 6, 5.3, 6.6, 5.2, 5.2], "coloraxis": "coloraxis", "size": [5.3, 5.6, 6.1, 4.9, 5.2, 5, 5.1, 5.7, 5.1, 5, 5, 5.2, 5.4, 5, 5.3, 6.4, 5.2, 5.1, 5.5, 5.2, 5.2, 6.4, 5.7, 6.1, 5.6, 5, 4.9, 4.9, 5.1, 5.6, 5.7, 4.9, 5.4, 5, 5.5, 5.2, 6, 5.3, 6.6, 5.2, 5.2], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [178.9, 178.19, 177.32, 177.8, 175.82, 176.68, 176.7, 178.53, 179.67, 176.45, 177.63, 177.78, 180.33, 175.9, 177.51, 176.08, 176.18, 177.77, 175.4, 176.29, 176.42, 178.06, 175.29, 175.78, 176.03, 176.56, 176.17, 176.09, 180.35, 175.68, 176.12, 178.58, 174.86, 177.55, 178.85, 176.01, 177.01, 176.09, 178.4, 178.13, 177.42], "xaxis": "x", "y": [-46, -15, -78, -77, -169, -93, -164, -22, -12, -150, -33, -33, -33, -175, -43, -165, -184, -31, -248, -33, -122, -15, -276, -158, -159, -100, -138, -134, -12, -159, -119, -14, -216, -25, -16, -13, -40, -68, -30, -28, -33], "yaxis": "y"}], "name": "-38"}, {"data": [{"hovertemplate": "Lat=-39<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [6.2, 5.1, 5, 5.2, 5.3, 5.4, 5.1, 5.1, 5.8, 5.1, 5, 5.5, 5.5, 5.4, 5.7, 5.5, 5.7, 5.1], "coloraxis": "coloraxis", "size": [6.2, 5.1, 5, 5.2, 5.3, 5.4, 5.1, 5.1, 5.8, 5.1, 5, 5.5, 5.5, 5.4, 5.7, 5.5, 5.7, 5.1], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [174.94, 177.86, 175.74, 180.69, 175.88, 175.91, 178.78, 175.19, 174.22, 178.5, 175.46, 177.68, 175.96, 176.91, 176.83, 176.76, 176.49, 174.71], "xaxis": "x", "y": [-226, -20, -104, -18, -96, -49, -21, -116, -216, -12, -63, -26, -30, -26, -22, -17, -21, -131], "yaxis": "y"}], "name": "-39"}, {"data": [{"hovertemplate": "Lat=-40<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.2, 6.3, 5.4, 5.1, 5.4, 5.4, 6.4, 5.2, 5, 5.3, 5.4, 5, 5.8, 5.6, 5.2, 5.1, 5.4, 5.2, 5.4, 5, 5.6, 6.3, 5.6, 5.6, 6.3, 6, 5.9, 5.3], "coloraxis": "coloraxis", "size": [5.2, 6.3, 5.4, 5.1, 5.4, 5.4, 6.4, 5.2, 5, 5.3, 5.4, 5, 5.8, 5.6, 5.2, 5.1, 5.4, 5.2, 5.4, 5, 5.6, 6.3, 5.6, 5.6, 6.3, 6, 5.9, 5.3], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [176.66, 173.63, 176.33, 179.01, 173.66, 175.27, 176.53, 173.68, 175.06, 176.13, 176.66, 176.98, 174.98, 174.09, 176.28, 173.42, 176.02, 176.07, 175.66, 174.46, 176.29, 175.8, 174.94, 176.47, 176.09, 177.58, 174.17, 175.47], "xaxis": "x", "y": [-21, -230, -27, -24, -153, -45, -16, -94, -48, -38, -15, -31, -26, -114, -32, -185, -25, -55, -15, -88, -30, -24, -70, -24, -32, -12, -90, -46], "yaxis": "y"}], "name": "-40"}, {"data": [{"hovertemplate": "Lat=-41<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [4.9, 5.1, 5.4, 5.2, 5.3, 5.2, 5.2, 5.2, 5.3, 5.4, 5.1, 5.1, 5.5, 5.3, 5, 6.5, 5.9, 4.9, 5.4, 5.3, 5.7, 5.9, 5.5, 5.6, 6.1, 5.7, 6.6, 5.9, 5.2, 5.6, 5.5, 5.1, 5.4, 5.4, 5.3, 5.2, 5.5], "coloraxis": "coloraxis", "size": [4.9, 5.1, 5.4, 5.2, 5.3, 5.2, 5.2, 5.2, 5.3, 5.4, 5.1, 5.1, 5.5, 5.3, 5, 6.5, 5.9, 4.9, 5.4, 5.3, 5.7, 5.9, 5.5, 5.6, 6.1, 5.7, 6.6, 5.9, 5.2, 5.6, 5.5, 5.1, 5.4, 5.4, 5.3, 5.2, 5.5], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [175.32, 178.68, 175.48, 173.34, 175.16, 173.4, 174.08, 176.02, 174.33, 175.35, 176.14, 175.79, 174.37, 172.52, 174.29, 174.17, 173.71, 174.47, 174.13, 174.1, 174.2, 174, 174.26, 174.25, 174.29, 171.7, 174.04, 174.17, 174.03, 173.93, 175.62, 174.32, 174.22, 173.96, 171.43, 173.14, 172.82], "xaxis": "x", "y": [-29, -34, -15, -79, -31, -60, -69, -19, -15, -20, -27, -18, -17, -93, -15, -12, -75, -20, -17, -17, -13, -15, -18, -19, -26, -15, -12, -17, -19, -12, -15, -28, -25, -21, -15, -52, -64], "yaxis": "y"}], "name": "-41"}, {"data": [{"hovertemplate": "Lat=-42<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [6.1, 5.8, 7.8, 5.2, 5.7, 4.9, 4.9, 5.1, 5.7, 5.2, 5, 5.7, 5.1, 5.2, 6, 5.3, 5, 6.4, 5, 5.1, 5, 5.2, 4.9, 5.5, 6.1, 6.7, 5.6], "coloraxis": "coloraxis", "size": [6.1, 5.8, 7.8, 5.2, 5.7, 4.9, 4.9, 5.1, 5.7, 5.2, 5, 5.7, 5.1, 5.2, 6, 5.3, 5, 6.4, 5, 5.1, 5, 5.2, 4.9, 5.5, 6.1, 6.7, 5.6], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [173.07, 171.86, 173.85, 173.81, 172.74, 177.92, 173.75, 173.95, 173.86, 172.98, 173.69, 173.74, 173.43, 173.62, 172.78, 172.9, 173.73, 173.07, 171.54, 173.89, 172.67, 172.97, 173.95, 172.85, 171.76, 171.47, 171.18], "xaxis": "x", "y": [-48, -15, -19, -19, -15, -28, -26, -22, -12, -12, -16, -19, -19, -21, -15, -31, -19, -12, -59, -20, -12, -12, -22, -12, -15, -15, -12], "yaxis": "y"}], "name": "-42"}, {"data": [{"hovertemplate": "Lat=-43<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.5, 4.9, 5.9, 5.2, 5.4, 5.6, 5.7, 5.1, 5.2, 5.5, 5.6, 6, 5.1, 5.2, 5.8, 7, 4.8, 5, 4.8, 5, 4.9, 6.1, 4.9, 5.2, 5.4, 4.9, 5.7, 4.9, 5.4, 5.4, 5.2, 5, 6.1], "coloraxis": "coloraxis", "size": [5.5, 4.9, 5.9, 5.2, 5.4, 5.6, 5.7, 5.1, 5.2, 5.5, 5.6, 6, 5.1, 5.2, 5.8, 7, 4.8, 5, 4.8, 5, 4.9, 6.1, 4.9, 5.2, 5.4, 4.9, 5.7, 4.9, 5.4, 5.4, 5.2, 5, 6.1], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [171.61, 173.04, 171.54, 171.48, 171.81, 171.8, 172.54, 172.31, 172.62, 172.56, 172.55, 172.62, 172.78, 172.69, 172.58, 172.12, 172.28, 172.31, 172.7, 172.73, 171.91, 172.52, 172.74, 172.44, 172.69, 172.85, 172.56, 172.68, 169.62, 168.81, 169.23, 168.75, 170.66], "xaxis": "x", "y": [-15, -12, -15, -10, -15, -15, -12, -12, -12, -12, -12, -12, -17, -12, -12, -12, -12, -14, -12, -12, -12, -12, -12, -12, -12, -13, -12, -16, -15, -12, -15, -12, -10], "yaxis": "y"}], "name": "-43"}, {"data": [{"hovertemplate": "Lat=-44<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.4, 5.8, 5.3, 5.6, 4.8, 4.9, 5.5, 5.6, 5, 4.9, 5.6, 5.1, 5, 6.1, 6.8, 5.2, 6.6, 6.7, 5, 5.6, 5, 5.3], "coloraxis": "coloraxis", "size": [5.4, 5.8, 5.3, 5.6, 4.8, 4.9, 5.5, 5.6, 5, 4.9, 5.6, 5.1, 5, 6.1, 6.8, 5.2, 6.6, 6.7, 5, 5.6, 5, 5.3], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [168.42, 168.55, 167.91, 166.93, 167.66, 169.97, 167.71, 168.73, 167.51, 167.38, 167.39, 167.34, 167.21, 167.25, 167.24, 166.15, 167.63, 167.05, 167.54, 167, 166.59, 167.32], "xaxis": "x", "y": [-15, -15, -15, -15, -21, -12, -15, -14, -24, -24, -17, -18, -27, -19, -19, -15, -15, -62, -86, -14, -40, -116], "yaxis": "y"}], "name": "-44"}, {"data": [{"hovertemplate": "Lat=-45<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.4, 7.2, 6.1, 7, 6.4, 5.5, 5.2, 5.5, 5.2, 6.5, 4.9, 5.2, 5.5, 5.2, 5.4, 5.1, 5.2, 5.3, 5.1, 5.5, 5.1, 6.1, 5.2, 5, 5.6, 7.8, 5.2, 5], "coloraxis": "coloraxis", "size": [5.4, 7.2, 6.1, 7, 6.4, 5.5, 5.2, 5.5, 5.2, 6.5, 4.9, 5.2, 5.5, 5.2, 5.4, 5.1, 5.2, 5.3, 5.1, 5.5, 5.1, 6.1, 5.2, 5, 5.6, 7.8, 5.2, 5], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [167.23, 166.87, 166.7, 166.73, 166.6, 166.52, 166.62, 166.68, 166.68, 166.59, 166.44, 166.44, 167.64, 166.61, 166.46, 166.36, 165.97, 166.07, 166.75, 166.02, 166.42, 166.13, 166.72, 166.12, 166.73, 166.26, 165.82, 165.76], "xaxis": "x", "y": [-15, -32, -20, -15, -15, -49, -12, -27, -101, -18, -23, -24, -122, -15, -18, -17, -14, -12, -93, -12, -22, -12, -112, -31, -15, -23, -25, -21], "yaxis": "y"}], "name": "-45"}, {"data": [{"hovertemplate": "Lat=-46<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5, 5.7, 5.1, 5.6, 5.8, 5.8, 5.4, 5, 7.1, 6.2, 7.3, 6, 5.2, 5.4, 5, 5, 5.2], "coloraxis": "coloraxis", "size": [5, 5.7, 5.1, 5.6, 5.8, 5.8, 5.4, 5, 7.1, 6.2, 7.3, 6, 5.2, 5.4, 5, 5, 5.2], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [165.72, 165.82, 165.84, 166.09, 165.74, 165.85, 165.75, 165.67, 164.91, 164.64, 165.77, 165.38, 165.22, 165.27, 165.32, 165.04, 165.69], "xaxis": "x", "y": [-13, -20, -26, -15, -23, -18, -21, -29, -40, -10, -20, -19, -23, -18, -33, -32, -41], "yaxis": "y"}], "name": "-46"}, {"data": [{"hovertemplate": "Lat=-47<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5, 5, 5.2, 5.9, 4.9, 5.5, 5.5, 4.9, 5.2, 5.8, 4.9, 5.1, 5, 5.6], "coloraxis": "coloraxis", "size": [5, 5, 5.2, 5.9, 4.9, 5.5, 5.5, 4.9, 5.2, 5.8, 4.9, 5.1, 5, 5.6], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [165.43, 165.04, 165.96, 165.14, 165.43, 164.59, 164.62, 165.1, 165.11, 165.08, 165.26, 164.74, 164.42, 164.53], "xaxis": "x", "y": [-22, -29, -33, -15, -18, -15, -15, -12, -13, -12, -19, -17, -21, -15], "yaxis": "y"}], "name": "-47"}, {"data": [{"hovertemplate": "Lat=-48<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.2, 5.7, 5.1, 5.6, 5.3, 5.3, 5.1, 5.3, 5.4, 5.5, 7.6, 4.9, 5], "coloraxis": "coloraxis", "size": [5.2, 5.7, 5.1, 5.6, 5.3, 5.3, 5.1, 5.3, 5.4, 5.5, 7.6, 4.9, 5], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [165.5, 163.65, 164.19, 164.51, 164.51, 164.56, 164.24, 164.2, 163.86, 164.15, 164.39, 164.13, 163.89], "xaxis": "x", "y": [-15, -15, -14, -22, -21, -30, -18, -12, -15, -15, -33, -21, -14], "yaxis": "y"}], "name": "-48"}, {"data": [{"hovertemplate": "Lat=-49<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>", "legendgroup": "", "marker": {"color": [5.7, 5, 6, 4.9, 5.4, 5.1, 5.9, 5.6, 5.4, 5.2, 5.2, 6.1, 5.7, 5.1, 5.3, 6.6, 7.5, 6.6, 5.5, 6, 4.8, 5.1, 5.7, 5.7, 5.7, 5.4, 5.4, 5.2, 5.3, 5.4, 5, 4.9, 5.1, 5.1, 5.2, 5.4, 5.4, 5, 8.1, 6.2, 6], "coloraxis": "coloraxis", "size": [5.7, 5, 6, 4.9, 5.4, 5.1, 5.9, 5.6, 5.4, 5.2, 5.2, 6.1, 5.7, 5.1, 5.3, 6.6, 7.5, 6.6, 5.5, 6, 4.8, 5.1, 5.7, 5.7, 5.7, 5.4, 5.4, 5.2, 5.3, 5.4, 5, 4.9, 5.1, 5.1, 5.2, 5.4, 5.4, 5, 8.1, 6.2, 6], "sizemode": "area", "sizeref": 0.081, "symbol": "circle"}, "mode": "markers", "name": "", "orientation": "v", "showlegend": false, "type": "scatter", "x": [164.11, 164.26, 164.03, 161.07, 163.89, 164.32, 164.03, 164.01, 164.33, 164.24, 163.98, 164.19, 164.14, 164.38, 164.27, 163.99, 164.1, 164.01, 162.99, 163.79, 175.17, 163.47, 163.8, 163.71, 163.88, 163.35, 160.85, 163.5, 163.47, 162.91, 163.47, 163.26, 163.48, 163.33, 163.07, 163.35, 163.92, 163.47, 161.25, 163.25, 163.2], "xaxis": "x", "y": [-15, -33, -18, -14, -12, -38, -12, -15, -24, -39, -15, -26, -34, -42, -35, -32, -13, -31, -15, -15, -20, -12, -15, -25, -23, -15, -12, -12, -19, -15, -21, -25, -12, -22, -15, -14, -15, -21, -27, -12, -19], "yaxis": "y"}], "name": "-49"}], "layout": {"coloraxis": {"colorbar": {"title": {"text": "Mag"}}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]]}, "legend": {"itemsizing": "constant", "tracegroupgap": 0}, "margin": {"t": 60}, "sliders": [{"active": 0, "currentvalue": {"prefix": "Lat="}, "len": 0.9, "pad": {"b": 10, "t": 60}, "steps": [{"args": [["-30"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-30", "method": "animate"}, {"args": [["-31"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-31", "method": "animate"}, {"args": [["-32"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-32", "method": "animate"}, {"args": [["-33"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-33", "method": "animate"}, {"args": [["-34"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-34", "method": "animate"}, {"args": [["-35"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-35", "method": "animate"}, {"args": [["-36"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-36", "method": "animate"}, {"args": [["-37"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-37", "method": "animate"}, {"args": [["-38"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-38", "method": "animate"}, {"args": [["-39"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-39", "method": "animate"}, {"args": [["-40"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-40", "method": "animate"}, {"args": [["-41"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-41", "method": "animate"}, {"args": [["-42"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-42", "method": "animate"}, {"args": [["-43"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-43", "method": "animate"}, {"args": [["-44"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-44", "method": "animate"}, {"args": [["-45"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-45", "method": "animate"}, {"args": [["-46"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-46", "method": "animate"}, {"args": [["-47"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-47", "method": "animate"}, {"args": [["-48"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-48", "method": "animate"}, {"args": [["-49"], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "-49", "method": "animate"}], "x": 0.1, "xanchor": "left", "y": 0, "yanchor": "top"}], "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]], "sequentialminus": [[0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "updatemenus": [{"buttons": [{"args": [null, {"frame": {"duration": 500, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 500, "easing": "linear"}}], "label": "&#9654;", "method": "animate"}, {"args": [[null], {"frame": {"duration": 0, "redraw": false}, "fromcurrent": true, "mode": "immediate", "transition": {"duration": 0, "easing": "linear"}}], "label": "&#9724;", "method": "animate"}], "direction": "left", "pad": {"r": 10, "t": 70}, "showactive": false, "type": "buttons", "x": 0.1, "xanchor": "right", "y": 0, "yanchor": "top"}], "xaxis": {"anchor": "y", "domain": [0, 1], "range": [160, 184], "title": {"text": "Longitude"}}, "yaxis": {"anchor": "x", "domain": [0, 1], "range": [-600, 0], "title": {"text": "Depth(km)"}}}}, "text/html": ["<div>                            <div id=\"11fd5704-6738-40de-8a60-a1d5d9b0537d\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"11fd5704-6738-40de-8a60-a1d5d9b0537d\")) {                    Plotly.newPlot(                        \"11fd5704-6738-40de-8a60-a1d5d9b0537d\",                        [{\"hovertemplate\":\"Lat=-30<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0],\"coloraxis\":\"coloraxis\",\"size\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[182.31,183.3,183.19,182.84,183.57,182.57,180.27,183.3,182.33,181.61,182.87,182.3,182.74,182.45,181.96,182.33,182.44,182.17,182.9,182.34,182.85,182.21,182.42,183.28,182.55,182.87,181.88,183.54,182.33,182.65,182.62,183.47,182.34,182.38,182.33,180.51,183.42,182.44,182.0,182.41,182.39,182.54,180.92,182.61,182.47,182.08,182.08,182.43,182.54,183.33,183.39,182.49,183.09,182.54,182.33,182.77,180.81,182.57,182.36,182.48,182.17,181.81,182.46,182.09,182.47,182.45,182.81,182.81,180.81,182.52,182.4,183.71,182.64,181.97,182.49,182.12,182.86,182.47,182.32,181.76,182.45,183.04,180.8,182.83,181.71,182.55,182.54,182.98,182.1,182.39,182.67,182.59,182.45,181.53,182.4,181.6,182.22,182.45,182.66,182.29,182.54,182.83,180.6,183.37,183.01,182.12,182.38,182.53,182.51,182.57,182.15,182.46,182.76,182.11,182.44,183.14,182.43,182.45,183.21,182.68,182.23,165.91,182.55,182.35,182.01,182.84,182.36,183.11,183.06,182.28,182.23,180.83,182.28,183.25,182.44,182.71,181.14,182.51,182.02,182.68,183.32,182.76,182.28,180.78,183.7,181.03,182.15,180.94,182.86,182.23,181.88,182.56,183.33,183.33,182.68,183.83,182.25,182.27,180.99,165.52,180.16,180.51,182.24,182.47,182.36,182.82,182.0,182.23,182.46,182.56,182.68,182.43,181.52,182.66,183.15,180.22,183.12,183.14,182.81,183.7,182.73,180.88,182.33,181.15,180.86,182.54,182.7,182.69,182.29,180.6,182.64,180.42,182.68,182.47,182.78,181.94,182.54,181.71,181.42,182.07,182.52,182.38,183.56,182.64,182.7,182.15,182.68,181.29,183.59,180.79,182.87,183.49,182.25,181.07,182.16,180.94,183.24,180.84,182.47,182.14,182.4,182.28,182.62,182.13,182.22,182.49,182.79,181.46,182.52,181.57,182.81,182.25,182.98,182.99,182.11,182.03,182.27,182.16,182.71,182.85,182.85,182.35,181.76,181.85,182.21,182.27,182.5,183.06,183.0,182.12,182.11,182.31,181.87,183.06,182.06,182.19,181.84,182.1,180.44,182.13,180.15,180.16,182.06,183.32,180.67,180.62,183.62,182.12,182.02,182.89,180.45,181.87,182.87,182.08,182.04,182.38,181.65,183.18,182.06,182.15,182.21,182.77,182.58,182.06,182.92,181.96,182.04,182.82,180.18,181.44,182.01,181.06,181.11,182.13,181.58,180.02,180.56,182.78,181.82,180.0,182.7,182.05,181.92,182.27,182.19,182.92,180.98,183.01,183.75,183.33,181.57,180.34,180.66,182.76,180.62,183.32,181.76,180.08,182.21,180.27,182.88,183.05,183.07,183.45,180.2,182.56,182.69],\"xaxis\":\"x\",\"y\":[-44,-14,-22,-17,-35,-15,-340,-18,-55,-128,-26,-12,-32,-15,-15,-61,-15,-33,-35,-47,-23,-48,-52,-23,-42,-15,-29,-12,-40,-40,-42,-30,-52,-83,-35,-351,-18,-46,-20,-56,-39,-39,-36,-43,-47,-46,-51,-45,-42,-24,-20,-16,-21,-47,-57,-18,-16,-44,-49,-54,-54,-87,-55,-45,-46,-36,-28,-24,-16,-35,-50,-15,-31,-159,-40,-46,-28,-44,-44,-152,-54,-19,-322,-33,-27,-46,-56,-23,-55,-28,-44,-42,-18,-129,-49,-51,-49,-41,-30,-39,-44,-31,-30,-15,-15,-54,-38,-26,-51,-37,-58,-38,-28,-48,-51,-15,-44,-39,-20,-29,-45,-12,-41,-38,-46,-40,-46,-12,-15,-53,-61,-13,-49,-28,-48,-33,-243,-12,-45,-18,-15,-29,-50,-12,-49,-12,-62,-185,-41,-34,-72,-32,-28,-29,-31,-46,-49,-47,-12,-15,-319,-231,-37,-30,-32,-29,-28,-51,-38,-41,-15,-39,-92,-43,-22,-441,-15,-29,-29,-45,-24,-237,-87,-227,-15,-38,-26,-26,-47,-370,-32,-348,-27,-40,-28,-48,-29,-64,-14,-59,-57,-41,-18,-25,-29,-55,-31,-154,-15,-224,-15,-46,-24,-65,-29,-15,-15,-258,-37,-44,-52,-48,-51,-62,-47,-31,-31,-12,-32,-156,-34,-48,-23,-46,-52,-52,-50,-50,-22,-24,-36,-40,-34,-49,-46,-41,-35,-15,-12,-51,-52,-45,-45,-21,-55,-49,-53,-50,-364,-40,-421,-412,-56,-20,-139,-157,-15,-51,-42,-19,-15,-39,-19,-45,-51,-42,-138,-12,-38,-53,-58,-15,-42,-54,-12,-46,-53,-19,-391,-128,-51,-13,-15,-44,-144,-418,-15,-15,-28,-337,-15,-52,-62,-46,-86,-21,-51,-17,-12,-12,-129,-329,-15,-18,-263,-16,-108,-409,-48,-367,-18,-17,-12,-15,-398,-24,-20],\"yaxis\":\"y\",\"type\":\"scatter\"}],                        {\"template\":{\"data\":{\"histogram2dcontour\":[{\"type\":\"histogram2dcontour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"choropleth\":[{\"type\":\"choropleth\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"histogram2d\":[{\"type\":\"histogram2d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmap\":[{\"type\":\"heatmap\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmapgl\":[{\"type\":\"heatmapgl\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"contourcarpet\":[{\"type\":\"contourcarpet\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"contour\":[{\"type\":\"contour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"surface\":[{\"type\":\"surface\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"mesh3d\":[{\"type\":\"mesh3d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"parcoords\":[{\"type\":\"parcoords\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolargl\":[{\"type\":\"scatterpolargl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"scattergeo\":[{\"type\":\"scattergeo\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolar\":[{\"type\":\"scatterpolar\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"scattergl\":[{\"type\":\"scattergl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatter3d\":[{\"type\":\"scatter3d\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattermapbox\":[{\"type\":\"scattermapbox\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterternary\":[{\"type\":\"scatterternary\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattercarpet\":[{\"type\":\"scattercarpet\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}]},\"layout\":{\"autotypenumbers\":\"strict\",\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"hovermode\":\"closest\",\"hoverlabel\":{\"align\":\"left\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"bgcolor\":\"#E5ECF6\",\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"ternary\":{\"bgcolor\":\"#E5ECF6\",\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]]},\"xaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"yaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"geo\":{\"bgcolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"subunitcolor\":\"white\",\"showland\":true,\"showlakes\":true,\"lakecolor\":\"white\"},\"title\":{\"x\":0.05},\"mapbox\":{\"style\":\"light\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"Longitude\"},\"range\":[160,184]},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"Depth(km)\"},\"range\":[-600,0]},\"coloraxis\":{\"colorbar\":{\"title\":{\"text\":\"Mag\"}},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"legend\":{\"tracegroupgap\":0,\"itemsizing\":\"constant\"},\"margin\":{\"t\":60},\"updatemenus\":[{\"buttons\":[{\"args\":[null,{\"frame\":{\"duration\":500,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":500,\"easing\":\"linear\"}}],\"label\":\"&#9654;\",\"method\":\"animate\"},{\"args\":[[null],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"&#9724;\",\"method\":\"animate\"}],\"direction\":\"left\",\"pad\":{\"r\":10,\"t\":70},\"showactive\":false,\"type\":\"buttons\",\"x\":0.1,\"xanchor\":\"right\",\"y\":0,\"yanchor\":\"top\"}],\"sliders\":[{\"active\":0,\"currentvalue\":{\"prefix\":\"Lat=\"},\"len\":0.9,\"pad\":{\"b\":10,\"t\":60},\"steps\":[{\"args\":[[\"-30\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-30\",\"method\":\"animate\"},{\"args\":[[\"-31\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-31\",\"method\":\"animate\"},{\"args\":[[\"-32\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-32\",\"method\":\"animate\"},{\"args\":[[\"-33\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-33\",\"method\":\"animate\"},{\"args\":[[\"-34\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-34\",\"method\":\"animate\"},{\"args\":[[\"-35\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-35\",\"method\":\"animate\"},{\"args\":[[\"-36\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-36\",\"method\":\"animate\"},{\"args\":[[\"-37\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-37\",\"method\":\"animate\"},{\"args\":[[\"-38\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-38\",\"method\":\"animate\"},{\"args\":[[\"-39\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-39\",\"method\":\"animate\"},{\"args\":[[\"-40\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-40\",\"method\":\"animate\"},{\"args\":[[\"-41\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-41\",\"method\":\"animate\"},{\"args\":[[\"-42\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-42\",\"method\":\"animate\"},{\"args\":[[\"-43\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-43\",\"method\":\"animate\"},{\"args\":[[\"-44\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-44\",\"method\":\"animate\"},{\"args\":[[\"-45\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-45\",\"method\":\"animate\"},{\"args\":[[\"-46\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-46\",\"method\":\"animate\"},{\"args\":[[\"-47\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-47\",\"method\":\"animate\"},{\"args\":[[\"-48\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-48\",\"method\":\"animate\"},{\"args\":[[\"-49\"],{\"frame\":{\"duration\":0,\"redraw\":false},\"mode\":\"immediate\",\"fromcurrent\":true,\"transition\":{\"duration\":0,\"easing\":\"linear\"}}],\"label\":\"-49\",\"method\":\"animate\"}],\"x\":0.1,\"xanchor\":\"left\",\"y\":0,\"yanchor\":\"top\"}]},                        {\"responsive\": true}                    ).then(function(){\n", "                            Plotly.addFrames('11fd5704-6738-40de-8a60-a1d5d9b0537d', [{\"data\":[{\"hovertemplate\":\"Lat=-30<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0],\"coloraxis\":\"coloraxis\",\"size\":[5.2,6.1,5.3,5.4,5.5,6.2,5.4,5.3,5.2,4.9,6.9,6.5,5.7,5.8,5.4,6.0,5.6,5.4,5.3,5.6,5.5,5.2,6.4,5.4,5.7,5.3,5.0,5.0,5.9,5.1,5.6,5.1,5.4,5.2,5.4,5.4,5.0,5.9,5.3,5.2,5.8,5.5,5.4,5.0,5.3,5.4,5.9,5.7,5.0,5.2,5.0,6.3,6.4,6.7,5.1,5.9,5.2,5.2,6.1,5.2,5.5,5.3,5.0,6.5,6.6,6.3,5.5,5.9,5.0,5.3,5.3,6.2,5.3,5.0,5.2,5.3,5.7,5.1,5.3,6.1,5.1,5.2,5.5,5.1,5.8,5.2,4.8,5.2,5.3,5.2,5.0,5.4,6.2,5.6,5.2,5.3,5.2,5.4,5.5,6.2,5.1,5.1,5.2,6.1,5.9,5.9,5.9,5.1,5.1,5.5,5.6,5.5,5.3,5.0,6.5,5.6,5.0,5.3,5.0,6.1,5.1,5.4,5.1,4.9,5.2,5.1,5.6,5.0,5.5,5.1,5.2,5.1,5.1,5.0,5.1,5.1,6.0,5.2,5.4,6.5,5.1,5.0,5.2,6.3,6.3,5.4,5.6,5.6,5.4,5.5,5.0,5.0,5.0,5.0,5.0,6.0,5.4,5.2,5.3,5.2,5.1,5.2,5.5,5.2,5.6,5.0,6.0,5.0,5.3,5.0,6.6,5.5,5.6,5.1,4.9,5.2,6.4,5.0,5.0,5.8,5.0,5.1,5.3,5.6,6.1,5.8,5.3,5.3,5.4,6.1,5.6,6.2,5.2,5.5,5.1,5.3,5.5,5.5,5.9,5.1,5.1,5.0,4.9,5.1,5.2,4.9,5.3,6.9,5.3,6.9,5.3,5.3,5.8,4.9,5.8,6.0,6.0,5.3,5.7,5.6,5.2,5.3,5.2,5.2,6.4,5.3,5.1,5.9,5.3,6.2,5.0,5.2,7.0,5.0,5.3,5.4,6.0,6.0,4.8,5.0,5.1,5.3,5.2,6.2,6.1,6.7,5.1,5.6,5.2,5.8,5.5,5.3,5.1,5.0,5.1,6.5,5.2,5.5,5.8,5.2,6.2,5.3,5.2,4.9,5.3,6.6,5.3,5.1,5.2,5.1,5.8,5.5,5.0,5.2,5.2,5.4,5.4,6.0,5.2,5.3,5.0,5.4,4.7,5.1,6.3,5.9,5.9,5.0,6.3,5.7,6.4,5.8,5.8,6.9,5.5,5.2,5.1,6.1,5.7,5.5,6.1,5.4,5.6,6.7,5.5,5.1,5.3,5.0,5.0,5.9,5.5,5.7,5.1,5.0,5.3,4.9,5.6,6.1,7.3,6.7,5.6,5.0,5.4,5.6,6.2,5.1,5.0],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[182.31,183.3,183.19,182.84,183.57,182.57,180.27,183.3,182.33,181.61,182.87,182.3,182.74,182.45,181.96,182.33,182.44,182.17,182.9,182.34,182.85,182.21,182.42,183.28,182.55,182.87,181.88,183.54,182.33,182.65,182.62,183.47,182.34,182.38,182.33,180.51,183.42,182.44,182.0,182.41,182.39,182.54,180.92,182.61,182.47,182.08,182.08,182.43,182.54,183.33,183.39,182.49,183.09,182.54,182.33,182.77,180.81,182.57,182.36,182.48,182.17,181.81,182.46,182.09,182.47,182.45,182.81,182.81,180.81,182.52,182.4,183.71,182.64,181.97,182.49,182.12,182.86,182.47,182.32,181.76,182.45,183.04,180.8,182.83,181.71,182.55,182.54,182.98,182.1,182.39,182.67,182.59,182.45,181.53,182.4,181.6,182.22,182.45,182.66,182.29,182.54,182.83,180.6,183.37,183.01,182.12,182.38,182.53,182.51,182.57,182.15,182.46,182.76,182.11,182.44,183.14,182.43,182.45,183.21,182.68,182.23,165.91,182.55,182.35,182.01,182.84,182.36,183.11,183.06,182.28,182.23,180.83,182.28,183.25,182.44,182.71,181.14,182.51,182.02,182.68,183.32,182.76,182.28,180.78,183.7,181.03,182.15,180.94,182.86,182.23,181.88,182.56,183.33,183.33,182.68,183.83,182.25,182.27,180.99,165.52,180.16,180.51,182.24,182.47,182.36,182.82,182.0,182.23,182.46,182.56,182.68,182.43,181.52,182.66,183.15,180.22,183.12,183.14,182.81,183.7,182.73,180.88,182.33,181.15,180.86,182.54,182.7,182.69,182.29,180.6,182.64,180.42,182.68,182.47,182.78,181.94,182.54,181.71,181.42,182.07,182.52,182.38,183.56,182.64,182.7,182.15,182.68,181.29,183.59,180.79,182.87,183.49,182.25,181.07,182.16,180.94,183.24,180.84,182.47,182.14,182.4,182.28,182.62,182.13,182.22,182.49,182.79,181.46,182.52,181.57,182.81,182.25,182.98,182.99,182.11,182.03,182.27,182.16,182.71,182.85,182.85,182.35,181.76,181.85,182.21,182.27,182.5,183.06,183.0,182.12,182.11,182.31,181.87,183.06,182.06,182.19,181.84,182.1,180.44,182.13,180.15,180.16,182.06,183.32,180.67,180.62,183.62,182.12,182.02,182.89,180.45,181.87,182.87,182.08,182.04,182.38,181.65,183.18,182.06,182.15,182.21,182.77,182.58,182.06,182.92,181.96,182.04,182.82,180.18,181.44,182.01,181.06,181.11,182.13,181.58,180.02,180.56,182.78,181.82,180.0,182.7,182.05,181.92,182.27,182.19,182.92,180.98,183.01,183.75,183.33,181.57,180.34,180.66,182.76,180.62,183.32,181.76,180.08,182.21,180.27,182.88,183.05,183.07,183.45,180.2,182.56,182.69],\"xaxis\":\"x\",\"y\":[-44,-14,-22,-17,-35,-15,-340,-18,-55,-128,-26,-12,-32,-15,-15,-61,-15,-33,-35,-47,-23,-48,-52,-23,-42,-15,-29,-12,-40,-40,-42,-30,-52,-83,-35,-351,-18,-46,-20,-56,-39,-39,-36,-43,-47,-46,-51,-45,-42,-24,-20,-16,-21,-47,-57,-18,-16,-44,-49,-54,-54,-87,-55,-45,-46,-36,-28,-24,-16,-35,-50,-15,-31,-159,-40,-46,-28,-44,-44,-152,-54,-19,-322,-33,-27,-46,-56,-23,-55,-28,-44,-42,-18,-129,-49,-51,-49,-41,-30,-39,-44,-31,-30,-15,-15,-54,-38,-26,-51,-37,-58,-38,-28,-48,-51,-15,-44,-39,-20,-29,-45,-12,-41,-38,-46,-40,-46,-12,-15,-53,-61,-13,-49,-28,-48,-33,-243,-12,-45,-18,-15,-29,-50,-12,-49,-12,-62,-185,-41,-34,-72,-32,-28,-29,-31,-46,-49,-47,-12,-15,-319,-231,-37,-30,-32,-29,-28,-51,-38,-41,-15,-39,-92,-43,-22,-441,-15,-29,-29,-45,-24,-237,-87,-227,-15,-38,-26,-26,-47,-370,-32,-348,-27,-40,-28,-48,-29,-64,-14,-59,-57,-41,-18,-25,-29,-55,-31,-154,-15,-224,-15,-46,-24,-65,-29,-15,-15,-258,-37,-44,-52,-48,-51,-62,-47,-31,-31,-12,-32,-156,-34,-48,-23,-46,-52,-52,-50,-50,-22,-24,-36,-40,-34,-49,-46,-41,-35,-15,-12,-51,-52,-45,-45,-21,-55,-49,-53,-50,-364,-40,-421,-412,-56,-20,-139,-157,-15,-51,-42,-19,-15,-39,-19,-45,-51,-42,-138,-12,-38,-53,-58,-15,-42,-54,-12,-46,-53,-19,-391,-128,-51,-13,-15,-44,-144,-418,-15,-15,-28,-337,-15,-52,-62,-46,-86,-21,-51,-17,-12,-12,-129,-329,-15,-18,-263,-16,-108,-409,-48,-367,-18,-17,-12,-15,-398,-24,-20],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-30\"},{\"data\":[{\"hovertemplate\":\"Lat=-31<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[4.8,5.4,5.3,5.4,6.8,5.3,5.7,5.3,5.1,5.4,6.0,5.3,5.6,4.9,5.0,5.0,6.4,5.1,5.4,5.4,5.8,5.4,5.5,5.3,5.2,5.2,5.4,5.6,5.2,5.0,6.0,6.1,5.0,5.6,5.9,5.0,5.1,5.2,5.1,5.0,5.5,5.2,4.8,6.3,5.0,4.9,6.3,6.6,5.2,5.4,5.3,5.1,5.1,5.3,5.4,5.5,4.9,5.6,4.9,5.3,4.9,5.1,5.6,5.3,5.3,5.7,5.4,5.2,4.9,5.2,5.4,5.0,5.2,5.3,5.0,5.1,5.5,5.3,5.7,5.8,5.7,5.1,5.1,5.2,5.0,5.2,5.3,5.1,5.1,7.5,5.8,5.2,6.6,5.0,5.0,5.1,5.3,5.4,5.2,5.5,5.3,6.2,5.3,6.4,5.1,5.1,5.2,5.5,5.8,5.7,5.6,5.2,5.1,5.4,5.6,6.5,5.4,5.7,5.8,5.3,4.9,5.3,5.4,5.3,5.3,5.3,5.1,5.9,5.1,5.5,5.6,5.2,5.1,5.0,5.0,5.8,5.2,5.2,5.1,5.3,5.3,5.0,5.0,5.0,5.5,5.6,5.0,5.1,6.9,5.0,5.8,4.9,5.5,6.5,5.2,5.0,4.9,5.1,5.9,6.5,4.9,5.1,5.2,5.1,5.1,5.8,4.9,6.4,5.4,4.9,5.0,5.2,4.9,4.9,5.2,5.4,5.0,5.0,7.0,6.4,5.4,5.6,5.0,5.0,5.1,5.1,5.0,5.1,5.0,5.2,5.1,5.0],\"coloraxis\":\"coloraxis\",\"size\":[4.8,5.4,5.3,5.4,6.8,5.3,5.7,5.3,5.1,5.4,6.0,5.3,5.6,4.9,5.0,5.0,6.4,5.1,5.4,5.4,5.8,5.4,5.5,5.3,5.2,5.2,5.4,5.6,5.2,5.0,6.0,6.1,5.0,5.6,5.9,5.0,5.1,5.2,5.1,5.0,5.5,5.2,4.8,6.3,5.0,4.9,6.3,6.6,5.2,5.4,5.3,5.1,5.1,5.3,5.4,5.5,4.9,5.6,4.9,5.3,4.9,5.1,5.6,5.3,5.3,5.7,5.4,5.2,4.9,5.2,5.4,5.0,5.2,5.3,5.0,5.1,5.5,5.3,5.7,5.8,5.7,5.1,5.1,5.2,5.0,5.2,5.3,5.1,5.1,7.5,5.8,5.2,6.6,5.0,5.0,5.1,5.3,5.4,5.2,5.5,5.3,6.2,5.3,6.4,5.1,5.1,5.2,5.5,5.8,5.7,5.6,5.2,5.1,5.4,5.6,6.5,5.4,5.7,5.8,5.3,4.9,5.3,5.4,5.3,5.3,5.3,5.1,5.9,5.1,5.5,5.6,5.2,5.1,5.0,5.0,5.8,5.2,5.2,5.1,5.3,5.3,5.0,5.0,5.0,5.5,5.6,5.0,5.1,6.9,5.0,5.8,4.9,5.5,6.5,5.2,5.0,4.9,5.1,5.9,6.5,4.9,5.1,5.2,5.1,5.1,5.8,4.9,6.4,5.4,4.9,5.0,5.2,4.9,4.9,5.2,5.4,5.0,5.0,7.0,6.4,5.4,5.6,5.0,5.0,5.1,5.1,5.0,5.1,5.0,5.2,5.1,5.0],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[181.4,182.68,180.28,182.11,183.46,182.24,181.76,183.26,182.68,181.88,180.49,183.04,180.02,182.59,183.46,182.63,182.21,179.71,179.46,180.01,183.68,180.13,180.06,182.6,182.85,180.0,180.09,182.6,181.39,182.54,182.8,182.81,182.93,181.05,182.31,182.67,182.34,182.82,181.97,182.72,180.36,182.73,182.95,181.44,182.64,182.89,179.9,182.23,182.02,182.36,182.12,181.93,182.42,182.44,182.89,180.3,180.88,182.32,183.47,182.47,181.66,182.36,181.74,182.59,183.22,180.51,182.0,182.07,182.76,182.07,179.93,181.28,182.81,182.7,182.52,182.14,182.68,180.08,179.7,182.46,181.62,182.59,181.08,181.81,182.64,181.99,181.82,180.82,182.46,181.09,182.7,180.5,180.05,182.6,182.66,181.84,180.91,180.51,182.87,182.87,180.43,179.66,180.29,180.66,182.77,182.82,181.65,179.3,182.59,181.7,182.14,179.61,182.28,181.88,179.93,181.88,179.73,179.92,182.29,182.81,182.44,179.82,181.13,181.2,182.52,179.18,180.79,182.84,182.23,182.82,179.99,181.89,182.02,182.66,181.44,179.66,181.63,182.69,181.45,181.59,179.78,181.02,181.67,183.99,182.49,182.53,182.5,181.59,180.94,182.26,182.81,183.92,179.56,180.06,180.34,181.8,182.31,182.25,181.79,181.21,182.53,181.6,182.48,182.58,182.04,180.12,181.45,179.82,181.42,181.69,182.29,181.6,182.44,182.16,182.28,182.41,183.14,182.09,180.84,182.42,182.24,181.95,182.46,182.59,182.33,181.45,182.45,181.72,182.41,182.25,182.3,182.45],\"xaxis\":\"x\",\"y\":[-30,-19,-298,-33,-19,-37,-16,-52,-22,-56,-10,-12,-394,-28,-12,-19,-35,-433,-413,-342,-32,-388,-341,-15,-13,-361,-428,-21,-122,-22,-14,-15,-28,-24,-22,-29,-41,-13,-53,-31,-15,-14,-20,-36,-24,-17,-453,-23,-39,-35,-33,-80,-18,-40,-12,-247,-187,-13,-20,-26,-61,-34,-15,-16,-14,-217,-143,-41,-22,-40,-391,-104,-13,-13,-21,-27,-14,-351,-454,-20,-15,-32,-94,-38,-14,-43,-49,-168,-15,-151,-14,-228,-367,-22,-23,-64,-12,-178,-12,-10,-230,-437,-194,-15,-18,-20,-55,-425,-10,-15,-15,-421,-27,-15,-428,-48,-232,-356,-20,-12,-24,-351,-43,-108,-33,-509,-151,-12,-23,-10,-15,-36,-37,-24,-103,-370,-59,-12,-67,-57,-352,-116,-62,-17,-14,-14,-20,-61,-119,-23,-12,-23,-439,-231,-240,-48,-28,-25,-52,-104,-23,-15,-18,-21,-38,-297,-54,-226,-35,-57,-21,-53,-21,-22,-17,-15,-26,-39,-117,-12,-18,-15,-28,-30,-20,-51,-14,-50,-23,-20,-20,-29],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-31\"},{\"data\":[{\"hovertemplate\":\"Lat=-32<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.4,5.4,7.1,5.1,5.3,5.0,5.1,5.4,5.2,5.5,6.2,5.3,5.9,5.4,4.9,5.1,6.1,5.3,5.2,5.6,5.1,5.4,5.5,5.3,5.3,4.8,5.1,5.0,5.7,5.7,5.3,6.3,5.6,5.1,5.2,5.3,6.1,5.4,5.1,4.9,5.4,5.2,5.8,5.1,5.5,5.5,5.9,6.1,5.9,6.3,5.1,5.0,5.6,5.4,5.2,5.5,5.4,5.2,5.1,5.2,5.3,5.0,5.0,5.0,5.2,5.7,5.4,5.4,5.0,5.4,5.6,5.2,5.1,5.4,5.1,4.9,5.2,5.7,5.2,5.6,5.3,5.5,4.8,5.2,5.2,5.0,5.5,5.3,5.6,5.8,5.7,5.1,5.4,5.4,5.0,5.6,5.1,5.6,5.4,5.8,5.7,5.4,5.4,5.2,5.0,5.8,5.7,6.1,5.2,6.1,5.0,5.8,5.0,5.5,4.9,5.1,5.3,5.2,5.4,6.0,5.6,5.2,5.2,5.6,5.7,5.1,5.5,5.1,5.8,5.0,5.2,5.8,5.1,5.2,5.3,5.5,5.2,5.2,5.3,4.9,5.1,5.1,5.4,6.4,5.2,6.7,5.4,5.4,5.2,5.0,5.8,4.8,5.4,5.2,5.4,5.1,5.9,5.3,5.2,5.1,5.0,5.3,6.1,6.5,5.2,5.3,5.0,5.5,5.3,5.0,6.0,5.7,5.5,5.3,6.2,5.3,5.2,5.1,5.9,5.2,4.9,5.3,5.0,5.0,5.2,5.2,5.4,5.1,5.6,4.9,5.1,4.9,5.4,6.0,5.5,4.9,5.7,5.1,5.5,5.4,5.9,5.5,5.7,5.2,5.0,5.3,5.3,5.1,6.4,5.5,5.5,5.0,5.2,5.2,5.6,5.2,5.1],\"coloraxis\":\"coloraxis\",\"size\":[5.4,5.4,7.1,5.1,5.3,5.0,5.1,5.4,5.2,5.5,6.2,5.3,5.9,5.4,4.9,5.1,6.1,5.3,5.2,5.6,5.1,5.4,5.5,5.3,5.3,4.8,5.1,5.0,5.7,5.7,5.3,6.3,5.6,5.1,5.2,5.3,6.1,5.4,5.1,4.9,5.4,5.2,5.8,5.1,5.5,5.5,5.9,6.1,5.9,6.3,5.1,5.0,5.6,5.4,5.2,5.5,5.4,5.2,5.1,5.2,5.3,5.0,5.0,5.0,5.2,5.7,5.4,5.4,5.0,5.4,5.6,5.2,5.1,5.4,5.1,4.9,5.2,5.7,5.2,5.6,5.3,5.5,4.8,5.2,5.2,5.0,5.5,5.3,5.6,5.8,5.7,5.1,5.4,5.4,5.0,5.6,5.1,5.6,5.4,5.8,5.7,5.4,5.4,5.2,5.0,5.8,5.7,6.1,5.2,6.1,5.0,5.8,5.0,5.5,4.9,5.1,5.3,5.2,5.4,6.0,5.6,5.2,5.2,5.6,5.7,5.1,5.5,5.1,5.8,5.0,5.2,5.8,5.1,5.2,5.3,5.5,5.2,5.2,5.3,4.9,5.1,5.1,5.4,6.4,5.2,6.7,5.4,5.4,5.2,5.0,5.8,4.8,5.4,5.2,5.4,5.1,5.9,5.3,5.2,5.1,5.0,5.3,6.1,6.5,5.2,5.3,5.0,5.5,5.3,5.0,6.0,5.7,5.5,5.3,6.2,5.3,5.2,5.1,5.9,5.2,4.9,5.3,5.0,5.0,5.2,5.2,5.4,5.1,5.6,4.9,5.1,4.9,5.4,6.0,5.5,4.9,5.7,5.1,5.5,5.4,5.9,5.5,5.7,5.2,5.0,5.3,5.3,5.1,6.4,5.5,5.5,5.0,5.2,5.2,5.6,5.2,5.1],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[180.57,182.33,180.05,182.5,181.45,182.38,182.6,180.14,182.31,182.01,182.38,182.82,182.62,180.02,182.28,182.33,179.43,181.44,181.32,181.93,181.68,182.38,182.85,179.88,180.92,183.05,182.4,182.35,181.69,182.19,182.37,182.4,181.8,181.3,182.32,180.49,179.23,180.1,182.47,182.31,180.3,181.43,182.38,182.42,181.86,182.39,180.55,182.29,182.35,182.34,180.41,182.42,182.73,180.4,179.76,180.45,182.45,180.47,181.52,182.23,180.89,182.37,182.38,182.51,180.92,181.37,180.25,180.5,180.39,182.48,181.86,181.46,182.36,180.39,181.38,182.45,181.63,182.75,182.75,180.62,182.36,182.18,182.28,181.95,182.05,182.42,181.99,182.0,182.05,182.03,182.27,181.96,182.73,181.63,182.11,182.03,181.26,182.3,182.25,182.14,182.19,182.61,182.49,182.25,182.31,182.26,182.4,181.23,182.1,181.27,182.3,182.33,182.15,182.21,180.25,182.57,181.29,182.29,182.5,181.28,180.53,181.14,180.2,181.27,179.57,182.27,182.25,182.44,180.6,181.91,181.78,182.2,182.1,180.87,180.92,181.56,181.89,181.94,180.91,181.56,182.01,181.42,181.75,182.29,181.58,181.14,181.49,181.42,181.75,181.91,181.16,181.83,181.85,179.74,181.14,179.07,181.88,182.2,181.9,181.38,181.83,181.93,181.14,181.22,181.94,181.32,180.02,181.66,181.94,181.97,182.23,181.86,181.15,182.09,182.27,182.08,181.29,181.98,180.72,182.3,181.97,181.82,181.17,181.83,181.32,181.95,180.99,182.26,181.14,181.71,181.19,181.96,182.07,179.94,181.81,182.06,179.96,181.98,180.95,182.04,182.24,180.98,181.87,181.97,182.12,182.29,181.23,182.24,182.31,181.05,179.77,182.27,179.8,179.87,181.94,182.29,181.99],\"xaxis\":\"x\",\"y\":[-65,-14,-345,-16,-49,-18,-39,-222,-16,-10,-16,-12,-13,-25,-15,-21,-455,-15,-54,-10,-53,-18,-12,-300,-36,-18,-31,-19,-15,-17,-18,-10,-14,-52,-28,-12,-353,-15,-14,-23,-263,-50,-15,-30,-10,-15,-15,-10,-14,-15,-12,-23,-10,-12,-15,-15,-12,-12,-53,-14,-123,-21,-30,-24,-12,-15,-15,-12,-13,-10,-15,-54,-22,-12,-47,-19,-15,-10,-10,-105,-33,-15,-13,-19,-25,-28,-19,-20,-18,-19,-15,-21,-15,-15,-23,-16,-51,-21,-20,-15,-15,-25,-12,-20,-36,-15,-13,-47,-16,-49,-19,-12,-29,-22,-160,-33,-37,-17,-12,-50,-129,-35,-252,-26,-360,-17,-28,-22,-90,-20,-30,-14,-22,-130,-38,-24,-24,-24,-40,-12,-22,-46,-15,-15,-15,-42,-12,-46,-28,-23,-47,-28,-20,-12,-44,-212,-15,-15,-18,-51,-28,-15,-50,-46,-18,-42,-20,-10,-23,-23,-15,-20,-43,-18,-12,-17,-63,-21,-42,-15,-21,-17,-53,-33,-49,-19,-29,-15,-47,-20,-48,-21,-17,-205,-13,-22,-31,-15,-59,-20,-15,-52,-15,-23,-15,-15,-46,-47,-51,-51,-249,-23,-254,-12,-15,-15,-22],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-32\"},{\"data\":[{\"hovertemplate\":\"Lat=-33<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.9,5.0,4.9,5.5,5.4,5.7,5.6,5.4,4.9,5.1,5.1,5.7,5.3,5.4,5.5,5.1,5.3,5.3,5.3,5.1,5.0,5.4,5.0,5.8,5.6,5.4,5.0,5.2,5.6,5.2,5.0,5.2,5.6,5.4,5.5,5.0,5.0,5.2,5.5,5.1,5.9,5.4,5.2,4.9,5.4,5.3,5.6,5.0,5.3,5.7,5.1,5.3,5.4,5.9,5.6,5.3,4.9,5.4,5.4,5.1,5.3,5.4,5.2,5.9,5.2,5.3,5.1,5.3,5.1,5.6,5.1,5.1,5.3,5.2,5.1,7.4,5.2,5.8,5.0,5.9,6.0,5.9,5.5,5.9,4.9,5.4,5.5,4.8,4.7,4.8,5.0,5.3,5.5,5.2,5.4,5.5,5.3,5.0,4.9,5.5,5.1,5.0,6.2,5.0,5.0,5.1,5.9,5.1,5.1,5.5,5.3,5.4,5.5,6.0,5.5,5.4,5.9,5.2,5.0,4.9,5.4,5.0,5.1,5.1,5.2,4.9,5.1,5.1,5.2,4.9,6.0,5.6,5.4,5.1,4.9,5.3,6.0,5.3,5.1,5.1,5.9,5.6,5.0,5.0,5.3,5.5,5.4,5.6],\"coloraxis\":\"coloraxis\",\"size\":[5.9,5.0,4.9,5.5,5.4,5.7,5.6,5.4,4.9,5.1,5.1,5.7,5.3,5.4,5.5,5.1,5.3,5.3,5.3,5.1,5.0,5.4,5.0,5.8,5.6,5.4,5.0,5.2,5.6,5.2,5.0,5.2,5.6,5.4,5.5,5.0,5.0,5.2,5.5,5.1,5.9,5.4,5.2,4.9,5.4,5.3,5.6,5.0,5.3,5.7,5.1,5.3,5.4,5.9,5.6,5.3,4.9,5.4,5.4,5.1,5.3,5.4,5.2,5.9,5.2,5.3,5.1,5.3,5.1,5.6,5.1,5.1,5.3,5.2,5.1,7.4,5.2,5.8,5.0,5.9,6.0,5.9,5.5,5.9,4.9,5.4,5.5,4.8,4.7,4.8,5.0,5.3,5.5,5.2,5.4,5.5,5.3,5.0,4.9,5.5,5.1,5.0,6.2,5.0,5.0,5.1,5.9,5.1,5.1,5.5,5.3,5.4,5.5,6.0,5.5,5.4,5.9,5.2,5.0,4.9,5.4,5.0,5.1,5.1,5.2,4.9,5.1,5.1,5.2,4.9,6.0,5.6,5.4,5.1,4.9,5.3,6.0,5.3,5.1,5.1,5.9,5.6,5.0,5.0,5.3,5.5,5.4,5.6],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[180.89,182.0,181.46,182.2,180.99,181.75,180.68,182.16,181.83,182.18,182.09,181.98,181.05,182.17,180.07,182.45,182.14,182.13,180.57,183.3,182.11,182.15,179.92,181.85,180.43,181.94,181.73,181.92,180.6,182.07,181.02,181.28,181.89,180.76,183.44,181.38,182.23,181.76,182.36,181.22,179.95,181.04,182.0,180.92,180.93,181.52,180.84,182.71,180.59,181.34,182.33,180.48,181.54,182.55,179.95,180.85,182.25,180.85,180.96,181.95,181.28,180.79,179.37,181.09,182.22,181.1,182.35,180.79,181.97,180.83,181.96,181.47,180.94,181.01,181.83,182.45,181.86,182.22,182.22,181.57,180.74,180.14,181.79,181.62,181.73,181.0,181.71,182.37,182.26,179.62,181.92,180.32,180.84,179.59,181.61,182.03,181.86,182.29,182.16,180.2,181.85,181.71,182.37,181.32,181.73,181.88,180.84,180.99,181.77,181.63,179.8,181.56,181.76,180.49,181.6,179.51,179.87,181.84,180.83,179.59,182.26,181.4,180.85,179.65,180.83,181.5,181.84,179.68,181.59,179.48,179.63,179.46,179.46,180.87,181.81,180.91,178.81,181.88,179.58,182.5,180.82,180.81,179.53,181.74,178.69,181.72,181.46,181.61],\"xaxis\":\"x\",\"y\":[-40,-32,-37,-15,-56,-15,-121,-12,-23,-27,-19,-18,-55,-18,-168,-86,-17,-12,-67,-33,-20,-12,-12,-18,-60,-15,-21,-26,-23,-21,-47,-41,-21,-42,-15,-45,-24,-19,-15,-39,-10,-24,-19,-49,-56,-15,-49,-22,-17,-30,-17,-87,-18,-15,-12,-20,-22,-45,-58,-22,-30,-56,-223,-15,-15,-15,-19,-63,-13,-54,-24,-33,-57,-56,-16,-37,-20,-12,-21,-15,-44,-20,-15,-17,-24,-15,-15,-21,-19,-18,-22,-15,-59,-27,-53,-12,-18,-21,-21,-33,-22,-14,-55,-49,-21,-22,-42,-39,-27,-12,-154,-15,-15,-14,-12,-15,-161,-15,-43,-15,-12,-21,-56,-19,-12,-18,-21,-13,-17,-18,-200,-16,-12,-48,-50,-45,-282,-16,-12,-15,-41,-41,-12,-13,-262,-14,-15,-18],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-33\"},{\"data\":[{\"hovertemplate\":\"Lat=-34<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.4,5.0,4.8,5.2,4.9,5.3,5.7,5.5,5.5,5.8,5.1,5.0,5.0,5.4,5.4,5.5,5.3,5.0,5.2,5.6,6.1,5.0,5.1,5.6,5.7,6.6,5.7,5.2,5.1,5.3,5.5,5.3,5.1,6.5,5.2,5.3,4.9,5.6,5.1,5.0,4.9,5.1,5.0,5.0,6.1,5.3,5.6,5.9,5.2,5.6,5.4,5.3,5.4,5.2,5.0,5.2,5.2,6.8,5.6,5.3,6.1,5.3,5.5,5.6,5.9,5.2,5.4,5.4,5.4,5.2,5.7,5.1,5.4,5.6,5.1,5.0,5.2,5.5,5.1],\"coloraxis\":\"coloraxis\",\"size\":[5.4,5.0,4.8,5.2,4.9,5.3,5.7,5.5,5.5,5.8,5.1,5.0,5.0,5.4,5.4,5.5,5.3,5.0,5.2,5.6,6.1,5.0,5.1,5.6,5.7,6.6,5.7,5.2,5.1,5.3,5.5,5.3,5.1,6.5,5.2,5.3,4.9,5.6,5.1,5.0,4.9,5.1,5.0,5.0,6.1,5.3,5.6,5.9,5.2,5.6,5.4,5.3,5.4,5.2,5.0,5.2,5.2,6.8,5.6,5.3,6.1,5.3,5.5,5.6,5.9,5.2,5.4,5.4,5.4,5.2,5.7,5.1,5.4,5.6,5.1,5.0,5.2,5.5,5.1],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[181.87,180.87,182.91,179.51,179.57,179.48,181.06,180.14,181.49,178.99,179.76,179.3,179.41,178.8,181.1,180.24,182.28,181.89,179.7,180.31,181.69,181.43,181.51,179.59,179.71,180.17,179.18,180.9,181.4,181.5,181.44,181.29,181.26,179.33,181.0,181.31,180.55,179.25,181.49,180.34,180.33,181.73,178.3,181.2,181.79,181.96,180.21,180.32,179.15,179.98,180.27,181.51,181.05,181.32,181.29,179.7,179.14,181.6,180.62,181.93,180.07,178.82,181.05,180.3,182.02,181.1,180.49,181.06,178.84,181.06,178.82,179.19,181.32,181.21,181.25,180.24,181.24,180.91,179.63],\"xaxis\":\"x\",\"y\":[-12,-41,-15,-12,-13,-222,-222,-52,-15,-15,-111,-19,-27,-183,-15,-35,-15,-12,-119,-54,-63,-15,-15,-110,-155,-100,-15,-79,-27,-22,-17,-15,-24,-15,-28,-17,-45,-203,-54,-64,-85,-29,-188,-32,-14,-12,-27,-15,-160,-110,-15,-63,-22,-25,-27,-39,-109,-61,-31,-15,-30,-220,-17,-28,-38,-20,-15,-20,-162,-21,-201,-183,-58,-15,-22,-43,-19,-48,-86],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-34\"},{\"data\":[{\"hovertemplate\":\"Lat=-35<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.6,5.2,5.3,5.7,4.9,5.3,6.5,5.4,5.8,5.3,5.0,5.1,5.1,5.9,5.1,5.3,5.8,6.1,5.8,5.6,4.9,5.2,5.3,5.1,4.9,5.4,5.4,5.1,4.9,5.6,5.2,5.4,5.6,5.4,5.1,5.8,5.4,5.3,5.3,5.4,5.0,5.7,5.2,5.0,5.2,5.0,5.2,5.2,5.2,5.2,5.2,5.4,5.4,5.3,5.6,6.3,5.3,5.4],\"coloraxis\":\"coloraxis\",\"size\":[5.6,5.2,5.3,5.7,4.9,5.3,6.5,5.4,5.8,5.3,5.0,5.1,5.1,5.9,5.1,5.3,5.8,6.1,5.8,5.6,4.9,5.2,5.3,5.1,4.9,5.4,5.4,5.1,4.9,5.6,5.2,5.4,5.6,5.4,5.1,5.8,5.4,5.3,5.3,5.4,5.0,5.7,5.2,5.0,5.2,5.0,5.2,5.2,5.2,5.2,5.2,5.4,5.4,5.3,5.6,6.3,5.3,5.4],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[180.97,177.27,180.22,181.1,178.86,180.98,180.92,179.13,181.4,179.47,178.75,181.14,180.86,180.15,178.82,180.98,181.64,181.32,180.76,180.93,180.94,181.02,180.86,179.65,180.18,180.3,180.8,180.95,181.38,180.72,180.3,178.91,178.47,178.5,178.61,179.12,180.75,180.73,180.83,178.35,178.5,180.75,180.76,178.57,179.42,180.99,180.74,178.42,178.45,178.4,178.58,178.39,178.31,179.26,180.69,178.89,179.72,177.89],\"xaxis\":\"x\",\"y\":[-30,-528,-42,-15,-18,-12,-56,-33,-12,-105,-220,-20,-20,-15,-16,-12,-15,-12,-15,-19,-23,-27,-25,-49,-41,-25,-18,-21,-21,-26,-15,-164,-15,-216,-171,-97,-19,-18,-25,-12,-194,-28,-22,-18,-85,-31,-21,-12,-12,-14,-12,-12,-14,-68,-15,-110,-15,-214],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-35\"},{\"data\":[{\"hovertemplate\":\"Lat=-36<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.1,5.9,5.1,5.4,5.4,5.4,5.6,5.6,5.7,5.7,5.8,5.3,5.4,5.3,5.1,5.0,6.1,5.4,5.4,5.8,5.1,5.4,5.7,5.1,6.8,5.2,5.3,5.0,7.1,5.6,5.4,4.9,5.4,5.4,5.1,4.9,5.6,4.9,5.2,5.5,5.4,5.0,5.3,5.3,5.7,5.3,5.5,5.4,5.4],\"coloraxis\":\"coloraxis\",\"size\":[5.1,5.9,5.1,5.4,5.4,5.4,5.6,5.6,5.7,5.7,5.8,5.3,5.4,5.3,5.1,5.0,6.1,5.4,5.4,5.8,5.1,5.4,5.7,5.1,6.8,5.2,5.3,5.0,7.1,5.6,5.4,4.9,5.4,5.4,5.1,4.9,5.6,4.9,5.2,5.5,5.4,5.0,5.3,5.3,5.7,5.3,5.5,5.4,5.4],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[180.29,178.2,180.06,177.49,177.6,180.78,177.62,177.58,177.48,177.62,177.53,179.08,177.59,176.91,177.41,177.4,178.78,177.35,180.77,180.87,181.02,177.26,178.89,181.15,177.47,176.72,179.82,178.35,180.92,180.91,176.92,177.2,180.14,176.59,177.85,180.72,176.78,180.96,177.85,179.82,176.57,179.07,180.66,177.86,177.6,180.12,180.59,177.22,176.69],\"xaxis\":\"x\",\"y\":[-26,-185,-25,-15,-24,-14,-10,-10,-10,-10,-10,-53,-10,-265,-12,-14,-83,-12,-15,-15,-17,-296,-15,-15,-19,-318,-15,-88,-59,-15,-39,-17,-20,-333,-185,-41,-210,-23,-130,-19,-283,-17,-15,-120,-153,-15,-15,-136,-360],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-36\"},{\"data\":[{\"hovertemplate\":\"Lat=-37<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.7,5.3,5.2,6.7,5.0,5.1,5.8,5.4,6.0,5.2,6.3,5.8,5.1,5.0,5.2,5.0,5.1,7.1,5.8,5.0,5.9,5.0,4.9,5.0,5.1,4.9,6.0,5.6,5.3,5.2,5.0,5.1,5.9,5.2,4.9,5.4,5.1,4.9,5.2,5.4,6.2,5.2,5.1,5.5,5.9,5.0,5.8,6.7,5.3,5.3,6.2,5.2,5.3,5.2,4.9,5.7,7.2,5.2,5.2,5.2,5.7,5.6,5.1,5.8,5.9,5.6,5.1,6.0,5.4,5.2,5.0,5.0,6.5,5.0,5.0,5.3,4.8,5.7,6.5,5.3,4.9,5.0,5.0,5.5],\"coloraxis\":\"coloraxis\",\"size\":[5.7,5.3,5.2,6.7,5.0,5.1,5.8,5.4,6.0,5.2,6.3,5.8,5.1,5.0,5.2,5.0,5.1,7.1,5.8,5.0,5.9,5.0,4.9,5.0,5.1,4.9,6.0,5.6,5.3,5.2,5.0,5.1,5.9,5.2,4.9,5.4,5.1,4.9,5.2,5.4,6.2,5.2,5.1,5.5,5.9,5.0,5.8,6.7,5.3,5.3,6.2,5.2,5.3,5.2,4.9,5.7,7.2,5.2,5.2,5.2,5.7,5.6,5.1,5.8,5.9,5.6,5.1,6.0,5.4,5.2,5.0,5.0,6.5,5.0,5.0,5.3,4.8,5.7,6.5,5.3,4.9,5.0,5.0,5.5],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[180.03,181.53,179.31,179.82,177.11,179.1,178.85,178.85,179.08,178.58,177.45,179.05,179.09,177.13,178.85,179.61,179.05,179.03,178.8,177.42,177.3,180.5,178.96,178.84,180.43,179.12,177.34,177.19,179.44,176.64,177.34,179.97,178.88,179.53,178.93,178.79,180.38,179.99,178.87,177.3,176.94,178.82,179.98,179.64,178.69,177.29,179.62,179.74,179.74,176.68,179.84,176.69,177.17,177.31,177.28,179.65,179.4,178.76,180.89,179.18,179.2,179.36,180.53,180.04,179.24,179.29,176.58,179.33,179.49,176.93,177.87,177.59,177.03,177.91,177.66,179.28,177.69,179.16,179.17,176.01,178.3,176.62,177.81,176.58],\"xaxis\":\"x\",\"y\":[-15,-33,-15,-15,-202,-37,-20,-12,-21,-33,-15,-27,-47,-163,-15,-24,-32,-28,-26,-152,-20,-27,-39,-36,-15,-23,-131,-15,-15,-183,-156,-17,-37,-15,-29,-25,-16,-28,-22,-146,-15,-22,-12,-12,-18,-21,-12,-21,-12,-288,-10,-165,-13,-15,-104,-12,-15,-15,-15,-15,-15,-15,-24,-15,-15,-49,-15,-15,-15,-163,-49,-94,-15,-63,-50,-15,-65,-15,-15,-293,-21,-12,-50,-12],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-37\"},{\"data\":[{\"hovertemplate\":\"Lat=-38<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.3,5.6,6.1,4.9,5.2,5.0,5.1,5.7,5.1,5.0,5.0,5.2,5.4,5.0,5.3,6.4,5.2,5.1,5.5,5.2,5.2,6.4,5.7,6.1,5.6,5.0,4.9,4.9,5.1,5.6,5.7,4.9,5.4,5.0,5.5,5.2,6.0,5.3,6.6,5.2,5.2],\"coloraxis\":\"coloraxis\",\"size\":[5.3,5.6,6.1,4.9,5.2,5.0,5.1,5.7,5.1,5.0,5.0,5.2,5.4,5.0,5.3,6.4,5.2,5.1,5.5,5.2,5.2,6.4,5.7,6.1,5.6,5.0,4.9,4.9,5.1,5.6,5.7,4.9,5.4,5.0,5.5,5.2,6.0,5.3,6.6,5.2,5.2],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[178.9,178.19,177.32,177.8,175.82,176.68,176.7,178.53,179.67,176.45,177.63,177.78,180.33,175.9,177.51,176.08,176.18,177.77,175.4,176.29,176.42,178.06,175.29,175.78,176.03,176.56,176.17,176.09,180.35,175.68,176.12,178.58,174.86,177.55,178.85,176.01,177.01,176.09,178.4,178.13,177.42],\"xaxis\":\"x\",\"y\":[-46,-15,-78,-77,-169,-93,-164,-22,-12,-150,-33,-33,-33,-175,-43,-165,-184,-31,-248,-33,-122,-15,-276,-158,-159,-100,-138,-134,-12,-159,-119,-14,-216,-25,-16,-13,-40,-68,-30,-28,-33],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-38\"},{\"data\":[{\"hovertemplate\":\"Lat=-39<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[6.2,5.1,5.0,5.2,5.3,5.4,5.1,5.1,5.8,5.1,5.0,5.5,5.5,5.4,5.7,5.5,5.7,5.1],\"coloraxis\":\"coloraxis\",\"size\":[6.2,5.1,5.0,5.2,5.3,5.4,5.1,5.1,5.8,5.1,5.0,5.5,5.5,5.4,5.7,5.5,5.7,5.1],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[174.94,177.86,175.74,180.69,175.88,175.91,178.78,175.19,174.22,178.5,175.46,177.68,175.96,176.91,176.83,176.76,176.49,174.71],\"xaxis\":\"x\",\"y\":[-226,-20,-104,-18,-96,-49,-21,-116,-216,-12,-63,-26,-30,-26,-22,-17,-21,-131],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-39\"},{\"data\":[{\"hovertemplate\":\"Lat=-40<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.2,6.3,5.4,5.1,5.4,5.4,6.4,5.2,5.0,5.3,5.4,5.0,5.8,5.6,5.2,5.1,5.4,5.2,5.4,5.0,5.6,6.3,5.6,5.6,6.3,6.0,5.9,5.3],\"coloraxis\":\"coloraxis\",\"size\":[5.2,6.3,5.4,5.1,5.4,5.4,6.4,5.2,5.0,5.3,5.4,5.0,5.8,5.6,5.2,5.1,5.4,5.2,5.4,5.0,5.6,6.3,5.6,5.6,6.3,6.0,5.9,5.3],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[176.66,173.63,176.33,179.01,173.66,175.27,176.53,173.68,175.06,176.13,176.66,176.98,174.98,174.09,176.28,173.42,176.02,176.07,175.66,174.46,176.29,175.8,174.94,176.47,176.09,177.58,174.17,175.47],\"xaxis\":\"x\",\"y\":[-21,-230,-27,-24,-153,-45,-16,-94,-48,-38,-15,-31,-26,-114,-32,-185,-25,-55,-15,-88,-30,-24,-70,-24,-32,-12,-90,-46],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-40\"},{\"data\":[{\"hovertemplate\":\"Lat=-41<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[4.9,5.1,5.4,5.2,5.3,5.2,5.2,5.2,5.3,5.4,5.1,5.1,5.5,5.3,5.0,6.5,5.9,4.9,5.4,5.3,5.7,5.9,5.5,5.6,6.1,5.7,6.6,5.9,5.2,5.6,5.5,5.1,5.4,5.4,5.3,5.2,5.5],\"coloraxis\":\"coloraxis\",\"size\":[4.9,5.1,5.4,5.2,5.3,5.2,5.2,5.2,5.3,5.4,5.1,5.1,5.5,5.3,5.0,6.5,5.9,4.9,5.4,5.3,5.7,5.9,5.5,5.6,6.1,5.7,6.6,5.9,5.2,5.6,5.5,5.1,5.4,5.4,5.3,5.2,5.5],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[175.32,178.68,175.48,173.34,175.16,173.4,174.08,176.02,174.33,175.35,176.14,175.79,174.37,172.52,174.29,174.17,173.71,174.47,174.13,174.1,174.2,174.0,174.26,174.25,174.29,171.7,174.04,174.17,174.03,173.93,175.62,174.32,174.22,173.96,171.43,173.14,172.82],\"xaxis\":\"x\",\"y\":[-29,-34,-15,-79,-31,-60,-69,-19,-15,-20,-27,-18,-17,-93,-15,-12,-75,-20,-17,-17,-13,-15,-18,-19,-26,-15,-12,-17,-19,-12,-15,-28,-25,-21,-15,-52,-64],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-41\"},{\"data\":[{\"hovertemplate\":\"Lat=-42<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[6.1,5.8,7.8,5.2,5.7,4.9,4.9,5.1,5.7,5.2,5.0,5.7,5.1,5.2,6.0,5.3,5.0,6.4,5.0,5.1,5.0,5.2,4.9,5.5,6.1,6.7,5.6],\"coloraxis\":\"coloraxis\",\"size\":[6.1,5.8,7.8,5.2,5.7,4.9,4.9,5.1,5.7,5.2,5.0,5.7,5.1,5.2,6.0,5.3,5.0,6.4,5.0,5.1,5.0,5.2,4.9,5.5,6.1,6.7,5.6],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[173.07,171.86,173.85,173.81,172.74,177.92,173.75,173.95,173.86,172.98,173.69,173.74,173.43,173.62,172.78,172.9,173.73,173.07,171.54,173.89,172.67,172.97,173.95,172.85,171.76,171.47,171.18],\"xaxis\":\"x\",\"y\":[-48,-15,-19,-19,-15,-28,-26,-22,-12,-12,-16,-19,-19,-21,-15,-31,-19,-12,-59,-20,-12,-12,-22,-12,-15,-15,-12],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-42\"},{\"data\":[{\"hovertemplate\":\"Lat=-43<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.5,4.9,5.9,5.2,5.4,5.6,5.7,5.1,5.2,5.5,5.6,6.0,5.1,5.2,5.8,7.0,4.8,5.0,4.8,5.0,4.9,6.1,4.9,5.2,5.4,4.9,5.7,4.9,5.4,5.4,5.2,5.0,6.1],\"coloraxis\":\"coloraxis\",\"size\":[5.5,4.9,5.9,5.2,5.4,5.6,5.7,5.1,5.2,5.5,5.6,6.0,5.1,5.2,5.8,7.0,4.8,5.0,4.8,5.0,4.9,6.1,4.9,5.2,5.4,4.9,5.7,4.9,5.4,5.4,5.2,5.0,6.1],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[171.61,173.04,171.54,171.48,171.81,171.8,172.54,172.31,172.62,172.56,172.55,172.62,172.78,172.69,172.58,172.12,172.28,172.31,172.7,172.73,171.91,172.52,172.74,172.44,172.69,172.85,172.56,172.68,169.62,168.81,169.23,168.75,170.66],\"xaxis\":\"x\",\"y\":[-15,-12,-15,-10,-15,-15,-12,-12,-12,-12,-12,-12,-17,-12,-12,-12,-12,-14,-12,-12,-12,-12,-12,-12,-12,-13,-12,-16,-15,-12,-15,-12,-10],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-43\"},{\"data\":[{\"hovertemplate\":\"Lat=-44<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.4,5.8,5.3,5.6,4.8,4.9,5.5,5.6,5.0,4.9,5.6,5.1,5.0,6.1,6.8,5.2,6.6,6.7,5.0,5.6,5.0,5.3],\"coloraxis\":\"coloraxis\",\"size\":[5.4,5.8,5.3,5.6,4.8,4.9,5.5,5.6,5.0,4.9,5.6,5.1,5.0,6.1,6.8,5.2,6.6,6.7,5.0,5.6,5.0,5.3],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[168.42,168.55,167.91,166.93,167.66,169.97,167.71,168.73,167.51,167.38,167.39,167.34,167.21,167.25,167.24,166.15,167.63,167.05,167.54,167.0,166.59,167.32],\"xaxis\":\"x\",\"y\":[-15,-15,-15,-15,-21,-12,-15,-14,-24,-24,-17,-18,-27,-19,-19,-15,-15,-62,-86,-14,-40,-116],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-44\"},{\"data\":[{\"hovertemplate\":\"Lat=-45<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.4,7.2,6.1,7.0,6.4,5.5,5.2,5.5,5.2,6.5,4.9,5.2,5.5,5.2,5.4,5.1,5.2,5.3,5.1,5.5,5.1,6.1,5.2,5.0,5.6,7.8,5.2,5.0],\"coloraxis\":\"coloraxis\",\"size\":[5.4,7.2,6.1,7.0,6.4,5.5,5.2,5.5,5.2,6.5,4.9,5.2,5.5,5.2,5.4,5.1,5.2,5.3,5.1,5.5,5.1,6.1,5.2,5.0,5.6,7.8,5.2,5.0],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[167.23,166.87,166.7,166.73,166.6,166.52,166.62,166.68,166.68,166.59,166.44,166.44,167.64,166.61,166.46,166.36,165.97,166.07,166.75,166.02,166.42,166.13,166.72,166.12,166.73,166.26,165.82,165.76],\"xaxis\":\"x\",\"y\":[-15,-32,-20,-15,-15,-49,-12,-27,-101,-18,-23,-24,-122,-15,-18,-17,-14,-12,-93,-12,-22,-12,-112,-31,-15,-23,-25,-21],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-45\"},{\"data\":[{\"hovertemplate\":\"Lat=-46<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.0,5.7,5.1,5.6,5.8,5.8,5.4,5.0,7.1,6.2,7.3,6.0,5.2,5.4,5.0,5.0,5.2],\"coloraxis\":\"coloraxis\",\"size\":[5.0,5.7,5.1,5.6,5.8,5.8,5.4,5.0,7.1,6.2,7.3,6.0,5.2,5.4,5.0,5.0,5.2],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[165.72,165.82,165.84,166.09,165.74,165.85,165.75,165.67,164.91,164.64,165.77,165.38,165.22,165.27,165.32,165.04,165.69],\"xaxis\":\"x\",\"y\":[-13,-20,-26,-15,-23,-18,-21,-29,-40,-10,-20,-19,-23,-18,-33,-32,-41],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-46\"},{\"data\":[{\"hovertemplate\":\"Lat=-47<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.0,5.0,5.2,5.9,4.9,5.5,5.5,4.9,5.2,5.8,4.9,5.1,5.0,5.6],\"coloraxis\":\"coloraxis\",\"size\":[5.0,5.0,5.2,5.9,4.9,5.5,5.5,4.9,5.2,5.8,4.9,5.1,5.0,5.6],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[165.43,165.04,165.96,165.14,165.43,164.59,164.62,165.1,165.11,165.08,165.26,164.74,164.42,164.53],\"xaxis\":\"x\",\"y\":[-22,-29,-33,-15,-18,-15,-15,-12,-13,-12,-19,-17,-21,-15],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-47\"},{\"data\":[{\"hovertemplate\":\"Lat=-48<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.2,5.7,5.1,5.6,5.3,5.3,5.1,5.3,5.4,5.5,7.6,4.9,5.0],\"coloraxis\":\"coloraxis\",\"size\":[5.2,5.7,5.1,5.6,5.3,5.3,5.1,5.3,5.4,5.5,7.6,4.9,5.0],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[165.5,163.65,164.19,164.51,164.51,164.56,164.24,164.2,163.86,164.15,164.39,164.13,163.89],\"xaxis\":\"x\",\"y\":[-15,-15,-14,-22,-21,-30,-18,-12,-15,-15,-33,-21,-14],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-48\"},{\"data\":[{\"hovertemplate\":\"Lat=-49<br>Longitude=%{x}<br>Depth(km)=%{y}<br>Mag=%{marker.color}<extra></extra>\",\"legendgroup\":\"\",\"marker\":{\"color\":[5.7,5.0,6.0,4.9,5.4,5.1,5.9,5.6,5.4,5.2,5.2,6.1,5.7,5.1,5.3,6.6,7.5,6.6,5.5,6.0,4.8,5.1,5.7,5.7,5.7,5.4,5.4,5.2,5.3,5.4,5.0,4.9,5.1,5.1,5.2,5.4,5.4,5.0,8.1,6.2,6.0],\"coloraxis\":\"coloraxis\",\"size\":[5.7,5.0,6.0,4.9,5.4,5.1,5.9,5.6,5.4,5.2,5.2,6.1,5.7,5.1,5.3,6.6,7.5,6.6,5.5,6.0,4.8,5.1,5.7,5.7,5.7,5.4,5.4,5.2,5.3,5.4,5.0,4.9,5.1,5.1,5.2,5.4,5.4,5.0,8.1,6.2,6.0],\"sizemode\":\"area\",\"sizeref\":0.081,\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"orientation\":\"v\",\"showlegend\":false,\"x\":[164.11,164.26,164.03,161.07,163.89,164.32,164.03,164.01,164.33,164.24,163.98,164.19,164.14,164.38,164.27,163.99,164.1,164.01,162.99,163.79,175.17,163.47,163.8,163.71,163.88,163.35,160.85,163.5,163.47,162.91,163.47,163.26,163.48,163.33,163.07,163.35,163.92,163.47,161.25,163.25,163.2],\"xaxis\":\"x\",\"y\":[-15,-33,-18,-14,-12,-38,-12,-15,-24,-39,-15,-26,-34,-42,-35,-32,-13,-31,-15,-15,-20,-12,-15,-25,-23,-15,-12,-12,-19,-15,-21,-25,-12,-22,-15,-14,-15,-21,-27,-12,-19],\"yaxis\":\"y\",\"type\":\"scatter\"}],\"name\":\"-49\"}]);\n", "                        }).then(function(){\n", "                            \n", "var gd = document.getElementById('11fd5704-6738-40de-8a60-a1d5d9b0537d');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["import plotly.express as px\n", "df = pd.read_excel('data/meca_all.xlsx')\n", "px.scatter(df, x=\"Longitude\", y=\"Depth(km)\", animation_frame=\"Lat\", \n", "           size=\"Mag\", color=\"Mag\", size_max=10, range_x=[160,184], range_y=[-600,0])\n"]}], "metadata": {"celltoolbar": "Tags", "kernelspec": {"display_name": "Python 3", "language": "python", "name": "python3"}, "language_info": {"codemirror_mode": {"name": "ipython", "version": 3}, "file_extension": ".py", "mimetype": "text/x-python", "name": "python", "nbconvert_exporter": "python", "pygments_lexer": "ipython3", "version": "3.8.8"}}, "nbformat": 4, "nbformat_minor": 4}